""" Cisco_IOS_XR_ipv4_pim_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ipv4\-pim package operational data.

This module contains definitions
for the following management objects\:
  pim\-ma\: PIM MA operational data
  pim\: pim
  ipv6\-pim\: ipv6 pim
  pim6\-ma\: pim6 ma

Copyright (c) 2013\-2016 by Cisco Systems, Inc.
All rights reserved.

"""


import re
import collections

from enum import Enum

from ydk.types import Empty, YList, YLeafList, DELETE, Decimal64, FixedBitsDict

from ydk.errors import YPYError, YPYModelError



class PimAfiEnum(Enum):
    """
    PimAfiEnum

    Address family

    .. data:: ipv4_unicast = 0

    	IP v4 unicast

    .. data:: ipv6_unicast = 1

    	IP v6 unicast

    """

    ipv4_unicast = 0

    ipv6_unicast = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
        return meta._meta_table['PimAfiEnum']


class PimClientEnum(Enum):
    """
    PimClientEnum

    Pim client

    .. data:: none = 0

    	No Client

    .. data:: configured_embedded_rp = 1

    	Embedded RP from configuration

    .. data:: embedded = 2

    	Embedded RP learnt from the Group addr

    .. data:: permanent = 3

    	Permanent

    .. data:: auto_rp = 4

    	AutoRP

    .. data:: bsr = 5

    	BSR

    .. data:: configured = 6

    	Configured

    .. data:: static = 7

    	Static

    """

    none = 0

    configured_embedded_rp = 1

    embedded = 2

    permanent = 3

    auto_rp = 4

    bsr = 5

    configured = 6

    static = 7


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
        return meta._meta_table['PimClientEnum']


class PimInterfaceEnum(Enum):
    """
    PimInterfaceEnum

    Interface Type

    .. data:: encap_interface = 0

    	Encap Interface

    .. data:: decap_interface = 1

    	Decap Interface

    .. data:: mdt_interface = 2

    	MDT Interface

    """

    encap_interface = 0

    decap_interface = 1

    mdt_interface = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
        return meta._meta_table['PimInterfaceEnum']


class PimProtocolEnum(Enum):
    """
    PimProtocolEnum

    Pim protocol

    .. data:: non_routable = 0

    	Non Routable

    .. data:: sparse_mode = 1

    	Sparse Mode

    .. data:: dense_mode = 2

    	Dense Mode

    .. data:: bidir = 3

    	Bidirectional Mode

    .. data:: ssm = 4

    	Source Specific Multicast Mode

    .. data:: maximum = 5

    	Maximum

    .. data:: any = 6

    	Any

    """

    non_routable = 0

    sparse_mode = 1

    dense_mode = 2

    bidir = 3

    ssm = 4

    maximum = 5

    any = 6


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
        return meta._meta_table['PimProtocolEnum']


class PimSafiEnum(Enum):
    """
    PimSafiEnum

    Pim safi

    .. data:: unicast = 1

    	SAFI unicast

    .. data:: multicast = 2

    	SAFI Multicast

    .. data:: all = 3

    	SAFI all

    .. data:: default = 4

    	SAFI default

    """

    unicast = 1

    multicast = 2

    all = 3

    default = 4


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
        return meta._meta_table['PimSafiEnum']


class PimShowProtocolEnum(Enum):
    """
    PimShowProtocolEnum

    Pim show protocol

    .. data:: no_route = 0

    	no route

    .. data:: sm = 1

    	sm

    .. data:: dm = 2

    	dm

    .. data:: bidir = 3

    	bidir

    .. data:: ssm = 4

    	ssm

    .. data:: maximum = 5

    	maximum

    .. data:: any = 6

    	any

    """

    no_route = 0

    sm = 1

    dm = 2

    bidir = 3

    ssm = 4

    maximum = 5

    any = 6


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
        return meta._meta_table['PimShowProtocolEnum']


class PimShowRangeClientEnum(Enum):
    """
    PimShowRangeClientEnum

    Pim show range client

    .. data:: no_client = 0

    	no client

    .. data:: embedded_config = 1

    	embedded config

    .. data:: embedded = 2

    	embedded

    .. data:: permanent = 3

    	permanent

    .. data:: auto_rp = 4

    	auto rp

    .. data:: bsr = 5

    	bsr

    .. data:: config = 6

    	config

    .. data:: static = 7

    	static

    """

    no_client = 0

    embedded_config = 1

    embedded = 2

    permanent = 3

    auto_rp = 4

    bsr = 5

    config = 6

    static = 7


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
        return meta._meta_table['PimShowRangeClientEnum']


class PimTopologyEntryFlagEnum(Enum):
    """
    PimTopologyEntryFlagEnum

    Pim topology entry flag

    .. data:: kat = 0

    	KAT

    .. data:: aa = 1

    	AA

    .. data:: pa = 2

    	PA

    .. data:: ra = 3

    	RA

    .. data:: ia = 4

    	IA

    .. data:: rr = 5

    	RR

    .. data:: lh = 6

    	LH

    .. data:: dss = 7

    	DSS

    .. data:: dcc = 8

    	DCC

    .. data:: sr = 9

    	SR

    .. data:: e = 10

    	E

    .. data:: ex = 11

    	EX

    .. data:: ma = 12

    	MA

    .. data:: mt = 13

    	MT

    .. data:: mfa = 14

    	MFA

    .. data:: mfp = 15

    	MFP

    .. data:: mfb = 16

    	MFB

    """

    kat = 0

    aa = 1

    pa = 2

    ra = 3

    ia = 4

    rr = 5

    lh = 6

    dss = 7

    dcc = 8

    sr = 9

    e = 10

    ex = 11

    ma = 12

    mt = 13

    mfa = 14

    mfp = 15

    mfb = 16


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
        return meta._meta_table['PimTopologyEntryFlagEnum']


class PimTopologyInterfaceFlagEnum(Enum):
    """
    PimTopologyInterfaceFlagEnum

    Pim topology interface flag

    .. data:: lh = 0

    	LH

    .. data:: ld = 1

    	LD

    .. data:: li = 2

    	LI

    .. data:: ii = 3

    	II

    .. data:: id = 4

    	ID

    .. data:: as_ = 5

    	AS

    .. data:: ab = 6

    	AB

    .. data:: ex = 7

    	EX

    """

    lh = 0

    ld = 1

    li = 2

    ii = 3

    id = 4

    as_ = 5

    ab = 6

    ex = 7


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
        return meta._meta_table['PimTopologyInterfaceFlagEnum']



class PimMa(object):
    """
    PIM MA operational data
    
    .. attribute:: active
    
    	Active Process
    	**type**\:   :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active>`
    
    .. attribute:: standby
    
    	Standby Process
    	**type**\:   :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby>`
    
    

    """

    _prefix = 'ipv4-pim-oper'
    _revision = '2015-11-09'

    def __init__(self):
        self.active = PimMa.Active()
        self.active.parent = self
        self.standby = PimMa.Standby()
        self.standby.parent = self


    class Active(object):
        """
        Active Process
        
        .. attribute:: interface_table
        
        	Interface Table
        	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable>`
        
        .. attribute:: pim_ma_summary
        
        	PIM MA summary
        	**type**\:   :py:class:`PimMaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.PimMaSummary>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.interface_table = PimMa.Active.InterfaceTable()
            self.interface_table.parent = self
            self.pim_ma_summary = PimMa.Active.PimMaSummary()
            self.pim_ma_summary.parent = self


        class InterfaceTable(object):
            """
            Interface Table
            
            .. attribute:: interface_by_handles
            
            	Table of PIM MA interfaces indexed by handle
            	**type**\:   :py:class:`InterfaceByHandles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByHandles>`
            
            .. attribute:: interface_by_names
            
            	Table of PIM MA interfaces indexed by name
            	**type**\:   :py:class:`InterfaceByNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByNames>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.interface_by_handles = PimMa.Active.InterfaceTable.InterfaceByHandles()
                self.interface_by_handles.parent = self
                self.interface_by_names = PimMa.Active.InterfaceTable.InterfaceByNames()
                self.interface_by_names.parent = self


            class InterfaceByHandles(object):
                """
                Table of PIM MA interfaces indexed by handle
                
                .. attribute:: interface_by_handle
                
                	PIM MA interface referenced by handle
                	**type**\: list of    :py:class:`InterfaceByHandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_by_handle = YList()
                    self.interface_by_handle.parent = self
                    self.interface_by_handle.name = 'interface_by_handle'


                class InterfaceByHandle(object):
                    """
                    PIM MA interface referenced by handle
                    
                    .. attribute:: interface_handle  <key>
                    
                    	Interface handle
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterfaceEnum>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_handle = None
                        self.interface_name_xr = None
                        self.interface_type = None
                        self.rp_address = PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress()
                        self.rp_address.parent = self
                        self.source_address = PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress()
                        self.source_address.parent = self
                        self.vrf_name = None


                    class RpAddress(object):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress']['meta_info']


                    class SourceAddress(object):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_handle is None:
                            raise YPYModelError('Key property interface_handle is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim-ma/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:interface-table/Cisco-IOS-XR-ipv4-pim-oper:interface-by-handles/Cisco-IOS-XR-ipv4-pim-oper:interface-by-handle[Cisco-IOS-XR-ipv4-pim-oper:interface-handle = ' + str(self.interface_handle) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_handle is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.interface_type is not None:
                            return True

                        if self.rp_address is not None and self.rp_address._has_data():
                            return True

                        if self.source_address is not None and self.source_address._has_data():
                            return True

                        if self.vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim-ma/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:interface-table/Cisco-IOS-XR-ipv4-pim-oper:interface-by-handles'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_by_handle is not None:
                        for child_ref in self.interface_by_handle:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['PimMa.Active.InterfaceTable.InterfaceByHandles']['meta_info']


            class InterfaceByNames(object):
                """
                Table of PIM MA interfaces indexed by name
                
                .. attribute:: interface_by_name
                
                	PIM MA interface referenced by name
                	**type**\: list of    :py:class:`InterfaceByName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_by_name = YList()
                    self.interface_by_name.parent = self
                    self.interface_by_name.name = 'interface_by_name'


                class InterfaceByName(object):
                    """
                    PIM MA interface referenced by name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterfaceEnum>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.interface_type = None
                        self.rp_address = PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress()
                        self.rp_address.parent = self
                        self.source_address = PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress()
                        self.source_address.parent = self
                        self.vrf_name = None


                    class RpAddress(object):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress']['meta_info']


                    class SourceAddress(object):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim-ma/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:interface-table/Cisco-IOS-XR-ipv4-pim-oper:interface-by-names/Cisco-IOS-XR-ipv4-pim-oper:interface-by-name[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.interface_type is not None:
                            return True

                        if self.rp_address is not None and self.rp_address._has_data():
                            return True

                        if self.source_address is not None and self.source_address._has_data():
                            return True

                        if self.vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim-ma/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:interface-table/Cisco-IOS-XR-ipv4-pim-oper:interface-by-names'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_by_name is not None:
                        for child_ref in self.interface_by_name:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['PimMa.Active.InterfaceTable.InterfaceByNames']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-ipv4-pim-oper:pim-ma/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:interface-table'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.interface_by_handles is not None and self.interface_by_handles._has_data():
                    return True

                if self.interface_by_names is not None and self.interface_by_names._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                return meta._meta_table['PimMa.Active.InterfaceTable']['meta_info']


        class PimMaSummary(object):
            """
            PIM MA summary
            
            .. attribute:: decap_interface_count
            
            	Decap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: encap_interface_count
            
            	Encap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: is_edm_connection_open
            
            	EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_im_connection_open
            
            	IM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_netio_connection_open
            
            	Netio Connection Open
            	**type**\:  bool
            
            .. attribute:: is_standby_edm_connection_open
            
            	Standby EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: mdt_interface_count
            
            	MDT Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.decap_interface_count = None
                self.encap_interface_count = None
                self.is_edm_connection_open = None
                self.is_im_connection_open = None
                self.is_netio_connection_open = None
                self.is_standby_edm_connection_open = None
                self.mdt_interface_count = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-ipv4-pim-oper:pim-ma/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:pim-ma-summary'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.decap_interface_count is not None:
                    return True

                if self.encap_interface_count is not None:
                    return True

                if self.is_edm_connection_open is not None:
                    return True

                if self.is_im_connection_open is not None:
                    return True

                if self.is_netio_connection_open is not None:
                    return True

                if self.is_standby_edm_connection_open is not None:
                    return True

                if self.mdt_interface_count is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                return meta._meta_table['PimMa.Active.PimMaSummary']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-ipv4-pim-oper:pim-ma/Cisco-IOS-XR-ipv4-pim-oper:active'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.interface_table is not None and self.interface_table._has_data():
                return True

            if self.pim_ma_summary is not None and self.pim_ma_summary._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
            return meta._meta_table['PimMa.Active']['meta_info']


    class Standby(object):
        """
        Standby Process
        
        .. attribute:: interface_table
        
        	Interface Table
        	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable>`
        
        .. attribute:: pim_ma_summary
        
        	PIM MA summary
        	**type**\:   :py:class:`PimMaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.PimMaSummary>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.interface_table = PimMa.Standby.InterfaceTable()
            self.interface_table.parent = self
            self.pim_ma_summary = PimMa.Standby.PimMaSummary()
            self.pim_ma_summary.parent = self


        class InterfaceTable(object):
            """
            Interface Table
            
            .. attribute:: interface_by_handles
            
            	Table of PIM MA interfaces indexed by handle
            	**type**\:   :py:class:`InterfaceByHandles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByHandles>`
            
            .. attribute:: interface_by_names
            
            	Table of PIM MA interfaces indexed by name
            	**type**\:   :py:class:`InterfaceByNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByNames>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.interface_by_handles = PimMa.Standby.InterfaceTable.InterfaceByHandles()
                self.interface_by_handles.parent = self
                self.interface_by_names = PimMa.Standby.InterfaceTable.InterfaceByNames()
                self.interface_by_names.parent = self


            class InterfaceByHandles(object):
                """
                Table of PIM MA interfaces indexed by handle
                
                .. attribute:: interface_by_handle
                
                	PIM MA interface referenced by handle
                	**type**\: list of    :py:class:`InterfaceByHandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_by_handle = YList()
                    self.interface_by_handle.parent = self
                    self.interface_by_handle.name = 'interface_by_handle'


                class InterfaceByHandle(object):
                    """
                    PIM MA interface referenced by handle
                    
                    .. attribute:: interface_handle  <key>
                    
                    	Interface handle
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterfaceEnum>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_handle = None
                        self.interface_name_xr = None
                        self.interface_type = None
                        self.rp_address = PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress()
                        self.rp_address.parent = self
                        self.source_address = PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress()
                        self.source_address.parent = self
                        self.vrf_name = None


                    class RpAddress(object):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress']['meta_info']


                    class SourceAddress(object):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_handle is None:
                            raise YPYModelError('Key property interface_handle is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim-ma/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:interface-table/Cisco-IOS-XR-ipv4-pim-oper:interface-by-handles/Cisco-IOS-XR-ipv4-pim-oper:interface-by-handle[Cisco-IOS-XR-ipv4-pim-oper:interface-handle = ' + str(self.interface_handle) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_handle is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.interface_type is not None:
                            return True

                        if self.rp_address is not None and self.rp_address._has_data():
                            return True

                        if self.source_address is not None and self.source_address._has_data():
                            return True

                        if self.vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim-ma/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:interface-table/Cisco-IOS-XR-ipv4-pim-oper:interface-by-handles'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_by_handle is not None:
                        for child_ref in self.interface_by_handle:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['PimMa.Standby.InterfaceTable.InterfaceByHandles']['meta_info']


            class InterfaceByNames(object):
                """
                Table of PIM MA interfaces indexed by name
                
                .. attribute:: interface_by_name
                
                	PIM MA interface referenced by name
                	**type**\: list of    :py:class:`InterfaceByName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_by_name = YList()
                    self.interface_by_name.parent = self
                    self.interface_by_name.name = 'interface_by_name'


                class InterfaceByName(object):
                    """
                    PIM MA interface referenced by name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterfaceEnum>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.interface_type = None
                        self.rp_address = PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress()
                        self.rp_address.parent = self
                        self.source_address = PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress()
                        self.source_address.parent = self
                        self.vrf_name = None


                    class RpAddress(object):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress']['meta_info']


                    class SourceAddress(object):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim-ma/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:interface-table/Cisco-IOS-XR-ipv4-pim-oper:interface-by-names/Cisco-IOS-XR-ipv4-pim-oper:interface-by-name[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.interface_type is not None:
                            return True

                        if self.rp_address is not None and self.rp_address._has_data():
                            return True

                        if self.source_address is not None and self.source_address._has_data():
                            return True

                        if self.vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim-ma/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:interface-table/Cisco-IOS-XR-ipv4-pim-oper:interface-by-names'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_by_name is not None:
                        for child_ref in self.interface_by_name:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['PimMa.Standby.InterfaceTable.InterfaceByNames']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-ipv4-pim-oper:pim-ma/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:interface-table'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.interface_by_handles is not None and self.interface_by_handles._has_data():
                    return True

                if self.interface_by_names is not None and self.interface_by_names._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                return meta._meta_table['PimMa.Standby.InterfaceTable']['meta_info']


        class PimMaSummary(object):
            """
            PIM MA summary
            
            .. attribute:: decap_interface_count
            
            	Decap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: encap_interface_count
            
            	Encap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: is_edm_connection_open
            
            	EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_im_connection_open
            
            	IM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_netio_connection_open
            
            	Netio Connection Open
            	**type**\:  bool
            
            .. attribute:: is_standby_edm_connection_open
            
            	Standby EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: mdt_interface_count
            
            	MDT Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.decap_interface_count = None
                self.encap_interface_count = None
                self.is_edm_connection_open = None
                self.is_im_connection_open = None
                self.is_netio_connection_open = None
                self.is_standby_edm_connection_open = None
                self.mdt_interface_count = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-ipv4-pim-oper:pim-ma/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:pim-ma-summary'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.decap_interface_count is not None:
                    return True

                if self.encap_interface_count is not None:
                    return True

                if self.is_edm_connection_open is not None:
                    return True

                if self.is_im_connection_open is not None:
                    return True

                if self.is_netio_connection_open is not None:
                    return True

                if self.is_standby_edm_connection_open is not None:
                    return True

                if self.mdt_interface_count is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                return meta._meta_table['PimMa.Standby.PimMaSummary']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-ipv4-pim-oper:pim-ma/Cisco-IOS-XR-ipv4-pim-oper:standby'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.interface_table is not None and self.interface_table._has_data():
                return True

            if self.pim_ma_summary is not None and self.pim_ma_summary._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
            return meta._meta_table['PimMa.Standby']['meta_info']

    @property
    def _common_path(self):

        return '/Cisco-IOS-XR-ipv4-pim-oper:pim-ma'

    def is_config(self):
        ''' Returns True if this instance represents config data else returns False '''
        return False

    def _has_data(self):
        if not self.is_config():
            return False
        if self.active is not None and self.active._has_data():
            return True

        if self.standby is not None and self.standby._has_data():
            return True

        return False

    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
        return meta._meta_table['PimMa']['meta_info']


class Pim(object):
    """
    pim
    
    .. attribute:: active
    
    	Active Process
    	**type**\:   :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active>`
    
    .. attribute:: standby
    
    	Standby Process
    	**type**\:   :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby>`
    
    

    """

    _prefix = 'ipv4-pim-oper'
    _revision = '2015-11-09'

    def __init__(self):
        self.active = Pim.Active()
        self.active.parent = self
        self.standby = Pim.Standby()
        self.standby.parent = self


    class Standby(object):
        """
        Standby Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:   :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:   :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.default_context = Pim.Standby.DefaultContext()
            self.default_context.parent = self
            self.process = Pim.Standby.Process()
            self.process.parent = self
            self.vrfs = Pim.Standby.Vrfs()
            self.vrfs.parent = self


        class DefaultContext(object):
            """
            Default Context
            
            .. attribute:: auto_rp
            
            	PIM Auto\-RP information
            	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.AutoRp>`
            
            .. attribute:: bgp_afs
            
            	PIM BGP SAFI table
            	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BgpAfs>`
            
            .. attribute:: bidir_df_states
            
            	Bidirectional PIM DF election state table
            	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfStates>`
            
            .. attribute:: bidir_df_winners
            
            	Bidirectional PIM DF election winner table
            	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfWinners>`
            
            .. attribute:: bsr
            
            	PIM BSR information
            	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr>`
            
            .. attribute:: context
            
            	PIM context information
            	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context>`
            
            .. attribute:: global_interfaces
            
            	PIM global interface table
            	**type**\:   :py:class:`GlobalInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GlobalInterfaces>`
            
            .. attribute:: gre
            
            	GRE information
            	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre>`
            
            .. attribute:: group_map_match_rpfs
            
            	Find matching group\-mapping for the specified group address
            	**type**\:   :py:class:`GroupMapMatchRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchRpfs>`
            
            .. attribute:: group_map_match_sources
            
            	Find the matching group\-mapping with source information on specified group address
            	**type**\:   :py:class:`GroupMapMatchSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchSources>`
            
            .. attribute:: group_map_rpfs
            
            	PIM group mapping information
            	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs>`
            
            .. attribute:: group_map_sources
            
            	PIM group\-mapping with source information
            	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources>`
            
            .. attribute:: ifrs_interfaces
            
            	PIM interfaces in forward reference store table
            	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: ifrs_summary
            
            	PIM interfaces in forward reference store summary
            	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.IfrsSummary>`
            
            .. attribute:: interface_old_formats
            
            	PIM interfaces in old format
            	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceOldFormats>`
            
            .. attribute:: interface_statistics
            
            	PIM interface statistics
            	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceStatistics>`
            
            .. attribute:: interfaces
            
            	PIM interfaces
            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Interfaces>`
            
            .. attribute:: jp_statistics
            
            	PIM join prune statistics table
            	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.JpStatistics>`
            
            .. attribute:: mib_databases
            
            	PIM group database for mroute mibs table
            	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases>`
            
            .. attribute:: multicast_static_routes
            
            	PIM multicast static route table
            	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MulticastStaticRoutes>`
            
            .. attribute:: neighbor_old_formats
            
            	PIM neighbor table old format
            	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NeighborOldFormats>`
            
            .. attribute:: neighbor_summaries
            
            	PIM neighbor summary table
            	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NeighborSummaries>`
            
            .. attribute:: neighbors
            
            	PIM neighbor table
            	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Neighbors>`
            
            .. attribute:: net_io_tunnels
            
            	Tunnel information that NETIO has 
            	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels>`
            
            .. attribute:: ranges
            
            	PIM range list information
            	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges>`
            
            .. attribute:: route_policy
            
            	PIM route policy
            	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy>`
            
            .. attribute:: rpf_redirect
            
            	PIM ECMP RPF\-redirect bundle
            	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect>`
            
            .. attribute:: rpf_summary
            
            	PIM RPF registration summary
            	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfSummary>`
            
            .. attribute:: safs
            
            	SAFI table and type
            	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs>`
            
            .. attribute:: summary
            
            	PIM summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Summary>`
            
            .. attribute:: table_contexts
            
            	PIM table context list
            	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TableContexts>`
            
            .. attribute:: topologies
            
            	PIM topology table
            	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies>`
            
            .. attribute:: topology_entry_flag_route_counts
            
            	Route count for topology with entry flag set
            	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts>`
            
            .. attribute:: topology_interface_flag_route_counts
            
            	Route count for topology with interface flag set
            	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts>`
            
            .. attribute:: topology_route_count
            
            	Topology route count information from PIM topology table
            	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyRouteCount>`
            
            .. attribute:: traffic_counters
            
            	PIM message traffic counters
            	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TrafficCounters>`
            
            .. attribute:: tunnels
            
            	Tunnels information that PIM has
            	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.auto_rp = Pim.Standby.DefaultContext.AutoRp()
                self.auto_rp.parent = self
                self.bgp_afs = Pim.Standby.DefaultContext.BgpAfs()
                self.bgp_afs.parent = self
                self.bidir_df_states = Pim.Standby.DefaultContext.BidirDfStates()
                self.bidir_df_states.parent = self
                self.bidir_df_winners = Pim.Standby.DefaultContext.BidirDfWinners()
                self.bidir_df_winners.parent = self
                self.bsr = Pim.Standby.DefaultContext.Bsr()
                self.bsr.parent = self
                self.context = Pim.Standby.DefaultContext.Context()
                self.context.parent = self
                self.global_interfaces = Pim.Standby.DefaultContext.GlobalInterfaces()
                self.global_interfaces.parent = self
                self.gre = Pim.Standby.DefaultContext.Gre()
                self.gre.parent = self
                self.group_map_match_rpfs = Pim.Standby.DefaultContext.GroupMapMatchRpfs()
                self.group_map_match_rpfs.parent = self
                self.group_map_match_sources = Pim.Standby.DefaultContext.GroupMapMatchSources()
                self.group_map_match_sources.parent = self
                self.group_map_rpfs = Pim.Standby.DefaultContext.GroupMapRpfs()
                self.group_map_rpfs.parent = self
                self.group_map_sources = Pim.Standby.DefaultContext.GroupMapSources()
                self.group_map_sources.parent = self
                self.ifrs_interfaces = Pim.Standby.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self.ifrs_summary = Pim.Standby.DefaultContext.IfrsSummary()
                self.ifrs_summary.parent = self
                self.interface_old_formats = Pim.Standby.DefaultContext.InterfaceOldFormats()
                self.interface_old_formats.parent = self
                self.interface_statistics = Pim.Standby.DefaultContext.InterfaceStatistics()
                self.interface_statistics.parent = self
                self.interfaces = Pim.Standby.DefaultContext.Interfaces()
                self.interfaces.parent = self
                self.jp_statistics = Pim.Standby.DefaultContext.JpStatistics()
                self.jp_statistics.parent = self
                self.mib_databases = Pim.Standby.DefaultContext.MibDatabases()
                self.mib_databases.parent = self
                self.multicast_static_routes = Pim.Standby.DefaultContext.MulticastStaticRoutes()
                self.multicast_static_routes.parent = self
                self.neighbor_old_formats = Pim.Standby.DefaultContext.NeighborOldFormats()
                self.neighbor_old_formats.parent = self
                self.neighbor_summaries = Pim.Standby.DefaultContext.NeighborSummaries()
                self.neighbor_summaries.parent = self
                self.neighbors = Pim.Standby.DefaultContext.Neighbors()
                self.neighbors.parent = self
                self.net_io_tunnels = Pim.Standby.DefaultContext.NetIoTunnels()
                self.net_io_tunnels.parent = self
                self.ranges = Pim.Standby.DefaultContext.Ranges()
                self.ranges.parent = self
                self.route_policy = Pim.Standby.DefaultContext.RoutePolicy()
                self.route_policy.parent = self
                self.rpf_redirect = Pim.Standby.DefaultContext.RpfRedirect()
                self.rpf_redirect.parent = self
                self.rpf_summary = Pim.Standby.DefaultContext.RpfSummary()
                self.rpf_summary.parent = self
                self.safs = Pim.Standby.DefaultContext.Safs()
                self.safs.parent = self
                self.summary = Pim.Standby.DefaultContext.Summary()
                self.summary.parent = self
                self.table_contexts = Pim.Standby.DefaultContext.TableContexts()
                self.table_contexts.parent = self
                self.topologies = Pim.Standby.DefaultContext.Topologies()
                self.topologies.parent = self
                self.topology_entry_flag_route_counts = Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts()
                self.topology_entry_flag_route_counts.parent = self
                self.topology_interface_flag_route_counts = Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts()
                self.topology_interface_flag_route_counts.parent = self
                self.topology_route_count = Pim.Standby.DefaultContext.TopologyRouteCount()
                self.topology_route_count.parent = self
                self.traffic_counters = Pim.Standby.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self.tunnels = Pim.Standby.DefaultContext.Tunnels()
                self.tunnels.parent = self


            class GlobalInterfaces(object):
                """
                PIM global interface table
                
                .. attribute:: global_interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`GlobalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.global_interface = YList()
                    self.global_interface.parent = self
                    self.global_interface.name = 'global_interface'


                class GlobalInterface(object):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.configured_override_interval = None
                        self.configured_propagation_delay = None
                        self.dr_address = Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress()
                        self.dr_address.parent = self
                        self.dr_priority = None
                        self.external_neighbor_count = None
                        self.generation_id = None
                        self.hello_expiry = None
                        self.hello_interval = None
                        self.idb_acl_name = None
                        self.idb_acl_provided = None
                        self.idb_current_count = None
                        self.idb_max_count = None
                        self.idb_oor_enabled = None
                        self.idb_threshold_count = None
                        self.interface_address = YList()
                        self.interface_address.parent = self
                        self.interface_address.name = 'interface_address'
                        self.interface_address_mask = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bidirectional_capable = None
                        self.is_enabled = None
                        self.is_proxy_capable = None
                        self.join_prune_interval = None
                        self.neighbor_count = None
                        self.neighbor_filter_name = None
                        self.override_interval = None
                        self.passive_interface = None
                        self.propagation_delay = None
                        self.prune_delay_enabled = None
                        self.virtual_interface = None


                    class DrAddress(object):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress']['meta_info']


                    class InterfaceAddress(object):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:global-interfaces/Cisco-IOS-XR-ipv4-pim-oper:global-interface[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.are_we_dr is not None:
                            return True

                        if self.bfd_enabled is not None:
                            return True

                        if self.bfd_interval is not None:
                            return True

                        if self.bfd_multiplier is not None:
                            return True

                        if self.configured_override_interval is not None:
                            return True

                        if self.configured_propagation_delay is not None:
                            return True

                        if self.dr_address is not None and self.dr_address._has_data():
                            return True

                        if self.dr_priority is not None:
                            return True

                        if self.external_neighbor_count is not None:
                            return True

                        if self.generation_id is not None:
                            return True

                        if self.hello_expiry is not None:
                            return True

                        if self.hello_interval is not None:
                            return True

                        if self.idb_acl_name is not None:
                            return True

                        if self.idb_acl_provided is not None:
                            return True

                        if self.idb_current_count is not None:
                            return True

                        if self.idb_max_count is not None:
                            return True

                        if self.idb_oor_enabled is not None:
                            return True

                        if self.idb_threshold_count is not None:
                            return True

                        if self.interface_address is not None:
                            for child_ref in self.interface_address:
                                if child_ref._has_data():
                                    return True

                        if self.interface_address_mask is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_enabled is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.join_prune_interval is not None:
                            return True

                        if self.neighbor_count is not None:
                            return True

                        if self.neighbor_filter_name is not None:
                            return True

                        if self.override_interval is not None:
                            return True

                        if self.passive_interface is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.prune_delay_enabled is not None:
                            return True

                        if self.virtual_interface is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:global-interfaces'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.global_interface is not None:
                        for child_ref in self.global_interface:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.GlobalInterfaces']['meta_info']


            class IfrsInterfaces(object):
                """
                PIM interfaces in forward reference store table
                
                .. attribute:: ifrs_interface
                
                	PIM IFRS interface information
                	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.ifrs_interface = YList()
                    self.ifrs_interface.parent = self
                    self.ifrs_interface.name = 'ifrs_interface'


                class IfrsInterface(object):
                    """
                    PIM IFRS interface information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.configured_override_interval = None
                        self.configured_propagation_delay = None
                        self.dr_address = Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress()
                        self.dr_address.parent = self
                        self.dr_priority = None
                        self.external_neighbor_count = None
                        self.generation_id = None
                        self.hello_expiry = None
                        self.hello_interval = None
                        self.idb_acl_name = None
                        self.idb_acl_provided = None
                        self.idb_current_count = None
                        self.idb_max_count = None
                        self.idb_oor_enabled = None
                        self.idb_threshold_count = None
                        self.interface_address = YList()
                        self.interface_address.parent = self
                        self.interface_address.name = 'interface_address'
                        self.interface_address_mask = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bidirectional_capable = None
                        self.is_enabled = None
                        self.is_proxy_capable = None
                        self.join_prune_interval = None
                        self.neighbor_count = None
                        self.neighbor_filter_name = None
                        self.override_interval = None
                        self.passive_interface = None
                        self.propagation_delay = None
                        self.prune_delay_enabled = None
                        self.virtual_interface = None


                    class DrAddress(object):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress']['meta_info']


                    class InterfaceAddress(object):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ifrs-interfaces/Cisco-IOS-XR-ipv4-pim-oper:ifrs-interface[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.are_we_dr is not None:
                            return True

                        if self.bfd_enabled is not None:
                            return True

                        if self.bfd_interval is not None:
                            return True

                        if self.bfd_multiplier is not None:
                            return True

                        if self.configured_override_interval is not None:
                            return True

                        if self.configured_propagation_delay is not None:
                            return True

                        if self.dr_address is not None and self.dr_address._has_data():
                            return True

                        if self.dr_priority is not None:
                            return True

                        if self.external_neighbor_count is not None:
                            return True

                        if self.generation_id is not None:
                            return True

                        if self.hello_expiry is not None:
                            return True

                        if self.hello_interval is not None:
                            return True

                        if self.idb_acl_name is not None:
                            return True

                        if self.idb_acl_provided is not None:
                            return True

                        if self.idb_current_count is not None:
                            return True

                        if self.idb_max_count is not None:
                            return True

                        if self.idb_oor_enabled is not None:
                            return True

                        if self.idb_threshold_count is not None:
                            return True

                        if self.interface_address is not None:
                            for child_ref in self.interface_address:
                                if child_ref._has_data():
                                    return True

                        if self.interface_address_mask is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_enabled is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.join_prune_interval is not None:
                            return True

                        if self.neighbor_count is not None:
                            return True

                        if self.neighbor_filter_name is not None:
                            return True

                        if self.override_interval is not None:
                            return True

                        if self.passive_interface is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.prune_delay_enabled is not None:
                            return True

                        if self.virtual_interface is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ifrs-interfaces'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.ifrs_interface is not None:
                        for child_ref in self.ifrs_interface:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.IfrsInterfaces']['meta_info']


            class Safs(object):
                """
                SAFI table and type
                
                .. attribute:: saf
                
                	SAF name 
                	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.saf = YList()
                    self.saf.parent = self
                    self.saf.name = 'saf'


                class Saf(object):
                    """
                    SAF name 
                    
                    .. attribute:: rpf_hash_source_groups
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups>`
                    
                    .. attribute:: rpf_hash_sources
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources>`
                    
                    .. attribute:: rpfs
                    
                    	PIM RPF information table
                    	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs>`
                    
                    .. attribute:: saf_name
                    
                    	SAF name 
                    	**type**\:   :py:class:`PimSafiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafiEnum>`
                    
                    .. attribute:: topology_name
                    
                    	Topology name 
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.rpf_hash_source_groups = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups()
                        self.rpf_hash_source_groups.parent = self
                        self.rpf_hash_sources = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources()
                        self.rpf_hash_sources.parent = self
                        self.rpfs = Pim.Standby.DefaultContext.Safs.Saf.Rpfs()
                        self.rpfs.parent = self
                        self.saf_name = None
                        self.topology_name = None


                    class RpfHashSourceGroups(object):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source_group
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rpf_hash_source_group = YList()
                            self.rpf_hash_source_group.parent = self
                            self.rpf_hash_source_group.name = 'rpf_hash_source_group'


                        class RpfHashSourceGroup(object):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: mask_length
                            
                            	Hash mask length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.group_address = None
                                self.mask_length = None
                                self.mofrr = None
                                self.next_hop_address = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                self.next_hop_address.parent = self
                                self.next_hop_interface = None
                                self.next_hop_multipath_enabled = None
                                self.secondary_next_hop_address = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self.secondary_next_hop_interface = None
                                self.source_address = None


                            class NextHopAddress(object):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-groups/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-group/Cisco-IOS-XR-ipv4-pim-oper:next-hop-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress']['meta_info']


                            class SecondaryNextHopAddress(object):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-groups/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-group/Cisco-IOS-XR-ipv4-pim-oper:secondary-next-hop-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-groups/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-group'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.group_address is not None:
                                    return True

                                if self.mask_length is not None:
                                    return True

                                if self.mofrr is not None:
                                    return True

                                if self.next_hop_address is not None and self.next_hop_address._has_data():
                                    return True

                                if self.next_hop_interface is not None:
                                    return True

                                if self.next_hop_multipath_enabled is not None:
                                    return True

                                if self.secondary_next_hop_address is not None and self.secondary_next_hop_address._has_data():
                                    return True

                                if self.secondary_next_hop_interface is not None:
                                    return True

                                if self.source_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-groups'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rpf_hash_source_group is not None:
                                for child_ref in self.rpf_hash_source_group:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups']['meta_info']


                    class RpfHashSources(object):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rpf_hash_source = YList()
                            self.rpf_hash_source.parent = self
                            self.rpf_hash_source.name = 'rpf_hash_source'


                        class RpfHashSource(object):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mofrr = None
                                self.next_hop_address = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                self.next_hop_address.parent = self
                                self.next_hop_interface = None
                                self.next_hop_multipath_enabled = None
                                self.secondary_next_hop_address = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self.secondary_next_hop_interface = None
                                self.source_address = None


                            class NextHopAddress(object):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-sources/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source/Cisco-IOS-XR-ipv4-pim-oper:next-hop-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress']['meta_info']


                            class SecondaryNextHopAddress(object):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-sources/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source/Cisco-IOS-XR-ipv4-pim-oper:secondary-next-hop-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-sources/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mofrr is not None:
                                    return True

                                if self.next_hop_address is not None and self.next_hop_address._has_data():
                                    return True

                                if self.next_hop_interface is not None:
                                    return True

                                if self.next_hop_multipath_enabled is not None:
                                    return True

                                if self.secondary_next_hop_address is not None and self.secondary_next_hop_address._has_data():
                                    return True

                                if self.secondary_next_hop_interface is not None:
                                    return True

                                if self.source_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-sources'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rpf_hash_source is not None:
                                for child_ref in self.rpf_hash_source:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources']['meta_info']


                    class Rpfs(object):
                        """
                        PIM RPF information table
                        
                        .. attribute:: rpf
                        
                        	PIM RPF information
                        	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rpf = YList()
                            self.rpf.parent = self
                            self.rpf.name = 'rpf'


                        class Rpf(object):
                            """
                            PIM RPF information
                            
                            .. attribute:: registered_address  <key>
                            
                            	Address for which RPF lookup
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: is_rpf_bgp_route
                            
                            	Is RPF through BGP route
                            	**type**\:  bool
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address_xr
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                            
                            .. attribute:: rpf_path
                            
                            	RPF Paths list
                            	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.registered_address = None
                                self.is_connected = None
                                self.is_rpf_bgp_route = None
                                self.metric = None
                                self.metric_preference = None
                                self.registered_address_xr = Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                self.registered_address_xr.parent = self
                                self.rpf_path = YList()
                                self.rpf_path.parent = self
                                self.rpf_path.name = 'rpf_path'


                            class RegisteredAddressXr(object):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:registered-address-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr']['meta_info']


                            class RpfPath(object):
                                """
                                RPF Paths list
                                
                                .. attribute:: connector
                                
                                	Connector Attribute
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface_disabled
                                
                                	Is the rpf interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                .. attribute:: is_via_mlsm
                                
                                	Via Mstatic LSM
                                	**type**\:  bool
                                
                                .. attribute:: rpf_interface_name
                                
                                	RPF Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: rpf_neighbor
                                
                                	RPF neighbor
                                	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                
                                .. attribute:: rpf_nexthop
                                
                                	RPF nexthop
                                	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.connector = None
                                    self.extranet_vrf_name = None
                                    self.is_connector_attribute_present = None
                                    self.is_rpf_interface_disabled = None
                                    self.is_via_lsm = None
                                    self.is_via_mlsm = None
                                    self.rpf_interface_name = None
                                    self.rpf_neighbor = Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self.rpf_nexthop = Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                    self.rpf_nexthop.parent = self


                                class RpfNeighbor(object):
                                    """
                                    RPF neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor']['meta_info']


                                class RpfNexthop(object):
                                    """
                                    RPF nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-nexthop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.connector is not None:
                                        return True

                                    if self.extranet_vrf_name is not None:
                                        return True

                                    if self.is_connector_attribute_present is not None:
                                        return True

                                    if self.is_rpf_interface_disabled is not None:
                                        return True

                                    if self.is_via_lsm is not None:
                                        return True

                                    if self.is_via_mlsm is not None:
                                        return True

                                    if self.rpf_interface_name is not None:
                                        return True

                                    if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                        return True

                                    if self.rpf_nexthop is not None and self.rpf_nexthop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath']['meta_info']

                            @property
                            def _common_path(self):
                                if self.registered_address is None:
                                    raise YPYModelError('Key property registered_address is None')

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpfs/Cisco-IOS-XR-ipv4-pim-oper:rpf[Cisco-IOS-XR-ipv4-pim-oper:registered-address = ' + str(self.registered_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.registered_address is not None:
                                    return True

                                if self.is_connected is not None:
                                    return True

                                if self.is_rpf_bgp_route is not None:
                                    return True

                                if self.metric is not None:
                                    return True

                                if self.metric_preference is not None:
                                    return True

                                if self.registered_address_xr is not None and self.registered_address_xr._has_data():
                                    return True

                                if self.rpf_path is not None:
                                    for child_ref in self.rpf_path:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpfs'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rpf is not None:
                                for child_ref in self.rpf:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Safs.Saf.Rpfs']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups._has_data():
                            return True

                        if self.rpf_hash_sources is not None and self.rpf_hash_sources._has_data():
                            return True

                        if self.rpfs is not None and self.rpfs._has_data():
                            return True

                        if self.saf_name is not None:
                            return True

                        if self.topology_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.Safs.Saf']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.saf is not None:
                        for child_ref in self.saf:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.Safs']['meta_info']


            class InterfaceStatistics(object):
                """
                PIM interface statistics
                
                .. attribute:: interface_statistic
                
                	PIM interface statistics
                	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_statistic = YList()
                    self.interface_statistic.parent = self
                    self.interface_statistic.name = 'interface_statistic'


                class InterfaceStatistic(object):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_ack_message
                    
                    	Input Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_message
                    
                    	Input Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_miscellaneous
                    
                    	Miscellaneous packet in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register
                    
                    	Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_ack_message
                    
                    	Output Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_message
                    
                    	Output Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register
                    
                    	Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.input_assert = None
                        self.input_bsr_message = None
                        self.input_candidate_rp_advertisement = None
                        self.input_df_election = None
                        self.input_graft_ack_message = None
                        self.input_graft_message = None
                        self.input_hello = None
                        self.input_jp = None
                        self.input_miscellaneous = None
                        self.input_register = None
                        self.input_register_stop = None
                        self.output_assert = None
                        self.output_bsr_message = None
                        self.output_candidate_rp_advertisement = None
                        self.output_df_election = None
                        self.output_graft_ack_message = None
                        self.output_graft_message = None
                        self.output_hello = None
                        self.output_jp = None
                        self.output_register = None
                        self.output_register_stop = None

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interface-statistics/Cisco-IOS-XR-ipv4-pim-oper:interface-statistic[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.input_assert is not None:
                            return True

                        if self.input_bsr_message is not None:
                            return True

                        if self.input_candidate_rp_advertisement is not None:
                            return True

                        if self.input_df_election is not None:
                            return True

                        if self.input_graft_ack_message is not None:
                            return True

                        if self.input_graft_message is not None:
                            return True

                        if self.input_hello is not None:
                            return True

                        if self.input_jp is not None:
                            return True

                        if self.input_miscellaneous is not None:
                            return True

                        if self.input_register is not None:
                            return True

                        if self.input_register_stop is not None:
                            return True

                        if self.output_assert is not None:
                            return True

                        if self.output_bsr_message is not None:
                            return True

                        if self.output_candidate_rp_advertisement is not None:
                            return True

                        if self.output_df_election is not None:
                            return True

                        if self.output_graft_ack_message is not None:
                            return True

                        if self.output_graft_message is not None:
                            return True

                        if self.output_hello is not None:
                            return True

                        if self.output_jp is not None:
                            return True

                        if self.output_register is not None:
                            return True

                        if self.output_register_stop is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interface-statistics'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_statistic is not None:
                        for child_ref in self.interface_statistic:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.InterfaceStatistics']['meta_info']


            class TopologyRouteCount(object):
                """
                Topology route count information from PIM
                topology table
                
                .. attribute:: active_group_ranges
                
                	No. of (\*,G/M) routes active in mrib
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_address
                
                	Group Address
                	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyRouteCount.GroupAddress>`
                
                .. attribute:: group_ranges
                
                	No. of (\*,G/M) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groute_count
                
                	No. of (\*,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: sg_route_count
                
                	No. of (S,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sgr_route_count
                
                	No. of (S,G)RPT routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.active_group_ranges = None
                    self.group_address = Pim.Standby.DefaultContext.TopologyRouteCount.GroupAddress()
                    self.group_address.parent = self
                    self.group_ranges = None
                    self.groute_count = None
                    self.is_node_low_memory = None
                    self.sg_route_count = None
                    self.sgr_route_count = None


                class GroupAddress(object):
                    """
                    Group Address
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.af_name = None
                        self.ipv4_address = None
                        self.ipv6_address = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-route-count/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.af_name is not None:
                            return True

                        if self.ipv4_address is not None:
                            return True

                        if self.ipv6_address is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.TopologyRouteCount.GroupAddress']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-route-count'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.active_group_ranges is not None:
                        return True

                    if self.group_address is not None and self.group_address._has_data():
                        return True

                    if self.group_ranges is not None:
                        return True

                    if self.groute_count is not None:
                        return True

                    if self.is_node_low_memory is not None:
                        return True

                    if self.sg_route_count is not None:
                        return True

                    if self.sgr_route_count is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.TopologyRouteCount']['meta_info']


            class JpStatistics(object):
                """
                PIM join prune statistics table
                
                .. attribute:: jp_statistic
                
                	PIM Join Prune Statistics
                	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.JpStatistics.JpStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.jp_statistic = YList()
                    self.jp_statistic.parent = self
                    self.jp_statistic.name = 'jp_statistic'


                class JpStatistic(object):
                    """
                    PIM Join Prune Statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mtu
                    
                    	Interface MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received
                    
                    	Received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received100
                    
                    	Received 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_10k
                    
                    	Received 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_1k
                    
                    	Received 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_50k
                    
                    	Deprecated by Received100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted
                    
                    	Transmitted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: transmitted100
                    
                    	Transmitted 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_10k
                    
                    	Transmitted 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_1k
                    
                    	Transmitted 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_50k
                    
                    	Deprecated by Transmitted100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.mtu = None
                        self.received = None
                        self.received100 = None
                        self.received_10k = None
                        self.received_1k = None
                        self.received_50k = None
                        self.transmitted = None
                        self.transmitted100 = None
                        self.transmitted_10k = None
                        self.transmitted_1k = None
                        self.transmitted_50k = None

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:jp-statistics/Cisco-IOS-XR-ipv4-pim-oper:jp-statistic[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.mtu is not None:
                            return True

                        if self.received is not None:
                            return True

                        if self.received100 is not None:
                            return True

                        if self.received_10k is not None:
                            return True

                        if self.received_1k is not None:
                            return True

                        if self.received_50k is not None:
                            return True

                        if self.transmitted is not None:
                            return True

                        if self.transmitted100 is not None:
                            return True

                        if self.transmitted_10k is not None:
                            return True

                        if self.transmitted_1k is not None:
                            return True

                        if self.transmitted_50k is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.JpStatistics.JpStatistic']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:jp-statistics'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.jp_statistic is not None:
                        for child_ref in self.jp_statistic:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.JpStatistics']['meta_info']


            class MibDatabases(object):
                """
                PIM group database for mroute mibs table
                
                .. attribute:: mib_database
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases.MibDatabase>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.mib_database = YList()
                    self.mib_database.parent = self
                    self.mib_database.name = 'mib_database'


                class MibDatabase(object):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: assert_metric
                    
                    	Assert Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_metric_preference
                    
                    	Assert Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_rpt_bit
                    
                    	Assert RPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: bidirectional_route
                    
                    	Is this Bidir ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Multicast satic route group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr>`
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface name 
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_mask
                    
                    	Mask of the multicast root
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_neighbor
                    
                    	The RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor>`
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: source_address
                    
                    	Multicast static route source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr>`
                    
                    .. attribute:: source_netmask
                    
                    	Source mask
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: spt_bit
                    
                    	Is SPT bit set ?
                    	**type**\:  bool
                    
                    .. attribute:: upstream_assert_timer
                    
                    	Upstream Assert Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime of route
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.assert_metric = None
                        self.assert_metric_preference = None
                        self.assert_rpt_bit = None
                        self.bidirectional_route = None
                        self.group_address = None
                        self.group_address_xr = Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self.protocol = None
                        self.rpf_drop = None
                        self.rpf_extranet = None
                        self.rpf_interface_name = None
                        self.rpf_mask = None
                        self.rpf_neighbor = Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self.rpf_root = Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot()
                        self.rpf_root.parent = self
                        self.rpf_safi = None
                        self.rpf_table_name = None
                        self.rpf_vrf_name = None
                        self.source_address = None
                        self.source_address_xr = Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self.source_netmask = None
                        self.spt_bit = None
                        self.upstream_assert_timer = None
                        self.uptime = None


                    class SourceAddressXr(object):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases/Cisco-IOS-XR-ipv4-pim-oper:mib-database/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr']['meta_info']


                    class GroupAddressXr(object):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases/Cisco-IOS-XR-ipv4-pim-oper:mib-database/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr']['meta_info']


                    class RpfNeighbor(object):
                        """
                        The RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases/Cisco-IOS-XR-ipv4-pim-oper:mib-database/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor']['meta_info']


                    class RpfRoot(object):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases/Cisco-IOS-XR-ipv4-pim-oper:mib-database/Cisco-IOS-XR-ipv4-pim-oper:rpf-root'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases/Cisco-IOS-XR-ipv4-pim-oper:mib-database'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.assert_metric is not None:
                            return True

                        if self.assert_metric_preference is not None:
                            return True

                        if self.assert_rpt_bit is not None:
                            return True

                        if self.bidirectional_route is not None:
                            return True

                        if self.group_address is not None:
                            return True

                        if self.group_address_xr is not None and self.group_address_xr._has_data():
                            return True

                        if self.protocol is not None:
                            return True

                        if self.rpf_drop is not None:
                            return True

                        if self.rpf_extranet is not None:
                            return True

                        if self.rpf_interface_name is not None:
                            return True

                        if self.rpf_mask is not None:
                            return True

                        if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                            return True

                        if self.rpf_root is not None and self.rpf_root._has_data():
                            return True

                        if self.rpf_safi is not None:
                            return True

                        if self.rpf_table_name is not None:
                            return True

                        if self.rpf_vrf_name is not None:
                            return True

                        if self.source_address is not None:
                            return True

                        if self.source_address_xr is not None and self.source_address_xr._has_data():
                            return True

                        if self.source_netmask is not None:
                            return True

                        if self.spt_bit is not None:
                            return True

                        if self.upstream_assert_timer is not None:
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.MibDatabases.MibDatabase']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.mib_database is not None:
                        for child_ref in self.mib_database:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.MibDatabases']['meta_info']


            class GroupMapMatchRpfs(object):
                """
                Find matching group\-mapping for the specified
                group address
                
                .. attribute:: group_map_match_rpf
                
                	PIM group matching mapping entry
                	**type**\: list of    :py:class:`GroupMapMatchRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.group_map_match_rpf = YList()
                    self.group_map_match_rpf.parent = self
                    self.group_map_match_rpf.name = 'group_map_match_rpf'


                class GroupMapMatchRpf(object):
                    """
                    PIM group matching mapping entry
                    
                    .. attribute:: group_address  <key>
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\:  bool
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation>`
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor>`
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_address = None
                        self.are_we_rp = None
                        self.group_map_information = Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self.rpf_interface_name = None
                        self.rpf_neighbor = Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self.rpf_vrf_name = None


                    class RpfNeighbor(object):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor']['meta_info']


                    class GroupMapInformation(object):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.group_count = None
                            self.is_override = None
                            self.is_used = None
                            self.mrib_active = None
                            self.prefix = Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.priority = None
                            self.protocol = None
                            self.rp_address = Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self


                        class Prefix(object):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix']['meta_info']


                        class RpAddress(object):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.group_count is not None:
                                return True

                            if self.is_override is not None:
                                return True

                            if self.is_used is not None:
                                return True

                            if self.mrib_active is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation']['meta_info']

                    @property
                    def _common_path(self):
                        if self.group_address is None:
                            raise YPYModelError('Key property group_address is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-rpf[Cisco-IOS-XR-ipv4-pim-oper:group-address = ' + str(self.group_address) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_address is not None:
                            return True

                        if self.are_we_rp is not None:
                            return True

                        if self.group_map_information is not None and self.group_map_information._has_data():
                            return True

                        if self.rpf_interface_name is not None:
                            return True

                        if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                            return True

                        if self.rpf_vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-rpfs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.group_map_match_rpf is not None:
                        for child_ref in self.group_map_match_rpf:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.GroupMapMatchRpfs']['meta_info']


            class NeighborOldFormats(object):
                """
                PIM neighbor table old format
                
                .. attribute:: neighbor_old_format
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.neighbor_old_format = YList()
                    self.neighbor_old_format.parent = self
                    self.neighbor_old_format.name = 'neighbor_old_format'


                class NeighborOldFormat(object):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.dr_priority = None
                        self.expires = None
                        self.expiry_timer = None
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bfd_state = None
                        self.is_bidirectional_capable = None
                        self.is_dr_priority_capable = None
                        self.is_ecmp_redirect_capable = None
                        self.is_proxy_capable = None
                        self.is_this_neighbor_dr = None
                        self.is_this_neighbor_us = None
                        self.neighbor_address = None
                        self.neighbor_address_xr = YList()
                        self.neighbor_address_xr.parent = self
                        self.neighbor_address_xr.name = 'neighbor_address_xr'
                        self.override_interval = None
                        self.propagation_delay = None
                        self.uptime = None


                    class NeighborAddressXr(object):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-formats/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-format/Cisco-IOS-XR-ipv4-pim-oper:neighbor-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-formats/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-format'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.dr_priority is not None:
                            return True

                        if self.expires is not None:
                            return True

                        if self.expiry_timer is not None:
                            return True

                        if self.interface_name is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bfd_state is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_dr_priority_capable is not None:
                            return True

                        if self.is_ecmp_redirect_capable is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.is_this_neighbor_dr is not None:
                            return True

                        if self.is_this_neighbor_us is not None:
                            return True

                        if self.neighbor_address is not None:
                            return True

                        if self.neighbor_address_xr is not None:
                            for child_ref in self.neighbor_address_xr:
                                if child_ref._has_data():
                                    return True

                        if self.override_interval is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-formats'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.neighbor_old_format is not None:
                        for child_ref in self.neighbor_old_format:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.NeighborOldFormats']['meta_info']


            class IfrsSummary(object):
                """
                PIM interfaces in forward reference store
                summary
                
                .. attribute:: configuration_count
                
                	Configuration counts
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_count
                
                	Number of interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.configuration_count = None
                    self.interface_count = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ifrs-summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.configuration_count is not None:
                        return True

                    if self.interface_count is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.IfrsSummary']['meta_info']


            class Ranges(object):
                """
                PIM range list information
                
                .. attribute:: range
                
                	PIM range list information
                	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.range = YList()
                    self.range.parent = self
                    self.range.name = 'range'


                class Range(object):
                    """
                    PIM range list information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                    
                    .. attribute:: client_xr
                    
                    	Client mapping learnt via
                    	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                    
                    .. attribute:: expires
                    
                    	When mapping expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: group_range
                    
                    	List of group ranges
                    	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range.GroupRange>`
                    
                    .. attribute:: protocol
                    
                    	PIM protocol
                    	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	Rendezvous point address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr>`
                    
                    .. attribute:: source_of_information
                    
                    	Source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.client = None
                        self.client_xr = None
                        self.expires = None
                        self.group_range = YList()
                        self.group_range.parent = self
                        self.group_range.name = 'group_range'
                        self.protocol = None
                        self.rp_address = None
                        self.rp_address_xr = Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self.source_of_information = Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation()
                        self.source_of_information.parent = self


                    class RpAddressXr(object):
                        """
                        Rendezvous point address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr']['meta_info']


                    class SourceOfInformation(object):
                        """
                        Source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation']['meta_info']


                    class GroupRange(object):
                        """
                        List of group ranges
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.expires = None
                            self.prefix = Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.source_of_information = Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation()
                            self.source_of_information.parent = self
                            self.uptime = None


                        class Prefix(object):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range/Cisco-IOS-XR-ipv4-pim-oper:group-range/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix']['meta_info']


                        class SourceOfInformation(object):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range/Cisco-IOS-XR-ipv4-pim-oper:group-range/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range/Cisco-IOS-XR-ipv4-pim-oper:group-range'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.expires is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.source_of_information is not None and self.source_of_information._has_data():
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Ranges.Range.GroupRange']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.client is not None:
                            return True

                        if self.client_xr is not None:
                            return True

                        if self.expires is not None:
                            return True

                        if self.group_range is not None:
                            for child_ref in self.group_range:
                                if child_ref._has_data():
                                    return True

                        if self.protocol is not None:
                            return True

                        if self.rp_address is not None:
                            return True

                        if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                            return True

                        if self.source_of_information is not None and self.source_of_information._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.Ranges.Range']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.range is not None:
                        for child_ref in self.range:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.Ranges']['meta_info']


            class InterfaceOldFormats(object):
                """
                PIM interfaces in old format
                
                .. attribute:: interface_old_format
                
                	PIM interface name
                	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_old_format = YList()
                    self.interface_old_format.parent = self
                    self.interface_old_format.name = 'interface_old_format'


                class InterfaceOldFormat(object):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.configured_override_interval = None
                        self.configured_propagation_delay = None
                        self.dr_address = Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                        self.dr_address.parent = self
                        self.dr_priority = None
                        self.external_neighbor_count = None
                        self.generation_id = None
                        self.hello_expiry = None
                        self.hello_interval = None
                        self.idb_acl_name = None
                        self.idb_acl_provided = None
                        self.idb_current_count = None
                        self.idb_max_count = None
                        self.idb_oor_enabled = None
                        self.idb_threshold_count = None
                        self.interface_address = YList()
                        self.interface_address.parent = self
                        self.interface_address.name = 'interface_address'
                        self.interface_address_mask = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bidirectional_capable = None
                        self.is_enabled = None
                        self.is_proxy_capable = None
                        self.join_prune_interval = None
                        self.neighbor_count = None
                        self.neighbor_filter_name = None
                        self.override_interval = None
                        self.passive_interface = None
                        self.propagation_delay = None
                        self.prune_delay_enabled = None
                        self.virtual_interface = None


                    class DrAddress(object):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress']['meta_info']


                    class InterfaceAddress(object):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interface-old-formats/Cisco-IOS-XR-ipv4-pim-oper:interface-old-format[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.are_we_dr is not None:
                            return True

                        if self.bfd_enabled is not None:
                            return True

                        if self.bfd_interval is not None:
                            return True

                        if self.bfd_multiplier is not None:
                            return True

                        if self.configured_override_interval is not None:
                            return True

                        if self.configured_propagation_delay is not None:
                            return True

                        if self.dr_address is not None and self.dr_address._has_data():
                            return True

                        if self.dr_priority is not None:
                            return True

                        if self.external_neighbor_count is not None:
                            return True

                        if self.generation_id is not None:
                            return True

                        if self.hello_expiry is not None:
                            return True

                        if self.hello_interval is not None:
                            return True

                        if self.idb_acl_name is not None:
                            return True

                        if self.idb_acl_provided is not None:
                            return True

                        if self.idb_current_count is not None:
                            return True

                        if self.idb_max_count is not None:
                            return True

                        if self.idb_oor_enabled is not None:
                            return True

                        if self.idb_threshold_count is not None:
                            return True

                        if self.interface_address is not None:
                            for child_ref in self.interface_address:
                                if child_ref._has_data():
                                    return True

                        if self.interface_address_mask is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_enabled is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.join_prune_interval is not None:
                            return True

                        if self.neighbor_count is not None:
                            return True

                        if self.neighbor_filter_name is not None:
                            return True

                        if self.override_interval is not None:
                            return True

                        if self.passive_interface is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.prune_delay_enabled is not None:
                            return True

                        if self.virtual_interface is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interface-old-formats'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_old_format is not None:
                        for child_ref in self.interface_old_format:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.InterfaceOldFormats']['meta_info']


            class Bsr(object):
                """
                PIM BSR information
                
                .. attribute:: bsr_elections
                
                	PIM BSR election state
                	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.BsrElections>`
                
                .. attribute:: candidate_rps
                
                	PIM candidate\-RP
                	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.CandidateRps>`
                
                .. attribute:: rp_caches
                
                	PIM BSR RP cache table
                	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bsr_elections = Pim.Standby.DefaultContext.Bsr.BsrElections()
                    self.bsr_elections.parent = self
                    self.candidate_rps = Pim.Standby.DefaultContext.Bsr.CandidateRps()
                    self.candidate_rps.parent = self
                    self.rp_caches = Pim.Standby.DefaultContext.Bsr.RpCaches()
                    self.rp_caches.parent = self


                class RpCaches(object):
                    """
                    PIM BSR RP cache table
                    
                    .. attribute:: rp_cache
                    
                    	PIM BSR RP cache
                    	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.rp_cache = YList()
                        self.rp_cache.parent = self
                        self.rp_cache.name = 'rp_cache'


                    class RpCache(object):
                        """
                        PIM BSR RP cache
                        
                        .. attribute:: group_prefix  <key>
                        
                        	Group prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: candidate_rp_group_count
                        
                        	C\-RP count for this Prefix
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: candidate_rp_list
                        
                        	C\-RP list for this prefix
                        	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList>`
                        
                        .. attribute:: group_prefix_length
                        
                        	Group Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_prefix_xr
                        
                        	Group Prefix
                        	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.group_prefix = None
                            self.candidate_rp_group_count = None
                            self.candidate_rp_list = Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList()
                            self.candidate_rp_list.parent = self
                            self.group_prefix_length = None
                            self.group_prefix_xr = Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr()
                            self.group_prefix_xr.parent = self


                        class GroupPrefixXr(object):
                            """
                            Group Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-prefix-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr']['meta_info']


                        class CandidateRpList(object):
                            """
                            C\-RP list for this prefix
                            
                            .. attribute:: pim_bsr_crp_bag
                            
                            	pim bsr crp bag
                            	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pim_bsr_crp_bag = YList()
                                self.pim_bsr_crp_bag.parent = self
                                self.pim_bsr_crp_bag.name = 'pim_bsr_crp_bag'


                            class PimBsrCrpBag(object):
                                """
                                pim bsr crp bag
                                
                                .. attribute:: candidate_rp_address
                                
                                	C\-RP address
                                	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                
                                .. attribute:: candidate_rp_expires
                                
                                	C\-RP Expires
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_holdtime
                                
                                	C\-RP Holdtime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_priority
                                
                                	C\-RP Priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: candidate_rp_up_time
                                
                                	C\-RP Uptime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: protocol
                                
                                	PIM Protocol
                                	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.candidate_rp_address = Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                    self.candidate_rp_address.parent = self
                                    self.candidate_rp_expires = None
                                    self.candidate_rp_holdtime = None
                                    self.candidate_rp_priority = None
                                    self.candidate_rp_up_time = None
                                    self.protocol = None


                                class CandidateRpAddress(object):
                                    """
                                    C\-RP address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:pim-bsr-crp-bag'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.candidate_rp_address is not None and self.candidate_rp_address._has_data():
                                        return True

                                    if self.candidate_rp_expires is not None:
                                        return True

                                    if self.candidate_rp_holdtime is not None:
                                        return True

                                    if self.candidate_rp_priority is not None:
                                        return True

                                    if self.candidate_rp_up_time is not None:
                                        return True

                                    if self.protocol is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp-list'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pim_bsr_crp_bag is not None:
                                    for child_ref in self.pim_bsr_crp_bag:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList']['meta_info']

                        @property
                        def _common_path(self):
                            if self.group_prefix is None:
                                raise YPYModelError('Key property group_prefix is None')

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:rp-caches/Cisco-IOS-XR-ipv4-pim-oper:rp-cache[Cisco-IOS-XR-ipv4-pim-oper:group-prefix = ' + str(self.group_prefix) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.group_prefix is not None:
                                return True

                            if self.candidate_rp_group_count is not None:
                                return True

                            if self.candidate_rp_list is not None and self.candidate_rp_list._has_data():
                                return True

                            if self.group_prefix_length is not None:
                                return True

                            if self.group_prefix_xr is not None and self.group_prefix_xr._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:rp-caches'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.rp_cache is not None:
                            for child_ref in self.rp_cache:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.Bsr.RpCaches']['meta_info']


                class CandidateRps(object):
                    """
                    PIM candidate\-RP
                    
                    .. attribute:: candidate_rp
                    
                    	PIM BSR candidate RP information
                    	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.candidate_rp = YList()
                        self.candidate_rp.parent = self
                        self.candidate_rp.name = 'candidate_rp'


                    class CandidateRp(object):
                        """
                        PIM BSR candidate RP information
                        
                        .. attribute:: rp_address  <key>
                        
                        	Candidate\-RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: acl_name
                        
                        	Group Access\-List Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: candidate_rp
                        
                        	Cand\-RP Address
                        	**type**\:   :py:class:`CandidateRp_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_>`
                        
                        .. attribute:: candidate_rp_advance_interval
                        
                        	Cand\-RP Adv Interval in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: candidate_rp_mode
                        
                        	Cand\-RP Mode
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: candidate_rp_scope
                        
                        	Cand\-RP Scope
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: candidate_rp_uptime
                        
                        	Cand\-RP uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_access
                        
                        	Group Ranges Using this Cand\-RP
                        	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                        
                        .. attribute:: crp_holdtime
                        
                        	Cand\-RP Holdtime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_priority
                        
                        	Cand\-RP Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rp_address = None
                            self.acl_name = None
                            self.candidate_rp = Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_()
                            self.candidate_rp.parent = self
                            self.candidate_rp_advance_interval = None
                            self.candidate_rp_mode = None
                            self.candidate_rp_scope = None
                            self.candidate_rp_uptime = None
                            self.crp_access = YList()
                            self.crp_access.parent = self
                            self.crp_access.name = 'crp_access'
                            self.crp_holdtime = None
                            self.crp_priority = None


                        class CandidateRp_(object):
                            """
                            Cand\-RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_']['meta_info']


                        class CrpAccess(object):
                            """
                            Group Ranges Using this Cand\-RP
                            
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.acl_name = None
                                self.candidate_rp_mode = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:crp-access'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.acl_name is not None:
                                    return True

                                if self.candidate_rp_mode is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess']['meta_info']

                        @property
                        def _common_path(self):
                            if self.rp_address is None:
                                raise YPYModelError('Key property rp_address is None')

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:candidate-rps/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp[Cisco-IOS-XR-ipv4-pim-oper:rp-address = ' + str(self.rp_address) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rp_address is not None:
                                return True

                            if self.acl_name is not None:
                                return True

                            if self.candidate_rp is not None and self.candidate_rp._has_data():
                                return True

                            if self.candidate_rp_advance_interval is not None:
                                return True

                            if self.candidate_rp_mode is not None:
                                return True

                            if self.candidate_rp_scope is not None:
                                return True

                            if self.candidate_rp_uptime is not None:
                                return True

                            if self.crp_access is not None:
                                for child_ref in self.crp_access:
                                    if child_ref._has_data():
                                        return True

                            if self.crp_holdtime is not None:
                                return True

                            if self.crp_priority is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:candidate-rps'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.candidate_rp is not None:
                            for child_ref in self.candidate_rp:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.Bsr.CandidateRps']['meta_info']


                class BsrElections(object):
                    """
                    PIM BSR election state
                    
                    .. attribute:: bsr_election
                    
                    	PIM BSR information
                    	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bsr_election = YList()
                        self.bsr_election.parent = self
                        self.bsr_election.name = 'bsr_election'


                    class BsrElection(object):
                        """
                        PIM BSR information
                        
                        .. attribute:: pim_scope  <key>
                        
                        	BSR information
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: bootstrap_timeout
                        
                        	Bootstrap Timeout
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_address
                        
                        	BSR address
                        	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress>`
                        
                        .. attribute:: bsr_election_state
                        
                        	BSR Election State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_mask_length
                        
                        	Hash Function Mask Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_priority
                        
                        	BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_scope
                        
                        	BSR Scope
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_up_time
                        
                        	BSR Uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_bsr_address
                        
                        	C\-BSR address
                        	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                        
                        .. attribute:: candidate_bsr_flag
                        
                        	BSR Candidate Config Flag
                        	**type**\:  bool
                        
                        .. attribute:: candidate_bsr_mask_length
                        
                        	C\-BSR Hash Func. Mask Len
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_priority
                        
                        	C\-BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_state
                        
                        	BSR Candidate State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.pim_scope = None
                            self.bootstrap_timeout = None
                            self.bsr_address = Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress()
                            self.bsr_address.parent = self
                            self.bsr_election_state = None
                            self.bsr_mask_length = None
                            self.bsr_priority = None
                            self.bsr_scope = None
                            self.bsr_up_time = None
                            self.candidate_bsr_address = Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                            self.candidate_bsr_address.parent = self
                            self.candidate_bsr_flag = None
                            self.candidate_bsr_mask_length = None
                            self.candidate_bsr_priority = None
                            self.candidate_bsr_state = None


                        class BsrAddress(object):
                            """
                            BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bsr-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress']['meta_info']


                        class CandidateBsrAddress(object):
                            """
                            C\-BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-bsr-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.pim_scope is None:
                                raise YPYModelError('Key property pim_scope is None')

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:bsr-elections/Cisco-IOS-XR-ipv4-pim-oper:bsr-election[Cisco-IOS-XR-ipv4-pim-oper:pim-scope = ' + str(self.pim_scope) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.pim_scope is not None:
                                return True

                            if self.bootstrap_timeout is not None:
                                return True

                            if self.bsr_address is not None and self.bsr_address._has_data():
                                return True

                            if self.bsr_election_state is not None:
                                return True

                            if self.bsr_mask_length is not None:
                                return True

                            if self.bsr_priority is not None:
                                return True

                            if self.bsr_scope is not None:
                                return True

                            if self.bsr_up_time is not None:
                                return True

                            if self.candidate_bsr_address is not None and self.candidate_bsr_address._has_data():
                                return True

                            if self.candidate_bsr_flag is not None:
                                return True

                            if self.candidate_bsr_mask_length is not None:
                                return True

                            if self.candidate_bsr_priority is not None:
                                return True

                            if self.candidate_bsr_state is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:bsr-elections'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bsr_election is not None:
                            for child_ref in self.bsr_election:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.Bsr.BsrElections']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bsr_elections is not None and self.bsr_elections._has_data():
                        return True

                    if self.candidate_rps is not None and self.candidate_rps._has_data():
                        return True

                    if self.rp_caches is not None and self.rp_caches._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.Bsr']['meta_info']


            class RoutePolicy(object):
                """
                PIM route policy
                
                .. attribute:: route_policy_statistics
                
                	PIM route policy statistics
                	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics>`
                
                .. attribute:: route_policy_tests
                
                	PIM route policy test run table
                	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.route_policy_statistics = Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics()
                    self.route_policy_statistics.parent = self
                    self.route_policy_tests = Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests()
                    self.route_policy_tests.parent = self


                class RoutePolicyStatistics(object):
                    """
                    PIM route policy statistics
                    
                    .. attribute:: any_table
                    
                    	Number of RPF lookup in any Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table
                    
                    	Number of RPF lookup in default\-only Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop
                    
                    	Number of RPF drops
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pass_
                    
                    	Number of RPF pass
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: policy_name
                    
                    	RPF policy name
                    	**type**\:  str
                    
                    .. attribute:: requests
                    
                    	Number of RPF lookup requests
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.any_table = None
                        self.default_table = None
                        self.drop = None
                        self.pass_ = None
                        self.policy_name = None
                        self.requests = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy/Cisco-IOS-XR-ipv4-pim-oper:route-policy-statistics'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.any_table is not None:
                            return True

                        if self.default_table is not None:
                            return True

                        if self.drop is not None:
                            return True

                        if self.pass_ is not None:
                            return True

                        if self.policy_name is not None:
                            return True

                        if self.requests is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics']['meta_info']


                class RoutePolicyTests(object):
                    """
                    PIM route policy test run table
                    
                    .. attribute:: route_policy_test
                    
                    	PIM route policy test run
                    	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.route_policy_test = YList()
                        self.route_policy_test.parent = self
                        self.route_policy_test.name = 'route_policy_test'


                    class RoutePolicyTest(object):
                        """
                        PIM route policy test run
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Default table selected
                        	**type**\:  bool
                        
                        .. attribute:: ext_comm
                        
                        	Extended Community
                        	**type**\:  str
                        
                        	**length:** 1..8
                        
                        .. attribute:: extended_community_rt
                        
                        	Route Target
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                        
                        .. attribute:: pass_
                        
                        	Pass
                        	**type**\:  bool
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                        
                        .. attribute:: table_active
                        
                        	Table active
                        	**type**\:  bool
                        
                        .. attribute:: table_exists
                        
                        	Table exists
                        	**type**\:  bool
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_name
                        
                        	VRF name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.afi = None
                            self.default_table = None
                            self.ext_comm = None
                            self.extended_community_rt = None
                            self.group_address = None
                            self.group_address_xr = Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self.pass_ = None
                            self.policy_name = None
                            self.safi = None
                            self.source_address = None
                            self.source_address_xr = Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self.table_active = None
                            self.table_exists = None
                            self.table_name = None
                            self.vrf_name = None


                        class SourceAddressXr(object):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy/Cisco-IOS-XR-ipv4-pim-oper:route-policy-tests/Cisco-IOS-XR-ipv4-pim-oper:route-policy-test/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr']['meta_info']


                        class GroupAddressXr(object):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy/Cisco-IOS-XR-ipv4-pim-oper:route-policy-tests/Cisco-IOS-XR-ipv4-pim-oper:route-policy-test/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy/Cisco-IOS-XR-ipv4-pim-oper:route-policy-tests/Cisco-IOS-XR-ipv4-pim-oper:route-policy-test'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.afi is not None:
                                return True

                            if self.default_table is not None:
                                return True

                            if self.ext_comm is not None:
                                return True

                            if self.extended_community_rt is not None:
                                return True

                            if self.group_address is not None:
                                return True

                            if self.group_address_xr is not None and self.group_address_xr._has_data():
                                return True

                            if self.pass_ is not None:
                                return True

                            if self.policy_name is not None:
                                return True

                            if self.safi is not None:
                                return True

                            if self.source_address is not None:
                                return True

                            if self.source_address_xr is not None and self.source_address_xr._has_data():
                                return True

                            if self.table_active is not None:
                                return True

                            if self.table_exists is not None:
                                return True

                            if self.table_name is not None:
                                return True

                            if self.vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy/Cisco-IOS-XR-ipv4-pim-oper:route-policy-tests'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.route_policy_test is not None:
                            for child_ref in self.route_policy_test:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.route_policy_statistics is not None and self.route_policy_statistics._has_data():
                        return True

                    if self.route_policy_tests is not None and self.route_policy_tests._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.RoutePolicy']['meta_info']


            class RpfSummary(object):
                """
                PIM RPF registration summary
                
                .. attribute:: default_safi
                
                	Default RPF Table SAFI
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: default_table_name
                
                	Default RPF Table Name
                	**type**\:  str
                
                .. attribute:: is_isis_mtr_configured
                
                	Is ISIS MTR configured?
                	**type**\:  bool
                
                .. attribute:: is_isis_te_configured
                
                	Is ISIS TE configured?
                	**type**\:  bool
                
                .. attribute:: is_mbgp_configured
                
                	Is MBGP configured?
                	**type**\:  bool
                
                .. attribute:: is_multipath_enabled
                
                	Is Multipath Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_interface_hash_enabled
                
                	Is Multipath Interface Hash Extension Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_hash_enabled
                
                	Is Multipath Source based Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_next_hop_hash_enabled
                
                	Is Multipath Source\-Nexthop Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_ospf_te_configured
                
                	Is OSPF TE configured?
                	**type**\:  bool
                
                .. attribute:: is_rib_convergence
                
                	RIB Convergence status
                	**type**\:  bool
                
                .. attribute:: mo_frr_configured
                
                	Is MoFRR configured?
                	**type**\:  bool
                
                .. attribute:: rib_convergence_time_left
                
                	RIB convergence time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_convergence_timeout
                
                	RIB convergence timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_mo_frr_configured
                
                	Is MoFRR RIB configured?
                	**type**\:  bool
                
                .. attribute:: rpf_registrations
                
                	RPF Registration count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	Is RUMP MuRIB enabled?
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.default_safi = None
                    self.default_table_name = None
                    self.is_isis_mtr_configured = None
                    self.is_isis_te_configured = None
                    self.is_mbgp_configured = None
                    self.is_multipath_enabled = None
                    self.is_multipath_interface_hash_enabled = None
                    self.is_multipath_source_hash_enabled = None
                    self.is_multipath_source_next_hop_hash_enabled = None
                    self.is_ospf_te_configured = None
                    self.is_rib_convergence = None
                    self.mo_frr_configured = None
                    self.rib_convergence_time_left = None
                    self.rib_convergence_timeout = None
                    self.rib_mo_frr_configured = None
                    self.rpf_registrations = None
                    self.rump_enabled = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.default_safi is not None:
                        return True

                    if self.default_table_name is not None:
                        return True

                    if self.is_isis_mtr_configured is not None:
                        return True

                    if self.is_isis_te_configured is not None:
                        return True

                    if self.is_mbgp_configured is not None:
                        return True

                    if self.is_multipath_enabled is not None:
                        return True

                    if self.is_multipath_interface_hash_enabled is not None:
                        return True

                    if self.is_multipath_source_hash_enabled is not None:
                        return True

                    if self.is_multipath_source_next_hop_hash_enabled is not None:
                        return True

                    if self.is_ospf_te_configured is not None:
                        return True

                    if self.is_rib_convergence is not None:
                        return True

                    if self.mo_frr_configured is not None:
                        return True

                    if self.rib_convergence_time_left is not None:
                        return True

                    if self.rib_convergence_timeout is not None:
                        return True

                    if self.rib_mo_frr_configured is not None:
                        return True

                    if self.rpf_registrations is not None:
                        return True

                    if self.rump_enabled is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.RpfSummary']['meta_info']


            class Interfaces(object):
                """
                PIM interfaces
                
                .. attribute:: interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Interfaces.Interface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface = YList()
                    self.interface.parent = self
                    self.interface.name = 'interface'


                class Interface(object):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.configured_override_interval = None
                        self.configured_propagation_delay = None
                        self.dr_address = Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress()
                        self.dr_address.parent = self
                        self.dr_priority = None
                        self.external_neighbor_count = None
                        self.generation_id = None
                        self.hello_expiry = None
                        self.hello_interval = None
                        self.idb_acl_name = None
                        self.idb_acl_provided = None
                        self.idb_current_count = None
                        self.idb_max_count = None
                        self.idb_oor_enabled = None
                        self.idb_threshold_count = None
                        self.interface_address = YList()
                        self.interface_address.parent = self
                        self.interface_address.name = 'interface_address'
                        self.interface_address_mask = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bidirectional_capable = None
                        self.is_enabled = None
                        self.is_proxy_capable = None
                        self.join_prune_interval = None
                        self.neighbor_count = None
                        self.neighbor_filter_name = None
                        self.override_interval = None
                        self.passive_interface = None
                        self.propagation_delay = None
                        self.prune_delay_enabled = None
                        self.virtual_interface = None


                    class DrAddress(object):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress']['meta_info']


                    class InterfaceAddress(object):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interfaces/Cisco-IOS-XR-ipv4-pim-oper:interface[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.are_we_dr is not None:
                            return True

                        if self.bfd_enabled is not None:
                            return True

                        if self.bfd_interval is not None:
                            return True

                        if self.bfd_multiplier is not None:
                            return True

                        if self.configured_override_interval is not None:
                            return True

                        if self.configured_propagation_delay is not None:
                            return True

                        if self.dr_address is not None and self.dr_address._has_data():
                            return True

                        if self.dr_priority is not None:
                            return True

                        if self.external_neighbor_count is not None:
                            return True

                        if self.generation_id is not None:
                            return True

                        if self.hello_expiry is not None:
                            return True

                        if self.hello_interval is not None:
                            return True

                        if self.idb_acl_name is not None:
                            return True

                        if self.idb_acl_provided is not None:
                            return True

                        if self.idb_current_count is not None:
                            return True

                        if self.idb_max_count is not None:
                            return True

                        if self.idb_oor_enabled is not None:
                            return True

                        if self.idb_threshold_count is not None:
                            return True

                        if self.interface_address is not None:
                            for child_ref in self.interface_address:
                                if child_ref._has_data():
                                    return True

                        if self.interface_address_mask is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_enabled is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.join_prune_interval is not None:
                            return True

                        if self.neighbor_count is not None:
                            return True

                        if self.neighbor_filter_name is not None:
                            return True

                        if self.override_interval is not None:
                            return True

                        if self.passive_interface is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.prune_delay_enabled is not None:
                            return True

                        if self.virtual_interface is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.Interfaces.Interface']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interfaces'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface is not None:
                        for child_ref in self.interface:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.Interfaces']['meta_info']


            class NetIoTunnels(object):
                """
                Tunnel information that NETIO has 
                
                .. attribute:: net_io_tunnel
                
                	PIM netio tunnel information
                	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.net_io_tunnel = YList()
                    self.net_io_tunnel.parent = self
                    self.net_io_tunnel.name = 'net_io_tunnel'


                class NetIoTunnel(object):
                    """
                    PIM netio tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.tunnel_name = None
                        self.group_address_netio = Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self.rp_address = Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress()
                        self.rp_address.parent = self
                        self.source_address = Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress()
                        self.source_address.parent = self
                        self.source_address_netio = Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self.vrf_name = None


                    class SourceAddress(object):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress']['meta_info']


                    class RpAddress(object):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress']['meta_info']


                    class SourceAddressNetio(object):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-netio'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio']['meta_info']


                    class GroupAddressNetio(object):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-netio'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio']['meta_info']

                    @property
                    def _common_path(self):
                        if self.tunnel_name is None:
                            raise YPYModelError('Key property tunnel_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:net-io-tunnels/Cisco-IOS-XR-ipv4-pim-oper:net-io-tunnel[Cisco-IOS-XR-ipv4-pim-oper:tunnel-name = ' + str(self.tunnel_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.tunnel_name is not None:
                            return True

                        if self.group_address_netio is not None and self.group_address_netio._has_data():
                            return True

                        if self.rp_address is not None and self.rp_address._has_data():
                            return True

                        if self.source_address is not None and self.source_address._has_data():
                            return True

                        if self.source_address_netio is not None and self.source_address_netio._has_data():
                            return True

                        if self.vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:net-io-tunnels'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.net_io_tunnel is not None:
                        for child_ref in self.net_io_tunnel:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.NetIoTunnels']['meta_info']


            class BidirDfStates(object):
                """
                Bidirectional PIM DF election state table
                
                .. attribute:: bidir_df_state
                
                	Bidirectional PIM DF Election Table Entry
                	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfStates.BidirDfState>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bidir_df_state = YList()
                    self.bidir_df_state.parent = self
                    self.bidir_df_state.name = 'bidir_df_state'


                class BidirDfState(object):
                    """
                    Bidirectional PIM DF Election Table Entry
                    
                    .. attribute:: election_state
                    
                    	DF Election State
                    	**type**\:  str
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: our_metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: our_metric_preference
                    
                    	MetricPreference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr>`
                    
                    .. attribute:: time_nano_seconds
                    
                    	Timer expires (nseconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: time_seconds
                    
                    	Timer expires (seconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.election_state = None
                        self.interface_name = None
                        self.our_metric = None
                        self.our_metric_preference = None
                        self.pim_interface_name = None
                        self.rp_address = None
                        self.rp_address_xr = Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self.time_nano_seconds = None
                        self.time_seconds = None


                    class RpAddressXr(object):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-states/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-state/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-states/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-state'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.election_state is not None:
                            return True

                        if self.interface_name is not None:
                            return True

                        if self.our_metric is not None:
                            return True

                        if self.our_metric_preference is not None:
                            return True

                        if self.pim_interface_name is not None:
                            return True

                        if self.rp_address is not None:
                            return True

                        if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                            return True

                        if self.time_nano_seconds is not None:
                            return True

                        if self.time_seconds is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.BidirDfStates.BidirDfState']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-states'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bidir_df_state is not None:
                        for child_ref in self.bidir_df_state:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.BidirDfStates']['meta_info']


            class Topologies(object):
                """
                PIM topology table
                
                .. attribute:: topology
                
                	PIM topology information
                	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.topology = YList()
                    self.topology.parent = self
                    self.topology.name = 'topology'


                class Topology(object):
                    """
                    PIM topology information
                    
                    .. attribute:: alive
                    
                    	Alive time in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: anycast_rp_match
                    
                    	Group matches Anycast\-RP policy
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_route_target
                    
                    	Anycast\-RP RT
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: assume_alive
                    
                    	The Assume Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: bgp_join
                    
                    	BGP C JOIN
                    	**type**\:  bool
                    
                    .. attribute:: bgpjp_time
                    
                    	BGP C JP Time
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: connected
                    
                    	Is Connected ?
                    	**type**\:  bool
                    
                    .. attribute:: customer_routing_type
                    
                    	Type of Customer Routing in the MVPN
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: dont_check_connected
                    
                    	Do we need to make the connected check on this route ?
                    	**type**\:  bool
                    
                    .. attribute:: expiry
                    
                    	When this entry expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: extranet_route
                    
                    	Is a Extranet route ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr>`
                    
                    .. attribute:: inherit_alive
                    
                    	The Inherit Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: inherit_spt
                    
                    	The Inherit SPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: is_via_lsm
                    
                    	Via LSM
                    	**type**\:  bool
                    
                    .. attribute:: jp_status
                    
                    	Join\-Prune Status
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: jp_timer
                    
                    	Join\-Prune Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: last_hop
                    
                    	Are we last hop ?
                    	**type**\:  bool
                    
                    .. attribute:: limit_reached
                    
                    	Have we throttled the creation of routes or interfaces ?
                    	**type**\:  bool
                    
                    .. attribute:: low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_active
                    
                    	Is MoFRR Active?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_backup
                    
                    	Is this Mofrr Backup?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_primary
                    
                    	Is this Mofrr Primary?
                    	**type**\:  bool
                    
                    .. attribute:: orig_src_address
                    
                    	Orig Src Address
                    	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress>`
                    
                    .. attribute:: outgoing_interface
                    
                    	Outgoing interface list
                    	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface>`
                    
                    .. attribute:: probe_alive
                    
                    	The Probe Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                    
                    .. attribute:: proxy
                    
                    	Is the RPF target a proxy?
                    	**type**\:  bool
                    
                    .. attribute:: proxy_address
                    
                    	RPF Proxy address
                    	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress>`
                    
                    .. attribute:: really_alive
                    
                    	The Really Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: register_received
                    
                    	Have registers been received for this source ?
                    	**type**\:  bool
                    
                    .. attribute:: register_received_timer
                    
                    	Register Received Timer in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: remote_source
                    
                    	MSDP told us
                    	**type**\:  bool
                    
                    .. attribute:: rib_mo_frr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rp_address
                    
                    	RP Address (If rpt)
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.RpAddress>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor>`
                    
                    .. attribute:: rpf_proxy_enabled
                    
                    	Is rpf if proxy enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: rpt
                    
                    	RPT bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpt_xr
                    
                    	Is this on the RPT ?
                    	**type**\:  bool
                    
                    .. attribute:: sa_joined
                    
                    	BGP SA join
                    	**type**\:  bool
                    
                    .. attribute:: sa_received
                    
                    	BGP SA received
                    	**type**\:  bool
                    
                    .. attribute:: sa_sent
                    
                    	BGP SA sent
                    	**type**\:  bool
                    
                    .. attribute:: secondary_rpf_interface_name
                    
                    	Secondary Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: secondary_rpf_neighbor
                    
                    	Secondary RPF Neighbor
                    	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor>`
                    
                    .. attribute:: sending_null_registers
                    
                    	Are we sending null registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: sending_registers
                    
                    	Are we sending registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: signal_sources
                    
                    	Signal Sources on route?
                    	**type**\:  bool
                    
                    .. attribute:: source_address
                    
                    	Source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr>`
                    
                    .. attribute:: spt
                    
                    	Is this on the SPT ?
                    	**type**\:  bool
                    
                    .. attribute:: suppress_registers
                    
                    	When the Null register probe expires
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: vxlan
                    
                    	Is this VXLAN?
                    	**type**\:  bool
                    
                    .. attribute:: wildcard
                    
                    	WC \-Wildcard
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.alive = None
                        self.anycast_rp_match = None
                        self.anycast_rp_route_target = None
                        self.assume_alive = None
                        self.bgp_join = None
                        self.bgpjp_time = None
                        self.connected = None
                        self.customer_routing_type = None
                        self.dont_check_connected = None
                        self.expiry = None
                        self.extranet_route = None
                        self.group_address = None
                        self.group_address_xr = Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self.inherit_alive = None
                        self.inherit_spt = None
                        self.is_via_lsm = None
                        self.jp_status = None
                        self.jp_timer = None
                        self.last_hop = None
                        self.limit_reached = None
                        self.low_memory = None
                        self.mofrr_active = None
                        self.mofrr_backup = None
                        self.mofrr_enabled = None
                        self.mofrr_primary = None
                        self.orig_src_address = Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress()
                        self.orig_src_address.parent = self
                        self.outgoing_interface = YList()
                        self.outgoing_interface.parent = self
                        self.outgoing_interface.name = 'outgoing_interface'
                        self.probe_alive = None
                        self.protocol = None
                        self.proxy = None
                        self.proxy_address = Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress()
                        self.proxy_address.parent = self
                        self.really_alive = None
                        self.register_received = None
                        self.register_received_timer = None
                        self.remote_source = None
                        self.rib_mo_frr_enabled = None
                        self.rp_address = Pim.Standby.DefaultContext.Topologies.Topology.RpAddress()
                        self.rp_address.parent = self
                        self.rpf_drop = None
                        self.rpf_extranet = None
                        self.rpf_interface_name = None
                        self.rpf_neighbor = Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self.rpf_proxy_enabled = None
                        self.rpf_root = Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot()
                        self.rpf_root.parent = self
                        self.rpf_safi = None
                        self.rpf_table_name = None
                        self.rpf_vrf_name = None
                        self.rpt = None
                        self.rpt_xr = None
                        self.sa_joined = None
                        self.sa_received = None
                        self.sa_sent = None
                        self.secondary_rpf_interface_name = None
                        self.secondary_rpf_neighbor = Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor()
                        self.secondary_rpf_neighbor.parent = self
                        self.sending_null_registers = None
                        self.sending_registers = None
                        self.signal_sources = None
                        self.source_address = None
                        self.source_address_xr = Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self.spt = None
                        self.suppress_registers = None
                        self.uptime = None
                        self.vxlan = None
                        self.wildcard = None


                    class GroupAddressXr(object):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr']['meta_info']


                    class SourceAddressXr(object):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr']['meta_info']


                    class RpAddress(object):
                        """
                        RP Address (If rpt)
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Topologies.Topology.RpAddress']['meta_info']


                    class RpfNeighbor(object):
                        """
                        RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor']['meta_info']


                    class SecondaryRpfNeighbor(object):
                        """
                        Secondary RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:secondary-rpf-neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor']['meta_info']


                    class RpfRoot(object):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:rpf-root'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot']['meta_info']


                    class ProxyAddress(object):
                        """
                        RPF Proxy address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:proxy-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress']['meta_info']


                    class OrigSrcAddress(object):
                        """
                        Orig Src Address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:orig-src-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress']['meta_info']


                    class OutgoingInterface(object):
                        """
                        Outgoing interface list
                        
                        .. attribute:: admin_boundary
                        
                        	Is this an administrative boundary ?
                        	**type**\:  bool
                        
                        .. attribute:: assert_timer
                        
                        	Assert Timer in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: assert_winner
                        
                        	Assert Winner
                        	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner>`
                        
                        .. attribute:: bgp_c_mcast_join
                        
                        	BGP C\-Mcast join
                        	**type**\:  bool
                        
                        .. attribute:: bgp_c_mcast_prune_delay_timer
                        
                        	BGP C\-MCAST Prune Suppression in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: data_mdt_join
                        
                        	Data MDT join
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	Expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: extranet_interface
                        
                        	Is this an Extranet Interface ?
                        	**type**\:  bool
                        
                        .. attribute:: forwarding_state
                        
                        	Forward or Prune
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: igmp_membership
                        
                        	IGMP membership
                        	**type**\:  bool
                        
                        .. attribute:: immediate_state
                        
                        	Immediate fwding state
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_interest_info
                        
                        	Internal Interest
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_state
                        
                        	Join\-Prune State
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer (secs)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: local_mdt_join
                        
                        	Default MDT Join
                        	**type**\:  bool
                        
                        .. attribute:: local_members
                        
                        	Local Information
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: mdt_safi_join
                        
                        	MDT Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mldp_inband_mdt
                        
                        	MLDP Inband MDT interface
                        	**type**\:  bool
                        
                        .. attribute:: mldp_stale
                        
                        	OLE is stale
                        	**type**\:  bool
                        
                        .. attribute:: mvp_nv6_safi_join
                        
                        	MVPN IPv6 Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mvpn_safi_join
                        
                        	MVPN Safi join
                        	**type**\:  bool
                        
                        .. attribute:: sa_prune
                        
                        	BGP SA Prune state
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vrf_name
                        
                        	VRF which physically owns
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.admin_boundary = None
                            self.assert_timer = None
                            self.assert_winner = Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner()
                            self.assert_winner.parent = self
                            self.bgp_c_mcast_join = None
                            self.bgp_c_mcast_prune_delay_timer = None
                            self.data_mdt_join = None
                            self.expiry = None
                            self.extranet_interface = None
                            self.forwarding_state = None
                            self.igmp_membership = None
                            self.immediate_state = None
                            self.interface_name = None
                            self.internal_interest_info = None
                            self.jp_state = None
                            self.jp_timer = None
                            self.last_hop = None
                            self.local_mdt_join = None
                            self.local_members = None
                            self.mdt_safi_join = None
                            self.mldp_inband_mdt = None
                            self.mldp_stale = None
                            self.mvp_nv6_safi_join = None
                            self.mvpn_safi_join = None
                            self.sa_prune = None
                            self.uptime = None
                            self.vrf_name = None


                        class AssertWinner(object):
                            """
                            Assert Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:outgoing-interface/Cisco-IOS-XR-ipv4-pim-oper:assert-winner'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:outgoing-interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.admin_boundary is not None:
                                return True

                            if self.assert_timer is not None:
                                return True

                            if self.assert_winner is not None and self.assert_winner._has_data():
                                return True

                            if self.bgp_c_mcast_join is not None:
                                return True

                            if self.bgp_c_mcast_prune_delay_timer is not None:
                                return True

                            if self.data_mdt_join is not None:
                                return True

                            if self.expiry is not None:
                                return True

                            if self.extranet_interface is not None:
                                return True

                            if self.forwarding_state is not None:
                                return True

                            if self.igmp_membership is not None:
                                return True

                            if self.immediate_state is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.internal_interest_info is not None:
                                return True

                            if self.jp_state is not None:
                                return True

                            if self.jp_timer is not None:
                                return True

                            if self.last_hop is not None:
                                return True

                            if self.local_mdt_join is not None:
                                return True

                            if self.local_members is not None:
                                return True

                            if self.mdt_safi_join is not None:
                                return True

                            if self.mldp_inband_mdt is not None:
                                return True

                            if self.mldp_stale is not None:
                                return True

                            if self.mvp_nv6_safi_join is not None:
                                return True

                            if self.mvpn_safi_join is not None:
                                return True

                            if self.sa_prune is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            if self.vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.alive is not None:
                            return True

                        if self.anycast_rp_match is not None:
                            return True

                        if self.anycast_rp_route_target is not None:
                            return True

                        if self.assume_alive is not None:
                            return True

                        if self.bgp_join is not None:
                            return True

                        if self.bgpjp_time is not None:
                            return True

                        if self.connected is not None:
                            return True

                        if self.customer_routing_type is not None:
                            return True

                        if self.dont_check_connected is not None:
                            return True

                        if self.expiry is not None:
                            return True

                        if self.extranet_route is not None:
                            return True

                        if self.group_address is not None:
                            return True

                        if self.group_address_xr is not None and self.group_address_xr._has_data():
                            return True

                        if self.inherit_alive is not None:
                            return True

                        if self.inherit_spt is not None:
                            return True

                        if self.is_via_lsm is not None:
                            return True

                        if self.jp_status is not None:
                            return True

                        if self.jp_timer is not None:
                            return True

                        if self.last_hop is not None:
                            return True

                        if self.limit_reached is not None:
                            return True

                        if self.low_memory is not None:
                            return True

                        if self.mofrr_active is not None:
                            return True

                        if self.mofrr_backup is not None:
                            return True

                        if self.mofrr_enabled is not None:
                            return True

                        if self.mofrr_primary is not None:
                            return True

                        if self.orig_src_address is not None and self.orig_src_address._has_data():
                            return True

                        if self.outgoing_interface is not None:
                            for child_ref in self.outgoing_interface:
                                if child_ref._has_data():
                                    return True

                        if self.probe_alive is not None:
                            return True

                        if self.protocol is not None:
                            return True

                        if self.proxy is not None:
                            return True

                        if self.proxy_address is not None and self.proxy_address._has_data():
                            return True

                        if self.really_alive is not None:
                            return True

                        if self.register_received is not None:
                            return True

                        if self.register_received_timer is not None:
                            return True

                        if self.remote_source is not None:
                            return True

                        if self.rib_mo_frr_enabled is not None:
                            return True

                        if self.rp_address is not None and self.rp_address._has_data():
                            return True

                        if self.rpf_drop is not None:
                            return True

                        if self.rpf_extranet is not None:
                            return True

                        if self.rpf_interface_name is not None:
                            return True

                        if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                            return True

                        if self.rpf_proxy_enabled is not None:
                            return True

                        if self.rpf_root is not None and self.rpf_root._has_data():
                            return True

                        if self.rpf_safi is not None:
                            return True

                        if self.rpf_table_name is not None:
                            return True

                        if self.rpf_vrf_name is not None:
                            return True

                        if self.rpt is not None:
                            return True

                        if self.rpt_xr is not None:
                            return True

                        if self.sa_joined is not None:
                            return True

                        if self.sa_received is not None:
                            return True

                        if self.sa_sent is not None:
                            return True

                        if self.secondary_rpf_interface_name is not None:
                            return True

                        if self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor._has_data():
                            return True

                        if self.sending_null_registers is not None:
                            return True

                        if self.sending_registers is not None:
                            return True

                        if self.signal_sources is not None:
                            return True

                        if self.source_address is not None:
                            return True

                        if self.source_address_xr is not None and self.source_address_xr._has_data():
                            return True

                        if self.spt is not None:
                            return True

                        if self.suppress_registers is not None:
                            return True

                        if self.uptime is not None:
                            return True

                        if self.vxlan is not None:
                            return True

                        if self.wildcard is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.Topologies.Topology']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.topology is not None:
                        for child_ref in self.topology:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.Topologies']['meta_info']


            class BgpAfs(object):
                """
                PIM BGP SAFI table
                
                .. attribute:: bgp_af
                
                	PIM BGP SAFI information
                	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BgpAfs.BgpAf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bgp_af = YList()
                    self.bgp_af.parent = self
                    self.bgp_af.name = 'bgp_af'


                class BgpAf(object):
                    """
                    PIM BGP SAFI information
                    
                    .. attribute:: extranet_path_count
                    
                    	Count of dependent extranet paths
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group
                    
                    	Group address
                    	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group>`
                    
                    .. attribute:: group_address
                    
                    	Group IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: is_bgp_added
                    
                    	SAFI learnt from BGP
                    	**type**\:  bool
                    
                    .. attribute:: next_hop
                    
                    	Next hop address
                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop>`
                    
                    .. attribute:: route_distinguisher
                    
                    	Router ID
                    	**type**\:  str
                    
                    	**length:** 0..256
                    
                    .. attribute:: source
                    
                    	Source address
                    	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source>`
                    
                    .. attribute:: source_address
                    
                    	Source IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.extranet_path_count = None
                        self.group = Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group()
                        self.group.parent = self
                        self.group_address = None
                        self.is_bgp_added = None
                        self.next_hop = Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop()
                        self.next_hop.parent = self
                        self.route_distinguisher = None
                        self.source = Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source()
                        self.source.parent = self
                        self.source_address = None


                    class Source(object):
                        """
                        Source address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs/Cisco-IOS-XR-ipv4-pim-oper:bgp-af/Cisco-IOS-XR-ipv4-pim-oper:source'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source']['meta_info']


                    class Group(object):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs/Cisco-IOS-XR-ipv4-pim-oper:bgp-af/Cisco-IOS-XR-ipv4-pim-oper:group'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group']['meta_info']


                    class NextHop(object):
                        """
                        Next hop address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs/Cisco-IOS-XR-ipv4-pim-oper:bgp-af/Cisco-IOS-XR-ipv4-pim-oper:next-hop'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs/Cisco-IOS-XR-ipv4-pim-oper:bgp-af'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.extranet_path_count is not None:
                            return True

                        if self.group is not None and self.group._has_data():
                            return True

                        if self.group_address is not None:
                            return True

                        if self.is_bgp_added is not None:
                            return True

                        if self.next_hop is not None and self.next_hop._has_data():
                            return True

                        if self.route_distinguisher is not None:
                            return True

                        if self.source is not None and self.source._has_data():
                            return True

                        if self.source_address is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.BgpAfs.BgpAf']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bgp_af is not None:
                        for child_ref in self.bgp_af:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.BgpAfs']['meta_info']


            class AutoRp(object):
                """
                PIM Auto\-RP information
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:auto-rp'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.AutoRp']['meta_info']


            class TopologyInterfaceFlagRouteCounts(object):
                """
                Route count for topology with interface flag set
                
                .. attribute:: topology_interface_flag_route_count
                
                	Route count for topology with interface flag set
                	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.topology_interface_flag_route_count = YList()
                    self.topology_interface_flag_route_count.parent = self
                    self.topology_interface_flag_route_count.name = 'topology_interface_flag_route_count'


                class TopologyInterfaceFlagRouteCount(object):
                    """
                    Route count for topology with interface flag
                    set
                    
                    .. attribute:: interface_flag  <key>
                    
                    	Interface flag
                    	**type**\:   :py:class:`PimTopologyInterfaceFlagEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlagEnum>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_flag = None
                        self.active_group_ranges = None
                        self.group_address = Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self.group_ranges = None
                        self.groute_count = None
                        self.is_node_low_memory = None
                        self.sg_route_count = None
                        self.sgr_route_count = None


                    class GroupAddress(object):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_flag is None:
                            raise YPYModelError('Key property interface_flag is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-interface-flag-route-counts/Cisco-IOS-XR-ipv4-pim-oper:topology-interface-flag-route-count[Cisco-IOS-XR-ipv4-pim-oper:interface-flag = ' + str(self.interface_flag) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_flag is not None:
                            return True

                        if self.active_group_ranges is not None:
                            return True

                        if self.group_address is not None and self.group_address._has_data():
                            return True

                        if self.group_ranges is not None:
                            return True

                        if self.groute_count is not None:
                            return True

                        if self.is_node_low_memory is not None:
                            return True

                        if self.sg_route_count is not None:
                            return True

                        if self.sgr_route_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-interface-flag-route-counts'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.topology_interface_flag_route_count is not None:
                        for child_ref in self.topology_interface_flag_route_count:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts']['meta_info']


            class GroupMapSources(object):
                """
                PIM group\-mapping with source information
                
                .. attribute:: group_map_source
                
                	PIM Group Mapping Entry with source information
                	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.group_map_source = YList()
                    self.group_map_source.parent = self
                    self.group_map_source.name = 'group_map_source'


                class GroupMapSource(object):
                    """
                    PIM Group Mapping Entry with source information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                    
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: priority
                    
                    	RP Priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocolEnum>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation>`
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.client = None
                        self.expires = None
                        self.group_map_information = Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self.holdtime = None
                        self.prefix = None
                        self.prefix_length = None
                        self.priority = None
                        self.protocol = None
                        self.rp_address = None
                        self.source_of_information = Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self.uptime = None


                    class SourceOfInformation(object):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-source/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation']['meta_info']


                    class GroupMapInformation(object):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.group_count = None
                            self.is_override = None
                            self.is_used = None
                            self.mrib_active = None
                            self.prefix = Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.priority = None
                            self.protocol = None
                            self.rp_address = Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self


                        class Prefix(object):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-source/Cisco-IOS-XR-ipv4-pim-oper:group-map-information/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix']['meta_info']


                        class RpAddress(object):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-source/Cisco-IOS-XR-ipv4-pim-oper:group-map-information/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-source/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.group_count is not None:
                                return True

                            if self.is_override is not None:
                                return True

                            if self.is_used is not None:
                                return True

                            if self.mrib_active is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-source'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.client is not None:
                            return True

                        if self.expires is not None:
                            return True

                        if self.group_map_information is not None and self.group_map_information._has_data():
                            return True

                        if self.holdtime is not None:
                            return True

                        if self.prefix is not None:
                            return True

                        if self.prefix_length is not None:
                            return True

                        if self.priority is not None:
                            return True

                        if self.protocol is not None:
                            return True

                        if self.rp_address is not None:
                            return True

                        if self.source_of_information is not None and self.source_of_information._has_data():
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.group_map_source is not None:
                        for child_ref in self.group_map_source:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.GroupMapSources']['meta_info']


            class TrafficCounters(object):
                """
                PIM message traffic counters
                
                .. attribute:: boundary_acl_rx_drop
                
                	Inc. JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: boundary_acl_tx_drop
                
                	Out JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_error
                
                	Checksum errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: elapsed_time
                
                	Running time for counters in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: format_error
                
                	Malformed packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert
                
                	Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert_batched
                
                	Batched Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_bsr_message
                
                	Input BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_candidate_rp_advertisement
                
                	Input Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_data_register
                
                	Data Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_df_election
                
                	DF Election packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_ecmp_redirect
                
                	Input Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_hello
                
                	Hello packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_jp
                
                	Join Prune packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb_error
                
                	No IDB for intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_pim_error
                
                	PIM Disabled on intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_error
                
                	No VRF for idb error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_null_register
                
                	Null Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim_version_error
                
                	Invalid PIM version error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_register_stop
                
                	Register Stop packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: inputs
                
                	Packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_destination_packets
                
                	Control Packets with Invalid Destination
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_join_prunes
                
                	PIM invalid Join/Prunes received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_registers
                
                	PIM invalid registers received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_local_source_address
                
                	Data MDT Join msgs dropped due to local source addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_idb
                
                	Data MDT Join msgs dropped due to idb missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_vrf
                
                	Data MDT Join msgs dropped due to vrf missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_null_local_address
                
                	Data MDT Join msgs dropped due to null local addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_bad_type
                
                	Data MDT TLV bad type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_received
                
                	Data MDT Join Msgs received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_sent
                
                	Data MDT Join Msgs sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_joins_drop_multiple_encapsulation
                
                	MDT Join msgs dropped due to multiple Encap limitation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_send_queue_full
                
                	Packets dropped since mdt send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_socket_error
                
                	MDT Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_invalid_lsm_identifier
                
                	 Invalid LSM ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_mdt_socket_connection
                
                	Packets dropped since no mdt socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_source_address
                
                	Packets dropped since no source address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: non_supported_packets
                
                	PIM non supported pckets
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert
                
                	Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert_batched
                
                	Batched Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_bsr_message
                
                	Output BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_candidate_rp_advertisement
                
                	Output Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_data_register
                
                	Data Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_df_election
                
                	DF Election packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_ecmp_redirect
                
                	Output Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello
                
                	Hello packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello_bytes
                
                	Output Hello Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_join_group
                
                	Output Join Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_join_prune_bytes
                
                	Output JP Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_jp
                
                	Join Prune packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_loop_error
                
                	Output on loopback error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_null_register
                
                	Null Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_prune_group
                
                	Output Prune Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_register_stop
                
                	Register Stop packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: outputs
                
                	Packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_dequeued
                
                	Packets Dequeued per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_enqueued
                
                	Packets Enqueued per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_packman_error
                
                	Packets Dropped due to Pakman Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue
                
                	Packet queue state and statistics
                	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TrafficCounters.PacketQueue>`
                
                .. attribute:: packet_queue_last_clear
                
                	Time in seconds since the last clear of all packet queues stats
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: packet_queue_length
                
                	Packet Queue Length per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue_size
                
                	Packet Queue Size per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_read_socket_error
                
                	Packet Read Socket Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_tail_drop
                
                	Packet Tail Drop per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_standby
                
                	Packets Dropped due to Standby Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pakman_error
                
                	Pakman packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_queue_full
                
                	Packets dropped since send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_error
                
                	Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_packets_error
                
                	Packets received in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: truncated_pim_packets
                
                	Packets dropped due to truncated Joins or Prunes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.boundary_acl_rx_drop = None
                    self.boundary_acl_tx_drop = None
                    self.checksum_error = None
                    self.elapsed_time = None
                    self.format_error = None
                    self.input_assert = None
                    self.input_assert_batched = None
                    self.input_bsr_message = None
                    self.input_candidate_rp_advertisement = None
                    self.input_data_register = None
                    self.input_df_election = None
                    self.input_ecmp_redirect = None
                    self.input_hello = None
                    self.input_jp = None
                    self.input_no_idb_error = None
                    self.input_no_pim_error = None
                    self.input_no_vrf_error = None
                    self.input_null_register = None
                    self.input_pim_version_error = None
                    self.input_register_stop = None
                    self.inputs = None
                    self.invalid_destination_packets = None
                    self.invalid_join_prunes = None
                    self.invalid_registers = None
                    self.mdt_drop_local_source_address = None
                    self.mdt_drop_no_idb = None
                    self.mdt_drop_no_vrf = None
                    self.mdt_drop_null_local_address = None
                    self.mdt_join_bad_type = None
                    self.mdt_join_tlv_received = None
                    self.mdt_join_tlv_sent = None
                    self.mdt_joins_drop_multiple_encapsulation = None
                    self.mdt_send_queue_full = None
                    self.mdt_socket_error = None
                    self.mldp_mdt_invalid_lsm_identifier = None
                    self.no_mdt_socket_connection = None
                    self.no_socket_connection = None
                    self.no_source_address = None
                    self.non_supported_packets = None
                    self.output_assert = None
                    self.output_assert_batched = None
                    self.output_bsr_message = None
                    self.output_candidate_rp_advertisement = None
                    self.output_data_register = None
                    self.output_df_election = None
                    self.output_ecmp_redirect = None
                    self.output_hello = None
                    self.output_hello_bytes = None
                    self.output_join_group = None
                    self.output_join_prune_bytes = None
                    self.output_jp = None
                    self.output_loop_error = None
                    self.output_null_register = None
                    self.output_prune_group = None
                    self.output_register_stop = None
                    self.outputs = None
                    self.packet_dequeued = YLeafList()
                    self.packet_dequeued.parent = self
                    self.packet_dequeued.name = 'packet_dequeued'
                    self.packet_enqueued = YLeafList()
                    self.packet_enqueued.parent = self
                    self.packet_enqueued.name = 'packet_enqueued'
                    self.packet_packman_error = None
                    self.packet_queue = YList()
                    self.packet_queue.parent = self
                    self.packet_queue.name = 'packet_queue'
                    self.packet_queue_last_clear = None
                    self.packet_queue_length = YLeafList()
                    self.packet_queue_length.parent = self
                    self.packet_queue_length.name = 'packet_queue_length'
                    self.packet_queue_size = YLeafList()
                    self.packet_queue_size.parent = self
                    self.packet_queue_size.name = 'packet_queue_size'
                    self.packet_read_socket_error = None
                    self.packet_tail_drop = YLeafList()
                    self.packet_tail_drop.parent = self
                    self.packet_tail_drop.name = 'packet_tail_drop'
                    self.packets_standby = None
                    self.pakman_error = None
                    self.send_queue_full = None
                    self.socket_error = None
                    self.standby_packets_error = None
                    self.truncated_pim_packets = None


                class PacketQueue(object):
                    """
                    Packet queue state and statistics
                    
                    .. attribute:: packet_queue_priority
                    
                    	Priority of this packet queue
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_state
                    
                    	State of the queue
                    	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState>`
                    
                    .. attribute:: packet_queue_stats
                    
                    	Statistics about the queue
                    	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.packet_queue_priority = None
                        self.packet_queue_state = Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState()
                        self.packet_queue_state.parent = self
                        self.packet_queue_stats = Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats()
                        self.packet_queue_stats.parent = self


                    class PacketQueueState(object):
                        """
                        State of the queue
                        
                        .. attribute:: max_queue_size
                        
                        	Maximum size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_bytes
                        
                        	Size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_packets
                        
                        	Size of queue in number of packets
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.max_queue_size = None
                            self.queue_size_bytes = None
                            self.queue_size_packets = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:traffic-counters/Cisco-IOS-XR-ipv4-pim-oper:packet-queue/Cisco-IOS-XR-ipv4-pim-oper:packet-queue-state'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.max_queue_size is not None:
                                return True

                            if self.queue_size_bytes is not None:
                                return True

                            if self.queue_size_packets is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState']['meta_info']


                    class PacketQueueStats(object):
                        """
                        Statistics about the queue
                        
                        .. attribute:: dequeued_packets
                        
                        	Total number of packets dequeued from this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: enqueued_packets
                        
                        	Total number of packets enqueued to this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: high_water_mark_bytes
                        
                        	Highest number of bytes enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: high_water_mark_packets
                        
                        	Highest number of packets enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tail_drops
                        
                        	Number packets dropped from this queue due to max size
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dequeued_packets = None
                            self.enqueued_packets = None
                            self.high_water_mark_bytes = None
                            self.high_water_mark_packets = None
                            self.tail_drops = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:traffic-counters/Cisco-IOS-XR-ipv4-pim-oper:packet-queue/Cisco-IOS-XR-ipv4-pim-oper:packet-queue-stats'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dequeued_packets is not None:
                                return True

                            if self.enqueued_packets is not None:
                                return True

                            if self.high_water_mark_bytes is not None:
                                return True

                            if self.high_water_mark_packets is not None:
                                return True

                            if self.tail_drops is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:traffic-counters/Cisco-IOS-XR-ipv4-pim-oper:packet-queue'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.packet_queue_priority is not None:
                            return True

                        if self.packet_queue_state is not None and self.packet_queue_state._has_data():
                            return True

                        if self.packet_queue_stats is not None and self.packet_queue_stats._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.TrafficCounters.PacketQueue']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:traffic-counters'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.boundary_acl_rx_drop is not None:
                        return True

                    if self.boundary_acl_tx_drop is not None:
                        return True

                    if self.checksum_error is not None:
                        return True

                    if self.elapsed_time is not None:
                        return True

                    if self.format_error is not None:
                        return True

                    if self.input_assert is not None:
                        return True

                    if self.input_assert_batched is not None:
                        return True

                    if self.input_bsr_message is not None:
                        return True

                    if self.input_candidate_rp_advertisement is not None:
                        return True

                    if self.input_data_register is not None:
                        return True

                    if self.input_df_election is not None:
                        return True

                    if self.input_ecmp_redirect is not None:
                        return True

                    if self.input_hello is not None:
                        return True

                    if self.input_jp is not None:
                        return True

                    if self.input_no_idb_error is not None:
                        return True

                    if self.input_no_pim_error is not None:
                        return True

                    if self.input_no_vrf_error is not None:
                        return True

                    if self.input_null_register is not None:
                        return True

                    if self.input_pim_version_error is not None:
                        return True

                    if self.input_register_stop is not None:
                        return True

                    if self.inputs is not None:
                        return True

                    if self.invalid_destination_packets is not None:
                        return True

                    if self.invalid_join_prunes is not None:
                        return True

                    if self.invalid_registers is not None:
                        return True

                    if self.mdt_drop_local_source_address is not None:
                        return True

                    if self.mdt_drop_no_idb is not None:
                        return True

                    if self.mdt_drop_no_vrf is not None:
                        return True

                    if self.mdt_drop_null_local_address is not None:
                        return True

                    if self.mdt_join_bad_type is not None:
                        return True

                    if self.mdt_join_tlv_received is not None:
                        return True

                    if self.mdt_join_tlv_sent is not None:
                        return True

                    if self.mdt_joins_drop_multiple_encapsulation is not None:
                        return True

                    if self.mdt_send_queue_full is not None:
                        return True

                    if self.mdt_socket_error is not None:
                        return True

                    if self.mldp_mdt_invalid_lsm_identifier is not None:
                        return True

                    if self.no_mdt_socket_connection is not None:
                        return True

                    if self.no_socket_connection is not None:
                        return True

                    if self.no_source_address is not None:
                        return True

                    if self.non_supported_packets is not None:
                        return True

                    if self.output_assert is not None:
                        return True

                    if self.output_assert_batched is not None:
                        return True

                    if self.output_bsr_message is not None:
                        return True

                    if self.output_candidate_rp_advertisement is not None:
                        return True

                    if self.output_data_register is not None:
                        return True

                    if self.output_df_election is not None:
                        return True

                    if self.output_ecmp_redirect is not None:
                        return True

                    if self.output_hello is not None:
                        return True

                    if self.output_hello_bytes is not None:
                        return True

                    if self.output_join_group is not None:
                        return True

                    if self.output_join_prune_bytes is not None:
                        return True

                    if self.output_jp is not None:
                        return True

                    if self.output_loop_error is not None:
                        return True

                    if self.output_null_register is not None:
                        return True

                    if self.output_prune_group is not None:
                        return True

                    if self.output_register_stop is not None:
                        return True

                    if self.outputs is not None:
                        return True

                    if self.packet_dequeued is not None:
                        for child in self.packet_dequeued:
                            if child is not None:
                                return True

                    if self.packet_enqueued is not None:
                        for child in self.packet_enqueued:
                            if child is not None:
                                return True

                    if self.packet_packman_error is not None:
                        return True

                    if self.packet_queue is not None:
                        for child_ref in self.packet_queue:
                            if child_ref._has_data():
                                return True

                    if self.packet_queue_last_clear is not None:
                        return True

                    if self.packet_queue_length is not None:
                        for child in self.packet_queue_length:
                            if child is not None:
                                return True

                    if self.packet_queue_size is not None:
                        for child in self.packet_queue_size:
                            if child is not None:
                                return True

                    if self.packet_read_socket_error is not None:
                        return True

                    if self.packet_tail_drop is not None:
                        for child in self.packet_tail_drop:
                            if child is not None:
                                return True

                    if self.packets_standby is not None:
                        return True

                    if self.pakman_error is not None:
                        return True

                    if self.send_queue_full is not None:
                        return True

                    if self.socket_error is not None:
                        return True

                    if self.standby_packets_error is not None:
                        return True

                    if self.truncated_pim_packets is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.TrafficCounters']['meta_info']


            class GroupMapRpfs(object):
                """
                PIM group mapping information
                
                .. attribute:: group_map_rpf
                
                	PIM group mapping entry
                	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.group_map_rpf = YList()
                    self.group_map_rpf.parent = self
                    self.group_map_rpf.name = 'group_map_rpf'


                class GroupMapRpf(object):
                    """
                    PIM group mapping entry
                    
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\:  bool
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocolEnum>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_priority
                    
                    	RP priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.are_we_rp = None
                        self.client = None
                        self.group_map_information = Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self.prefix = None
                        self.prefix_length = None
                        self.protocol = None
                        self.rp_address = None
                        self.rp_priority = None
                        self.rpf_interface_name = None
                        self.rpf_neighbor = Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self.rpf_vrf_name = None


                    class RpfNeighbor(object):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor']['meta_info']


                    class GroupMapInformation(object):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.group_count = None
                            self.is_override = None
                            self.is_used = None
                            self.mrib_active = None
                            self.prefix = Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.priority = None
                            self.protocol = None
                            self.rp_address = Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self


                        class Prefix(object):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf/Cisco-IOS-XR-ipv4-pim-oper:group-map-information/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix']['meta_info']


                        class RpAddress(object):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf/Cisco-IOS-XR-ipv4-pim-oper:group-map-information/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.group_count is not None:
                                return True

                            if self.is_override is not None:
                                return True

                            if self.is_used is not None:
                                return True

                            if self.mrib_active is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.are_we_rp is not None:
                            return True

                        if self.client is not None:
                            return True

                        if self.group_map_information is not None and self.group_map_information._has_data():
                            return True

                        if self.prefix is not None:
                            return True

                        if self.prefix_length is not None:
                            return True

                        if self.protocol is not None:
                            return True

                        if self.rp_address is not None:
                            return True

                        if self.rp_priority is not None:
                            return True

                        if self.rpf_interface_name is not None:
                            return True

                        if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                            return True

                        if self.rpf_vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.group_map_rpf is not None:
                        for child_ref in self.group_map_rpf:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.GroupMapRpfs']['meta_info']


            class Summary(object):
                """
                PIM summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bsr_candidate_rp_set_count = None
                    self.bsr_candidate_rp_set_limit = None
                    self.bsr_candidate_rp_set_threshold = None
                    self.bsr_range_threshold = None
                    self.bsr_ranges_count = None
                    self.bsr_ranges_limit = None
                    self.global_auto_rp_ranges_limit = None
                    self.global_bsr_candidate_rp_set_count = None
                    self.global_bsr_candidate_rp_set_limit = None
                    self.global_bsr_candidate_rp_set_threshold = None
                    self.global_bsr_ranges_count = None
                    self.global_bsr_ranges_limit = None
                    self.global_bsr_ranges_threshold = None
                    self.global_register_limit = None
                    self.is_bsr_ranges_threshold_reached = None
                    self.is_global_auto_rp_ranges_limit_reached = None
                    self.is_global_bsr_ranges_limit_reached = None
                    self.is_global_register_limit_reached = None
                    self.is_global_route_limit_reached = None
                    self.is_global_rxi_limit_reached = None
                    self.is_maximum_enforcement_disabled = None
                    self.is_node_low_memory = None
                    self.is_ranges_limit_reached = None
                    self.is_route_limit_reached = None
                    self.ranges_count = None
                    self.ranges_limit = None
                    self.ranges_threshold = None
                    self.register_count = None
                    self.register_limit = None
                    self.register_limit_reached = None
                    self.register_threshold = None
                    self.route_count = None
                    self.route_limit = None
                    self.route_low_water_mark = None
                    self.route_threshold = None
                    self.rxi_limit_reached = None
                    self.rxi_low_water_mark = None
                    self.topology_interface_state_count = None
                    self.topology_interface_state_limit = None
                    self.topology_interface_state_threshold = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bsr_candidate_rp_set_count is not None:
                        return True

                    if self.bsr_candidate_rp_set_limit is not None:
                        return True

                    if self.bsr_candidate_rp_set_threshold is not None:
                        return True

                    if self.bsr_range_threshold is not None:
                        return True

                    if self.bsr_ranges_count is not None:
                        return True

                    if self.bsr_ranges_limit is not None:
                        return True

                    if self.global_auto_rp_ranges_limit is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_count is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_limit is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_threshold is not None:
                        return True

                    if self.global_bsr_ranges_count is not None:
                        return True

                    if self.global_bsr_ranges_limit is not None:
                        return True

                    if self.global_bsr_ranges_threshold is not None:
                        return True

                    if self.global_register_limit is not None:
                        return True

                    if self.is_bsr_ranges_threshold_reached is not None:
                        return True

                    if self.is_global_auto_rp_ranges_limit_reached is not None:
                        return True

                    if self.is_global_bsr_ranges_limit_reached is not None:
                        return True

                    if self.is_global_register_limit_reached is not None:
                        return True

                    if self.is_global_route_limit_reached is not None:
                        return True

                    if self.is_global_rxi_limit_reached is not None:
                        return True

                    if self.is_maximum_enforcement_disabled is not None:
                        return True

                    if self.is_node_low_memory is not None:
                        return True

                    if self.is_ranges_limit_reached is not None:
                        return True

                    if self.is_route_limit_reached is not None:
                        return True

                    if self.ranges_count is not None:
                        return True

                    if self.ranges_limit is not None:
                        return True

                    if self.ranges_threshold is not None:
                        return True

                    if self.register_count is not None:
                        return True

                    if self.register_limit is not None:
                        return True

                    if self.register_limit_reached is not None:
                        return True

                    if self.register_threshold is not None:
                        return True

                    if self.route_count is not None:
                        return True

                    if self.route_limit is not None:
                        return True

                    if self.route_low_water_mark is not None:
                        return True

                    if self.route_threshold is not None:
                        return True

                    if self.rxi_limit_reached is not None:
                        return True

                    if self.rxi_low_water_mark is not None:
                        return True

                    if self.topology_interface_state_count is not None:
                        return True

                    if self.topology_interface_state_limit is not None:
                        return True

                    if self.topology_interface_state_threshold is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.Summary']['meta_info']


            class Gre(object):
                """
                GRE information
                
                .. attribute:: gre_hashes
                
                	GRE hash
                	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreHashes>`
                
                .. attribute:: gre_next_hops
                
                	GRE destination neighbor table
                	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.gre_hashes = Pim.Standby.DefaultContext.Gre.GreHashes()
                    self.gre_hashes.parent = self
                    self.gre_next_hops = Pim.Standby.DefaultContext.Gre.GreNextHops()
                    self.gre_next_hops.parent = self


                class GreHashes(object):
                    """
                    GRE hash
                    
                    .. attribute:: gre_hash
                    
                    	PIM GRE Hashed Underlying Interface
                    	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreHashes.GreHash>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.gre_hash = YList()
                        self.gre_hash.parent = self
                        self.gre_hash.name = 'gre_hash'


                    class GreHash(object):
                        """
                        PIM GRE Hashed Underlying Interface
                        
                        .. attribute:: destination_address  <key>
                        
                        	Destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: ifname  <key>
                        
                        	GRE Tunnel Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: source_address  <key>
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: next_hop_interface
                        
                        	Next hop neighbor interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.destination_address = None
                            self.ifname = None
                            self.source_address = None
                            self.next_hop_interface = None

                        @property
                        def _common_path(self):
                            if self.destination_address is None:
                                raise YPYModelError('Key property destination_address is None')
                            if self.ifname is None:
                                raise YPYModelError('Key property ifname is None')
                            if self.source_address is None:
                                raise YPYModelError('Key property source_address is None')

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:gre/Cisco-IOS-XR-ipv4-pim-oper:gre-hashes/Cisco-IOS-XR-ipv4-pim-oper:gre-hash[Cisco-IOS-XR-ipv4-pim-oper:destination-address = ' + str(self.destination_address) + '][Cisco-IOS-XR-ipv4-pim-oper:ifname = ' + str(self.ifname) + '][Cisco-IOS-XR-ipv4-pim-oper:source-address = ' + str(self.source_address) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.destination_address is not None:
                                return True

                            if self.ifname is not None:
                                return True

                            if self.source_address is not None:
                                return True

                            if self.next_hop_interface is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Gre.GreHashes.GreHash']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:gre/Cisco-IOS-XR-ipv4-pim-oper:gre-hashes'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.gre_hash is not None:
                            for child_ref in self.gre_hash:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.Gre.GreHashes']['meta_info']


                class GreNextHops(object):
                    """
                    GRE destination neighbor table
                    
                    .. attribute:: gre_next_hop
                    
                    	PIM GRE address next\-hop information
                    	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.gre_next_hop = YList()
                        self.gre_next_hop.parent = self
                        self.gre_next_hop.name = 'gre_next_hop'


                    class GreNextHop(object):
                        """
                        PIM GRE address next\-hop information
                        
                        .. attribute:: destination_address  <key>
                        
                        	GRE destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: gre_path
                        
                        	GRE Paths list
                        	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath>`
                        
                        .. attribute:: is_connected
                        
                        	Are we connected ?
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: registered_address
                        
                        	Address registered
                        	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.destination_address = None
                            self.gre_path = YList()
                            self.gre_path.parent = self
                            self.gre_path.name = 'gre_path'
                            self.is_connected = None
                            self.metric = None
                            self.metric_preference = None
                            self.registered_address = Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                            self.registered_address.parent = self


                        class RegisteredAddress(object):
                            """
                            Address registered
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:registered-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress']['meta_info']


                        class GrePath(object):
                            """
                            GRE Paths list
                            
                            .. attribute:: extranet_vrf_name
                            
                            	Extranet VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: gre_interface_name
                            
                            	GRE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: gre_neighbor
                            
                            	GRE neighbor
                            	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                            
                            .. attribute:: gre_next_hop
                            
                            	GRE nexthop
                            	**type**\:   :py:class:`GreNextHop_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_>`
                            
                            .. attribute:: is_connector_attribute_present
                            
                            	Connector attribute present
                            	**type**\:  bool
                            
                            .. attribute:: is_gre_interface_disabled
                            
                            	Is the gre interface disabled ?
                            	**type**\:  bool
                            
                            .. attribute:: is_via_lsm
                            
                            	Via LSM
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.extranet_vrf_name = None
                                self.gre_interface_name = None
                                self.gre_neighbor = Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                self.gre_neighbor.parent = self
                                self.gre_next_hop = Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_()
                                self.gre_next_hop.parent = self
                                self.is_connector_attribute_present = None
                                self.is_gre_interface_disabled = None
                                self.is_via_lsm = None


                            class GreNeighbor(object):
                                """
                                GRE neighbor
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-neighbor'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor']['meta_info']


                            class GreNextHop_(object):
                                """
                                GRE nexthop
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-path'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.extranet_vrf_name is not None:
                                    return True

                                if self.gre_interface_name is not None:
                                    return True

                                if self.gre_neighbor is not None and self.gre_neighbor._has_data():
                                    return True

                                if self.gre_next_hop is not None and self.gre_next_hop._has_data():
                                    return True

                                if self.is_connector_attribute_present is not None:
                                    return True

                                if self.is_gre_interface_disabled is not None:
                                    return True

                                if self.is_via_lsm is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath']['meta_info']

                        @property
                        def _common_path(self):
                            if self.destination_address is None:
                                raise YPYModelError('Key property destination_address is None')

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:gre/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hops/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hop[Cisco-IOS-XR-ipv4-pim-oper:destination-address = ' + str(self.destination_address) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.destination_address is not None:
                                return True

                            if self.gre_path is not None:
                                for child_ref in self.gre_path:
                                    if child_ref._has_data():
                                        return True

                            if self.is_connected is not None:
                                return True

                            if self.metric is not None:
                                return True

                            if self.metric_preference is not None:
                                return True

                            if self.registered_address is not None and self.registered_address._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:gre/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hops'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.gre_next_hop is not None:
                            for child_ref in self.gre_next_hop:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.Gre.GreNextHops']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:gre'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.gre_hashes is not None and self.gre_hashes._has_data():
                        return True

                    if self.gre_next_hops is not None and self.gre_next_hops._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.Gre']['meta_info']


            class BidirDfWinners(object):
                """
                Bidirectional PIM DF election winner table
                
                .. attribute:: bidir_df_winner
                
                	Bidirectional PIM DF election table entry
                	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bidir_df_winner = YList()
                    self.bidir_df_winner.parent = self
                    self.bidir_df_winner.name = 'bidir_df_winner'


                class BidirDfWinner(object):
                    """
                    Bidirectional PIM DF election table entry
                    
                    .. attribute:: are_we_df
                    
                    	Are we DF
                    	**type**\:  bool
                    
                    .. attribute:: df_winner
                    
                    	DF Winner
                    	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner>`
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_preference
                    
                    	Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                    
                    .. attribute:: rp_lan
                    
                    	Is this the RP LAN
                    	**type**\:  bool
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.are_we_df = None
                        self.df_winner = Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner()
                        self.df_winner.parent = self
                        self.interface_name = None
                        self.metric = None
                        self.metric_preference = None
                        self.pim_interface_name = None
                        self.rp_address = None
                        self.rp_address_xr = Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self.rp_lan = None
                        self.uptime = None


                    class RpAddressXr(object):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winners/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winner/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr']['meta_info']


                    class DfWinner(object):
                        """
                        DF Winner
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winners/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winner/Cisco-IOS-XR-ipv4-pim-oper:df-winner'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winners/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winner'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.are_we_df is not None:
                            return True

                        if self.df_winner is not None and self.df_winner._has_data():
                            return True

                        if self.interface_name is not None:
                            return True

                        if self.metric is not None:
                            return True

                        if self.metric_preference is not None:
                            return True

                        if self.pim_interface_name is not None:
                            return True

                        if self.rp_address is not None:
                            return True

                        if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                            return True

                        if self.rp_lan is not None:
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winners'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bidir_df_winner is not None:
                        for child_ref in self.bidir_df_winner:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.BidirDfWinners']['meta_info']


            class TableContexts(object):
                """
                PIM table context list
                
                .. attribute:: table_context
                
                	PIM table context information
                	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TableContexts.TableContext>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.table_context = YList()
                    self.table_context.parent = self
                    self.table_context.name = 'table_context'


                class TableContext(object):
                    """
                    PIM table context information
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: saf_name
                    
                    	SAF name
                    	**type**\:   :py:class:`PimSafiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafiEnum>`
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: topology_name
                    
                    	Topology name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.afi = None
                        self.is_active = None
                        self.is_ital_registration_done = None
                        self.is_rib_convergence = None
                        self.is_rib_convergence_received = None
                        self.is_rib_registration_done = None
                        self.rpf_registrations = None
                        self.saf_name = None
                        self.safi = None
                        self.table_id = None
                        self.table_name = None
                        self.topology_name = None
                        self.vrf_id = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:table-contexts/Cisco-IOS-XR-ipv4-pim-oper:table-context'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.afi is not None:
                            return True

                        if self.is_active is not None:
                            return True

                        if self.is_ital_registration_done is not None:
                            return True

                        if self.is_rib_convergence is not None:
                            return True

                        if self.is_rib_convergence_received is not None:
                            return True

                        if self.is_rib_registration_done is not None:
                            return True

                        if self.rpf_registrations is not None:
                            return True

                        if self.saf_name is not None:
                            return True

                        if self.safi is not None:
                            return True

                        if self.table_id is not None:
                            return True

                        if self.table_name is not None:
                            return True

                        if self.topology_name is not None:
                            return True

                        if self.vrf_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.TableContexts.TableContext']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:table-contexts'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.table_context is not None:
                        for child_ref in self.table_context:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.TableContexts']['meta_info']


            class NeighborSummaries(object):
                """
                PIM neighbor summary table
                
                .. attribute:: neighbor_summary
                
                	PIM neighbor summary information
                	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.neighbor_summary = YList()
                    self.neighbor_summary.parent = self
                    self.neighbor_summary.name = 'neighbor_summary'


                class NeighborSummary(object):
                    """
                    PIM neighbor summary information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: number_of_external_neighbors
                    
                    	Number of external neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: number_of_neighbors
                    
                    	Number of neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.number_of_external_neighbors = None
                        self.number_of_neighbors = None

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbor-summaries/Cisco-IOS-XR-ipv4-pim-oper:neighbor-summary[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.number_of_external_neighbors is not None:
                            return True

                        if self.number_of_neighbors is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbor-summaries'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.neighbor_summary is not None:
                        for child_ref in self.neighbor_summary:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.NeighborSummaries']['meta_info']


            class Context(object):
                """
                PIM context information
                
                .. attribute:: active_table_count
                
                	Number of active Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: allow_rp_configured
                
                	Allow RP Configured
                	**type**\:  bool
                
                .. attribute:: allow_rp_group_list
                
                	Allow RP Group\-List ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: allow_rp_rp_list
                
                	Allow RP RP\-list ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: anycast_rp_configured
                
                	Anycast\-RP config
                	**type**\:  bool
                
                .. attribute:: anycast_rp_policy_name
                
                	Anycast\-RP Policy Name
                	**type**\:  str
                
                .. attribute:: anycast_rp_range
                
                	Anycast\-RP Ranges
                	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.AnycastRpRange>`
                
                .. attribute:: bgp_auto_discovery_configured
                
                	BGP Auto\-Discovery configured
                	**type**\:  bool
                
                .. attribute:: bgp_auto_discovery_type
                
                	BGP Auto Discovery Type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_i_pmsi_added
                
                	BGP I\-PMSI Added
                	**type**\:  bool
                
                .. attribute:: bgp_remote_address
                
                	BGP remote interface address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: bgp_remote_interface
                
                	BGP remote interface handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: bgp_remote_interface_name
                
                	BGP remote interface name
                	**type**\:  str
                
                .. attribute:: bgp_remote_on
                
                	BGP remote interface status
                	**type**\:  bool
                
                .. attribute:: bgp_remote_state
                
                	BGP remote interface state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_source_active_announce
                
                	Send BGP Source\-Active Announcements
                	**type**\:  bool
                
                .. attribute:: export_route_target
                
                	Export Route Targets
                	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.ExportRouteTarget>`
                
                .. attribute:: gin_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: gin_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: gin_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: import_route_target
                
                	Import Route Targets
                	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.ImportRouteTarget>`
                
                .. attribute:: in_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: in_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: in_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_signaling_local_enabled
                
                	Inband signaling Local enabled
                	**type**\:  bool
                
                .. attribute:: in_band_signaling_remote_enabled
                
                	Inband signaling Remote enabled
                	**type**\:  bool
                
                .. attribute:: inter_autonomous_system_enabled
                
                	Inter\-AS Enabled
                	**type**\:  bool
                
                .. attribute:: ir_maximum_mdt_aggregation
                
                	IR MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_announce_interval
                
                	IR Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_switchover_interval
                
                	IR Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_interface
                
                	IRMDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: ir_mdt_mtu
                
                	IRMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_name
                
                	IR MDT Name
                	**type**\:  str
                
                .. attribute:: ir_mdt_rpf_identifier
                
                	IR RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_tail_label
                
                	IR Tail Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_active
                
                	Active
                	**type**\:  bool
                
                .. attribute:: is_active_ital
                
                	Active ITAL
                	**type**\:  bool
                
                .. attribute:: is_all_interface_disable_operation
                
                	PIM all interface disable operation
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_enabled
                
                	Auto RP Listen Enabled
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_sock_add
                
                	Auto RP listen sock add
                	**type**\:  bool
                
                .. attribute:: is_create_gin_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_in_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_ir_mdt_interface
                
                	Create IR MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mdt_interface
                
                	Create MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mldp_mdt_interface
                
                	Create MLDP MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_rsvp_te_mdt_interface
                
                	Create RSVP\-TE MDT interface
                	**type**\:  bool
                
                .. attribute:: is_default_granges
                
                	Default granges
                	**type**\:  bool
                
                .. attribute:: is_gin_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_in_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_ir_mdt_owner
                
                	IR MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_add_required
                
                	VRF LPTS filter required on Socket
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_added
                
                	VRF LPTS filter added on Socket
                	**type**\:  bool
                
                .. attribute:: is_m_host_publish_pending
                
                	Publish pending for MHost Default interface
                	**type**\:  bool
                
                .. attribute:: is_mdt_owner
                
                	MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mldp_mdt_owner
                
                	MLDP MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mrib_register
                
                	MRIB Register
                	**type**\:  bool
                
                .. attribute:: is_multicast_rib_registration
                
                	Mcast RIB Registration
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converge_received
                
                	PIM NSF RIB converge received
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converged
                
                	PIM NSF RIB converged
                	**type**\:  bool
                
                .. attribute:: is_redistribution_reset
                
                	Pending redist reset
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_add_required
                
                	VRF LPTS filter required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_added
                
                	VRF LPTS filter added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_add_required
                
                	VRF required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_added
                
                	VRF added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_enabled
                
                	PIM RIB multiplath enabled
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_interface_hash
                
                	PIM RIB multipath interface hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_hash
                
                	PIM RIB multipath source based hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_next_hop_hash
                
                	PIM RIB multipath source\-nexthop hash
                	**type**\:  bool
                
                .. attribute:: is_routing_enabled
                
                	Routing Enabled
                	**type**\:  bool
                
                .. attribute:: is_rsvp_te_mdt_owner
                
                	RSVP\-TE MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_socket_add_required
                
                	VRF required on Socket
                	**type**\:  bool
                
                .. attribute:: is_socket_added
                
                	VRF added on Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_add_required
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_added
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind
                
                	VRF bound on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind_required
                
                	VRF bind required on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_unicast_rib_registration
                
                	Ucast RIB Registration
                	**type**\:  bool
                
                .. attribute:: maximum_mdt_aggregation
                
                	MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_announce_interval
                
                	Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_switchover_interval
                
                	Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_default_group
                
                	MDT Default group
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_gre_remote_rpf_identifier
                
                	GRE\-MDT Remote RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_gre_rpf_identifier
                
                	GRE\-MDT RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_interface
                
                	MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mdt_mtu
                
                	MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_neighbor_filter_name
                
                	MDT Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: mdt_partitioned_ir_control_identifier
                
                	Partitioned IR MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_partitioned_mdt_control_identifier
                
                	Partitioned MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mhost_default_interface_config
                
                	Configured Mhost Defint
                	**type**\:  str
                
                .. attribute:: mhost_interface
                
                	MHost handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mldp_auto_rp_announce_tree_added
                
                	MLDP Autorp Announce Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_auto_rp_discovery_tree_added
                
                	MLDP Autorp Discovery Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_bsr_control_tree_added
                
                	MLDP BSR Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_control_head_lsm_identifier
                
                	MLDP MVPN Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_local_label
                
                	Partitioned MDT Head local label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_lsm_identifier
                
                	MLDP Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_maximum_mdt_aggregation
                
                	MLDP MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_announce_interval
                
                	MLDP Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_switchover_interval
                
                	MLDP Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_interface
                
                	MLDP MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mldp_mdt_mtu
                
                	MLDP MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_name
                
                	MLDP MDT Name
                	**type**\:  str
                
                .. attribute:: mldp_mdt_remote_rpf_identifier
                
                	MLDP Remote RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_rpf_identifier
                
                	MLDP RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partioned_mp2m_ptree
                
                	MP2MP Partitioned MDT tree
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_head_lsm_identifier
                
                	Partitioned MDT Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partitioned_mdt_configured
                
                	MLDP Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_mdt_identifier
                
                	MLDP Partitioned MDT Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_head_lsm_identifier
                
                	MLDP Remote Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_partitioned_mdt_configured
                
                	MLDP Remote Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_root_address
                
                	MLDP Root addresses
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_root_count
                
                	MLDP Root count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: murib_id
                
                	MURIB ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: neighbor_filter_name
                
                	Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: non_default_vrf_count_on_socket
                
                	Count of non\-default vrfs on raw socket
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: organization_unique_identifier
                
                	OUI for VPN\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: p2mpte_li_drop
                
                	Route LI updates dropped for P2MP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: redistribution_reset_count
                
                	Redist reset count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_default_group
                
                	Remote Default Group
                	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.RemoteDefaultGroup>`
                
                .. attribute:: remote_table_id
                
                	Remote Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_distinguisher
                
                	RD value
                	**type**\:  str
                
                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                
                .. attribute:: rpf_default_table
                
                	RPF Default Table
                	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.RpfDefaultTable>`
                
                .. attribute:: rpf_id
                
                	RPF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rpf_policy_name
                
                	RPF topology selection route\-policy name
                	**type**\:  str
                
                .. attribute:: rsvp_te_maximum_mdt_aggregation
                
                	RSVP\-TE MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_announce_interval
                
                	RSVP\-TE Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_switchover_interval
                
                	RSVP\-TE Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_interface
                
                	RSVP\-TEMDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: rsvp_te_mdt_mtu
                
                	RSVP\-TEMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_name
                
                	RSVP\-TE MDT Name
                	**type**\:  str
                
                .. attribute:: rsvp_te_mdt_rpf_identifier
                
                	RSVP\-TE RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_static_p2mp_count
                
                	Number of Static P2MP\-TE MDT
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	PIM is using MuRIB
                	**type**\:  bool
                
                .. attribute:: sg_expiry_time
                
                	S,G Expiry Time Configured, in seconds
                	**type**\:  int
                
                	**range:** 0..65535
                
                	**units**\: second
                
                .. attribute:: sg_expiry_timer_configured
                
                	S,G Expiry Timer Configured
                	**type**\:  bool
                
                .. attribute:: sg_expiry_timer_sg_list
                
                	S,G expiry timer ACL name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: stale_rd_present
                
                	RD is stale
                	**type**\:  bool
                
                .. attribute:: suppress_pim_data_mdt_tlv
                
                	Suppress PIM Data\-MDT TLV Announcements
                	**type**\:  bool
                
                .. attribute:: suppress_shared_tree_join
                
                	Suppress Shared\-Tree Joins
                	**type**\:  bool
                
                .. attribute:: table_count
                
                	Number of configured Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: table_id
                
                	Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: umh
                
                	Join UMH Core\-Tree
                	**type**\:  bool
                
                .. attribute:: valid_rd_present
                
                	RD is valid
                	**type**\:  bool
                
                .. attribute:: vpn_index
                
                	VPN Index
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vrf_id
                
                	VRF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.active_table_count = None
                    self.allow_rp_configured = None
                    self.allow_rp_group_list = None
                    self.allow_rp_rp_list = None
                    self.anycast_rp_configured = None
                    self.anycast_rp_policy_name = None
                    self.anycast_rp_range = YList()
                    self.anycast_rp_range.parent = self
                    self.anycast_rp_range.name = 'anycast_rp_range'
                    self.bgp_auto_discovery_configured = None
                    self.bgp_auto_discovery_type = None
                    self.bgp_i_pmsi_added = None
                    self.bgp_remote_address = None
                    self.bgp_remote_interface = None
                    self.bgp_remote_interface_name = None
                    self.bgp_remote_on = None
                    self.bgp_remote_state = None
                    self.bgp_source_active_announce = None
                    self.export_route_target = YList()
                    self.export_route_target.parent = self
                    self.export_route_target.name = 'export_route_target'
                    self.gin_b_and_mdt_data_announce_interval = None
                    self.gin_b_and_mdt_data_switchover_interval = None
                    self.gin_b_and_mdt_interface = None
                    self.gin_b_and_mdt_mtu = None
                    self.gin_b_and_mdt_name = None
                    self.gin_b_and_mdt_rpf_identifier = None
                    self.gin_band_maximum_mdt_aggregation = None
                    self.import_route_target = YList()
                    self.import_route_target.parent = self
                    self.import_route_target.name = 'import_route_target'
                    self.in_b_and_mdt_data_announce_interval = None
                    self.in_b_and_mdt_data_switchover_interval = None
                    self.in_b_and_mdt_interface = None
                    self.in_b_and_mdt_mtu = None
                    self.in_b_and_mdt_name = None
                    self.in_b_and_mdt_rpf_identifier = None
                    self.in_band_maximum_mdt_aggregation = None
                    self.in_band_signaling_local_enabled = None
                    self.in_band_signaling_remote_enabled = None
                    self.inter_autonomous_system_enabled = None
                    self.ir_maximum_mdt_aggregation = None
                    self.ir_mdt_data_announce_interval = None
                    self.ir_mdt_data_switchover_interval = None
                    self.ir_mdt_interface = None
                    self.ir_mdt_mtu = None
                    self.ir_mdt_name = None
                    self.ir_mdt_rpf_identifier = None
                    self.ir_mdt_tail_label = None
                    self.is_active = None
                    self.is_active_ital = None
                    self.is_all_interface_disable_operation = None
                    self.is_auto_rp_listen_enabled = None
                    self.is_auto_rp_listen_sock_add = None
                    self.is_create_gin_b_and_mdt_interface = None
                    self.is_create_in_b_and_mdt_interface = None
                    self.is_create_ir_mdt_interface = None
                    self.is_create_mdt_interface = None
                    self.is_create_mldp_mdt_interface = None
                    self.is_create_rsvp_te_mdt_interface = None
                    self.is_default_granges = None
                    self.is_gin_b_and_mdt_owner = None
                    self.is_in_b_and_mdt_owner = None
                    self.is_ir_mdt_owner = None
                    self.is_lpts_socket_add_required = None
                    self.is_lpts_socket_added = None
                    self.is_m_host_publish_pending = None
                    self.is_mdt_owner = None
                    self.is_mldp_mdt_owner = None
                    self.is_mrib_register = None
                    self.is_multicast_rib_registration = None
                    self.is_pim_nsf_rib_converge_received = None
                    self.is_pim_nsf_rib_converged = None
                    self.is_redistribution_reset = None
                    self.is_register_injection_lpts_socket_add_required = None
                    self.is_register_injection_lpts_socket_added = None
                    self.is_register_injection_socket_add_required = None
                    self.is_register_injection_socket_added = None
                    self.is_rib_multipath_enabled = None
                    self.is_rib_multipath_interface_hash = None
                    self.is_rib_multipath_source_hash = None
                    self.is_rib_multipath_source_next_hop_hash = None
                    self.is_routing_enabled = None
                    self.is_rsvp_te_mdt_owner = None
                    self.is_socket_add_required = None
                    self.is_socket_added = None
                    self.is_udp_socket_add_required = None
                    self.is_udp_socket_added = None
                    self.is_udp_socket_bind = None
                    self.is_udp_socket_bind_required = None
                    self.is_unicast_rib_registration = None
                    self.maximum_mdt_aggregation = None
                    self.mdt_data_announce_interval = None
                    self.mdt_data_switchover_interval = None
                    self.mdt_default_group = None
                    self.mdt_gre_remote_rpf_identifier = None
                    self.mdt_gre_rpf_identifier = None
                    self.mdt_interface = None
                    self.mdt_mtu = None
                    self.mdt_neighbor_filter_name = None
                    self.mdt_partitioned_ir_control_identifier = None
                    self.mdt_partitioned_mdt_control_identifier = None
                    self.mhost_default_interface_config = None
                    self.mhost_interface = None
                    self.mldp_auto_rp_announce_tree_added = None
                    self.mldp_auto_rp_discovery_tree_added = None
                    self.mldp_bsr_control_tree_added = None
                    self.mldp_control_head_lsm_identifier = None
                    self.mldp_head_local_label = None
                    self.mldp_head_lsm_identifier = None
                    self.mldp_maximum_mdt_aggregation = None
                    self.mldp_mdt_data_announce_interval = None
                    self.mldp_mdt_data_switchover_interval = None
                    self.mldp_mdt_interface = None
                    self.mldp_mdt_mtu = None
                    self.mldp_mdt_name = None
                    self.mldp_mdt_remote_rpf_identifier = None
                    self.mldp_mdt_rpf_identifier = None
                    self.mldp_partioned_mp2m_ptree = None
                    self.mldp_partitioned_head_lsm_identifier = None
                    self.mldp_partitioned_mdt_configured = None
                    self.mldp_partitioned_mdt_identifier = None
                    self.mldp_remote_head_lsm_identifier = None
                    self.mldp_remote_partitioned_mdt_configured = None
                    self.mldp_root_address = YLeafList()
                    self.mldp_root_address.parent = self
                    self.mldp_root_address.name = 'mldp_root_address'
                    self.mldp_root_count = None
                    self.murib_id = None
                    self.neighbor_filter_name = None
                    self.non_default_vrf_count_on_socket = None
                    self.organization_unique_identifier = None
                    self.p2mpte_li_drop = None
                    self.redistribution_reset_count = None
                    self.remote_default_group = Pim.Standby.DefaultContext.Context.RemoteDefaultGroup()
                    self.remote_default_group.parent = self
                    self.remote_table_id = None
                    self.route_distinguisher = None
                    self.rpf_default_table = Pim.Standby.DefaultContext.Context.RpfDefaultTable()
                    self.rpf_default_table.parent = self
                    self.rpf_id = None
                    self.rpf_policy_name = None
                    self.rsvp_te_maximum_mdt_aggregation = None
                    self.rsvp_te_mdt_data_announce_interval = None
                    self.rsvp_te_mdt_data_switchover_interval = None
                    self.rsvp_te_mdt_interface = None
                    self.rsvp_te_mdt_mtu = None
                    self.rsvp_te_mdt_name = None
                    self.rsvp_te_mdt_rpf_identifier = None
                    self.rsvp_te_mdt_static_p2mp_count = None
                    self.rump_enabled = None
                    self.sg_expiry_time = None
                    self.sg_expiry_timer_configured = None
                    self.sg_expiry_timer_sg_list = None
                    self.stale_rd_present = None
                    self.suppress_pim_data_mdt_tlv = None
                    self.suppress_shared_tree_join = None
                    self.table_count = None
                    self.table_id = None
                    self.umh = None
                    self.valid_rd_present = None
                    self.vpn_index = None
                    self.vrf_id = None


                class RemoteDefaultGroup(object):
                    """
                    Remote Default Group
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.af_name = None
                        self.ipv4_address = None
                        self.ipv6_address = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:remote-default-group'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.af_name is not None:
                            return True

                        if self.ipv4_address is not None:
                            return True

                        if self.ipv6_address is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.Context.RemoteDefaultGroup']['meta_info']


                class RpfDefaultTable(object):
                    """
                    RPF Default Table
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.afi = None
                        self.is_active = None
                        self.is_ital_registration_done = None
                        self.is_rib_convergence = None
                        self.is_rib_convergence_received = None
                        self.is_rib_registration_done = None
                        self.rpf_registrations = None
                        self.safi = None
                        self.table_id = None
                        self.table_name = None
                        self.vrf_id = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:rpf-default-table'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.afi is not None:
                            return True

                        if self.is_active is not None:
                            return True

                        if self.is_ital_registration_done is not None:
                            return True

                        if self.is_rib_convergence is not None:
                            return True

                        if self.is_rib_convergence_received is not None:
                            return True

                        if self.is_rib_registration_done is not None:
                            return True

                        if self.rpf_registrations is not None:
                            return True

                        if self.safi is not None:
                            return True

                        if self.table_id is not None:
                            return True

                        if self.table_name is not None:
                            return True

                        if self.vrf_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.Context.RpfDefaultTable']['meta_info']


                class ExportRouteTarget(object):
                    """
                    Export Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.anycast_rp = None
                        self.anycast_rp_marked = None
                        self.bgp_auto_discovery = None
                        self.configured = None
                        self.route_target = None
                        self.segment_border = None
                        self.update_pending = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:export-route-target'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.anycast_rp is not None:
                            return True

                        if self.anycast_rp_marked is not None:
                            return True

                        if self.bgp_auto_discovery is not None:
                            return True

                        if self.configured is not None:
                            return True

                        if self.route_target is not None:
                            return True

                        if self.segment_border is not None:
                            return True

                        if self.update_pending is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.Context.ExportRouteTarget']['meta_info']


                class ImportRouteTarget(object):
                    """
                    Import Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.anycast_rp = None
                        self.anycast_rp_marked = None
                        self.bgp_auto_discovery = None
                        self.configured = None
                        self.route_target = None
                        self.segment_border = None
                        self.update_pending = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:import-route-target'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.anycast_rp is not None:
                            return True

                        if self.anycast_rp_marked is not None:
                            return True

                        if self.bgp_auto_discovery is not None:
                            return True

                        if self.configured is not None:
                            return True

                        if self.route_target is not None:
                            return True

                        if self.segment_border is not None:
                            return True

                        if self.update_pending is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.Context.ImportRouteTarget']['meta_info']


                class AnycastRpRange(object):
                    """
                    Anycast\-RP Ranges
                    
                    .. attribute:: ancast_rp_marked
                    
                    	Anycast\-RP Range marked
                    	**type**\:  bool
                    
                    .. attribute:: prefix
                    
                    	Anycast\-RP Range Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Anycast\-RP Range Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ancast_rp_marked = None
                        self.prefix = Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix()
                        self.prefix.parent = self
                        self.prefix_length = None


                    class Prefix(object):
                        """
                        Anycast\-RP Range Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:anycast-rp-range/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:anycast-rp-range'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ancast_rp_marked is not None:
                            return True

                        if self.prefix is not None and self.prefix._has_data():
                            return True

                        if self.prefix_length is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.Context.AnycastRpRange']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.active_table_count is not None:
                        return True

                    if self.allow_rp_configured is not None:
                        return True

                    if self.allow_rp_group_list is not None:
                        return True

                    if self.allow_rp_rp_list is not None:
                        return True

                    if self.anycast_rp_configured is not None:
                        return True

                    if self.anycast_rp_policy_name is not None:
                        return True

                    if self.anycast_rp_range is not None:
                        for child_ref in self.anycast_rp_range:
                            if child_ref._has_data():
                                return True

                    if self.bgp_auto_discovery_configured is not None:
                        return True

                    if self.bgp_auto_discovery_type is not None:
                        return True

                    if self.bgp_i_pmsi_added is not None:
                        return True

                    if self.bgp_remote_address is not None:
                        return True

                    if self.bgp_remote_interface is not None:
                        return True

                    if self.bgp_remote_interface_name is not None:
                        return True

                    if self.bgp_remote_on is not None:
                        return True

                    if self.bgp_remote_state is not None:
                        return True

                    if self.bgp_source_active_announce is not None:
                        return True

                    if self.export_route_target is not None:
                        for child_ref in self.export_route_target:
                            if child_ref._has_data():
                                return True

                    if self.gin_b_and_mdt_data_announce_interval is not None:
                        return True

                    if self.gin_b_and_mdt_data_switchover_interval is not None:
                        return True

                    if self.gin_b_and_mdt_interface is not None:
                        return True

                    if self.gin_b_and_mdt_mtu is not None:
                        return True

                    if self.gin_b_and_mdt_name is not None:
                        return True

                    if self.gin_b_and_mdt_rpf_identifier is not None:
                        return True

                    if self.gin_band_maximum_mdt_aggregation is not None:
                        return True

                    if self.import_route_target is not None:
                        for child_ref in self.import_route_target:
                            if child_ref._has_data():
                                return True

                    if self.in_b_and_mdt_data_announce_interval is not None:
                        return True

                    if self.in_b_and_mdt_data_switchover_interval is not None:
                        return True

                    if self.in_b_and_mdt_interface is not None:
                        return True

                    if self.in_b_and_mdt_mtu is not None:
                        return True

                    if self.in_b_and_mdt_name is not None:
                        return True

                    if self.in_b_and_mdt_rpf_identifier is not None:
                        return True

                    if self.in_band_maximum_mdt_aggregation is not None:
                        return True

                    if self.in_band_signaling_local_enabled is not None:
                        return True

                    if self.in_band_signaling_remote_enabled is not None:
                        return True

                    if self.inter_autonomous_system_enabled is not None:
                        return True

                    if self.ir_maximum_mdt_aggregation is not None:
                        return True

                    if self.ir_mdt_data_announce_interval is not None:
                        return True

                    if self.ir_mdt_data_switchover_interval is not None:
                        return True

                    if self.ir_mdt_interface is not None:
                        return True

                    if self.ir_mdt_mtu is not None:
                        return True

                    if self.ir_mdt_name is not None:
                        return True

                    if self.ir_mdt_rpf_identifier is not None:
                        return True

                    if self.ir_mdt_tail_label is not None:
                        return True

                    if self.is_active is not None:
                        return True

                    if self.is_active_ital is not None:
                        return True

                    if self.is_all_interface_disable_operation is not None:
                        return True

                    if self.is_auto_rp_listen_enabled is not None:
                        return True

                    if self.is_auto_rp_listen_sock_add is not None:
                        return True

                    if self.is_create_gin_b_and_mdt_interface is not None:
                        return True

                    if self.is_create_in_b_and_mdt_interface is not None:
                        return True

                    if self.is_create_ir_mdt_interface is not None:
                        return True

                    if self.is_create_mdt_interface is not None:
                        return True

                    if self.is_create_mldp_mdt_interface is not None:
                        return True

                    if self.is_create_rsvp_te_mdt_interface is not None:
                        return True

                    if self.is_default_granges is not None:
                        return True

                    if self.is_gin_b_and_mdt_owner is not None:
                        return True

                    if self.is_in_b_and_mdt_owner is not None:
                        return True

                    if self.is_ir_mdt_owner is not None:
                        return True

                    if self.is_lpts_socket_add_required is not None:
                        return True

                    if self.is_lpts_socket_added is not None:
                        return True

                    if self.is_m_host_publish_pending is not None:
                        return True

                    if self.is_mdt_owner is not None:
                        return True

                    if self.is_mldp_mdt_owner is not None:
                        return True

                    if self.is_mrib_register is not None:
                        return True

                    if self.is_multicast_rib_registration is not None:
                        return True

                    if self.is_pim_nsf_rib_converge_received is not None:
                        return True

                    if self.is_pim_nsf_rib_converged is not None:
                        return True

                    if self.is_redistribution_reset is not None:
                        return True

                    if self.is_register_injection_lpts_socket_add_required is not None:
                        return True

                    if self.is_register_injection_lpts_socket_added is not None:
                        return True

                    if self.is_register_injection_socket_add_required is not None:
                        return True

                    if self.is_register_injection_socket_added is not None:
                        return True

                    if self.is_rib_multipath_enabled is not None:
                        return True

                    if self.is_rib_multipath_interface_hash is not None:
                        return True

                    if self.is_rib_multipath_source_hash is not None:
                        return True

                    if self.is_rib_multipath_source_next_hop_hash is not None:
                        return True

                    if self.is_routing_enabled is not None:
                        return True

                    if self.is_rsvp_te_mdt_owner is not None:
                        return True

                    if self.is_socket_add_required is not None:
                        return True

                    if self.is_socket_added is not None:
                        return True

                    if self.is_udp_socket_add_required is not None:
                        return True

                    if self.is_udp_socket_added is not None:
                        return True

                    if self.is_udp_socket_bind is not None:
                        return True

                    if self.is_udp_socket_bind_required is not None:
                        return True

                    if self.is_unicast_rib_registration is not None:
                        return True

                    if self.maximum_mdt_aggregation is not None:
                        return True

                    if self.mdt_data_announce_interval is not None:
                        return True

                    if self.mdt_data_switchover_interval is not None:
                        return True

                    if self.mdt_default_group is not None:
                        return True

                    if self.mdt_gre_remote_rpf_identifier is not None:
                        return True

                    if self.mdt_gre_rpf_identifier is not None:
                        return True

                    if self.mdt_interface is not None:
                        return True

                    if self.mdt_mtu is not None:
                        return True

                    if self.mdt_neighbor_filter_name is not None:
                        return True

                    if self.mdt_partitioned_ir_control_identifier is not None:
                        return True

                    if self.mdt_partitioned_mdt_control_identifier is not None:
                        return True

                    if self.mhost_default_interface_config is not None:
                        return True

                    if self.mhost_interface is not None:
                        return True

                    if self.mldp_auto_rp_announce_tree_added is not None:
                        return True

                    if self.mldp_auto_rp_discovery_tree_added is not None:
                        return True

                    if self.mldp_bsr_control_tree_added is not None:
                        return True

                    if self.mldp_control_head_lsm_identifier is not None:
                        return True

                    if self.mldp_head_local_label is not None:
                        return True

                    if self.mldp_head_lsm_identifier is not None:
                        return True

                    if self.mldp_maximum_mdt_aggregation is not None:
                        return True

                    if self.mldp_mdt_data_announce_interval is not None:
                        return True

                    if self.mldp_mdt_data_switchover_interval is not None:
                        return True

                    if self.mldp_mdt_interface is not None:
                        return True

                    if self.mldp_mdt_mtu is not None:
                        return True

                    if self.mldp_mdt_name is not None:
                        return True

                    if self.mldp_mdt_remote_rpf_identifier is not None:
                        return True

                    if self.mldp_mdt_rpf_identifier is not None:
                        return True

                    if self.mldp_partioned_mp2m_ptree is not None:
                        return True

                    if self.mldp_partitioned_head_lsm_identifier is not None:
                        return True

                    if self.mldp_partitioned_mdt_configured is not None:
                        return True

                    if self.mldp_partitioned_mdt_identifier is not None:
                        return True

                    if self.mldp_remote_head_lsm_identifier is not None:
                        return True

                    if self.mldp_remote_partitioned_mdt_configured is not None:
                        return True

                    if self.mldp_root_address is not None:
                        for child in self.mldp_root_address:
                            if child is not None:
                                return True

                    if self.mldp_root_count is not None:
                        return True

                    if self.murib_id is not None:
                        return True

                    if self.neighbor_filter_name is not None:
                        return True

                    if self.non_default_vrf_count_on_socket is not None:
                        return True

                    if self.organization_unique_identifier is not None:
                        return True

                    if self.p2mpte_li_drop is not None:
                        return True

                    if self.redistribution_reset_count is not None:
                        return True

                    if self.remote_default_group is not None and self.remote_default_group._has_data():
                        return True

                    if self.remote_table_id is not None:
                        return True

                    if self.route_distinguisher is not None:
                        return True

                    if self.rpf_default_table is not None and self.rpf_default_table._has_data():
                        return True

                    if self.rpf_id is not None:
                        return True

                    if self.rpf_policy_name is not None:
                        return True

                    if self.rsvp_te_maximum_mdt_aggregation is not None:
                        return True

                    if self.rsvp_te_mdt_data_announce_interval is not None:
                        return True

                    if self.rsvp_te_mdt_data_switchover_interval is not None:
                        return True

                    if self.rsvp_te_mdt_interface is not None:
                        return True

                    if self.rsvp_te_mdt_mtu is not None:
                        return True

                    if self.rsvp_te_mdt_name is not None:
                        return True

                    if self.rsvp_te_mdt_rpf_identifier is not None:
                        return True

                    if self.rsvp_te_mdt_static_p2mp_count is not None:
                        return True

                    if self.rump_enabled is not None:
                        return True

                    if self.sg_expiry_time is not None:
                        return True

                    if self.sg_expiry_timer_configured is not None:
                        return True

                    if self.sg_expiry_timer_sg_list is not None:
                        return True

                    if self.stale_rd_present is not None:
                        return True

                    if self.suppress_pim_data_mdt_tlv is not None:
                        return True

                    if self.suppress_shared_tree_join is not None:
                        return True

                    if self.table_count is not None:
                        return True

                    if self.table_id is not None:
                        return True

                    if self.umh is not None:
                        return True

                    if self.valid_rd_present is not None:
                        return True

                    if self.vpn_index is not None:
                        return True

                    if self.vrf_id is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.Context']['meta_info']


            class TopologyEntryFlagRouteCounts(object):
                """
                Route count for topology with entry flag set
                
                .. attribute:: topology_entry_flag_route_count
                
                	Route count for topology with entry flag set
                	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.topology_entry_flag_route_count = YList()
                    self.topology_entry_flag_route_count.parent = self
                    self.topology_entry_flag_route_count.name = 'topology_entry_flag_route_count'


                class TopologyEntryFlagRouteCount(object):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: entry_flag  <key>
                    
                    	entry flag
                    	**type**\:   :py:class:`PimTopologyEntryFlagEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlagEnum>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.entry_flag = None
                        self.active_group_ranges = None
                        self.group_address = Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self.group_ranges = None
                        self.groute_count = None
                        self.is_node_low_memory = None
                        self.sg_route_count = None
                        self.sgr_route_count = None


                    class GroupAddress(object):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.entry_flag is None:
                            raise YPYModelError('Key property entry_flag is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-entry-flag-route-counts/Cisco-IOS-XR-ipv4-pim-oper:topology-entry-flag-route-count[Cisco-IOS-XR-ipv4-pim-oper:entry-flag = ' + str(self.entry_flag) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.entry_flag is not None:
                            return True

                        if self.active_group_ranges is not None:
                            return True

                        if self.group_address is not None and self.group_address._has_data():
                            return True

                        if self.group_ranges is not None:
                            return True

                        if self.groute_count is not None:
                            return True

                        if self.is_node_low_memory is not None:
                            return True

                        if self.sg_route_count is not None:
                            return True

                        if self.sgr_route_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-entry-flag-route-counts'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.topology_entry_flag_route_count is not None:
                        for child_ref in self.topology_entry_flag_route_count:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts']['meta_info']


            class RpfRedirect(object):
                """
                PIM ECMP RPF\-redirect bundle
                
                .. attribute:: bundle_interfaces
                
                	PIM ECMP RPF\-redirect bundle information
                	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces>`
                
                .. attribute:: redirect_route_databases
                
                	PIM ECMP RPF\-redirect route database
                	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bundle_interfaces = Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces()
                    self.bundle_interfaces.parent = self
                    self.redirect_route_databases = Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases()
                    self.redirect_route_databases.parent = self


                class RedirectRouteDatabases(object):
                    """
                    PIM ECMP RPF\-redirect route database
                    
                    .. attribute:: redirect_route_database
                    
                    	PIM ECMP RPF\-redirect route information
                    	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.redirect_route_database = YList()
                        self.redirect_route_database.parent = self
                        self.redirect_route_database.name = 'redirect_route_database'


                    class RedirectRouteDatabase(object):
                        """
                        PIM ECMP RPF\-redirect route information
                        
                        .. attribute:: bandwidth
                        
                        	Bandwidth in Kbps
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group ddress
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                        
                        .. attribute:: interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bandwidth = None
                            self.group_address = None
                            self.group_address_xr = Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self.interface = YList()
                            self.interface.parent = self
                            self.interface.name = 'interface'
                            self.source_address = None
                            self.source_address_xr = Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self.uptime = None


                        class GroupAddressXr(object):
                            """
                            Group ddress
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr']['meta_info']


                        class SourceAddressXr(object):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr']['meta_info']


                        class Interface(object):
                            """
                            Outgoing interface list
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_outgoing_interface
                            
                            	Is outgoing Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_rpf_interface
                            
                            	Is RPF Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_snoop_interface
                            
                            	Is snooping Interface
                            	**type**\:  bool
                            
                            .. attribute:: rpf_address
                            
                            	RPF Address
                            	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.expiry = None
                                self.interface_name = None
                                self.is_outgoing_interface = None
                                self.is_rpf_interface = None
                                self.is_snoop_interface = None
                                self.rpf_address = Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                self.rpf_address.parent = self
                                self.uptime = None


                            class RpfAddress(object):
                                """
                                RPF Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database/Cisco-IOS-XR-ipv4-pim-oper:interface/Cisco-IOS-XR-ipv4-pim-oper:rpf-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database/Cisco-IOS-XR-ipv4-pim-oper:interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.expiry is not None:
                                    return True

                                if self.interface_name is not None:
                                    return True

                                if self.is_outgoing_interface is not None:
                                    return True

                                if self.is_rpf_interface is not None:
                                    return True

                                if self.is_snoop_interface is not None:
                                    return True

                                if self.rpf_address is not None and self.rpf_address._has_data():
                                    return True

                                if self.uptime is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bandwidth is not None:
                                return True

                            if self.group_address is not None:
                                return True

                            if self.group_address_xr is not None and self.group_address_xr._has_data():
                                return True

                            if self.interface is not None:
                                for child_ref in self.interface:
                                    if child_ref._has_data():
                                        return True

                            if self.source_address is not None:
                                return True

                            if self.source_address_xr is not None and self.source_address_xr._has_data():
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.redirect_route_database is not None:
                            for child_ref in self.redirect_route_database:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases']['meta_info']


                class BundleInterfaces(object):
                    """
                    PIM ECMP RPF\-redirect bundle information
                    
                    .. attribute:: bundle_interface
                    
                    	PIM ECMP RPF\-redirect bundle interface information
                    	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bundle_interface = YList()
                        self.bundle_interface.parent = self
                        self.bundle_interface.name = 'bundle_interface'


                    class BundleInterface(object):
                        """
                        PIM ECMP RPF\-redirect bundle interface
                        information
                        
                        .. attribute:: allocated_bandwidth
                        
                        	Bandwidth allocated in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: allocated_threshold_bandwidth
                        
                        	Configured threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_bandwidth
                        
                        	Bandwidth available in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_threshold_bandwidth
                        
                        	Available threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: bundle_name
                        
                        	Bundle name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: interface_name
                        
                        	Bundle interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_redirect_bundle_name
                        
                        	RPF redirect bundle name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpf_redirect_interface_name
                        
                        	RPF redirect interface name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: snooping_bandwidth_used
                        
                        	Bandwidth used by snooped entries in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: topology_bandwidth_used
                        
                        	Bandwidth used by topology in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: total_bandwidth
                        
                        	Total bandwidth used in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.allocated_bandwidth = None
                            self.allocated_threshold_bandwidth = None
                            self.available_bandwidth = None
                            self.available_threshold_bandwidth = None
                            self.bundle_name = None
                            self.interface_name = None
                            self.rpf_redirect_bundle_name = None
                            self.rpf_redirect_interface_name = None
                            self.snooping_bandwidth_used = None
                            self.topology_bandwidth_used = None
                            self.total_bandwidth = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:bundle-interfaces/Cisco-IOS-XR-ipv4-pim-oper:bundle-interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.allocated_bandwidth is not None:
                                return True

                            if self.allocated_threshold_bandwidth is not None:
                                return True

                            if self.available_bandwidth is not None:
                                return True

                            if self.available_threshold_bandwidth is not None:
                                return True

                            if self.bundle_name is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.rpf_redirect_bundle_name is not None:
                                return True

                            if self.rpf_redirect_interface_name is not None:
                                return True

                            if self.snooping_bandwidth_used is not None:
                                return True

                            if self.topology_bandwidth_used is not None:
                                return True

                            if self.total_bandwidth is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:bundle-interfaces'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bundle_interface is not None:
                            for child_ref in self.bundle_interface:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bundle_interfaces is not None and self.bundle_interfaces._has_data():
                        return True

                    if self.redirect_route_databases is not None and self.redirect_route_databases._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.RpfRedirect']['meta_info']


            class Tunnels(object):
                """
                Tunnels information that PIM has
                
                .. attribute:: tunnel
                
                	PIM tunnel information
                	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels.Tunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.tunnel = YList()
                    self.tunnel.parent = self
                    self.tunnel.name = 'tunnel'


                class Tunnel(object):
                    """
                    PIM tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.tunnel_name = None
                        self.group_address_netio = Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self.rp_address = Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress()
                        self.rp_address.parent = self
                        self.source_address = Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress()
                        self.source_address.parent = self
                        self.source_address_netio = Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self.vrf_name = None


                    class SourceAddress(object):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress']['meta_info']


                    class RpAddress(object):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress']['meta_info']


                    class SourceAddressNetio(object):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-netio'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio']['meta_info']


                    class GroupAddressNetio(object):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-netio'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio']['meta_info']

                    @property
                    def _common_path(self):
                        if self.tunnel_name is None:
                            raise YPYModelError('Key property tunnel_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:tunnels/Cisco-IOS-XR-ipv4-pim-oper:tunnel[Cisco-IOS-XR-ipv4-pim-oper:tunnel-name = ' + str(self.tunnel_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.tunnel_name is not None:
                            return True

                        if self.group_address_netio is not None and self.group_address_netio._has_data():
                            return True

                        if self.rp_address is not None and self.rp_address._has_data():
                            return True

                        if self.source_address is not None and self.source_address._has_data():
                            return True

                        if self.source_address_netio is not None and self.source_address_netio._has_data():
                            return True

                        if self.vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.Tunnels.Tunnel']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:tunnels'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.tunnel is not None:
                        for child_ref in self.tunnel:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.Tunnels']['meta_info']


            class MulticastStaticRoutes(object):
                """
                PIM multicast static route table
                
                .. attribute:: multicast_static_route
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.multicast_static_route = YList()
                    self.multicast_static_route.parent = self
                    self.multicast_static_route.name = 'multicast_static_route'


                class MulticastStaticRoute(object):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: address
                    
                    	Network address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: distance
                    
                    	Distance
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_via_lsm
                    
                    	LSM flag
                    	**type**\:  bool
                    
                    .. attribute:: nexthop
                    
                    	Next Hop
                    	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: prefix_length_xr
                    
                    	Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.address = None
                        self.distance = None
                        self.interface_name = None
                        self.is_via_lsm = None
                        self.nexthop = Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                        self.nexthop.parent = self
                        self.prefix = Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                        self.prefix.parent = self
                        self.prefix_length = None
                        self.prefix_length_xr = None


                    class Prefix(object):
                        """
                        Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-routes/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-route/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix']['meta_info']


                    class Nexthop(object):
                        """
                        Next Hop
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-routes/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-route/Cisco-IOS-XR-ipv4-pim-oper:nexthop'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-routes/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-route'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.address is not None:
                            return True

                        if self.distance is not None:
                            return True

                        if self.interface_name is not None:
                            return True

                        if self.is_via_lsm is not None:
                            return True

                        if self.nexthop is not None and self.nexthop._has_data():
                            return True

                        if self.prefix is not None and self.prefix._has_data():
                            return True

                        if self.prefix_length is not None:
                            return True

                        if self.prefix_length_xr is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-routes'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.multicast_static_route is not None:
                        for child_ref in self.multicast_static_route:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.MulticastStaticRoutes']['meta_info']


            class GroupMapMatchSources(object):
                """
                Find the matching group\-mapping with source
                information on specified group address
                
                .. attribute:: group_map_match_source
                
                	PIM group\-matching mapping entry with source information
                	**type**\: list of    :py:class:`GroupMapMatchSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.group_map_match_source = YList()
                    self.group_map_match_source.parent = self
                    self.group_map_match_source.name = 'group_map_match_source'


                class GroupMapMatchSource(object):
                    """
                    PIM group\-matching mapping entry with source
                    information
                    
                    .. attribute:: group_address  <key>
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation>`
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_address = None
                        self.expires = None
                        self.group_map_information = Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self.holdtime = None
                        self.source_of_information = Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self.uptime = None


                    class SourceOfInformation(object):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation']['meta_info']


                    class GroupMapInformation(object):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.group_count = None
                            self.is_override = None
                            self.is_used = None
                            self.mrib_active = None
                            self.prefix = Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.priority = None
                            self.protocol = None
                            self.rp_address = Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self


                        class Prefix(object):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix']['meta_info']


                        class RpAddress(object):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.group_count is not None:
                                return True

                            if self.is_override is not None:
                                return True

                            if self.is_used is not None:
                                return True

                            if self.mrib_active is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation']['meta_info']

                    @property
                    def _common_path(self):
                        if self.group_address is None:
                            raise YPYModelError('Key property group_address is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-source[Cisco-IOS-XR-ipv4-pim-oper:group-address = ' + str(self.group_address) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_address is not None:
                            return True

                        if self.expires is not None:
                            return True

                        if self.group_map_information is not None and self.group_map_information._has_data():
                            return True

                        if self.holdtime is not None:
                            return True

                        if self.source_of_information is not None and self.source_of_information._has_data():
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-sources'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.group_map_match_source is not None:
                        for child_ref in self.group_map_match_source:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.GroupMapMatchSources']['meta_info']


            class Neighbors(object):
                """
                PIM neighbor table
                
                .. attribute:: neighbor
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Neighbors.Neighbor>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.neighbor = YList()
                    self.neighbor.parent = self
                    self.neighbor.name = 'neighbor'


                class Neighbor(object):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.dr_priority = None
                        self.expires = None
                        self.expiry_timer = None
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bfd_state = None
                        self.is_bidirectional_capable = None
                        self.is_dr_priority_capable = None
                        self.is_ecmp_redirect_capable = None
                        self.is_proxy_capable = None
                        self.is_this_neighbor_dr = None
                        self.is_this_neighbor_us = None
                        self.neighbor_address = None
                        self.neighbor_address_xr = YList()
                        self.neighbor_address_xr.parent = self
                        self.neighbor_address_xr.name = 'neighbor_address_xr'
                        self.override_interval = None
                        self.propagation_delay = None
                        self.uptime = None


                    class NeighborAddressXr(object):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbors/Cisco-IOS-XR-ipv4-pim-oper:neighbor/Cisco-IOS-XR-ipv4-pim-oper:neighbor-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbors/Cisco-IOS-XR-ipv4-pim-oper:neighbor'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.dr_priority is not None:
                            return True

                        if self.expires is not None:
                            return True

                        if self.expiry_timer is not None:
                            return True

                        if self.interface_name is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bfd_state is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_dr_priority_capable is not None:
                            return True

                        if self.is_ecmp_redirect_capable is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.is_this_neighbor_dr is not None:
                            return True

                        if self.is_this_neighbor_us is not None:
                            return True

                        if self.neighbor_address is not None:
                            return True

                        if self.neighbor_address_xr is not None:
                            for child_ref in self.neighbor_address_xr:
                                if child_ref._has_data():
                                    return True

                        if self.override_interval is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.DefaultContext.Neighbors.Neighbor']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbors'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.neighbor is not None:
                        for child_ref in self.neighbor:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.DefaultContext.Neighbors']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.auto_rp is not None and self.auto_rp._has_data():
                    return True

                if self.bgp_afs is not None and self.bgp_afs._has_data():
                    return True

                if self.bidir_df_states is not None and self.bidir_df_states._has_data():
                    return True

                if self.bidir_df_winners is not None and self.bidir_df_winners._has_data():
                    return True

                if self.bsr is not None and self.bsr._has_data():
                    return True

                if self.context is not None and self.context._has_data():
                    return True

                if self.global_interfaces is not None and self.global_interfaces._has_data():
                    return True

                if self.gre is not None and self.gre._has_data():
                    return True

                if self.group_map_match_rpfs is not None and self.group_map_match_rpfs._has_data():
                    return True

                if self.group_map_match_sources is not None and self.group_map_match_sources._has_data():
                    return True

                if self.group_map_rpfs is not None and self.group_map_rpfs._has_data():
                    return True

                if self.group_map_sources is not None and self.group_map_sources._has_data():
                    return True

                if self.ifrs_interfaces is not None and self.ifrs_interfaces._has_data():
                    return True

                if self.ifrs_summary is not None and self.ifrs_summary._has_data():
                    return True

                if self.interface_old_formats is not None and self.interface_old_formats._has_data():
                    return True

                if self.interface_statistics is not None and self.interface_statistics._has_data():
                    return True

                if self.interfaces is not None and self.interfaces._has_data():
                    return True

                if self.jp_statistics is not None and self.jp_statistics._has_data():
                    return True

                if self.mib_databases is not None and self.mib_databases._has_data():
                    return True

                if self.multicast_static_routes is not None and self.multicast_static_routes._has_data():
                    return True

                if self.neighbor_old_formats is not None and self.neighbor_old_formats._has_data():
                    return True

                if self.neighbor_summaries is not None and self.neighbor_summaries._has_data():
                    return True

                if self.neighbors is not None and self.neighbors._has_data():
                    return True

                if self.net_io_tunnels is not None and self.net_io_tunnels._has_data():
                    return True

                if self.ranges is not None and self.ranges._has_data():
                    return True

                if self.route_policy is not None and self.route_policy._has_data():
                    return True

                if self.rpf_redirect is not None and self.rpf_redirect._has_data():
                    return True

                if self.rpf_summary is not None and self.rpf_summary._has_data():
                    return True

                if self.safs is not None and self.safs._has_data():
                    return True

                if self.summary is not None and self.summary._has_data():
                    return True

                if self.table_contexts is not None and self.table_contexts._has_data():
                    return True

                if self.topologies is not None and self.topologies._has_data():
                    return True

                if self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts._has_data():
                    return True

                if self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts._has_data():
                    return True

                if self.topology_route_count is not None and self.topology_route_count._has_data():
                    return True

                if self.traffic_counters is not None and self.traffic_counters._has_data():
                    return True

                if self.tunnels is not None and self.tunnels._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                return meta._meta_table['Pim.Standby.DefaultContext']['meta_info']


        class Process(object):
            """
            Process
            
            .. attribute:: checkpoint_statistics
            
            	Checkpoint Statistics
            	**type**\:   :py:class:`CheckpointStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process.CheckpointStatistics>`
            
            .. attribute:: issu
            
            	ISSU Information
            	**type**\:   :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process.Issu>`
            
            .. attribute:: nsf
            
            	PIM NSF information
            	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process.Nsf>`
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process.Nsr>`
            
            .. attribute:: summary
            
            	PIM Global Summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process.Summary>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.checkpoint_statistics = Pim.Standby.Process.CheckpointStatistics()
                self.checkpoint_statistics.parent = self
                self.issu = Pim.Standby.Process.Issu()
                self.issu.parent = self
                self.nsf = Pim.Standby.Process.Nsf()
                self.nsf.parent = self
                self.nsr = Pim.Standby.Process.Nsr()
                self.nsr.parent = self
                self.summary = Pim.Standby.Process.Summary()
                self.summary.parent = self


            class CheckpointStatistics(object):
                """
                Checkpoint Statistics
                
                .. attribute:: checkpoint_table
                
                	Array of chkpt table stats
                	**type**\: list of    :py:class:`CheckpointTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process.CheckpointStatistics.CheckpointTable>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.checkpoint_table = YList()
                    self.checkpoint_table.parent = self
                    self.checkpoint_table.name = 'checkpoint_table'


                class CheckpointTable(object):
                    """
                    Array of chkpt table stats
                    
                    .. attribute:: is_mirrored
                    
                    	Table mirrored
                    	**type**\:  bool
                    
                    .. attribute:: statistic
                    
                    	Stats array
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_description
                    
                    	Table description
                    	**type**\:  str
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.is_mirrored = None
                        self.statistic = YLeafList()
                        self.statistic.parent = self
                        self.statistic.name = 'statistic'
                        self.table_description = None
                        self.table_name = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:checkpoint-statistics/Cisco-IOS-XR-ipv4-pim-oper:checkpoint-table'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.is_mirrored is not None:
                            return True

                        if self.statistic is not None:
                            for child in self.statistic:
                                if child is not None:
                                    return True

                        if self.table_description is not None:
                            return True

                        if self.table_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Process.CheckpointStatistics.CheckpointTable']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:checkpoint-statistics'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.checkpoint_table is not None:
                        for child_ref in self.checkpoint_table:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.Process.CheckpointStatistics']['meta_info']


            class Nsr(object):
                """
                NSR Information
                
                .. attribute:: count_connection_dn
                
                	No. of times connection went down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_connection_up
                
                	No. of times connection went up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_connection_dn
                
                	Time when connection went down
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_connection_up
                
                	Time when connection went up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: partner_connected
                
                	Partner process connected
                	**type**\:  bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\:  bool
                
                .. attribute:: rmf_timer_expiry
                
                	Time for RMF timer to expire
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: rmf_timer_valid
                
                	Is RMF timer running ?
                	**type**\:  bool
                
                .. attribute:: state
                
                	NSR state
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.count_connection_dn = None
                    self.count_connection_up = None
                    self.count_rmf_not_ready = None
                    self.count_rmf_ready = None
                    self.last_connection_dn = None
                    self.last_connection_up = None
                    self.last_rmf_not_ready = None
                    self.last_rmf_ready = None
                    self.partner_connected = None
                    self.rmf_notification_done = None
                    self.rmf_timer_expiry = None
                    self.rmf_timer_valid = None
                    self.state = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:nsr'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.count_connection_dn is not None:
                        return True

                    if self.count_connection_up is not None:
                        return True

                    if self.count_rmf_not_ready is not None:
                        return True

                    if self.count_rmf_ready is not None:
                        return True

                    if self.last_connection_dn is not None:
                        return True

                    if self.last_connection_up is not None:
                        return True

                    if self.last_rmf_not_ready is not None:
                        return True

                    if self.last_rmf_ready is not None:
                        return True

                    if self.partner_connected is not None:
                        return True

                    if self.rmf_notification_done is not None:
                        return True

                    if self.rmf_timer_expiry is not None:
                        return True

                    if self.rmf_timer_valid is not None:
                        return True

                    if self.state is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.Process.Nsr']['meta_info']


            class Summary(object):
                """
                PIM Global Summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bsr_candidate_rp_set_count = None
                    self.bsr_candidate_rp_set_limit = None
                    self.bsr_candidate_rp_set_threshold = None
                    self.bsr_range_threshold = None
                    self.bsr_ranges_count = None
                    self.bsr_ranges_limit = None
                    self.global_auto_rp_ranges_limit = None
                    self.global_bsr_candidate_rp_set_count = None
                    self.global_bsr_candidate_rp_set_limit = None
                    self.global_bsr_candidate_rp_set_threshold = None
                    self.global_bsr_ranges_count = None
                    self.global_bsr_ranges_limit = None
                    self.global_bsr_ranges_threshold = None
                    self.global_register_limit = None
                    self.is_bsr_ranges_threshold_reached = None
                    self.is_global_auto_rp_ranges_limit_reached = None
                    self.is_global_bsr_ranges_limit_reached = None
                    self.is_global_register_limit_reached = None
                    self.is_global_route_limit_reached = None
                    self.is_global_rxi_limit_reached = None
                    self.is_maximum_enforcement_disabled = None
                    self.is_node_low_memory = None
                    self.is_ranges_limit_reached = None
                    self.is_route_limit_reached = None
                    self.ranges_count = None
                    self.ranges_limit = None
                    self.ranges_threshold = None
                    self.register_count = None
                    self.register_limit = None
                    self.register_limit_reached = None
                    self.register_threshold = None
                    self.route_count = None
                    self.route_limit = None
                    self.route_low_water_mark = None
                    self.route_threshold = None
                    self.rxi_limit_reached = None
                    self.rxi_low_water_mark = None
                    self.topology_interface_state_count = None
                    self.topology_interface_state_limit = None
                    self.topology_interface_state_threshold = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bsr_candidate_rp_set_count is not None:
                        return True

                    if self.bsr_candidate_rp_set_limit is not None:
                        return True

                    if self.bsr_candidate_rp_set_threshold is not None:
                        return True

                    if self.bsr_range_threshold is not None:
                        return True

                    if self.bsr_ranges_count is not None:
                        return True

                    if self.bsr_ranges_limit is not None:
                        return True

                    if self.global_auto_rp_ranges_limit is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_count is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_limit is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_threshold is not None:
                        return True

                    if self.global_bsr_ranges_count is not None:
                        return True

                    if self.global_bsr_ranges_limit is not None:
                        return True

                    if self.global_bsr_ranges_threshold is not None:
                        return True

                    if self.global_register_limit is not None:
                        return True

                    if self.is_bsr_ranges_threshold_reached is not None:
                        return True

                    if self.is_global_auto_rp_ranges_limit_reached is not None:
                        return True

                    if self.is_global_bsr_ranges_limit_reached is not None:
                        return True

                    if self.is_global_register_limit_reached is not None:
                        return True

                    if self.is_global_route_limit_reached is not None:
                        return True

                    if self.is_global_rxi_limit_reached is not None:
                        return True

                    if self.is_maximum_enforcement_disabled is not None:
                        return True

                    if self.is_node_low_memory is not None:
                        return True

                    if self.is_ranges_limit_reached is not None:
                        return True

                    if self.is_route_limit_reached is not None:
                        return True

                    if self.ranges_count is not None:
                        return True

                    if self.ranges_limit is not None:
                        return True

                    if self.ranges_threshold is not None:
                        return True

                    if self.register_count is not None:
                        return True

                    if self.register_limit is not None:
                        return True

                    if self.register_limit_reached is not None:
                        return True

                    if self.register_threshold is not None:
                        return True

                    if self.route_count is not None:
                        return True

                    if self.route_limit is not None:
                        return True

                    if self.route_low_water_mark is not None:
                        return True

                    if self.route_threshold is not None:
                        return True

                    if self.rxi_limit_reached is not None:
                        return True

                    if self.rxi_low_water_mark is not None:
                        return True

                    if self.topology_interface_state_count is not None:
                        return True

                    if self.topology_interface_state_limit is not None:
                        return True

                    if self.topology_interface_state_threshold is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.Process.Summary']['meta_info']


            class Nsf(object):
                """
                PIM NSF information
                
                .. attribute:: configured_state
                
                	Is Multicast NSF Configured
                	**type**\:  bool
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_sec
                
                	Last ICD Notif Recv in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off_sec
                
                	Last NSF time OFF in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_sec
                
                	Last NSF time ON in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: nsf_state
                
                	Are we currently in NSF
                	**type**\:  bool
                
                .. attribute:: nsf_time_left
                
                	Multicast NSF time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: nsf_timeout
                
                	Multicast NSF timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: waiting_membership
                
                	Waiting for IGMP/MLD
                	**type**\:  bool
                
                .. attribute:: waiting_timer
                
                	Waiting for NSF timer expiry
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.configured_state = None
                    self.last_icd_notif_recv = None
                    self.last_icd_notif_recv_sec = None
                    self.last_nsf_off = None
                    self.last_nsf_off_sec = None
                    self.last_nsf_on = None
                    self.last_nsf_on_sec = None
                    self.nsf_state = None
                    self.nsf_time_left = None
                    self.nsf_timeout = None
                    self.respawn_count = None
                    self.waiting_membership = None
                    self.waiting_timer = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:nsf'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.configured_state is not None:
                        return True

                    if self.last_icd_notif_recv is not None:
                        return True

                    if self.last_icd_notif_recv_sec is not None:
                        return True

                    if self.last_nsf_off is not None:
                        return True

                    if self.last_nsf_off_sec is not None:
                        return True

                    if self.last_nsf_on is not None:
                        return True

                    if self.last_nsf_on_sec is not None:
                        return True

                    if self.nsf_state is not None:
                        return True

                    if self.nsf_time_left is not None:
                        return True

                    if self.nsf_timeout is not None:
                        return True

                    if self.respawn_count is not None:
                        return True

                    if self.waiting_membership is not None:
                        return True

                    if self.waiting_timer is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.Process.Nsf']['meta_info']


            class Issu(object):
                """
                ISSU Information
                
                .. attribute:: checkpoint_idt_timestamp
                
                	Time when Checkpoint IDT done
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: eoc_received_timestamp
                
                	Time when EOC was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: ihms_received_timestamp
                
                	Time when IHMS done was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: informationvalid
                
                	Is Information valid ?
                	**type**\:  bool
                
                .. attribute:: is_checkpoint_idt_done
                
                	Was Checkpoint IDT done ?
                	**type**\:  bool
                
                .. attribute:: is_eoc_received
                
                	Was EOC received ?
                	**type**\:  bool
                
                .. attribute:: is_ihms_done_received
                
                	Was IHMS done received ?
                	**type**\:  bool
                
                .. attribute:: is_nbr_sync_received
                
                	Was NBR Sync achieved ?
                	**type**\:  bool
                
                .. attribute:: is_rib_sync_received
                
                	Was RIB Sync received ?
                	**type**\:  bool
                
                .. attribute:: last_ha_role_notification_received
                
                	Time when last HA role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_phase_notification_received
                
                	Time when last ISSU Phase nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_role_notification_received
                
                	Time when last ISSU role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: nbr_sync_received_timestamp
                
                	Time when NBR Sync was achieved
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: phase_issu
                
                	ISSU Phase
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: rib_sync_received_timestamp
                
                	Time when RIB Sync was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: role_ha
                
                	HA role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: role_issu
                
                	ISSU role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.checkpoint_idt_timestamp = None
                    self.eoc_received_timestamp = None
                    self.ihms_received_timestamp = None
                    self.informationvalid = None
                    self.is_checkpoint_idt_done = None
                    self.is_eoc_received = None
                    self.is_ihms_done_received = None
                    self.is_nbr_sync_received = None
                    self.is_rib_sync_received = None
                    self.last_ha_role_notification_received = None
                    self.last_issu_phase_notification_received = None
                    self.last_issu_role_notification_received = None
                    self.nbr_sync_received_timestamp = None
                    self.phase_issu = None
                    self.rib_sync_received_timestamp = None
                    self.role_ha = None
                    self.role_issu = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:issu'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.checkpoint_idt_timestamp is not None:
                        return True

                    if self.eoc_received_timestamp is not None:
                        return True

                    if self.ihms_received_timestamp is not None:
                        return True

                    if self.informationvalid is not None:
                        return True

                    if self.is_checkpoint_idt_done is not None:
                        return True

                    if self.is_eoc_received is not None:
                        return True

                    if self.is_ihms_done_received is not None:
                        return True

                    if self.is_nbr_sync_received is not None:
                        return True

                    if self.is_rib_sync_received is not None:
                        return True

                    if self.last_ha_role_notification_received is not None:
                        return True

                    if self.last_issu_phase_notification_received is not None:
                        return True

                    if self.last_issu_role_notification_received is not None:
                        return True

                    if self.nbr_sync_received_timestamp is not None:
                        return True

                    if self.phase_issu is not None:
                        return True

                    if self.rib_sync_received_timestamp is not None:
                        return True

                    if self.role_ha is not None:
                        return True

                    if self.role_issu is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.Process.Issu']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:process'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.checkpoint_statistics is not None and self.checkpoint_statistics._has_data():
                    return True

                if self.issu is not None and self.issu._has_data():
                    return True

                if self.nsf is not None and self.nsf._has_data():
                    return True

                if self.nsr is not None and self.nsr._has_data():
                    return True

                if self.summary is not None and self.summary._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                return meta._meta_table['Pim.Standby.Process']['meta_info']


        class Vrfs(object):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF name
            	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.vrf = YList()
                self.vrf.parent = self
                self.vrf.name = 'vrf'


            class Vrf(object):
                """
                VRF name
                
                .. attribute:: vrf_name  <key>
                
                	VRF name 
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: auto_rp
                
                	PIM Auto\-RP information
                	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.AutoRp>`
                
                .. attribute:: bgp_afs
                
                	PIM BGP SAFI table
                	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BgpAfs>`
                
                .. attribute:: bidir_df_states
                
                	Bidirectional PIM DF election state table
                	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfStates>`
                
                .. attribute:: bidir_df_winners
                
                	Bidirectional PIM DF election winner table
                	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfWinners>`
                
                .. attribute:: bsr
                
                	PIM BSR information
                	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr>`
                
                .. attribute:: context
                
                	PIM context information
                	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context>`
                
                .. attribute:: gre
                
                	GRE information
                	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre>`
                
                .. attribute:: group_map_match_rpfs
                
                	Find matching group\-mapping for the specified group address
                	**type**\:   :py:class:`GroupMapMatchRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs>`
                
                .. attribute:: group_map_match_sources
                
                	Find the matching group\-mapping with source information on specified group address
                	**type**\:   :py:class:`GroupMapMatchSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchSources>`
                
                .. attribute:: group_map_rpfs
                
                	PIM group mapping information
                	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs>`
                
                .. attribute:: group_map_sources
                
                	PIM group\-mapping with source information
                	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources>`
                
                .. attribute:: ifrs_interfaces
                
                	PIM interfaces in forward reference store table
                	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: ifrs_summary
                
                	PIM interfaces in forward reference store summary
                	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.IfrsSummary>`
                
                .. attribute:: interface_old_formats
                
                	PIM interfaces in old format
                	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceOldFormats>`
                
                .. attribute:: interface_statistics
                
                	PIM interface statistics
                	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceStatistics>`
                
                .. attribute:: interfaces
                
                	PIM interfaces
                	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Interfaces>`
                
                .. attribute:: jp_statistics
                
                	PIM join prune statistics table
                	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.JpStatistics>`
                
                .. attribute:: mib_databases
                
                	PIM group database for mroute mibs table
                	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases>`
                
                .. attribute:: multicast_static_routes
                
                	PIM multicast static route table
                	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes>`
                
                .. attribute:: neighbor_old_formats
                
                	PIM neighbor table old format
                	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NeighborOldFormats>`
                
                .. attribute:: neighbor_summaries
                
                	PIM neighbor summary table
                	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NeighborSummaries>`
                
                .. attribute:: neighbors
                
                	PIM neighbor table
                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Neighbors>`
                
                .. attribute:: net_io_tunnels
                
                	Tunnel information that NETIO has 
                	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels>`
                
                .. attribute:: ranges
                
                	PIM range list information
                	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges>`
                
                .. attribute:: route_policy
                
                	PIM route policy
                	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy>`
                
                .. attribute:: rpf_redirect
                
                	PIM ECMP RPF\-redirect bundle
                	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect>`
                
                .. attribute:: rpf_summary
                
                	PIM RPF registration summary
                	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfSummary>`
                
                .. attribute:: safs
                
                	SAFI table and type
                	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs>`
                
                .. attribute:: summary
                
                	PIM summary
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Summary>`
                
                .. attribute:: table_contexts
                
                	PIM table context list
                	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TableContexts>`
                
                .. attribute:: topologies
                
                	PIM topology table
                	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies>`
                
                .. attribute:: topology_entry_flag_route_counts
                
                	Route count for topology with entry flag set
                	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts>`
                
                .. attribute:: topology_interface_flag_route_counts
                
                	Route count for topology with interface flag set
                	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts>`
                
                .. attribute:: topology_route_count
                
                	Topology route count information from PIM topology table
                	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyRouteCount>`
                
                .. attribute:: traffic_counters
                
                	PIM message traffic counters
                	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TrafficCounters>`
                
                .. attribute:: tunnels
                
                	Tunnels information that PIM has
                	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.vrf_name = None
                    self.auto_rp = Pim.Standby.Vrfs.Vrf.AutoRp()
                    self.auto_rp.parent = self
                    self.bgp_afs = Pim.Standby.Vrfs.Vrf.BgpAfs()
                    self.bgp_afs.parent = self
                    self.bidir_df_states = Pim.Standby.Vrfs.Vrf.BidirDfStates()
                    self.bidir_df_states.parent = self
                    self.bidir_df_winners = Pim.Standby.Vrfs.Vrf.BidirDfWinners()
                    self.bidir_df_winners.parent = self
                    self.bsr = Pim.Standby.Vrfs.Vrf.Bsr()
                    self.bsr.parent = self
                    self.context = Pim.Standby.Vrfs.Vrf.Context()
                    self.context.parent = self
                    self.gre = Pim.Standby.Vrfs.Vrf.Gre()
                    self.gre.parent = self
                    self.group_map_match_rpfs = Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs()
                    self.group_map_match_rpfs.parent = self
                    self.group_map_match_sources = Pim.Standby.Vrfs.Vrf.GroupMapMatchSources()
                    self.group_map_match_sources.parent = self
                    self.group_map_rpfs = Pim.Standby.Vrfs.Vrf.GroupMapRpfs()
                    self.group_map_rpfs.parent = self
                    self.group_map_sources = Pim.Standby.Vrfs.Vrf.GroupMapSources()
                    self.group_map_sources.parent = self
                    self.ifrs_interfaces = Pim.Standby.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self.ifrs_summary = Pim.Standby.Vrfs.Vrf.IfrsSummary()
                    self.ifrs_summary.parent = self
                    self.interface_old_formats = Pim.Standby.Vrfs.Vrf.InterfaceOldFormats()
                    self.interface_old_formats.parent = self
                    self.interface_statistics = Pim.Standby.Vrfs.Vrf.InterfaceStatistics()
                    self.interface_statistics.parent = self
                    self.interfaces = Pim.Standby.Vrfs.Vrf.Interfaces()
                    self.interfaces.parent = self
                    self.jp_statistics = Pim.Standby.Vrfs.Vrf.JpStatistics()
                    self.jp_statistics.parent = self
                    self.mib_databases = Pim.Standby.Vrfs.Vrf.MibDatabases()
                    self.mib_databases.parent = self
                    self.multicast_static_routes = Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes()
                    self.multicast_static_routes.parent = self
                    self.neighbor_old_formats = Pim.Standby.Vrfs.Vrf.NeighborOldFormats()
                    self.neighbor_old_formats.parent = self
                    self.neighbor_summaries = Pim.Standby.Vrfs.Vrf.NeighborSummaries()
                    self.neighbor_summaries.parent = self
                    self.neighbors = Pim.Standby.Vrfs.Vrf.Neighbors()
                    self.neighbors.parent = self
                    self.net_io_tunnels = Pim.Standby.Vrfs.Vrf.NetIoTunnels()
                    self.net_io_tunnels.parent = self
                    self.ranges = Pim.Standby.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self.route_policy = Pim.Standby.Vrfs.Vrf.RoutePolicy()
                    self.route_policy.parent = self
                    self.rpf_redirect = Pim.Standby.Vrfs.Vrf.RpfRedirect()
                    self.rpf_redirect.parent = self
                    self.rpf_summary = Pim.Standby.Vrfs.Vrf.RpfSummary()
                    self.rpf_summary.parent = self
                    self.safs = Pim.Standby.Vrfs.Vrf.Safs()
                    self.safs.parent = self
                    self.summary = Pim.Standby.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self.table_contexts = Pim.Standby.Vrfs.Vrf.TableContexts()
                    self.table_contexts.parent = self
                    self.topologies = Pim.Standby.Vrfs.Vrf.Topologies()
                    self.topologies.parent = self
                    self.topology_entry_flag_route_counts = Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts()
                    self.topology_entry_flag_route_counts.parent = self
                    self.topology_interface_flag_route_counts = Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts()
                    self.topology_interface_flag_route_counts.parent = self
                    self.topology_route_count = Pim.Standby.Vrfs.Vrf.TopologyRouteCount()
                    self.topology_route_count.parent = self
                    self.traffic_counters = Pim.Standby.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self.tunnels = Pim.Standby.Vrfs.Vrf.Tunnels()
                    self.tunnels.parent = self


                class IfrsInterfaces(object):
                    """
                    PIM interfaces in forward reference store table
                    
                    .. attribute:: ifrs_interface
                    
                    	PIM IFRS interface information
                    	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ifrs_interface = YList()
                        self.ifrs_interface.parent = self
                        self.ifrs_interface.name = 'ifrs_interface'


                    class IfrsInterface(object):
                        """
                        PIM IFRS interface information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.configured_override_interval = None
                            self.configured_propagation_delay = None
                            self.dr_address = Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress()
                            self.dr_address.parent = self
                            self.dr_priority = None
                            self.external_neighbor_count = None
                            self.generation_id = None
                            self.hello_expiry = None
                            self.hello_interval = None
                            self.idb_acl_name = None
                            self.idb_acl_provided = None
                            self.idb_current_count = None
                            self.idb_max_count = None
                            self.idb_oor_enabled = None
                            self.idb_threshold_count = None
                            self.interface_address = YList()
                            self.interface_address.parent = self
                            self.interface_address.name = 'interface_address'
                            self.interface_address_mask = None
                            self.interface_name_xr = None
                            self.is_batch_asserts_capable = None
                            self.is_bidirectional_capable = None
                            self.is_enabled = None
                            self.is_proxy_capable = None
                            self.join_prune_interval = None
                            self.neighbor_count = None
                            self.neighbor_filter_name = None
                            self.override_interval = None
                            self.passive_interface = None
                            self.propagation_delay = None
                            self.prune_delay_enabled = None
                            self.virtual_interface = None


                        class DrAddress(object):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress']['meta_info']


                        class InterfaceAddress(object):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:ifrs-interface[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.are_we_dr is not None:
                                return True

                            if self.bfd_enabled is not None:
                                return True

                            if self.bfd_interval is not None:
                                return True

                            if self.bfd_multiplier is not None:
                                return True

                            if self.configured_override_interval is not None:
                                return True

                            if self.configured_propagation_delay is not None:
                                return True

                            if self.dr_address is not None and self.dr_address._has_data():
                                return True

                            if self.dr_priority is not None:
                                return True

                            if self.external_neighbor_count is not None:
                                return True

                            if self.generation_id is not None:
                                return True

                            if self.hello_expiry is not None:
                                return True

                            if self.hello_interval is not None:
                                return True

                            if self.idb_acl_name is not None:
                                return True

                            if self.idb_acl_provided is not None:
                                return True

                            if self.idb_current_count is not None:
                                return True

                            if self.idb_max_count is not None:
                                return True

                            if self.idb_oor_enabled is not None:
                                return True

                            if self.idb_threshold_count is not None:
                                return True

                            if self.interface_address is not None:
                                for child_ref in self.interface_address:
                                    if child_ref._has_data():
                                        return True

                            if self.interface_address_mask is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.is_batch_asserts_capable is not None:
                                return True

                            if self.is_bidirectional_capable is not None:
                                return True

                            if self.is_enabled is not None:
                                return True

                            if self.is_proxy_capable is not None:
                                return True

                            if self.join_prune_interval is not None:
                                return True

                            if self.neighbor_count is not None:
                                return True

                            if self.neighbor_filter_name is not None:
                                return True

                            if self.override_interval is not None:
                                return True

                            if self.passive_interface is not None:
                                return True

                            if self.propagation_delay is not None:
                                return True

                            if self.prune_delay_enabled is not None:
                                return True

                            if self.virtual_interface is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:ifrs-interfaces'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ifrs_interface is not None:
                            for child_ref in self.ifrs_interface:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.IfrsInterfaces']['meta_info']


                class Safs(object):
                    """
                    SAFI table and type
                    
                    .. attribute:: saf
                    
                    	SAF name 
                    	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.saf = YList()
                        self.saf.parent = self
                        self.saf.name = 'saf'


                    class Saf(object):
                        """
                        SAF name 
                        
                        .. attribute:: rpf_hash_source_groups
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups>`
                        
                        .. attribute:: rpf_hash_sources
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources>`
                        
                        .. attribute:: rpfs
                        
                        	PIM RPF information table
                        	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs>`
                        
                        .. attribute:: saf_name
                        
                        	SAF name 
                        	**type**\:   :py:class:`PimSafiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafiEnum>`
                        
                        .. attribute:: topology_name
                        
                        	Topology name 
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rpf_hash_source_groups = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups()
                            self.rpf_hash_source_groups.parent = self
                            self.rpf_hash_sources = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources()
                            self.rpf_hash_sources.parent = self
                            self.rpfs = Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs()
                            self.rpfs.parent = self
                            self.saf_name = None
                            self.topology_name = None


                        class RpfHashSourceGroups(object):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source_group
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.rpf_hash_source_group = YList()
                                self.rpf_hash_source_group.parent = self
                                self.rpf_hash_source_group.name = 'rpf_hash_source_group'


                            class RpfHashSourceGroup(object):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: group_address
                                
                                	Group address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: mask_length
                                
                                	Hash mask length
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.group_address = None
                                    self.mask_length = None
                                    self.mofrr = None
                                    self.next_hop_address = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self.next_hop_interface = None
                                    self.next_hop_multipath_enabled = None
                                    self.secondary_next_hop_address = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self.secondary_next_hop_interface = None
                                    self.source_address = None


                                class NextHopAddress(object):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:next-hop-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress']['meta_info']


                                class SecondaryNextHopAddress(object):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:secondary-next-hop-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-group'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.group_address is not None:
                                        return True

                                    if self.mask_length is not None:
                                        return True

                                    if self.mofrr is not None:
                                        return True

                                    if self.next_hop_address is not None and self.next_hop_address._has_data():
                                        return True

                                    if self.next_hop_interface is not None:
                                        return True

                                    if self.next_hop_multipath_enabled is not None:
                                        return True

                                    if self.secondary_next_hop_address is not None and self.secondary_next_hop_address._has_data():
                                        return True

                                    if self.secondary_next_hop_interface is not None:
                                        return True

                                    if self.source_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-groups'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.rpf_hash_source_group is not None:
                                    for child_ref in self.rpf_hash_source_group:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups']['meta_info']


                        class RpfHashSources(object):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.rpf_hash_source = YList()
                                self.rpf_hash_source.parent = self
                                self.rpf_hash_source.name = 'rpf_hash_source'


                            class RpfHashSource(object):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mofrr = None
                                    self.next_hop_address = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self.next_hop_interface = None
                                    self.next_hop_multipath_enabled = None
                                    self.secondary_next_hop_address = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self.secondary_next_hop_interface = None
                                    self.source_address = None


                                class NextHopAddress(object):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:next-hop-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress']['meta_info']


                                class SecondaryNextHopAddress(object):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:secondary-next-hop-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mofrr is not None:
                                        return True

                                    if self.next_hop_address is not None and self.next_hop_address._has_data():
                                        return True

                                    if self.next_hop_interface is not None:
                                        return True

                                    if self.next_hop_multipath_enabled is not None:
                                        return True

                                    if self.secondary_next_hop_address is not None and self.secondary_next_hop_address._has_data():
                                        return True

                                    if self.secondary_next_hop_interface is not None:
                                        return True

                                    if self.source_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-sources'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.rpf_hash_source is not None:
                                    for child_ref in self.rpf_hash_source:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources']['meta_info']


                        class Rpfs(object):
                            """
                            PIM RPF information table
                            
                            .. attribute:: rpf
                            
                            	PIM RPF information
                            	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.rpf = YList()
                                self.rpf.parent = self
                                self.rpf.name = 'rpf'


                            class Rpf(object):
                                """
                                PIM RPF information
                                
                                .. attribute:: registered_address  <key>
                                
                                	Address for which RPF lookup
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: is_connected
                                
                                	Are we connected ?
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_rpf_bgp_route
                                
                                	Is RPF through BGP route
                                	**type**\:  bool
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_preference
                                
                                	Metric preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: registered_address_xr
                                
                                	Address registered
                                	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                                
                                .. attribute:: rpf_path
                                
                                	RPF Paths list
                                	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.registered_address = None
                                    self.is_connected = None
                                    self.is_rpf_bgp_route = None
                                    self.metric = None
                                    self.metric_preference = None
                                    self.registered_address_xr = Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                    self.registered_address_xr.parent = self
                                    self.rpf_path = YList()
                                    self.rpf_path.parent = self
                                    self.rpf_path.name = 'rpf_path'


                                class RegisteredAddressXr(object):
                                    """
                                    Address registered
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:registered-address-xr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr']['meta_info']


                                class RpfPath(object):
                                    """
                                    RPF Paths list
                                    
                                    .. attribute:: connector
                                    
                                    	Connector Attribute
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: extranet_vrf_name
                                    
                                    	Extranet VRF name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    .. attribute:: is_connector_attribute_present
                                    
                                    	Connector attribute present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rpf_interface_disabled
                                    
                                    	Is the rpf interface disabled ?
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_lsm
                                    
                                    	Via LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_mlsm
                                    
                                    	Via Mstatic LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpf_interface_name
                                    
                                    	RPF Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: rpf_neighbor
                                    
                                    	RPF neighbor
                                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                    
                                    .. attribute:: rpf_nexthop
                                    
                                    	RPF nexthop
                                    	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.connector = None
                                        self.extranet_vrf_name = None
                                        self.is_connector_attribute_present = None
                                        self.is_rpf_interface_disabled = None
                                        self.is_via_lsm = None
                                        self.is_via_mlsm = None
                                        self.rpf_interface_name = None
                                        self.rpf_neighbor = Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                        self.rpf_neighbor.parent = self
                                        self.rpf_nexthop = Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                        self.rpf_nexthop.parent = self


                                    class RpfNeighbor(object):
                                        """
                                        RPF neighbor
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor']['meta_info']


                                    class RpfNexthop(object):
                                        """
                                        RPF nexthop
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-nexthop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.connector is not None:
                                            return True

                                        if self.extranet_vrf_name is not None:
                                            return True

                                        if self.is_connector_attribute_present is not None:
                                            return True

                                        if self.is_rpf_interface_disabled is not None:
                                            return True

                                        if self.is_via_lsm is not None:
                                            return True

                                        if self.is_via_mlsm is not None:
                                            return True

                                        if self.rpf_interface_name is not None:
                                            return True

                                        if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                            return True

                                        if self.rpf_nexthop is not None and self.rpf_nexthop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.registered_address is None:
                                        raise YPYModelError('Key property registered_address is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf[Cisco-IOS-XR-ipv4-pim-oper:registered-address = ' + str(self.registered_address) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.registered_address is not None:
                                        return True

                                    if self.is_connected is not None:
                                        return True

                                    if self.is_rpf_bgp_route is not None:
                                        return True

                                    if self.metric is not None:
                                        return True

                                    if self.metric_preference is not None:
                                        return True

                                    if self.registered_address_xr is not None and self.registered_address_xr._has_data():
                                        return True

                                    if self.rpf_path is not None:
                                        for child_ref in self.rpf_path:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpfs'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.rpf is not None:
                                    for child_ref in self.rpf:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:saf'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups._has_data():
                                return True

                            if self.rpf_hash_sources is not None and self.rpf_hash_sources._has_data():
                                return True

                            if self.rpfs is not None and self.rpfs._has_data():
                                return True

                            if self.saf_name is not None:
                                return True

                            if self.topology_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.Safs.Saf']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:safs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.saf is not None:
                            for child_ref in self.saf:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.Safs']['meta_info']


                class InterfaceStatistics(object):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_statistic
                    
                    	PIM interface statistics
                    	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_statistic = YList()
                        self.interface_statistic.parent = self
                        self.interface_statistic.name = 'interface_statistic'


                    class InterfaceStatistic(object):
                        """
                        PIM interface statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: input_assert
                        
                        	Assert packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_bsr_message
                        
                        	Input BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_candidate_rp_advertisement
                        
                        	Input Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_df_election
                        
                        	DF Election packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_ack_message
                        
                        	Input Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_message
                        
                        	Input Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_hello
                        
                        	Hello packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_jp
                        
                        	Join Prune packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_miscellaneous
                        
                        	Miscellaneous packet in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register
                        
                        	Register packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register_stop
                        
                        	Register Stop packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_assert
                        
                        	Assert packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_bsr_message
                        
                        	Output BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_candidate_rp_advertisement
                        
                        	Output Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_df_election
                        
                        	DF Election packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_ack_message
                        
                        	Output Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_message
                        
                        	Output Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_hello
                        
                        	Hello packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_jp
                        
                        	Join Prune packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register
                        
                        	Register packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register_stop
                        
                        	Register Stop packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.input_assert = None
                            self.input_bsr_message = None
                            self.input_candidate_rp_advertisement = None
                            self.input_df_election = None
                            self.input_graft_ack_message = None
                            self.input_graft_message = None
                            self.input_hello = None
                            self.input_jp = None
                            self.input_miscellaneous = None
                            self.input_register = None
                            self.input_register_stop = None
                            self.output_assert = None
                            self.output_bsr_message = None
                            self.output_candidate_rp_advertisement = None
                            self.output_df_election = None
                            self.output_graft_ack_message = None
                            self.output_graft_message = None
                            self.output_hello = None
                            self.output_jp = None
                            self.output_register = None
                            self.output_register_stop = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-statistic[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.input_assert is not None:
                                return True

                            if self.input_bsr_message is not None:
                                return True

                            if self.input_candidate_rp_advertisement is not None:
                                return True

                            if self.input_df_election is not None:
                                return True

                            if self.input_graft_ack_message is not None:
                                return True

                            if self.input_graft_message is not None:
                                return True

                            if self.input_hello is not None:
                                return True

                            if self.input_jp is not None:
                                return True

                            if self.input_miscellaneous is not None:
                                return True

                            if self.input_register is not None:
                                return True

                            if self.input_register_stop is not None:
                                return True

                            if self.output_assert is not None:
                                return True

                            if self.output_bsr_message is not None:
                                return True

                            if self.output_candidate_rp_advertisement is not None:
                                return True

                            if self.output_df_election is not None:
                                return True

                            if self.output_graft_ack_message is not None:
                                return True

                            if self.output_graft_message is not None:
                                return True

                            if self.output_hello is not None:
                                return True

                            if self.output_jp is not None:
                                return True

                            if self.output_register is not None:
                                return True

                            if self.output_register_stop is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-statistics'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_statistic is not None:
                            for child_ref in self.interface_statistic:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.InterfaceStatistics']['meta_info']


                class TopologyRouteCount(object):
                    """
                    Topology route count information from PIM
                    topology table
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.active_group_ranges = None
                        self.group_address = Pim.Standby.Vrfs.Vrf.TopologyRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self.group_ranges = None
                        self.groute_count = None
                        self.is_node_low_memory = None
                        self.sg_route_count = None
                        self.sgr_route_count = None


                    class GroupAddress(object):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.TopologyRouteCount.GroupAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology-route-count'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.active_group_ranges is not None:
                            return True

                        if self.group_address is not None and self.group_address._has_data():
                            return True

                        if self.group_ranges is not None:
                            return True

                        if self.groute_count is not None:
                            return True

                        if self.is_node_low_memory is not None:
                            return True

                        if self.sg_route_count is not None:
                            return True

                        if self.sgr_route_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.TopologyRouteCount']['meta_info']


                class JpStatistics(object):
                    """
                    PIM join prune statistics table
                    
                    .. attribute:: jp_statistic
                    
                    	PIM Join Prune Statistics
                    	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.jp_statistic = YList()
                        self.jp_statistic.parent = self
                        self.jp_statistic.name = 'jp_statistic'


                    class JpStatistic(object):
                        """
                        PIM Join Prune Statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received
                        
                        	Received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received100
                        
                        	Received 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_10k
                        
                        	Received 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_1k
                        
                        	Received 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_50k
                        
                        	Deprecated by Received100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted
                        
                        	Transmitted
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transmitted100
                        
                        	Transmitted 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_10k
                        
                        	Transmitted 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_1k
                        
                        	Transmitted 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_50k
                        
                        	Deprecated by Transmitted100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.mtu = None
                            self.received = None
                            self.received100 = None
                            self.received_10k = None
                            self.received_1k = None
                            self.received_50k = None
                            self.transmitted = None
                            self.transmitted100 = None
                            self.transmitted_10k = None
                            self.transmitted_1k = None
                            self.transmitted_50k = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:jp-statistic[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.mtu is not None:
                                return True

                            if self.received is not None:
                                return True

                            if self.received100 is not None:
                                return True

                            if self.received_10k is not None:
                                return True

                            if self.received_1k is not None:
                                return True

                            if self.received_50k is not None:
                                return True

                            if self.transmitted is not None:
                                return True

                            if self.transmitted100 is not None:
                                return True

                            if self.transmitted_10k is not None:
                                return True

                            if self.transmitted_1k is not None:
                                return True

                            if self.transmitted_50k is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:jp-statistics'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.jp_statistic is not None:
                            for child_ref in self.jp_statistic:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.JpStatistics']['meta_info']


                class MibDatabases(object):
                    """
                    PIM group database for mroute mibs table
                    
                    .. attribute:: mib_database
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.mib_database = YList()
                        self.mib_database.parent = self
                        self.mib_database.name = 'mib_database'


                    class MibDatabase(object):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: assert_metric
                        
                        	Assert Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_metric_preference
                        
                        	Assert Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_rpt_bit
                        
                        	Assert RPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: bidirectional_route
                        
                        	Is this Bidir ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Multicast satic route group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr>`
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface name 
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_mask
                        
                        	Mask of the multicast root
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rpf_neighbor
                        
                        	The RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor>`
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: source_address
                        
                        	Multicast static route source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr>`
                        
                        .. attribute:: source_netmask
                        
                        	Source mask
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: spt_bit
                        
                        	Is SPT bit set ?
                        	**type**\:  bool
                        
                        .. attribute:: upstream_assert_timer
                        
                        	Upstream Assert Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime of route
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.assert_metric = None
                            self.assert_metric_preference = None
                            self.assert_rpt_bit = None
                            self.bidirectional_route = None
                            self.group_address = None
                            self.group_address_xr = Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self.protocol = None
                            self.rpf_drop = None
                            self.rpf_extranet = None
                            self.rpf_interface_name = None
                            self.rpf_mask = None
                            self.rpf_neighbor = Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self.rpf_root = Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot()
                            self.rpf_root.parent = self
                            self.rpf_safi = None
                            self.rpf_table_name = None
                            self.rpf_vrf_name = None
                            self.source_address = None
                            self.source_address_xr = Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self.source_netmask = None
                            self.spt_bit = None
                            self.upstream_assert_timer = None
                            self.uptime = None


                        class SourceAddressXr(object):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr']['meta_info']


                        class GroupAddressXr(object):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr']['meta_info']


                        class RpfNeighbor(object):
                            """
                            The RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor']['meta_info']


                        class RpfRoot(object):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-root'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:mib-database'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.assert_metric is not None:
                                return True

                            if self.assert_metric_preference is not None:
                                return True

                            if self.assert_rpt_bit is not None:
                                return True

                            if self.bidirectional_route is not None:
                                return True

                            if self.group_address is not None:
                                return True

                            if self.group_address_xr is not None and self.group_address_xr._has_data():
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rpf_drop is not None:
                                return True

                            if self.rpf_extranet is not None:
                                return True

                            if self.rpf_interface_name is not None:
                                return True

                            if self.rpf_mask is not None:
                                return True

                            if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                return True

                            if self.rpf_root is not None and self.rpf_root._has_data():
                                return True

                            if self.rpf_safi is not None:
                                return True

                            if self.rpf_table_name is not None:
                                return True

                            if self.rpf_vrf_name is not None:
                                return True

                            if self.source_address is not None:
                                return True

                            if self.source_address_xr is not None and self.source_address_xr._has_data():
                                return True

                            if self.source_netmask is not None:
                                return True

                            if self.spt_bit is not None:
                                return True

                            if self.upstream_assert_timer is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:mib-databases'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.mib_database is not None:
                            for child_ref in self.mib_database:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.MibDatabases']['meta_info']


                class GroupMapMatchRpfs(object):
                    """
                    Find matching group\-mapping for the specified
                    group address
                    
                    .. attribute:: group_map_match_rpf
                    
                    	PIM group matching mapping entry
                    	**type**\: list of    :py:class:`GroupMapMatchRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_map_match_rpf = YList()
                        self.group_map_match_rpf.parent = self
                        self.group_map_match_rpf.name = 'group_map_match_rpf'


                    class GroupMapMatchRpf(object):
                        """
                        PIM group matching mapping entry
                        
                        .. attribute:: group_address  <key>
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\:  bool
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation>`
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor>`
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.group_address = None
                            self.are_we_rp = None
                            self.group_map_information = Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self.rpf_interface_name = None
                            self.rpf_neighbor = Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self.rpf_vrf_name = None


                        class RpfNeighbor(object):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor']['meta_info']


                        class GroupMapInformation(object):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.client = None
                                self.group_count = None
                                self.is_override = None
                                self.is_used = None
                                self.mrib_active = None
                                self.prefix = Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self.prefix_length = None
                                self.priority = None
                                self.protocol = None
                                self.rp_address = Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self


                            class Prefix(object):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix']['meta_info']


                            class RpAddress(object):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.client is not None:
                                    return True

                                if self.group_count is not None:
                                    return True

                                if self.is_override is not None:
                                    return True

                                if self.is_used is not None:
                                    return True

                                if self.mrib_active is not None:
                                    return True

                                if self.prefix is not None and self.prefix._has_data():
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.priority is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.rp_address is not None and self.rp_address._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.group_address is None:
                                raise YPYModelError('Key property group_address is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-rpf[Cisco-IOS-XR-ipv4-pim-oper:group-address = ' + str(self.group_address) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.group_address is not None:
                                return True

                            if self.are_we_rp is not None:
                                return True

                            if self.group_map_information is not None and self.group_map_information._has_data():
                                return True

                            if self.rpf_interface_name is not None:
                                return True

                            if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                return True

                            if self.rpf_vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-rpfs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_map_match_rpf is not None:
                            for child_ref in self.group_map_match_rpf:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs']['meta_info']


                class NeighborOldFormats(object):
                    """
                    PIM neighbor table old format
                    
                    .. attribute:: neighbor_old_format
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.neighbor_old_format = YList()
                        self.neighbor_old_format.parent = self
                        self.neighbor_old_format.name = 'neighbor_old_format'


                    class NeighborOldFormat(object):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dr_priority = None
                            self.expires = None
                            self.expiry_timer = None
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.is_batch_asserts_capable = None
                            self.is_bfd_state = None
                            self.is_bidirectional_capable = None
                            self.is_dr_priority_capable = None
                            self.is_ecmp_redirect_capable = None
                            self.is_proxy_capable = None
                            self.is_this_neighbor_dr = None
                            self.is_this_neighbor_us = None
                            self.neighbor_address = None
                            self.neighbor_address_xr = YList()
                            self.neighbor_address_xr.parent = self
                            self.neighbor_address_xr.name = 'neighbor_address_xr'
                            self.override_interval = None
                            self.propagation_delay = None
                            self.uptime = None


                        class NeighborAddressXr(object):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-format'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dr_priority is not None:
                                return True

                            if self.expires is not None:
                                return True

                            if self.expiry_timer is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.is_batch_asserts_capable is not None:
                                return True

                            if self.is_bfd_state is not None:
                                return True

                            if self.is_bidirectional_capable is not None:
                                return True

                            if self.is_dr_priority_capable is not None:
                                return True

                            if self.is_ecmp_redirect_capable is not None:
                                return True

                            if self.is_proxy_capable is not None:
                                return True

                            if self.is_this_neighbor_dr is not None:
                                return True

                            if self.is_this_neighbor_us is not None:
                                return True

                            if self.neighbor_address is not None:
                                return True

                            if self.neighbor_address_xr is not None:
                                for child_ref in self.neighbor_address_xr:
                                    if child_ref._has_data():
                                        return True

                            if self.override_interval is not None:
                                return True

                            if self.propagation_delay is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-formats'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.neighbor_old_format is not None:
                            for child_ref in self.neighbor_old_format:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.NeighborOldFormats']['meta_info']


                class IfrsSummary(object):
                    """
                    PIM interfaces in forward reference store
                    summary
                    
                    .. attribute:: configuration_count
                    
                    	Configuration counts
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Number of interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.configuration_count = None
                        self.interface_count = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:ifrs-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.configuration_count is not None:
                            return True

                        if self.interface_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.IfrsSummary']['meta_info']


                class Ranges(object):
                    """
                    PIM range list information
                    
                    .. attribute:: range
                    
                    	PIM range list information
                    	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.range = YList()
                        self.range.parent = self
                        self.range.name = 'range'


                    class Range(object):
                        """
                        PIM range list information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                        
                        .. attribute:: client_xr
                        
                        	Client mapping learnt via
                        	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: group_range
                        
                        	List of group ranges
                        	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange>`
                        
                        .. attribute:: protocol
                        
                        	PIM protocol
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	Rendezvous point address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr>`
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.client_xr = None
                            self.expires = None
                            self.group_range = YList()
                            self.group_range.parent = self
                            self.group_range.name = 'group_range'
                            self.protocol = None
                            self.rp_address = None
                            self.rp_address_xr = Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self.source_of_information = Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation()
                            self.source_of_information.parent = self


                        class RpAddressXr(object):
                            """
                            Rendezvous point address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr']['meta_info']


                        class SourceOfInformation(object):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation']['meta_info']


                        class GroupRange(object):
                            """
                            List of group ranges
                            
                            .. attribute:: expires
                            
                            	When mapping expires
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: source_of_information
                            
                            	Source of information
                            	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.expires = None
                                self.prefix = Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix()
                                self.prefix.parent = self
                                self.prefix_length = None
                                self.source_of_information = Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation()
                                self.source_of_information.parent = self
                                self.uptime = None


                            class Prefix(object):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix']['meta_info']


                            class SourceOfInformation(object):
                                """
                                Source of information
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-range'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.expires is not None:
                                    return True

                                if self.prefix is not None and self.prefix._has_data():
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.source_of_information is not None and self.source_of_information._has_data():
                                    return True

                                if self.uptime is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:range'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.client_xr is not None:
                                return True

                            if self.expires is not None:
                                return True

                            if self.group_range is not None:
                                for child_ref in self.group_range:
                                    if child_ref._has_data():
                                        return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None:
                                return True

                            if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                                return True

                            if self.source_of_information is not None and self.source_of_information._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.Ranges.Range']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:ranges'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.range is not None:
                            for child_ref in self.range:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.Ranges']['meta_info']


                class InterfaceOldFormats(object):
                    """
                    PIM interfaces in old format
                    
                    .. attribute:: interface_old_format
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_old_format = YList()
                        self.interface_old_format.parent = self
                        self.interface_old_format.name = 'interface_old_format'


                    class InterfaceOldFormat(object):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.configured_override_interval = None
                            self.configured_propagation_delay = None
                            self.dr_address = Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                            self.dr_address.parent = self
                            self.dr_priority = None
                            self.external_neighbor_count = None
                            self.generation_id = None
                            self.hello_expiry = None
                            self.hello_interval = None
                            self.idb_acl_name = None
                            self.idb_acl_provided = None
                            self.idb_current_count = None
                            self.idb_max_count = None
                            self.idb_oor_enabled = None
                            self.idb_threshold_count = None
                            self.interface_address = YList()
                            self.interface_address.parent = self
                            self.interface_address.name = 'interface_address'
                            self.interface_address_mask = None
                            self.interface_name_xr = None
                            self.is_batch_asserts_capable = None
                            self.is_bidirectional_capable = None
                            self.is_enabled = None
                            self.is_proxy_capable = None
                            self.join_prune_interval = None
                            self.neighbor_count = None
                            self.neighbor_filter_name = None
                            self.override_interval = None
                            self.passive_interface = None
                            self.propagation_delay = None
                            self.prune_delay_enabled = None
                            self.virtual_interface = None


                        class DrAddress(object):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress']['meta_info']


                        class InterfaceAddress(object):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-old-format[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.are_we_dr is not None:
                                return True

                            if self.bfd_enabled is not None:
                                return True

                            if self.bfd_interval is not None:
                                return True

                            if self.bfd_multiplier is not None:
                                return True

                            if self.configured_override_interval is not None:
                                return True

                            if self.configured_propagation_delay is not None:
                                return True

                            if self.dr_address is not None and self.dr_address._has_data():
                                return True

                            if self.dr_priority is not None:
                                return True

                            if self.external_neighbor_count is not None:
                                return True

                            if self.generation_id is not None:
                                return True

                            if self.hello_expiry is not None:
                                return True

                            if self.hello_interval is not None:
                                return True

                            if self.idb_acl_name is not None:
                                return True

                            if self.idb_acl_provided is not None:
                                return True

                            if self.idb_current_count is not None:
                                return True

                            if self.idb_max_count is not None:
                                return True

                            if self.idb_oor_enabled is not None:
                                return True

                            if self.idb_threshold_count is not None:
                                return True

                            if self.interface_address is not None:
                                for child_ref in self.interface_address:
                                    if child_ref._has_data():
                                        return True

                            if self.interface_address_mask is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.is_batch_asserts_capable is not None:
                                return True

                            if self.is_bidirectional_capable is not None:
                                return True

                            if self.is_enabled is not None:
                                return True

                            if self.is_proxy_capable is not None:
                                return True

                            if self.join_prune_interval is not None:
                                return True

                            if self.neighbor_count is not None:
                                return True

                            if self.neighbor_filter_name is not None:
                                return True

                            if self.override_interval is not None:
                                return True

                            if self.passive_interface is not None:
                                return True

                            if self.propagation_delay is not None:
                                return True

                            if self.prune_delay_enabled is not None:
                                return True

                            if self.virtual_interface is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-old-formats'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_old_format is not None:
                            for child_ref in self.interface_old_format:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.InterfaceOldFormats']['meta_info']


                class Bsr(object):
                    """
                    PIM BSR information
                    
                    .. attribute:: bsr_elections
                    
                    	PIM BSR election state
                    	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.BsrElections>`
                    
                    .. attribute:: candidate_rps
                    
                    	PIM candidate\-RP
                    	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps>`
                    
                    .. attribute:: rp_caches
                    
                    	PIM BSR RP cache table
                    	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bsr_elections = Pim.Standby.Vrfs.Vrf.Bsr.BsrElections()
                        self.bsr_elections.parent = self
                        self.candidate_rps = Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps()
                        self.candidate_rps.parent = self
                        self.rp_caches = Pim.Standby.Vrfs.Vrf.Bsr.RpCaches()
                        self.rp_caches.parent = self


                    class RpCaches(object):
                        """
                        PIM BSR RP cache table
                        
                        .. attribute:: rp_cache
                        
                        	PIM BSR RP cache
                        	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rp_cache = YList()
                            self.rp_cache.parent = self
                            self.rp_cache.name = 'rp_cache'


                        class RpCache(object):
                            """
                            PIM BSR RP cache
                            
                            .. attribute:: group_prefix  <key>
                            
                            	Group prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: candidate_rp_group_count
                            
                            	C\-RP count for this Prefix
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: candidate_rp_list
                            
                            	C\-RP list for this prefix
                            	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList>`
                            
                            .. attribute:: group_prefix_length
                            
                            	Group Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_prefix_xr
                            
                            	Group Prefix
                            	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.group_prefix = None
                                self.candidate_rp_group_count = None
                                self.candidate_rp_list = Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList()
                                self.candidate_rp_list.parent = self
                                self.group_prefix_length = None
                                self.group_prefix_xr = Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                self.group_prefix_xr.parent = self


                            class GroupPrefixXr(object):
                                """
                                Group Prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-prefix-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr']['meta_info']


                            class CandidateRpList(object):
                                """
                                C\-RP list for this prefix
                                
                                .. attribute:: pim_bsr_crp_bag
                                
                                	pim bsr crp bag
                                	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.pim_bsr_crp_bag = YList()
                                    self.pim_bsr_crp_bag.parent = self
                                    self.pim_bsr_crp_bag.name = 'pim_bsr_crp_bag'


                                class PimBsrCrpBag(object):
                                    """
                                    pim bsr crp bag
                                    
                                    .. attribute:: candidate_rp_address
                                    
                                    	C\-RP address
                                    	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                    
                                    .. attribute:: candidate_rp_expires
                                    
                                    	C\-RP Expires
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_holdtime
                                    
                                    	C\-RP Holdtime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_priority
                                    
                                    	C\-RP Priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: candidate_rp_up_time
                                    
                                    	C\-RP Uptime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: protocol
                                    
                                    	PIM Protocol
                                    	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.candidate_rp_address = Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                        self.candidate_rp_address.parent = self
                                        self.candidate_rp_expires = None
                                        self.candidate_rp_holdtime = None
                                        self.candidate_rp_priority = None
                                        self.candidate_rp_up_time = None
                                        self.protocol = None


                                    class CandidateRpAddress(object):
                                        """
                                        C\-RP address
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:pim-bsr-crp-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.candidate_rp_address is not None and self.candidate_rp_address._has_data():
                                            return True

                                        if self.candidate_rp_expires is not None:
                                            return True

                                        if self.candidate_rp_holdtime is not None:
                                            return True

                                        if self.candidate_rp_priority is not None:
                                            return True

                                        if self.candidate_rp_up_time is not None:
                                            return True

                                        if self.protocol is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp-list'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.pim_bsr_crp_bag is not None:
                                        for child_ref in self.pim_bsr_crp_bag:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.group_prefix is None:
                                    raise YPYModelError('Key property group_prefix is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-cache[Cisco-IOS-XR-ipv4-pim-oper:group-prefix = ' + str(self.group_prefix) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.group_prefix is not None:
                                    return True

                                if self.candidate_rp_group_count is not None:
                                    return True

                                if self.candidate_rp_list is not None and self.candidate_rp_list._has_data():
                                    return True

                                if self.group_prefix_length is not None:
                                    return True

                                if self.group_prefix_xr is not None and self.group_prefix_xr._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-caches'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rp_cache is not None:
                                for child_ref in self.rp_cache:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.Bsr.RpCaches']['meta_info']


                    class CandidateRps(object):
                        """
                        PIM candidate\-RP
                        
                        .. attribute:: candidate_rp
                        
                        	PIM BSR candidate RP information
                        	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.candidate_rp = YList()
                            self.candidate_rp.parent = self
                            self.candidate_rp.name = 'candidate_rp'


                        class CandidateRp(object):
                            """
                            PIM BSR candidate RP information
                            
                            .. attribute:: rp_address  <key>
                            
                            	Candidate\-RP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp
                            
                            	Cand\-RP Address
                            	**type**\:   :py:class:`CandidateRp_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_>`
                            
                            .. attribute:: candidate_rp_advance_interval
                            
                            	Cand\-RP Adv Interval in seconds
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            .. attribute:: candidate_rp_scope
                            
                            	Cand\-RP Scope
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: candidate_rp_uptime
                            
                            	Cand\-RP uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_access
                            
                            	Group Ranges Using this Cand\-RP
                            	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                            
                            .. attribute:: crp_holdtime
                            
                            	Cand\-RP Holdtime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_priority
                            
                            	Cand\-RP Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.rp_address = None
                                self.acl_name = None
                                self.candidate_rp = Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_()
                                self.candidate_rp.parent = self
                                self.candidate_rp_advance_interval = None
                                self.candidate_rp_mode = None
                                self.candidate_rp_scope = None
                                self.candidate_rp_uptime = None
                                self.crp_access = YList()
                                self.crp_access.parent = self
                                self.crp_access.name = 'crp_access'
                                self.crp_holdtime = None
                                self.crp_priority = None


                            class CandidateRp_(object):
                                """
                                Cand\-RP Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_']['meta_info']


                            class CrpAccess(object):
                                """
                                Group Ranges Using this Cand\-RP
                                
                                .. attribute:: acl_name
                                
                                	Group Access\-List Name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: candidate_rp_mode
                                
                                	Cand\-RP Mode
                                	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.acl_name = None
                                    self.candidate_rp_mode = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:crp-access'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.acl_name is not None:
                                        return True

                                    if self.candidate_rp_mode is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.rp_address is None:
                                    raise YPYModelError('Key property rp_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp[Cisco-IOS-XR-ipv4-pim-oper:rp-address = ' + str(self.rp_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.rp_address is not None:
                                    return True

                                if self.acl_name is not None:
                                    return True

                                if self.candidate_rp is not None and self.candidate_rp._has_data():
                                    return True

                                if self.candidate_rp_advance_interval is not None:
                                    return True

                                if self.candidate_rp_mode is not None:
                                    return True

                                if self.candidate_rp_scope is not None:
                                    return True

                                if self.candidate_rp_uptime is not None:
                                    return True

                                if self.crp_access is not None:
                                    for child_ref in self.crp_access:
                                        if child_ref._has_data():
                                            return True

                                if self.crp_holdtime is not None:
                                    return True

                                if self.crp_priority is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rps'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.candidate_rp is not None:
                                for child_ref in self.candidate_rp:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps']['meta_info']


                    class BsrElections(object):
                        """
                        PIM BSR election state
                        
                        .. attribute:: bsr_election
                        
                        	PIM BSR information
                        	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bsr_election = YList()
                            self.bsr_election.parent = self
                            self.bsr_election.name = 'bsr_election'


                        class BsrElection(object):
                            """
                            PIM BSR information
                            
                            .. attribute:: pim_scope  <key>
                            
                            	BSR information
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: bootstrap_timeout
                            
                            	Bootstrap Timeout
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_address
                            
                            	BSR address
                            	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress>`
                            
                            .. attribute:: bsr_election_state
                            
                            	BSR Election State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_mask_length
                            
                            	Hash Function Mask Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_priority
                            
                            	BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_scope
                            
                            	BSR Scope
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_up_time
                            
                            	BSR Uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_bsr_address
                            
                            	C\-BSR address
                            	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                            
                            .. attribute:: candidate_bsr_flag
                            
                            	BSR Candidate Config Flag
                            	**type**\:  bool
                            
                            .. attribute:: candidate_bsr_mask_length
                            
                            	C\-BSR Hash Func. Mask Len
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_priority
                            
                            	C\-BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_state
                            
                            	BSR Candidate State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pim_scope = None
                                self.bootstrap_timeout = None
                                self.bsr_address = Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress()
                                self.bsr_address.parent = self
                                self.bsr_election_state = None
                                self.bsr_mask_length = None
                                self.bsr_priority = None
                                self.bsr_scope = None
                                self.bsr_up_time = None
                                self.candidate_bsr_address = Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                self.candidate_bsr_address.parent = self
                                self.candidate_bsr_flag = None
                                self.candidate_bsr_mask_length = None
                                self.candidate_bsr_priority = None
                                self.candidate_bsr_state = None


                            class BsrAddress(object):
                                """
                                BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bsr-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress']['meta_info']


                            class CandidateBsrAddress(object):
                                """
                                C\-BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-bsr-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.pim_scope is None:
                                    raise YPYModelError('Key property pim_scope is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bsr-election[Cisco-IOS-XR-ipv4-pim-oper:pim-scope = ' + str(self.pim_scope) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pim_scope is not None:
                                    return True

                                if self.bootstrap_timeout is not None:
                                    return True

                                if self.bsr_address is not None and self.bsr_address._has_data():
                                    return True

                                if self.bsr_election_state is not None:
                                    return True

                                if self.bsr_mask_length is not None:
                                    return True

                                if self.bsr_priority is not None:
                                    return True

                                if self.bsr_scope is not None:
                                    return True

                                if self.bsr_up_time is not None:
                                    return True

                                if self.candidate_bsr_address is not None and self.candidate_bsr_address._has_data():
                                    return True

                                if self.candidate_bsr_flag is not None:
                                    return True

                                if self.candidate_bsr_mask_length is not None:
                                    return True

                                if self.candidate_bsr_priority is not None:
                                    return True

                                if self.candidate_bsr_state is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bsr-elections'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bsr_election is not None:
                                for child_ref in self.bsr_election:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.Bsr.BsrElections']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bsr'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bsr_elections is not None and self.bsr_elections._has_data():
                            return True

                        if self.candidate_rps is not None and self.candidate_rps._has_data():
                            return True

                        if self.rp_caches is not None and self.rp_caches._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.Bsr']['meta_info']


                class RoutePolicy(object):
                    """
                    PIM route policy
                    
                    .. attribute:: route_policy_statistics
                    
                    	PIM route policy statistics
                    	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics>`
                    
                    .. attribute:: route_policy_tests
                    
                    	PIM route policy test run table
                    	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.route_policy_statistics = Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics()
                        self.route_policy_statistics.parent = self
                        self.route_policy_tests = Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests()
                        self.route_policy_tests.parent = self


                    class RoutePolicyStatistics(object):
                        """
                        PIM route policy statistics
                        
                        .. attribute:: any_table
                        
                        	Number of RPF lookup in any Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Number of RPF lookup in default\-only Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: drop
                        
                        	Number of RPF drops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pass_
                        
                        	Number of RPF pass
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: requests
                        
                        	Number of RPF lookup requests
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.any_table = None
                            self.default_table = None
                            self.drop = None
                            self.pass_ = None
                            self.policy_name = None
                            self.requests = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:route-policy-statistics'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.any_table is not None:
                                return True

                            if self.default_table is not None:
                                return True

                            if self.drop is not None:
                                return True

                            if self.pass_ is not None:
                                return True

                            if self.policy_name is not None:
                                return True

                            if self.requests is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics']['meta_info']


                    class RoutePolicyTests(object):
                        """
                        PIM route policy test run table
                        
                        .. attribute:: route_policy_test
                        
                        	PIM route policy test run
                        	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.route_policy_test = YList()
                            self.route_policy_test.parent = self
                            self.route_policy_test.name = 'route_policy_test'


                        class RoutePolicyTest(object):
                            """
                            PIM route policy test run
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: default_table
                            
                            	Default table selected
                            	**type**\:  bool
                            
                            .. attribute:: ext_comm
                            
                            	Extended Community
                            	**type**\:  str
                            
                            	**length:** 1..8
                            
                            .. attribute:: extended_community_rt
                            
                            	Route Target
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: group_address
                            
                            	Group IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                            
                            .. attribute:: pass_
                            
                            	Pass
                            	**type**\:  bool
                            
                            .. attribute:: policy_name
                            
                            	RPF policy name
                            	**type**\:  str
                            
                            .. attribute:: safi
                            
                            	SAFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_address
                            
                            	Source IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                            
                            .. attribute:: table_active
                            
                            	Table active
                            	**type**\:  bool
                            
                            .. attribute:: table_exists
                            
                            	Table exists
                            	**type**\:  bool
                            
                            .. attribute:: table_name
                            
                            	Table name
                            	**type**\:  str
                            
                            .. attribute:: vrf_name
                            
                            	VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.afi = None
                                self.default_table = None
                                self.ext_comm = None
                                self.extended_community_rt = None
                                self.group_address = None
                                self.group_address_xr = Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self.pass_ = None
                                self.policy_name = None
                                self.safi = None
                                self.source_address = None
                                self.source_address_xr = Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self.table_active = None
                                self.table_exists = None
                                self.table_name = None
                                self.vrf_name = None


                            class SourceAddressXr(object):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr']['meta_info']


                            class GroupAddressXr(object):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:route-policy-test'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.afi is not None:
                                    return True

                                if self.default_table is not None:
                                    return True

                                if self.ext_comm is not None:
                                    return True

                                if self.extended_community_rt is not None:
                                    return True

                                if self.group_address is not None:
                                    return True

                                if self.group_address_xr is not None and self.group_address_xr._has_data():
                                    return True

                                if self.pass_ is not None:
                                    return True

                                if self.policy_name is not None:
                                    return True

                                if self.safi is not None:
                                    return True

                                if self.source_address is not None:
                                    return True

                                if self.source_address_xr is not None and self.source_address_xr._has_data():
                                    return True

                                if self.table_active is not None:
                                    return True

                                if self.table_exists is not None:
                                    return True

                                if self.table_name is not None:
                                    return True

                                if self.vrf_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:route-policy-tests'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.route_policy_test is not None:
                                for child_ref in self.route_policy_test:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:route-policy'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.route_policy_statistics is not None and self.route_policy_statistics._has_data():
                            return True

                        if self.route_policy_tests is not None and self.route_policy_tests._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.RoutePolicy']['meta_info']


                class RpfSummary(object):
                    """
                    PIM RPF registration summary
                    
                    .. attribute:: default_safi
                    
                    	Default RPF Table SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table_name
                    
                    	Default RPF Table Name
                    	**type**\:  str
                    
                    .. attribute:: is_isis_mtr_configured
                    
                    	Is ISIS MTR configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_isis_te_configured
                    
                    	Is ISIS TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_mbgp_configured
                    
                    	Is MBGP configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_enabled
                    
                    	Is Multipath Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_interface_hash_enabled
                    
                    	Is Multipath Interface Hash Extension Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_hash_enabled
                    
                    	Is Multipath Source based Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_next_hop_hash_enabled
                    
                    	Is Multipath Source\-Nexthop Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ospf_te_configured
                    
                    	Is OSPF TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: mo_frr_configured
                    
                    	Is MoFRR configured?
                    	**type**\:  bool
                    
                    .. attribute:: rib_convergence_time_left
                    
                    	RIB convergence time left in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_convergence_timeout
                    
                    	RIB convergence timeout in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_mo_frr_configured
                    
                    	Is MoFRR RIB configured?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	Is RUMP MuRIB enabled?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.default_safi = None
                        self.default_table_name = None
                        self.is_isis_mtr_configured = None
                        self.is_isis_te_configured = None
                        self.is_mbgp_configured = None
                        self.is_multipath_enabled = None
                        self.is_multipath_interface_hash_enabled = None
                        self.is_multipath_source_hash_enabled = None
                        self.is_multipath_source_next_hop_hash_enabled = None
                        self.is_ospf_te_configured = None
                        self.is_rib_convergence = None
                        self.mo_frr_configured = None
                        self.rib_convergence_time_left = None
                        self.rib_convergence_timeout = None
                        self.rib_mo_frr_configured = None
                        self.rpf_registrations = None
                        self.rump_enabled = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.default_safi is not None:
                            return True

                        if self.default_table_name is not None:
                            return True

                        if self.is_isis_mtr_configured is not None:
                            return True

                        if self.is_isis_te_configured is not None:
                            return True

                        if self.is_mbgp_configured is not None:
                            return True

                        if self.is_multipath_enabled is not None:
                            return True

                        if self.is_multipath_interface_hash_enabled is not None:
                            return True

                        if self.is_multipath_source_hash_enabled is not None:
                            return True

                        if self.is_multipath_source_next_hop_hash_enabled is not None:
                            return True

                        if self.is_ospf_te_configured is not None:
                            return True

                        if self.is_rib_convergence is not None:
                            return True

                        if self.mo_frr_configured is not None:
                            return True

                        if self.rib_convergence_time_left is not None:
                            return True

                        if self.rib_convergence_timeout is not None:
                            return True

                        if self.rib_mo_frr_configured is not None:
                            return True

                        if self.rpf_registrations is not None:
                            return True

                        if self.rump_enabled is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.RpfSummary']['meta_info']


                class Interfaces(object):
                    """
                    PIM interfaces
                    
                    .. attribute:: interface
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Interfaces.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface = YList()
                        self.interface.parent = self
                        self.interface.name = 'interface'


                    class Interface(object):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.configured_override_interval = None
                            self.configured_propagation_delay = None
                            self.dr_address = Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress()
                            self.dr_address.parent = self
                            self.dr_priority = None
                            self.external_neighbor_count = None
                            self.generation_id = None
                            self.hello_expiry = None
                            self.hello_interval = None
                            self.idb_acl_name = None
                            self.idb_acl_provided = None
                            self.idb_current_count = None
                            self.idb_max_count = None
                            self.idb_oor_enabled = None
                            self.idb_threshold_count = None
                            self.interface_address = YList()
                            self.interface_address.parent = self
                            self.interface_address.name = 'interface_address'
                            self.interface_address_mask = None
                            self.interface_name_xr = None
                            self.is_batch_asserts_capable = None
                            self.is_bidirectional_capable = None
                            self.is_enabled = None
                            self.is_proxy_capable = None
                            self.join_prune_interval = None
                            self.neighbor_count = None
                            self.neighbor_filter_name = None
                            self.override_interval = None
                            self.passive_interface = None
                            self.propagation_delay = None
                            self.prune_delay_enabled = None
                            self.virtual_interface = None


                        class DrAddress(object):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress']['meta_info']


                        class InterfaceAddress(object):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.are_we_dr is not None:
                                return True

                            if self.bfd_enabled is not None:
                                return True

                            if self.bfd_interval is not None:
                                return True

                            if self.bfd_multiplier is not None:
                                return True

                            if self.configured_override_interval is not None:
                                return True

                            if self.configured_propagation_delay is not None:
                                return True

                            if self.dr_address is not None and self.dr_address._has_data():
                                return True

                            if self.dr_priority is not None:
                                return True

                            if self.external_neighbor_count is not None:
                                return True

                            if self.generation_id is not None:
                                return True

                            if self.hello_expiry is not None:
                                return True

                            if self.hello_interval is not None:
                                return True

                            if self.idb_acl_name is not None:
                                return True

                            if self.idb_acl_provided is not None:
                                return True

                            if self.idb_current_count is not None:
                                return True

                            if self.idb_max_count is not None:
                                return True

                            if self.idb_oor_enabled is not None:
                                return True

                            if self.idb_threshold_count is not None:
                                return True

                            if self.interface_address is not None:
                                for child_ref in self.interface_address:
                                    if child_ref._has_data():
                                        return True

                            if self.interface_address_mask is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.is_batch_asserts_capable is not None:
                                return True

                            if self.is_bidirectional_capable is not None:
                                return True

                            if self.is_enabled is not None:
                                return True

                            if self.is_proxy_capable is not None:
                                return True

                            if self.join_prune_interval is not None:
                                return True

                            if self.neighbor_count is not None:
                                return True

                            if self.neighbor_filter_name is not None:
                                return True

                            if self.override_interval is not None:
                                return True

                            if self.passive_interface is not None:
                                return True

                            if self.propagation_delay is not None:
                                return True

                            if self.prune_delay_enabled is not None:
                                return True

                            if self.virtual_interface is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.Interfaces.Interface']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interfaces'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface is not None:
                            for child_ref in self.interface:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.Interfaces']['meta_info']


                class NetIoTunnels(object):
                    """
                    Tunnel information that NETIO has 
                    
                    .. attribute:: net_io_tunnel
                    
                    	PIM netio tunnel information
                    	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.net_io_tunnel = YList()
                        self.net_io_tunnel.parent = self
                        self.net_io_tunnel.name = 'net_io_tunnel'


                    class NetIoTunnel(object):
                        """
                        PIM netio tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.tunnel_name = None
                            self.group_address_netio = Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self.rp_address = Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress()
                            self.rp_address.parent = self
                            self.source_address = Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress()
                            self.source_address.parent = self
                            self.source_address_netio = Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self.vrf_name = None


                        class SourceAddress(object):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress']['meta_info']


                        class RpAddress(object):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress']['meta_info']


                        class SourceAddressNetio(object):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-netio'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio']['meta_info']


                        class GroupAddressNetio(object):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-netio'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.tunnel_name is None:
                                raise YPYModelError('Key property tunnel_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:net-io-tunnel[Cisco-IOS-XR-ipv4-pim-oper:tunnel-name = ' + str(self.tunnel_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.tunnel_name is not None:
                                return True

                            if self.group_address_netio is not None and self.group_address_netio._has_data():
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            if self.source_address is not None and self.source_address._has_data():
                                return True

                            if self.source_address_netio is not None and self.source_address_netio._has_data():
                                return True

                            if self.vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:net-io-tunnels'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.net_io_tunnel is not None:
                            for child_ref in self.net_io_tunnel:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.NetIoTunnels']['meta_info']


                class BidirDfStates(object):
                    """
                    Bidirectional PIM DF election state table
                    
                    .. attribute:: bidir_df_state
                    
                    	Bidirectional PIM DF Election Table Entry
                    	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bidir_df_state = YList()
                        self.bidir_df_state.parent = self
                        self.bidir_df_state.name = 'bidir_df_state'


                    class BidirDfState(object):
                        """
                        Bidirectional PIM DF Election Table Entry
                        
                        .. attribute:: election_state
                        
                        	DF Election State
                        	**type**\:  str
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: our_metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: our_metric_preference
                        
                        	MetricPreference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr>`
                        
                        .. attribute:: time_nano_seconds
                        
                        	Timer expires (nseconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: time_seconds
                        
                        	Timer expires (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.election_state = None
                            self.interface_name = None
                            self.our_metric = None
                            self.our_metric_preference = None
                            self.pim_interface_name = None
                            self.rp_address = None
                            self.rp_address_xr = Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self.time_nano_seconds = None
                            self.time_seconds = None


                        class RpAddressXr(object):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-state'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.election_state is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.our_metric is not None:
                                return True

                            if self.our_metric_preference is not None:
                                return True

                            if self.pim_interface_name is not None:
                                return True

                            if self.rp_address is not None:
                                return True

                            if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                                return True

                            if self.time_nano_seconds is not None:
                                return True

                            if self.time_seconds is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-states'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bidir_df_state is not None:
                            for child_ref in self.bidir_df_state:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.BidirDfStates']['meta_info']


                class Topologies(object):
                    """
                    PIM topology table
                    
                    .. attribute:: topology
                    
                    	PIM topology information
                    	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.topology = YList()
                        self.topology.parent = self
                        self.topology.name = 'topology'


                    class Topology(object):
                        """
                        PIM topology information
                        
                        .. attribute:: alive
                        
                        	Alive time in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: anycast_rp_match
                        
                        	Group matches Anycast\-RP policy
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_route_target
                        
                        	Anycast\-RP RT
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: assume_alive
                        
                        	The Assume Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: bgp_join
                        
                        	BGP C JOIN
                        	**type**\:  bool
                        
                        .. attribute:: bgpjp_time
                        
                        	BGP C JP Time
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: connected
                        
                        	Is Connected ?
                        	**type**\:  bool
                        
                        .. attribute:: customer_routing_type
                        
                        	Type of Customer Routing in the MVPN
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: dont_check_connected
                        
                        	Do we need to make the connected check on this route ?
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	When this entry expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: extranet_route
                        
                        	Is a Extranet route ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr>`
                        
                        .. attribute:: inherit_alive
                        
                        	The Inherit Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: inherit_spt
                        
                        	The Inherit SPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: is_via_lsm
                        
                        	Via LSM
                        	**type**\:  bool
                        
                        .. attribute:: jp_status
                        
                        	Join\-Prune Status
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: limit_reached
                        
                        	Have we throttled the creation of routes or interfaces ?
                        	**type**\:  bool
                        
                        .. attribute:: low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_active
                        
                        	Is MoFRR Active?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_backup
                        
                        	Is this Mofrr Backup?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_primary
                        
                        	Is this Mofrr Primary?
                        	**type**\:  bool
                        
                        .. attribute:: orig_src_address
                        
                        	Orig Src Address
                        	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress>`
                        
                        .. attribute:: outgoing_interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface>`
                        
                        .. attribute:: probe_alive
                        
                        	The Probe Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: proxy
                        
                        	Is the RPF target a proxy?
                        	**type**\:  bool
                        
                        .. attribute:: proxy_address
                        
                        	RPF Proxy address
                        	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress>`
                        
                        .. attribute:: really_alive
                        
                        	The Really Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: register_received
                        
                        	Have registers been received for this source ?
                        	**type**\:  bool
                        
                        .. attribute:: register_received_timer
                        
                        	Register Received Timer in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: remote_source
                        
                        	MSDP told us
                        	**type**\:  bool
                        
                        .. attribute:: rib_mo_frr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rp_address
                        
                        	RP Address (If rpt)
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor>`
                        
                        .. attribute:: rpf_proxy_enabled
                        
                        	Is rpf if proxy enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpt
                        
                        	RPT bit
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpt_xr
                        
                        	Is this on the RPT ?
                        	**type**\:  bool
                        
                        .. attribute:: sa_joined
                        
                        	BGP SA join
                        	**type**\:  bool
                        
                        .. attribute:: sa_received
                        
                        	BGP SA received
                        	**type**\:  bool
                        
                        .. attribute:: sa_sent
                        
                        	BGP SA sent
                        	**type**\:  bool
                        
                        .. attribute:: secondary_rpf_interface_name
                        
                        	Secondary Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: secondary_rpf_neighbor
                        
                        	Secondary RPF Neighbor
                        	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor>`
                        
                        .. attribute:: sending_null_registers
                        
                        	Are we sending null registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: sending_registers
                        
                        	Are we sending registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: signal_sources
                        
                        	Signal Sources on route?
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr>`
                        
                        .. attribute:: spt
                        
                        	Is this on the SPT ?
                        	**type**\:  bool
                        
                        .. attribute:: suppress_registers
                        
                        	When the Null register probe expires
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vxlan
                        
                        	Is this VXLAN?
                        	**type**\:  bool
                        
                        .. attribute:: wildcard
                        
                        	WC \-Wildcard
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.alive = None
                            self.anycast_rp_match = None
                            self.anycast_rp_route_target = None
                            self.assume_alive = None
                            self.bgp_join = None
                            self.bgpjp_time = None
                            self.connected = None
                            self.customer_routing_type = None
                            self.dont_check_connected = None
                            self.expiry = None
                            self.extranet_route = None
                            self.group_address = None
                            self.group_address_xr = Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self.inherit_alive = None
                            self.inherit_spt = None
                            self.is_via_lsm = None
                            self.jp_status = None
                            self.jp_timer = None
                            self.last_hop = None
                            self.limit_reached = None
                            self.low_memory = None
                            self.mofrr_active = None
                            self.mofrr_backup = None
                            self.mofrr_enabled = None
                            self.mofrr_primary = None
                            self.orig_src_address = Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress()
                            self.orig_src_address.parent = self
                            self.outgoing_interface = YList()
                            self.outgoing_interface.parent = self
                            self.outgoing_interface.name = 'outgoing_interface'
                            self.probe_alive = None
                            self.protocol = None
                            self.proxy = None
                            self.proxy_address = Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress()
                            self.proxy_address.parent = self
                            self.really_alive = None
                            self.register_received = None
                            self.register_received_timer = None
                            self.remote_source = None
                            self.rib_mo_frr_enabled = None
                            self.rp_address = Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress()
                            self.rp_address.parent = self
                            self.rpf_drop = None
                            self.rpf_extranet = None
                            self.rpf_interface_name = None
                            self.rpf_neighbor = Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self.rpf_proxy_enabled = None
                            self.rpf_root = Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot()
                            self.rpf_root.parent = self
                            self.rpf_safi = None
                            self.rpf_table_name = None
                            self.rpf_vrf_name = None
                            self.rpt = None
                            self.rpt_xr = None
                            self.sa_joined = None
                            self.sa_received = None
                            self.sa_sent = None
                            self.secondary_rpf_interface_name = None
                            self.secondary_rpf_neighbor = Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor()
                            self.secondary_rpf_neighbor.parent = self
                            self.sending_null_registers = None
                            self.sending_registers = None
                            self.signal_sources = None
                            self.source_address = None
                            self.source_address_xr = Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self.spt = None
                            self.suppress_registers = None
                            self.uptime = None
                            self.vxlan = None
                            self.wildcard = None


                        class GroupAddressXr(object):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr']['meta_info']


                        class SourceAddressXr(object):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr']['meta_info']


                        class RpAddress(object):
                            """
                            RP Address (If rpt)
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress']['meta_info']


                        class RpfNeighbor(object):
                            """
                            RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor']['meta_info']


                        class SecondaryRpfNeighbor(object):
                            """
                            Secondary RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:secondary-rpf-neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor']['meta_info']


                        class RpfRoot(object):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-root'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot']['meta_info']


                        class ProxyAddress(object):
                            """
                            RPF Proxy address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:proxy-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress']['meta_info']


                        class OrigSrcAddress(object):
                            """
                            Orig Src Address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:orig-src-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress']['meta_info']


                        class OutgoingInterface(object):
                            """
                            Outgoing interface list
                            
                            .. attribute:: admin_boundary
                            
                            	Is this an administrative boundary ?
                            	**type**\:  bool
                            
                            .. attribute:: assert_timer
                            
                            	Assert Timer in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: assert_winner
                            
                            	Assert Winner
                            	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner>`
                            
                            .. attribute:: bgp_c_mcast_join
                            
                            	BGP C\-Mcast join
                            	**type**\:  bool
                            
                            .. attribute:: bgp_c_mcast_prune_delay_timer
                            
                            	BGP C\-MCAST Prune Suppression in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: data_mdt_join
                            
                            	Data MDT join
                            	**type**\:  bool
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: extranet_interface
                            
                            	Is this an Extranet Interface ?
                            	**type**\:  bool
                            
                            .. attribute:: forwarding_state
                            
                            	Forward or Prune
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: igmp_membership
                            
                            	IGMP membership
                            	**type**\:  bool
                            
                            .. attribute:: immediate_state
                            
                            	Immediate fwding state
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: interface_name
                            
                            	Interface Identifier
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_interest_info
                            
                            	Internal Interest
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: jp_state
                            
                            	Join\-Prune State
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: jp_timer
                            
                            	Join\-Prune Timer (secs)
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: last_hop
                            
                            	Are we last hop ?
                            	**type**\:  bool
                            
                            .. attribute:: local_mdt_join
                            
                            	Default MDT Join
                            	**type**\:  bool
                            
                            .. attribute:: local_members
                            
                            	Local Information
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: mdt_safi_join
                            
                            	MDT Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mldp_inband_mdt
                            
                            	MLDP Inband MDT interface
                            	**type**\:  bool
                            
                            .. attribute:: mldp_stale
                            
                            	OLE is stale
                            	**type**\:  bool
                            
                            .. attribute:: mvp_nv6_safi_join
                            
                            	MVPN IPv6 Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mvpn_safi_join
                            
                            	MVPN Safi join
                            	**type**\:  bool
                            
                            .. attribute:: sa_prune
                            
                            	BGP SA Prune state
                            	**type**\:  bool
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: vrf_name
                            
                            	VRF which physically owns
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.admin_boundary = None
                                self.assert_timer = None
                                self.assert_winner = Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner()
                                self.assert_winner.parent = self
                                self.bgp_c_mcast_join = None
                                self.bgp_c_mcast_prune_delay_timer = None
                                self.data_mdt_join = None
                                self.expiry = None
                                self.extranet_interface = None
                                self.forwarding_state = None
                                self.igmp_membership = None
                                self.immediate_state = None
                                self.interface_name = None
                                self.internal_interest_info = None
                                self.jp_state = None
                                self.jp_timer = None
                                self.last_hop = None
                                self.local_mdt_join = None
                                self.local_members = None
                                self.mdt_safi_join = None
                                self.mldp_inband_mdt = None
                                self.mldp_stale = None
                                self.mvp_nv6_safi_join = None
                                self.mvpn_safi_join = None
                                self.sa_prune = None
                                self.uptime = None
                                self.vrf_name = None


                            class AssertWinner(object):
                                """
                                Assert Winner
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:assert-winner'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:outgoing-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.admin_boundary is not None:
                                    return True

                                if self.assert_timer is not None:
                                    return True

                                if self.assert_winner is not None and self.assert_winner._has_data():
                                    return True

                                if self.bgp_c_mcast_join is not None:
                                    return True

                                if self.bgp_c_mcast_prune_delay_timer is not None:
                                    return True

                                if self.data_mdt_join is not None:
                                    return True

                                if self.expiry is not None:
                                    return True

                                if self.extranet_interface is not None:
                                    return True

                                if self.forwarding_state is not None:
                                    return True

                                if self.igmp_membership is not None:
                                    return True

                                if self.immediate_state is not None:
                                    return True

                                if self.interface_name is not None:
                                    return True

                                if self.internal_interest_info is not None:
                                    return True

                                if self.jp_state is not None:
                                    return True

                                if self.jp_timer is not None:
                                    return True

                                if self.last_hop is not None:
                                    return True

                                if self.local_mdt_join is not None:
                                    return True

                                if self.local_members is not None:
                                    return True

                                if self.mdt_safi_join is not None:
                                    return True

                                if self.mldp_inband_mdt is not None:
                                    return True

                                if self.mldp_stale is not None:
                                    return True

                                if self.mvp_nv6_safi_join is not None:
                                    return True

                                if self.mvpn_safi_join is not None:
                                    return True

                                if self.sa_prune is not None:
                                    return True

                                if self.uptime is not None:
                                    return True

                                if self.vrf_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.alive is not None:
                                return True

                            if self.anycast_rp_match is not None:
                                return True

                            if self.anycast_rp_route_target is not None:
                                return True

                            if self.assume_alive is not None:
                                return True

                            if self.bgp_join is not None:
                                return True

                            if self.bgpjp_time is not None:
                                return True

                            if self.connected is not None:
                                return True

                            if self.customer_routing_type is not None:
                                return True

                            if self.dont_check_connected is not None:
                                return True

                            if self.expiry is not None:
                                return True

                            if self.extranet_route is not None:
                                return True

                            if self.group_address is not None:
                                return True

                            if self.group_address_xr is not None and self.group_address_xr._has_data():
                                return True

                            if self.inherit_alive is not None:
                                return True

                            if self.inherit_spt is not None:
                                return True

                            if self.is_via_lsm is not None:
                                return True

                            if self.jp_status is not None:
                                return True

                            if self.jp_timer is not None:
                                return True

                            if self.last_hop is not None:
                                return True

                            if self.limit_reached is not None:
                                return True

                            if self.low_memory is not None:
                                return True

                            if self.mofrr_active is not None:
                                return True

                            if self.mofrr_backup is not None:
                                return True

                            if self.mofrr_enabled is not None:
                                return True

                            if self.mofrr_primary is not None:
                                return True

                            if self.orig_src_address is not None and self.orig_src_address._has_data():
                                return True

                            if self.outgoing_interface is not None:
                                for child_ref in self.outgoing_interface:
                                    if child_ref._has_data():
                                        return True

                            if self.probe_alive is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.proxy is not None:
                                return True

                            if self.proxy_address is not None and self.proxy_address._has_data():
                                return True

                            if self.really_alive is not None:
                                return True

                            if self.register_received is not None:
                                return True

                            if self.register_received_timer is not None:
                                return True

                            if self.remote_source is not None:
                                return True

                            if self.rib_mo_frr_enabled is not None:
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            if self.rpf_drop is not None:
                                return True

                            if self.rpf_extranet is not None:
                                return True

                            if self.rpf_interface_name is not None:
                                return True

                            if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                return True

                            if self.rpf_proxy_enabled is not None:
                                return True

                            if self.rpf_root is not None and self.rpf_root._has_data():
                                return True

                            if self.rpf_safi is not None:
                                return True

                            if self.rpf_table_name is not None:
                                return True

                            if self.rpf_vrf_name is not None:
                                return True

                            if self.rpt is not None:
                                return True

                            if self.rpt_xr is not None:
                                return True

                            if self.sa_joined is not None:
                                return True

                            if self.sa_received is not None:
                                return True

                            if self.sa_sent is not None:
                                return True

                            if self.secondary_rpf_interface_name is not None:
                                return True

                            if self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor._has_data():
                                return True

                            if self.sending_null_registers is not None:
                                return True

                            if self.sending_registers is not None:
                                return True

                            if self.signal_sources is not None:
                                return True

                            if self.source_address is not None:
                                return True

                            if self.source_address_xr is not None and self.source_address_xr._has_data():
                                return True

                            if self.spt is not None:
                                return True

                            if self.suppress_registers is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            if self.vxlan is not None:
                                return True

                            if self.wildcard is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.Topologies.Topology']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topologies'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.topology is not None:
                            for child_ref in self.topology:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.Topologies']['meta_info']


                class BgpAfs(object):
                    """
                    PIM BGP SAFI table
                    
                    .. attribute:: bgp_af
                    
                    	PIM BGP SAFI information
                    	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bgp_af = YList()
                        self.bgp_af.parent = self
                        self.bgp_af.name = 'bgp_af'


                    class BgpAf(object):
                        """
                        PIM BGP SAFI information
                        
                        .. attribute:: extranet_path_count
                        
                        	Count of dependent extranet paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group
                        
                        	Group address
                        	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group>`
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: is_bgp_added
                        
                        	SAFI learnt from BGP
                        	**type**\:  bool
                        
                        .. attribute:: next_hop
                        
                        	Next hop address
                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop>`
                        
                        .. attribute:: route_distinguisher
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**length:** 0..256
                        
                        .. attribute:: source
                        
                        	Source address
                        	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source>`
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.extranet_path_count = None
                            self.group = Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group()
                            self.group.parent = self
                            self.group_address = None
                            self.is_bgp_added = None
                            self.next_hop = Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop()
                            self.next_hop.parent = self
                            self.route_distinguisher = None
                            self.source = Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source()
                            self.source.parent = self
                            self.source_address = None


                        class Source(object):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source']['meta_info']


                        class Group(object):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group']['meta_info']


                        class NextHop(object):
                            """
                            Next hop address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:next-hop'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bgp-af'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.extranet_path_count is not None:
                                return True

                            if self.group is not None and self.group._has_data():
                                return True

                            if self.group_address is not None:
                                return True

                            if self.is_bgp_added is not None:
                                return True

                            if self.next_hop is not None and self.next_hop._has_data():
                                return True

                            if self.route_distinguisher is not None:
                                return True

                            if self.source is not None and self.source._has_data():
                                return True

                            if self.source_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bgp_af is not None:
                            for child_ref in self.bgp_af:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.BgpAfs']['meta_info']


                class AutoRp(object):
                    """
                    PIM Auto\-RP information
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:auto-rp'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.AutoRp']['meta_info']


                class TopologyInterfaceFlagRouteCounts(object):
                    """
                    Route count for topology with interface flag set
                    
                    .. attribute:: topology_interface_flag_route_count
                    
                    	Route count for topology with interface flag set
                    	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.topology_interface_flag_route_count = YList()
                        self.topology_interface_flag_route_count.parent = self
                        self.topology_interface_flag_route_count.name = 'topology_interface_flag_route_count'


                    class TopologyInterfaceFlagRouteCount(object):
                        """
                        Route count for topology with interface flag
                        set
                        
                        .. attribute:: interface_flag  <key>
                        
                        	Interface flag
                        	**type**\:   :py:class:`PimTopologyInterfaceFlagEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlagEnum>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_flag = None
                            self.active_group_ranges = None
                            self.group_address = Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                            self.group_address.parent = self
                            self.group_ranges = None
                            self.groute_count = None
                            self.is_node_low_memory = None
                            self.sg_route_count = None
                            self.sgr_route_count = None


                        class GroupAddress(object):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_flag is None:
                                raise YPYModelError('Key property interface_flag is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology-interface-flag-route-count[Cisco-IOS-XR-ipv4-pim-oper:interface-flag = ' + str(self.interface_flag) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_flag is not None:
                                return True

                            if self.active_group_ranges is not None:
                                return True

                            if self.group_address is not None and self.group_address._has_data():
                                return True

                            if self.group_ranges is not None:
                                return True

                            if self.groute_count is not None:
                                return True

                            if self.is_node_low_memory is not None:
                                return True

                            if self.sg_route_count is not None:
                                return True

                            if self.sgr_route_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology-interface-flag-route-counts'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.topology_interface_flag_route_count is not None:
                            for child_ref in self.topology_interface_flag_route_count:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts']['meta_info']


                class GroupMapSources(object):
                    """
                    PIM group\-mapping with source information
                    
                    .. attribute:: group_map_source
                    
                    	PIM Group Mapping Entry with source information
                    	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_map_source = YList()
                        self.group_map_source.parent = self
                        self.group_map_source.name = 'group_map_source'


                    class GroupMapSource(object):
                        """
                        PIM Group Mapping Entry with source information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                        
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	RP Priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.expires = None
                            self.group_map_information = Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self.holdtime = None
                            self.prefix = None
                            self.prefix_length = None
                            self.priority = None
                            self.protocol = None
                            self.rp_address = None
                            self.source_of_information = Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self.uptime = None


                        class SourceOfInformation(object):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation']['meta_info']


                        class GroupMapInformation(object):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.client = None
                                self.group_count = None
                                self.is_override = None
                                self.is_used = None
                                self.mrib_active = None
                                self.prefix = Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self.prefix_length = None
                                self.priority = None
                                self.protocol = None
                                self.rp_address = Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self


                            class Prefix(object):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix']['meta_info']


                            class RpAddress(object):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.client is not None:
                                    return True

                                if self.group_count is not None:
                                    return True

                                if self.is_override is not None:
                                    return True

                                if self.is_used is not None:
                                    return True

                                if self.mrib_active is not None:
                                    return True

                                if self.prefix is not None and self.prefix._has_data():
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.priority is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.rp_address is not None and self.rp_address._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-source'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.expires is not None:
                                return True

                            if self.group_map_information is not None and self.group_map_information._has_data():
                                return True

                            if self.holdtime is not None:
                                return True

                            if self.prefix is not None:
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None:
                                return True

                            if self.source_of_information is not None and self.source_of_information._has_data():
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_map_source is not None:
                            for child_ref in self.group_map_source:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapSources']['meta_info']


                class TrafficCounters(object):
                    """
                    PIM message traffic counters
                    
                    .. attribute:: boundary_acl_rx_drop
                    
                    	Inc. JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: boundary_acl_tx_drop
                    
                    	Out JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_error
                    
                    	Checksum errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: format_error
                    
                    	Malformed packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert_batched
                    
                    	Batched Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_data_register
                    
                    	Data Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_ecmp_redirect
                    
                    	Input Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb_error
                    
                    	No IDB for intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_pim_error
                    
                    	PIM Disabled on intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_error
                    
                    	No VRF for idb error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_null_register
                    
                    	Null Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim_version_error
                    
                    	Invalid PIM version error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: inputs
                    
                    	Packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_destination_packets
                    
                    	Control Packets with Invalid Destination
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_join_prunes
                    
                    	PIM invalid Join/Prunes received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_registers
                    
                    	PIM invalid registers received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_local_source_address
                    
                    	Data MDT Join msgs dropped due to local source addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_idb
                    
                    	Data MDT Join msgs dropped due to idb missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_vrf
                    
                    	Data MDT Join msgs dropped due to vrf missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_null_local_address
                    
                    	Data MDT Join msgs dropped due to null local addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_bad_type
                    
                    	Data MDT TLV bad type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_received
                    
                    	Data MDT Join Msgs received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_sent
                    
                    	Data MDT Join Msgs sent
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_joins_drop_multiple_encapsulation
                    
                    	MDT Join msgs dropped due to multiple Encap limitation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_send_queue_full
                    
                    	Packets dropped since mdt send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_socket_error
                    
                    	MDT Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_invalid_lsm_identifier
                    
                    	 Invalid LSM ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_mdt_socket_connection
                    
                    	Packets dropped since no mdt socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_source_address
                    
                    	Packets dropped since no source address
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: non_supported_packets
                    
                    	PIM non supported pckets
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert_batched
                    
                    	Batched Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_data_register
                    
                    	Data Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_ecmp_redirect
                    
                    	Output Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello_bytes
                    
                    	Output Hello Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_join_group
                    
                    	Output Join Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_join_prune_bytes
                    
                    	Output JP Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_loop_error
                    
                    	Output on loopback error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_null_register
                    
                    	Null Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_prune_group
                    
                    	Output Prune Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: outputs
                    
                    	Packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_dequeued
                    
                    	Packets Dequeued per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_enqueued
                    
                    	Packets Enqueued per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_packman_error
                    
                    	Packets Dropped due to Pakman Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue
                    
                    	Packet queue state and statistics
                    	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue>`
                    
                    .. attribute:: packet_queue_last_clear
                    
                    	Time in seconds since the last clear of all packet queues stats
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: packet_queue_length
                    
                    	Packet Queue Length per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_size
                    
                    	Packet Queue Size per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_read_socket_error
                    
                    	Packet Read Socket Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_tail_drop
                    
                    	Packet Tail Drop per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_standby
                    
                    	Packets Dropped due to Standby Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pakman_error
                    
                    	Pakman packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: send_queue_full
                    
                    	Packets dropped since send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_error
                    
                    	Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: standby_packets_error
                    
                    	Packets received in standby state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: truncated_pim_packets
                    
                    	Packets dropped due to truncated Joins or Prunes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.boundary_acl_rx_drop = None
                        self.boundary_acl_tx_drop = None
                        self.checksum_error = None
                        self.elapsed_time = None
                        self.format_error = None
                        self.input_assert = None
                        self.input_assert_batched = None
                        self.input_bsr_message = None
                        self.input_candidate_rp_advertisement = None
                        self.input_data_register = None
                        self.input_df_election = None
                        self.input_ecmp_redirect = None
                        self.input_hello = None
                        self.input_jp = None
                        self.input_no_idb_error = None
                        self.input_no_pim_error = None
                        self.input_no_vrf_error = None
                        self.input_null_register = None
                        self.input_pim_version_error = None
                        self.input_register_stop = None
                        self.inputs = None
                        self.invalid_destination_packets = None
                        self.invalid_join_prunes = None
                        self.invalid_registers = None
                        self.mdt_drop_local_source_address = None
                        self.mdt_drop_no_idb = None
                        self.mdt_drop_no_vrf = None
                        self.mdt_drop_null_local_address = None
                        self.mdt_join_bad_type = None
                        self.mdt_join_tlv_received = None
                        self.mdt_join_tlv_sent = None
                        self.mdt_joins_drop_multiple_encapsulation = None
                        self.mdt_send_queue_full = None
                        self.mdt_socket_error = None
                        self.mldp_mdt_invalid_lsm_identifier = None
                        self.no_mdt_socket_connection = None
                        self.no_socket_connection = None
                        self.no_source_address = None
                        self.non_supported_packets = None
                        self.output_assert = None
                        self.output_assert_batched = None
                        self.output_bsr_message = None
                        self.output_candidate_rp_advertisement = None
                        self.output_data_register = None
                        self.output_df_election = None
                        self.output_ecmp_redirect = None
                        self.output_hello = None
                        self.output_hello_bytes = None
                        self.output_join_group = None
                        self.output_join_prune_bytes = None
                        self.output_jp = None
                        self.output_loop_error = None
                        self.output_null_register = None
                        self.output_prune_group = None
                        self.output_register_stop = None
                        self.outputs = None
                        self.packet_dequeued = YLeafList()
                        self.packet_dequeued.parent = self
                        self.packet_dequeued.name = 'packet_dequeued'
                        self.packet_enqueued = YLeafList()
                        self.packet_enqueued.parent = self
                        self.packet_enqueued.name = 'packet_enqueued'
                        self.packet_packman_error = None
                        self.packet_queue = YList()
                        self.packet_queue.parent = self
                        self.packet_queue.name = 'packet_queue'
                        self.packet_queue_last_clear = None
                        self.packet_queue_length = YLeafList()
                        self.packet_queue_length.parent = self
                        self.packet_queue_length.name = 'packet_queue_length'
                        self.packet_queue_size = YLeafList()
                        self.packet_queue_size.parent = self
                        self.packet_queue_size.name = 'packet_queue_size'
                        self.packet_read_socket_error = None
                        self.packet_tail_drop = YLeafList()
                        self.packet_tail_drop.parent = self
                        self.packet_tail_drop.name = 'packet_tail_drop'
                        self.packets_standby = None
                        self.pakman_error = None
                        self.send_queue_full = None
                        self.socket_error = None
                        self.standby_packets_error = None
                        self.truncated_pim_packets = None


                    class PacketQueue(object):
                        """
                        Packet queue state and statistics
                        
                        .. attribute:: packet_queue_priority
                        
                        	Priority of this packet queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: packet_queue_state
                        
                        	State of the queue
                        	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState>`
                        
                        .. attribute:: packet_queue_stats
                        
                        	Statistics about the queue
                        	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.packet_queue_priority = None
                            self.packet_queue_state = Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState()
                            self.packet_queue_state.parent = self
                            self.packet_queue_stats = Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats()
                            self.packet_queue_stats.parent = self


                        class PacketQueueState(object):
                            """
                            State of the queue
                            
                            .. attribute:: max_queue_size
                            
                            	Maximum size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_bytes
                            
                            	Size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_packets
                            
                            	Size of queue in number of packets
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.max_queue_size = None
                                self.queue_size_bytes = None
                                self.queue_size_packets = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:packet-queue-state'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.max_queue_size is not None:
                                    return True

                                if self.queue_size_bytes is not None:
                                    return True

                                if self.queue_size_packets is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState']['meta_info']


                        class PacketQueueStats(object):
                            """
                            Statistics about the queue
                            
                            .. attribute:: dequeued_packets
                            
                            	Total number of packets dequeued from this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: enqueued_packets
                            
                            	Total number of packets enqueued to this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high_water_mark_bytes
                            
                            	Highest number of bytes enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: high_water_mark_packets
                            
                            	Highest number of packets enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tail_drops
                            
                            	Number packets dropped from this queue due to max size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dequeued_packets = None
                                self.enqueued_packets = None
                                self.high_water_mark_bytes = None
                                self.high_water_mark_packets = None
                                self.tail_drops = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:packet-queue-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dequeued_packets is not None:
                                    return True

                                if self.enqueued_packets is not None:
                                    return True

                                if self.high_water_mark_bytes is not None:
                                    return True

                                if self.high_water_mark_packets is not None:
                                    return True

                                if self.tail_drops is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:packet-queue'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.packet_queue_priority is not None:
                                return True

                            if self.packet_queue_state is not None and self.packet_queue_state._has_data():
                                return True

                            if self.packet_queue_stats is not None and self.packet_queue_stats._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:traffic-counters'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.boundary_acl_rx_drop is not None:
                            return True

                        if self.boundary_acl_tx_drop is not None:
                            return True

                        if self.checksum_error is not None:
                            return True

                        if self.elapsed_time is not None:
                            return True

                        if self.format_error is not None:
                            return True

                        if self.input_assert is not None:
                            return True

                        if self.input_assert_batched is not None:
                            return True

                        if self.input_bsr_message is not None:
                            return True

                        if self.input_candidate_rp_advertisement is not None:
                            return True

                        if self.input_data_register is not None:
                            return True

                        if self.input_df_election is not None:
                            return True

                        if self.input_ecmp_redirect is not None:
                            return True

                        if self.input_hello is not None:
                            return True

                        if self.input_jp is not None:
                            return True

                        if self.input_no_idb_error is not None:
                            return True

                        if self.input_no_pim_error is not None:
                            return True

                        if self.input_no_vrf_error is not None:
                            return True

                        if self.input_null_register is not None:
                            return True

                        if self.input_pim_version_error is not None:
                            return True

                        if self.input_register_stop is not None:
                            return True

                        if self.inputs is not None:
                            return True

                        if self.invalid_destination_packets is not None:
                            return True

                        if self.invalid_join_prunes is not None:
                            return True

                        if self.invalid_registers is not None:
                            return True

                        if self.mdt_drop_local_source_address is not None:
                            return True

                        if self.mdt_drop_no_idb is not None:
                            return True

                        if self.mdt_drop_no_vrf is not None:
                            return True

                        if self.mdt_drop_null_local_address is not None:
                            return True

                        if self.mdt_join_bad_type is not None:
                            return True

                        if self.mdt_join_tlv_received is not None:
                            return True

                        if self.mdt_join_tlv_sent is not None:
                            return True

                        if self.mdt_joins_drop_multiple_encapsulation is not None:
                            return True

                        if self.mdt_send_queue_full is not None:
                            return True

                        if self.mdt_socket_error is not None:
                            return True

                        if self.mldp_mdt_invalid_lsm_identifier is not None:
                            return True

                        if self.no_mdt_socket_connection is not None:
                            return True

                        if self.no_socket_connection is not None:
                            return True

                        if self.no_source_address is not None:
                            return True

                        if self.non_supported_packets is not None:
                            return True

                        if self.output_assert is not None:
                            return True

                        if self.output_assert_batched is not None:
                            return True

                        if self.output_bsr_message is not None:
                            return True

                        if self.output_candidate_rp_advertisement is not None:
                            return True

                        if self.output_data_register is not None:
                            return True

                        if self.output_df_election is not None:
                            return True

                        if self.output_ecmp_redirect is not None:
                            return True

                        if self.output_hello is not None:
                            return True

                        if self.output_hello_bytes is not None:
                            return True

                        if self.output_join_group is not None:
                            return True

                        if self.output_join_prune_bytes is not None:
                            return True

                        if self.output_jp is not None:
                            return True

                        if self.output_loop_error is not None:
                            return True

                        if self.output_null_register is not None:
                            return True

                        if self.output_prune_group is not None:
                            return True

                        if self.output_register_stop is not None:
                            return True

                        if self.outputs is not None:
                            return True

                        if self.packet_dequeued is not None:
                            for child in self.packet_dequeued:
                                if child is not None:
                                    return True

                        if self.packet_enqueued is not None:
                            for child in self.packet_enqueued:
                                if child is not None:
                                    return True

                        if self.packet_packman_error is not None:
                            return True

                        if self.packet_queue is not None:
                            for child_ref in self.packet_queue:
                                if child_ref._has_data():
                                    return True

                        if self.packet_queue_last_clear is not None:
                            return True

                        if self.packet_queue_length is not None:
                            for child in self.packet_queue_length:
                                if child is not None:
                                    return True

                        if self.packet_queue_size is not None:
                            for child in self.packet_queue_size:
                                if child is not None:
                                    return True

                        if self.packet_read_socket_error is not None:
                            return True

                        if self.packet_tail_drop is not None:
                            for child in self.packet_tail_drop:
                                if child is not None:
                                    return True

                        if self.packets_standby is not None:
                            return True

                        if self.pakman_error is not None:
                            return True

                        if self.send_queue_full is not None:
                            return True

                        if self.socket_error is not None:
                            return True

                        if self.standby_packets_error is not None:
                            return True

                        if self.truncated_pim_packets is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.TrafficCounters']['meta_info']


                class GroupMapRpfs(object):
                    """
                    PIM group mapping information
                    
                    .. attribute:: group_map_rpf
                    
                    	PIM group mapping entry
                    	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_map_rpf = YList()
                        self.group_map_rpf.parent = self
                        self.group_map_rpf.name = 'group_map_rpf'


                    class GroupMapRpf(object):
                        """
                        PIM group mapping entry
                        
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\:  bool
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_priority
                        
                        	RP priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.are_we_rp = None
                            self.client = None
                            self.group_map_information = Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self.prefix = None
                            self.prefix_length = None
                            self.protocol = None
                            self.rp_address = None
                            self.rp_priority = None
                            self.rpf_interface_name = None
                            self.rpf_neighbor = Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self.rpf_vrf_name = None


                        class RpfNeighbor(object):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor']['meta_info']


                        class GroupMapInformation(object):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.client = None
                                self.group_count = None
                                self.is_override = None
                                self.is_used = None
                                self.mrib_active = None
                                self.prefix = Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self.prefix_length = None
                                self.priority = None
                                self.protocol = None
                                self.rp_address = Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self


                            class Prefix(object):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix']['meta_info']


                            class RpAddress(object):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.client is not None:
                                    return True

                                if self.group_count is not None:
                                    return True

                                if self.is_override is not None:
                                    return True

                                if self.is_used is not None:
                                    return True

                                if self.mrib_active is not None:
                                    return True

                                if self.prefix is not None and self.prefix._has_data():
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.priority is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.rp_address is not None and self.rp_address._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.are_we_rp is not None:
                                return True

                            if self.client is not None:
                                return True

                            if self.group_map_information is not None and self.group_map_information._has_data():
                                return True

                            if self.prefix is not None:
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None:
                                return True

                            if self.rp_priority is not None:
                                return True

                            if self.rpf_interface_name is not None:
                                return True

                            if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                return True

                            if self.rpf_vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_map_rpf is not None:
                            for child_ref in self.group_map_rpf:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapRpfs']['meta_info']


                class Summary(object):
                    """
                    PIM summary
                    
                    .. attribute:: bsr_candidate_rp_set_count
                    
                    	Current crp\-set count from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_limit
                    
                    	Maximum crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_threshold
                    
                    	Threshold crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_range_threshold
                    
                    	Threshold group range from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_count
                    
                    	Current group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_limit
                    
                    	Maximum group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_auto_rp_ranges_limit
                    
                    	Global Auto\-RP maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_count
                    
                    	Global BSR current crp\-set count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_limit
                    
                    	Global BSR maximum crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_threshold
                    
                    	Global BSR Threshold crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_count
                    
                    	Global BSR current group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_limit
                    
                    	Global BSR maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_threshold
                    
                    	Global BSR Threshold group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_register_limit
                    
                    	Maximum global registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bsr_ranges_threshold_reached
                    
                    	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_auto_rp_ranges_limit_reached
                    
                    	Is global AutoRP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_bsr_ranges_limit_reached
                    
                    	Is global BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_register_limit_reached
                    
                    	Is global PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_route_limit_reached
                    
                    	Is global route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_rxi_limit_reached
                    
                    	Is global interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_maximum_enforcement_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\:  bool
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: is_ranges_limit_reached
                    
                    	Is Auto\-RP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_route_limit_reached
                    
                    	Is route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: ranges_count
                    
                    	Current group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_limit
                    
                    	Maximum group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_threshold
                    
                    	OOR theshold of grange ranges from AutoRP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_count
                    
                    	Current registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit
                    
                    	Maximum registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit_reached
                    
                    	Is PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: register_threshold
                    
                    	Threshold registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_count
                    
                    	Current routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_limit
                    
                    	Maximum routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_low_water_mark
                    
                    	The number of routes below which the throttle on route creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_threshold
                    
                    	Threshold routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rxi_limit_reached
                    
                    	Is interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: rxi_low_water_mark
                    
                    	The rxi below which the throttle on interface creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_count
                    
                    	Current Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_limit
                    
                    	Maximum Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_threshold
                    
                    	Topology Interface State threshold
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bsr_candidate_rp_set_count = None
                        self.bsr_candidate_rp_set_limit = None
                        self.bsr_candidate_rp_set_threshold = None
                        self.bsr_range_threshold = None
                        self.bsr_ranges_count = None
                        self.bsr_ranges_limit = None
                        self.global_auto_rp_ranges_limit = None
                        self.global_bsr_candidate_rp_set_count = None
                        self.global_bsr_candidate_rp_set_limit = None
                        self.global_bsr_candidate_rp_set_threshold = None
                        self.global_bsr_ranges_count = None
                        self.global_bsr_ranges_limit = None
                        self.global_bsr_ranges_threshold = None
                        self.global_register_limit = None
                        self.is_bsr_ranges_threshold_reached = None
                        self.is_global_auto_rp_ranges_limit_reached = None
                        self.is_global_bsr_ranges_limit_reached = None
                        self.is_global_register_limit_reached = None
                        self.is_global_route_limit_reached = None
                        self.is_global_rxi_limit_reached = None
                        self.is_maximum_enforcement_disabled = None
                        self.is_node_low_memory = None
                        self.is_ranges_limit_reached = None
                        self.is_route_limit_reached = None
                        self.ranges_count = None
                        self.ranges_limit = None
                        self.ranges_threshold = None
                        self.register_count = None
                        self.register_limit = None
                        self.register_limit_reached = None
                        self.register_threshold = None
                        self.route_count = None
                        self.route_limit = None
                        self.route_low_water_mark = None
                        self.route_threshold = None
                        self.rxi_limit_reached = None
                        self.rxi_low_water_mark = None
                        self.topology_interface_state_count = None
                        self.topology_interface_state_limit = None
                        self.topology_interface_state_threshold = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bsr_candidate_rp_set_count is not None:
                            return True

                        if self.bsr_candidate_rp_set_limit is not None:
                            return True

                        if self.bsr_candidate_rp_set_threshold is not None:
                            return True

                        if self.bsr_range_threshold is not None:
                            return True

                        if self.bsr_ranges_count is not None:
                            return True

                        if self.bsr_ranges_limit is not None:
                            return True

                        if self.global_auto_rp_ranges_limit is not None:
                            return True

                        if self.global_bsr_candidate_rp_set_count is not None:
                            return True

                        if self.global_bsr_candidate_rp_set_limit is not None:
                            return True

                        if self.global_bsr_candidate_rp_set_threshold is not None:
                            return True

                        if self.global_bsr_ranges_count is not None:
                            return True

                        if self.global_bsr_ranges_limit is not None:
                            return True

                        if self.global_bsr_ranges_threshold is not None:
                            return True

                        if self.global_register_limit is not None:
                            return True

                        if self.is_bsr_ranges_threshold_reached is not None:
                            return True

                        if self.is_global_auto_rp_ranges_limit_reached is not None:
                            return True

                        if self.is_global_bsr_ranges_limit_reached is not None:
                            return True

                        if self.is_global_register_limit_reached is not None:
                            return True

                        if self.is_global_route_limit_reached is not None:
                            return True

                        if self.is_global_rxi_limit_reached is not None:
                            return True

                        if self.is_maximum_enforcement_disabled is not None:
                            return True

                        if self.is_node_low_memory is not None:
                            return True

                        if self.is_ranges_limit_reached is not None:
                            return True

                        if self.is_route_limit_reached is not None:
                            return True

                        if self.ranges_count is not None:
                            return True

                        if self.ranges_limit is not None:
                            return True

                        if self.ranges_threshold is not None:
                            return True

                        if self.register_count is not None:
                            return True

                        if self.register_limit is not None:
                            return True

                        if self.register_limit_reached is not None:
                            return True

                        if self.register_threshold is not None:
                            return True

                        if self.route_count is not None:
                            return True

                        if self.route_limit is not None:
                            return True

                        if self.route_low_water_mark is not None:
                            return True

                        if self.route_threshold is not None:
                            return True

                        if self.rxi_limit_reached is not None:
                            return True

                        if self.rxi_low_water_mark is not None:
                            return True

                        if self.topology_interface_state_count is not None:
                            return True

                        if self.topology_interface_state_limit is not None:
                            return True

                        if self.topology_interface_state_threshold is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.Summary']['meta_info']


                class Gre(object):
                    """
                    GRE information
                    
                    .. attribute:: gre_hashes
                    
                    	GRE hash
                    	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreHashes>`
                    
                    .. attribute:: gre_next_hops
                    
                    	GRE destination neighbor table
                    	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.gre_hashes = Pim.Standby.Vrfs.Vrf.Gre.GreHashes()
                        self.gre_hashes.parent = self
                        self.gre_next_hops = Pim.Standby.Vrfs.Vrf.Gre.GreNextHops()
                        self.gre_next_hops.parent = self


                    class GreHashes(object):
                        """
                        GRE hash
                        
                        .. attribute:: gre_hash
                        
                        	PIM GRE Hashed Underlying Interface
                        	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.gre_hash = YList()
                            self.gre_hash.parent = self
                            self.gre_hash.name = 'gre_hash'


                        class GreHash(object):
                            """
                            PIM GRE Hashed Underlying Interface
                            
                            .. attribute:: destination_address  <key>
                            
                            	Destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: ifname  <key>
                            
                            	GRE Tunnel Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_address  <key>
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.destination_address = None
                                self.ifname = None
                                self.source_address = None
                                self.next_hop_interface = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.destination_address is None:
                                    raise YPYModelError('Key property destination_address is None')
                                if self.ifname is None:
                                    raise YPYModelError('Key property ifname is None')
                                if self.source_address is None:
                                    raise YPYModelError('Key property source_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-hash[Cisco-IOS-XR-ipv4-pim-oper:destination-address = ' + str(self.destination_address) + '][Cisco-IOS-XR-ipv4-pim-oper:ifname = ' + str(self.ifname) + '][Cisco-IOS-XR-ipv4-pim-oper:source-address = ' + str(self.source_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.destination_address is not None:
                                    return True

                                if self.ifname is not None:
                                    return True

                                if self.source_address is not None:
                                    return True

                                if self.next_hop_interface is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-hashes'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.gre_hash is not None:
                                for child_ref in self.gre_hash:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.Gre.GreHashes']['meta_info']


                    class GreNextHops(object):
                        """
                        GRE destination neighbor table
                        
                        .. attribute:: gre_next_hop
                        
                        	PIM GRE address next\-hop information
                        	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.gre_next_hop = YList()
                            self.gre_next_hop.parent = self
                            self.gre_next_hop.name = 'gre_next_hop'


                        class GreNextHop(object):
                            """
                            PIM GRE address next\-hop information
                            
                            .. attribute:: destination_address  <key>
                            
                            	GRE destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: gre_path
                            
                            	GRE Paths list
                            	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath>`
                            
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.destination_address = None
                                self.gre_path = YList()
                                self.gre_path.parent = self
                                self.gre_path.name = 'gre_path'
                                self.is_connected = None
                                self.metric = None
                                self.metric_preference = None
                                self.registered_address = Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                self.registered_address.parent = self


                            class RegisteredAddress(object):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:registered-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress']['meta_info']


                            class GrePath(object):
                                """
                                GRE Paths list
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: gre_interface_name
                                
                                	GRE Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: gre_neighbor
                                
                                	GRE neighbor
                                	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                                
                                .. attribute:: gre_next_hop
                                
                                	GRE nexthop
                                	**type**\:   :py:class:`GreNextHop_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_>`
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_gre_interface_disabled
                                
                                	Is the gre interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.extranet_vrf_name = None
                                    self.gre_interface_name = None
                                    self.gre_neighbor = Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                    self.gre_neighbor.parent = self
                                    self.gre_next_hop = Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_()
                                    self.gre_next_hop.parent = self
                                    self.is_connector_attribute_present = None
                                    self.is_gre_interface_disabled = None
                                    self.is_via_lsm = None


                                class GreNeighbor(object):
                                    """
                                    GRE neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-neighbor'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor']['meta_info']


                                class GreNextHop_(object):
                                    """
                                    GRE nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.extranet_vrf_name is not None:
                                        return True

                                    if self.gre_interface_name is not None:
                                        return True

                                    if self.gre_neighbor is not None and self.gre_neighbor._has_data():
                                        return True

                                    if self.gre_next_hop is not None and self.gre_next_hop._has_data():
                                        return True

                                    if self.is_connector_attribute_present is not None:
                                        return True

                                    if self.is_gre_interface_disabled is not None:
                                        return True

                                    if self.is_via_lsm is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.destination_address is None:
                                    raise YPYModelError('Key property destination_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hop[Cisco-IOS-XR-ipv4-pim-oper:destination-address = ' + str(self.destination_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.destination_address is not None:
                                    return True

                                if self.gre_path is not None:
                                    for child_ref in self.gre_path:
                                        if child_ref._has_data():
                                            return True

                                if self.is_connected is not None:
                                    return True

                                if self.metric is not None:
                                    return True

                                if self.metric_preference is not None:
                                    return True

                                if self.registered_address is not None and self.registered_address._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hops'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.gre_next_hop is not None:
                                for child_ref in self.gre_next_hop:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.Gre.GreNextHops']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.gre_hashes is not None and self.gre_hashes._has_data():
                            return True

                        if self.gre_next_hops is not None and self.gre_next_hops._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.Gre']['meta_info']


                class BidirDfWinners(object):
                    """
                    Bidirectional PIM DF election winner table
                    
                    .. attribute:: bidir_df_winner
                    
                    	Bidirectional PIM DF election table entry
                    	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bidir_df_winner = YList()
                        self.bidir_df_winner.parent = self
                        self.bidir_df_winner.name = 'bidir_df_winner'


                    class BidirDfWinner(object):
                        """
                        Bidirectional PIM DF election table entry
                        
                        .. attribute:: are_we_df
                        
                        	Are we DF
                        	**type**\:  bool
                        
                        .. attribute:: df_winner
                        
                        	DF Winner
                        	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner>`
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                        
                        .. attribute:: rp_lan
                        
                        	Is this the RP LAN
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.are_we_df = None
                            self.df_winner = Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner()
                            self.df_winner.parent = self
                            self.interface_name = None
                            self.metric = None
                            self.metric_preference = None
                            self.pim_interface_name = None
                            self.rp_address = None
                            self.rp_address_xr = Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self.rp_lan = None
                            self.uptime = None


                        class RpAddressXr(object):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr']['meta_info']


                        class DfWinner(object):
                            """
                            DF Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:df-winner'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winner'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.are_we_df is not None:
                                return True

                            if self.df_winner is not None and self.df_winner._has_data():
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.metric is not None:
                                return True

                            if self.metric_preference is not None:
                                return True

                            if self.pim_interface_name is not None:
                                return True

                            if self.rp_address is not None:
                                return True

                            if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                                return True

                            if self.rp_lan is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winners'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bidir_df_winner is not None:
                            for child_ref in self.bidir_df_winner:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.BidirDfWinners']['meta_info']


                class TableContexts(object):
                    """
                    PIM table context list
                    
                    .. attribute:: table_context
                    
                    	PIM table context information
                    	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TableContexts.TableContext>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.table_context = YList()
                        self.table_context.parent = self
                        self.table_context.name = 'table_context'


                    class TableContext(object):
                        """
                        PIM table context information
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: saf_name
                        
                        	SAF name
                        	**type**\:   :py:class:`PimSafiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafiEnum>`
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: topology_name
                        
                        	Topology name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.afi = None
                            self.is_active = None
                            self.is_ital_registration_done = None
                            self.is_rib_convergence = None
                            self.is_rib_convergence_received = None
                            self.is_rib_registration_done = None
                            self.rpf_registrations = None
                            self.saf_name = None
                            self.safi = None
                            self.table_id = None
                            self.table_name = None
                            self.topology_name = None
                            self.vrf_id = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:table-context'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.afi is not None:
                                return True

                            if self.is_active is not None:
                                return True

                            if self.is_ital_registration_done is not None:
                                return True

                            if self.is_rib_convergence is not None:
                                return True

                            if self.is_rib_convergence_received is not None:
                                return True

                            if self.is_rib_registration_done is not None:
                                return True

                            if self.rpf_registrations is not None:
                                return True

                            if self.saf_name is not None:
                                return True

                            if self.safi is not None:
                                return True

                            if self.table_id is not None:
                                return True

                            if self.table_name is not None:
                                return True

                            if self.topology_name is not None:
                                return True

                            if self.vrf_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.TableContexts.TableContext']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:table-contexts'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.table_context is not None:
                            for child_ref in self.table_context:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.TableContexts']['meta_info']


                class NeighborSummaries(object):
                    """
                    PIM neighbor summary table
                    
                    .. attribute:: neighbor_summary
                    
                    	PIM neighbor summary information
                    	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.neighbor_summary = YList()
                        self.neighbor_summary.parent = self
                        self.neighbor_summary.name = 'neighbor_summary'


                    class NeighborSummary(object):
                        """
                        PIM neighbor summary information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: number_of_external_neighbors
                        
                        	Number of external neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: number_of_neighbors
                        
                        	Number of neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.number_of_external_neighbors = None
                            self.number_of_neighbors = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-summary[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.number_of_external_neighbors is not None:
                                return True

                            if self.number_of_neighbors is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-summaries'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.neighbor_summary is not None:
                            for child_ref in self.neighbor_summary:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.NeighborSummaries']['meta_info']


                class Context(object):
                    """
                    PIM context information
                    
                    .. attribute:: active_table_count
                    
                    	Number of active Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: allow_rp_configured
                    
                    	Allow RP Configured
                    	**type**\:  bool
                    
                    .. attribute:: allow_rp_group_list
                    
                    	Allow RP Group\-List ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: allow_rp_rp_list
                    
                    	Allow RP RP\-list ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: anycast_rp_configured
                    
                    	Anycast\-RP config
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_policy_name
                    
                    	Anycast\-RP Policy Name
                    	**type**\:  str
                    
                    .. attribute:: anycast_rp_range
                    
                    	Anycast\-RP Ranges
                    	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange>`
                    
                    .. attribute:: bgp_auto_discovery_configured
                    
                    	BGP Auto\-Discovery configured
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery_type
                    
                    	BGP Auto Discovery Type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_i_pmsi_added
                    
                    	BGP I\-PMSI Added
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_address
                    
                    	BGP remote interface address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: bgp_remote_interface
                    
                    	BGP remote interface handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: bgp_remote_interface_name
                    
                    	BGP remote interface name
                    	**type**\:  str
                    
                    .. attribute:: bgp_remote_on
                    
                    	BGP remote interface status
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_state
                    
                    	BGP remote interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_source_active_announce
                    
                    	Send BGP Source\-Active Announcements
                    	**type**\:  bool
                    
                    .. attribute:: export_route_target
                    
                    	Export Route Targets
                    	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget>`
                    
                    .. attribute:: gin_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: gin_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: gin_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: import_route_target
                    
                    	Import Route Targets
                    	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget>`
                    
                    .. attribute:: in_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: in_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: in_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_signaling_local_enabled
                    
                    	Inband signaling Local enabled
                    	**type**\:  bool
                    
                    .. attribute:: in_band_signaling_remote_enabled
                    
                    	Inband signaling Remote enabled
                    	**type**\:  bool
                    
                    .. attribute:: inter_autonomous_system_enabled
                    
                    	Inter\-AS Enabled
                    	**type**\:  bool
                    
                    .. attribute:: ir_maximum_mdt_aggregation
                    
                    	IR MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_announce_interval
                    
                    	IR Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_switchover_interval
                    
                    	IR Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_interface
                    
                    	IRMDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: ir_mdt_mtu
                    
                    	IRMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_name
                    
                    	IR MDT Name
                    	**type**\:  str
                    
                    .. attribute:: ir_mdt_rpf_identifier
                    
                    	IR RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_tail_label
                    
                    	IR Tail Label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active
                    	**type**\:  bool
                    
                    .. attribute:: is_active_ital
                    
                    	Active ITAL
                    	**type**\:  bool
                    
                    .. attribute:: is_all_interface_disable_operation
                    
                    	PIM all interface disable operation
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_enabled
                    
                    	Auto RP Listen Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_sock_add
                    
                    	Auto RP listen sock add
                    	**type**\:  bool
                    
                    .. attribute:: is_create_gin_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_in_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_ir_mdt_interface
                    
                    	Create IR MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mdt_interface
                    
                    	Create MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mldp_mdt_interface
                    
                    	Create MLDP MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_rsvp_te_mdt_interface
                    
                    	Create RSVP\-TE MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_default_granges
                    
                    	Default granges
                    	**type**\:  bool
                    
                    .. attribute:: is_gin_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_in_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_ir_mdt_owner
                    
                    	IR MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_added
                    
                    	VRF LPTS filter added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_m_host_publish_pending
                    
                    	Publish pending for MHost Default interface
                    	**type**\:  bool
                    
                    .. attribute:: is_mdt_owner
                    
                    	MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mldp_mdt_owner
                    
                    	MLDP MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mrib_register
                    
                    	MRIB Register
                    	**type**\:  bool
                    
                    .. attribute:: is_multicast_rib_registration
                    
                    	Mcast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converge_received
                    
                    	PIM NSF RIB converge received
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converged
                    
                    	PIM NSF RIB converged
                    	**type**\:  bool
                    
                    .. attribute:: is_redistribution_reset
                    
                    	Pending redist reset
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_added
                    
                    	VRF LPTS filter added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_add_required
                    
                    	VRF required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_added
                    
                    	VRF added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_enabled
                    
                    	PIM RIB multiplath enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_interface_hash
                    
                    	PIM RIB multipath interface hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_hash
                    
                    	PIM RIB multipath source based hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_next_hop_hash
                    
                    	PIM RIB multipath source\-nexthop hash
                    	**type**\:  bool
                    
                    .. attribute:: is_routing_enabled
                    
                    	Routing Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rsvp_te_mdt_owner
                    
                    	RSVP\-TE MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_add_required
                    
                    	VRF required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_added
                    
                    	VRF added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_add_required
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_added
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind
                    
                    	VRF bound on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind_required
                    
                    	VRF bind required on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_unicast_rib_registration
                    
                    	Ucast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: maximum_mdt_aggregation
                    
                    	MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_announce_interval
                    
                    	Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_switchover_interval
                    
                    	Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_default_group
                    
                    	MDT Default group
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_gre_remote_rpf_identifier
                    
                    	GRE\-MDT Remote RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_gre_rpf_identifier
                    
                    	GRE\-MDT RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_interface
                    
                    	MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mdt_mtu
                    
                    	MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_neighbor_filter_name
                    
                    	MDT Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: mdt_partitioned_ir_control_identifier
                    
                    	Partitioned IR MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_partitioned_mdt_control_identifier
                    
                    	Partitioned MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mhost_default_interface_config
                    
                    	Configured Mhost Defint
                    	**type**\:  str
                    
                    .. attribute:: mhost_interface
                    
                    	MHost handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mldp_auto_rp_announce_tree_added
                    
                    	MLDP Autorp Announce Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_auto_rp_discovery_tree_added
                    
                    	MLDP Autorp Discovery Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_bsr_control_tree_added
                    
                    	MLDP BSR Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_control_head_lsm_identifier
                    
                    	MLDP MVPN Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_local_label
                    
                    	Partitioned MDT Head local label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_lsm_identifier
                    
                    	MLDP Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_maximum_mdt_aggregation
                    
                    	MLDP MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_announce_interval
                    
                    	MLDP Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_switchover_interval
                    
                    	MLDP Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_interface
                    
                    	MLDP MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mldp_mdt_mtu
                    
                    	MLDP MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_name
                    
                    	MLDP MDT Name
                    	**type**\:  str
                    
                    .. attribute:: mldp_mdt_remote_rpf_identifier
                    
                    	MLDP Remote RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_rpf_identifier
                    
                    	MLDP RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partioned_mp2m_ptree
                    
                    	MP2MP Partitioned MDT tree
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_head_lsm_identifier
                    
                    	Partitioned MDT Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partitioned_mdt_configured
                    
                    	MLDP Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_mdt_identifier
                    
                    	MLDP Partitioned MDT Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_head_lsm_identifier
                    
                    	MLDP Remote Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_partitioned_mdt_configured
                    
                    	MLDP Remote Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_root_address
                    
                    	MLDP Root addresses
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_root_count
                    
                    	MLDP Root count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: murib_id
                    
                    	MURIB ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: non_default_vrf_count_on_socket
                    
                    	Count of non\-default vrfs on raw socket
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: organization_unique_identifier
                    
                    	OUI for VPN\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mpte_li_drop
                    
                    	Route LI updates dropped for P2MP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redistribution_reset_count
                    
                    	Redist reset count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_default_group
                    
                    	Remote Default Group
                    	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup>`
                    
                    .. attribute:: remote_table_id
                    
                    	Remote Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_distinguisher
                    
                    	RD value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: rpf_default_table
                    
                    	RPF Default Table
                    	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable>`
                    
                    .. attribute:: rpf_id
                    
                    	RPF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_policy_name
                    
                    	RPF topology selection route\-policy name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_maximum_mdt_aggregation
                    
                    	RSVP\-TE MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_announce_interval
                    
                    	RSVP\-TE Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_switchover_interval
                    
                    	RSVP\-TE Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_interface
                    
                    	RSVP\-TEMDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rsvp_te_mdt_mtu
                    
                    	RSVP\-TEMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_name
                    
                    	RSVP\-TE MDT Name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_mdt_rpf_identifier
                    
                    	RSVP\-TE RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_static_p2mp_count
                    
                    	Number of Static P2MP\-TE MDT
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	PIM is using MuRIB
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_time
                    
                    	S,G Expiry Time Configured, in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: sg_expiry_timer_configured
                    
                    	S,G Expiry Timer Configured
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_timer_sg_list
                    
                    	S,G expiry timer ACL name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: stale_rd_present
                    
                    	RD is stale
                    	**type**\:  bool
                    
                    .. attribute:: suppress_pim_data_mdt_tlv
                    
                    	Suppress PIM Data\-MDT TLV Announcements
                    	**type**\:  bool
                    
                    .. attribute:: suppress_shared_tree_join
                    
                    	Suppress Shared\-Tree Joins
                    	**type**\:  bool
                    
                    .. attribute:: table_count
                    
                    	Number of configured Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: umh
                    
                    	Join UMH Core\-Tree
                    	**type**\:  bool
                    
                    .. attribute:: valid_rd_present
                    
                    	RD is valid
                    	**type**\:  bool
                    
                    .. attribute:: vpn_index
                    
                    	VPN Index
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.active_table_count = None
                        self.allow_rp_configured = None
                        self.allow_rp_group_list = None
                        self.allow_rp_rp_list = None
                        self.anycast_rp_configured = None
                        self.anycast_rp_policy_name = None
                        self.anycast_rp_range = YList()
                        self.anycast_rp_range.parent = self
                        self.anycast_rp_range.name = 'anycast_rp_range'
                        self.bgp_auto_discovery_configured = None
                        self.bgp_auto_discovery_type = None
                        self.bgp_i_pmsi_added = None
                        self.bgp_remote_address = None
                        self.bgp_remote_interface = None
                        self.bgp_remote_interface_name = None
                        self.bgp_remote_on = None
                        self.bgp_remote_state = None
                        self.bgp_source_active_announce = None
                        self.export_route_target = YList()
                        self.export_route_target.parent = self
                        self.export_route_target.name = 'export_route_target'
                        self.gin_b_and_mdt_data_announce_interval = None
                        self.gin_b_and_mdt_data_switchover_interval = None
                        self.gin_b_and_mdt_interface = None
                        self.gin_b_and_mdt_mtu = None
                        self.gin_b_and_mdt_name = None
                        self.gin_b_and_mdt_rpf_identifier = None
                        self.gin_band_maximum_mdt_aggregation = None
                        self.import_route_target = YList()
                        self.import_route_target.parent = self
                        self.import_route_target.name = 'import_route_target'
                        self.in_b_and_mdt_data_announce_interval = None
                        self.in_b_and_mdt_data_switchover_interval = None
                        self.in_b_and_mdt_interface = None
                        self.in_b_and_mdt_mtu = None
                        self.in_b_and_mdt_name = None
                        self.in_b_and_mdt_rpf_identifier = None
                        self.in_band_maximum_mdt_aggregation = None
                        self.in_band_signaling_local_enabled = None
                        self.in_band_signaling_remote_enabled = None
                        self.inter_autonomous_system_enabled = None
                        self.ir_maximum_mdt_aggregation = None
                        self.ir_mdt_data_announce_interval = None
                        self.ir_mdt_data_switchover_interval = None
                        self.ir_mdt_interface = None
                        self.ir_mdt_mtu = None
                        self.ir_mdt_name = None
                        self.ir_mdt_rpf_identifier = None
                        self.ir_mdt_tail_label = None
                        self.is_active = None
                        self.is_active_ital = None
                        self.is_all_interface_disable_operation = None
                        self.is_auto_rp_listen_enabled = None
                        self.is_auto_rp_listen_sock_add = None
                        self.is_create_gin_b_and_mdt_interface = None
                        self.is_create_in_b_and_mdt_interface = None
                        self.is_create_ir_mdt_interface = None
                        self.is_create_mdt_interface = None
                        self.is_create_mldp_mdt_interface = None
                        self.is_create_rsvp_te_mdt_interface = None
                        self.is_default_granges = None
                        self.is_gin_b_and_mdt_owner = None
                        self.is_in_b_and_mdt_owner = None
                        self.is_ir_mdt_owner = None
                        self.is_lpts_socket_add_required = None
                        self.is_lpts_socket_added = None
                        self.is_m_host_publish_pending = None
                        self.is_mdt_owner = None
                        self.is_mldp_mdt_owner = None
                        self.is_mrib_register = None
                        self.is_multicast_rib_registration = None
                        self.is_pim_nsf_rib_converge_received = None
                        self.is_pim_nsf_rib_converged = None
                        self.is_redistribution_reset = None
                        self.is_register_injection_lpts_socket_add_required = None
                        self.is_register_injection_lpts_socket_added = None
                        self.is_register_injection_socket_add_required = None
                        self.is_register_injection_socket_added = None
                        self.is_rib_multipath_enabled = None
                        self.is_rib_multipath_interface_hash = None
                        self.is_rib_multipath_source_hash = None
                        self.is_rib_multipath_source_next_hop_hash = None
                        self.is_routing_enabled = None
                        self.is_rsvp_te_mdt_owner = None
                        self.is_socket_add_required = None
                        self.is_socket_added = None
                        self.is_udp_socket_add_required = None
                        self.is_udp_socket_added = None
                        self.is_udp_socket_bind = None
                        self.is_udp_socket_bind_required = None
                        self.is_unicast_rib_registration = None
                        self.maximum_mdt_aggregation = None
                        self.mdt_data_announce_interval = None
                        self.mdt_data_switchover_interval = None
                        self.mdt_default_group = None
                        self.mdt_gre_remote_rpf_identifier = None
                        self.mdt_gre_rpf_identifier = None
                        self.mdt_interface = None
                        self.mdt_mtu = None
                        self.mdt_neighbor_filter_name = None
                        self.mdt_partitioned_ir_control_identifier = None
                        self.mdt_partitioned_mdt_control_identifier = None
                        self.mhost_default_interface_config = None
                        self.mhost_interface = None
                        self.mldp_auto_rp_announce_tree_added = None
                        self.mldp_auto_rp_discovery_tree_added = None
                        self.mldp_bsr_control_tree_added = None
                        self.mldp_control_head_lsm_identifier = None
                        self.mldp_head_local_label = None
                        self.mldp_head_lsm_identifier = None
                        self.mldp_maximum_mdt_aggregation = None
                        self.mldp_mdt_data_announce_interval = None
                        self.mldp_mdt_data_switchover_interval = None
                        self.mldp_mdt_interface = None
                        self.mldp_mdt_mtu = None
                        self.mldp_mdt_name = None
                        self.mldp_mdt_remote_rpf_identifier = None
                        self.mldp_mdt_rpf_identifier = None
                        self.mldp_partioned_mp2m_ptree = None
                        self.mldp_partitioned_head_lsm_identifier = None
                        self.mldp_partitioned_mdt_configured = None
                        self.mldp_partitioned_mdt_identifier = None
                        self.mldp_remote_head_lsm_identifier = None
                        self.mldp_remote_partitioned_mdt_configured = None
                        self.mldp_root_address = YLeafList()
                        self.mldp_root_address.parent = self
                        self.mldp_root_address.name = 'mldp_root_address'
                        self.mldp_root_count = None
                        self.murib_id = None
                        self.neighbor_filter_name = None
                        self.non_default_vrf_count_on_socket = None
                        self.organization_unique_identifier = None
                        self.p2mpte_li_drop = None
                        self.redistribution_reset_count = None
                        self.remote_default_group = Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup()
                        self.remote_default_group.parent = self
                        self.remote_table_id = None
                        self.route_distinguisher = None
                        self.rpf_default_table = Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable()
                        self.rpf_default_table.parent = self
                        self.rpf_id = None
                        self.rpf_policy_name = None
                        self.rsvp_te_maximum_mdt_aggregation = None
                        self.rsvp_te_mdt_data_announce_interval = None
                        self.rsvp_te_mdt_data_switchover_interval = None
                        self.rsvp_te_mdt_interface = None
                        self.rsvp_te_mdt_mtu = None
                        self.rsvp_te_mdt_name = None
                        self.rsvp_te_mdt_rpf_identifier = None
                        self.rsvp_te_mdt_static_p2mp_count = None
                        self.rump_enabled = None
                        self.sg_expiry_time = None
                        self.sg_expiry_timer_configured = None
                        self.sg_expiry_timer_sg_list = None
                        self.stale_rd_present = None
                        self.suppress_pim_data_mdt_tlv = None
                        self.suppress_shared_tree_join = None
                        self.table_count = None
                        self.table_id = None
                        self.umh = None
                        self.valid_rd_present = None
                        self.vpn_index = None
                        self.vrf_id = None


                    class RemoteDefaultGroup(object):
                        """
                        Remote Default Group
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:remote-default-group'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup']['meta_info']


                    class RpfDefaultTable(object):
                        """
                        RPF Default Table
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.afi = None
                            self.is_active = None
                            self.is_ital_registration_done = None
                            self.is_rib_convergence = None
                            self.is_rib_convergence_received = None
                            self.is_rib_registration_done = None
                            self.rpf_registrations = None
                            self.safi = None
                            self.table_id = None
                            self.table_name = None
                            self.vrf_id = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-default-table'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.afi is not None:
                                return True

                            if self.is_active is not None:
                                return True

                            if self.is_ital_registration_done is not None:
                                return True

                            if self.is_rib_convergence is not None:
                                return True

                            if self.is_rib_convergence_received is not None:
                                return True

                            if self.is_rib_registration_done is not None:
                                return True

                            if self.rpf_registrations is not None:
                                return True

                            if self.safi is not None:
                                return True

                            if self.table_id is not None:
                                return True

                            if self.table_name is not None:
                                return True

                            if self.vrf_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable']['meta_info']


                    class ExportRouteTarget(object):
                        """
                        Export Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.anycast_rp = None
                            self.anycast_rp_marked = None
                            self.bgp_auto_discovery = None
                            self.configured = None
                            self.route_target = None
                            self.segment_border = None
                            self.update_pending = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:export-route-target'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.anycast_rp is not None:
                                return True

                            if self.anycast_rp_marked is not None:
                                return True

                            if self.bgp_auto_discovery is not None:
                                return True

                            if self.configured is not None:
                                return True

                            if self.route_target is not None:
                                return True

                            if self.segment_border is not None:
                                return True

                            if self.update_pending is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget']['meta_info']


                    class ImportRouteTarget(object):
                        """
                        Import Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.anycast_rp = None
                            self.anycast_rp_marked = None
                            self.bgp_auto_discovery = None
                            self.configured = None
                            self.route_target = None
                            self.segment_border = None
                            self.update_pending = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:import-route-target'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.anycast_rp is not None:
                                return True

                            if self.anycast_rp_marked is not None:
                                return True

                            if self.bgp_auto_discovery is not None:
                                return True

                            if self.configured is not None:
                                return True

                            if self.route_target is not None:
                                return True

                            if self.segment_border is not None:
                                return True

                            if self.update_pending is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget']['meta_info']


                    class AnycastRpRange(object):
                        """
                        Anycast\-RP Ranges
                        
                        .. attribute:: ancast_rp_marked
                        
                        	Anycast\-RP Range marked
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Anycast\-RP Range Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Anycast\-RP Range Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ancast_rp_marked = None
                            self.prefix = Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None


                        class Prefix(object):
                            """
                            Anycast\-RP Range Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:anycast-rp-range'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ancast_rp_marked is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:context'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.active_table_count is not None:
                            return True

                        if self.allow_rp_configured is not None:
                            return True

                        if self.allow_rp_group_list is not None:
                            return True

                        if self.allow_rp_rp_list is not None:
                            return True

                        if self.anycast_rp_configured is not None:
                            return True

                        if self.anycast_rp_policy_name is not None:
                            return True

                        if self.anycast_rp_range is not None:
                            for child_ref in self.anycast_rp_range:
                                if child_ref._has_data():
                                    return True

                        if self.bgp_auto_discovery_configured is not None:
                            return True

                        if self.bgp_auto_discovery_type is not None:
                            return True

                        if self.bgp_i_pmsi_added is not None:
                            return True

                        if self.bgp_remote_address is not None:
                            return True

                        if self.bgp_remote_interface is not None:
                            return True

                        if self.bgp_remote_interface_name is not None:
                            return True

                        if self.bgp_remote_on is not None:
                            return True

                        if self.bgp_remote_state is not None:
                            return True

                        if self.bgp_source_active_announce is not None:
                            return True

                        if self.export_route_target is not None:
                            for child_ref in self.export_route_target:
                                if child_ref._has_data():
                                    return True

                        if self.gin_b_and_mdt_data_announce_interval is not None:
                            return True

                        if self.gin_b_and_mdt_data_switchover_interval is not None:
                            return True

                        if self.gin_b_and_mdt_interface is not None:
                            return True

                        if self.gin_b_and_mdt_mtu is not None:
                            return True

                        if self.gin_b_and_mdt_name is not None:
                            return True

                        if self.gin_b_and_mdt_rpf_identifier is not None:
                            return True

                        if self.gin_band_maximum_mdt_aggregation is not None:
                            return True

                        if self.import_route_target is not None:
                            for child_ref in self.import_route_target:
                                if child_ref._has_data():
                                    return True

                        if self.in_b_and_mdt_data_announce_interval is not None:
                            return True

                        if self.in_b_and_mdt_data_switchover_interval is not None:
                            return True

                        if self.in_b_and_mdt_interface is not None:
                            return True

                        if self.in_b_and_mdt_mtu is not None:
                            return True

                        if self.in_b_and_mdt_name is not None:
                            return True

                        if self.in_b_and_mdt_rpf_identifier is not None:
                            return True

                        if self.in_band_maximum_mdt_aggregation is not None:
                            return True

                        if self.in_band_signaling_local_enabled is not None:
                            return True

                        if self.in_band_signaling_remote_enabled is not None:
                            return True

                        if self.inter_autonomous_system_enabled is not None:
                            return True

                        if self.ir_maximum_mdt_aggregation is not None:
                            return True

                        if self.ir_mdt_data_announce_interval is not None:
                            return True

                        if self.ir_mdt_data_switchover_interval is not None:
                            return True

                        if self.ir_mdt_interface is not None:
                            return True

                        if self.ir_mdt_mtu is not None:
                            return True

                        if self.ir_mdt_name is not None:
                            return True

                        if self.ir_mdt_rpf_identifier is not None:
                            return True

                        if self.ir_mdt_tail_label is not None:
                            return True

                        if self.is_active is not None:
                            return True

                        if self.is_active_ital is not None:
                            return True

                        if self.is_all_interface_disable_operation is not None:
                            return True

                        if self.is_auto_rp_listen_enabled is not None:
                            return True

                        if self.is_auto_rp_listen_sock_add is not None:
                            return True

                        if self.is_create_gin_b_and_mdt_interface is not None:
                            return True

                        if self.is_create_in_b_and_mdt_interface is not None:
                            return True

                        if self.is_create_ir_mdt_interface is not None:
                            return True

                        if self.is_create_mdt_interface is not None:
                            return True

                        if self.is_create_mldp_mdt_interface is not None:
                            return True

                        if self.is_create_rsvp_te_mdt_interface is not None:
                            return True

                        if self.is_default_granges is not None:
                            return True

                        if self.is_gin_b_and_mdt_owner is not None:
                            return True

                        if self.is_in_b_and_mdt_owner is not None:
                            return True

                        if self.is_ir_mdt_owner is not None:
                            return True

                        if self.is_lpts_socket_add_required is not None:
                            return True

                        if self.is_lpts_socket_added is not None:
                            return True

                        if self.is_m_host_publish_pending is not None:
                            return True

                        if self.is_mdt_owner is not None:
                            return True

                        if self.is_mldp_mdt_owner is not None:
                            return True

                        if self.is_mrib_register is not None:
                            return True

                        if self.is_multicast_rib_registration is not None:
                            return True

                        if self.is_pim_nsf_rib_converge_received is not None:
                            return True

                        if self.is_pim_nsf_rib_converged is not None:
                            return True

                        if self.is_redistribution_reset is not None:
                            return True

                        if self.is_register_injection_lpts_socket_add_required is not None:
                            return True

                        if self.is_register_injection_lpts_socket_added is not None:
                            return True

                        if self.is_register_injection_socket_add_required is not None:
                            return True

                        if self.is_register_injection_socket_added is not None:
                            return True

                        if self.is_rib_multipath_enabled is not None:
                            return True

                        if self.is_rib_multipath_interface_hash is not None:
                            return True

                        if self.is_rib_multipath_source_hash is not None:
                            return True

                        if self.is_rib_multipath_source_next_hop_hash is not None:
                            return True

                        if self.is_routing_enabled is not None:
                            return True

                        if self.is_rsvp_te_mdt_owner is not None:
                            return True

                        if self.is_socket_add_required is not None:
                            return True

                        if self.is_socket_added is not None:
                            return True

                        if self.is_udp_socket_add_required is not None:
                            return True

                        if self.is_udp_socket_added is not None:
                            return True

                        if self.is_udp_socket_bind is not None:
                            return True

                        if self.is_udp_socket_bind_required is not None:
                            return True

                        if self.is_unicast_rib_registration is not None:
                            return True

                        if self.maximum_mdt_aggregation is not None:
                            return True

                        if self.mdt_data_announce_interval is not None:
                            return True

                        if self.mdt_data_switchover_interval is not None:
                            return True

                        if self.mdt_default_group is not None:
                            return True

                        if self.mdt_gre_remote_rpf_identifier is not None:
                            return True

                        if self.mdt_gre_rpf_identifier is not None:
                            return True

                        if self.mdt_interface is not None:
                            return True

                        if self.mdt_mtu is not None:
                            return True

                        if self.mdt_neighbor_filter_name is not None:
                            return True

                        if self.mdt_partitioned_ir_control_identifier is not None:
                            return True

                        if self.mdt_partitioned_mdt_control_identifier is not None:
                            return True

                        if self.mhost_default_interface_config is not None:
                            return True

                        if self.mhost_interface is not None:
                            return True

                        if self.mldp_auto_rp_announce_tree_added is not None:
                            return True

                        if self.mldp_auto_rp_discovery_tree_added is not None:
                            return True

                        if self.mldp_bsr_control_tree_added is not None:
                            return True

                        if self.mldp_control_head_lsm_identifier is not None:
                            return True

                        if self.mldp_head_local_label is not None:
                            return True

                        if self.mldp_head_lsm_identifier is not None:
                            return True

                        if self.mldp_maximum_mdt_aggregation is not None:
                            return True

                        if self.mldp_mdt_data_announce_interval is not None:
                            return True

                        if self.mldp_mdt_data_switchover_interval is not None:
                            return True

                        if self.mldp_mdt_interface is not None:
                            return True

                        if self.mldp_mdt_mtu is not None:
                            return True

                        if self.mldp_mdt_name is not None:
                            return True

                        if self.mldp_mdt_remote_rpf_identifier is not None:
                            return True

                        if self.mldp_mdt_rpf_identifier is not None:
                            return True

                        if self.mldp_partioned_mp2m_ptree is not None:
                            return True

                        if self.mldp_partitioned_head_lsm_identifier is not None:
                            return True

                        if self.mldp_partitioned_mdt_configured is not None:
                            return True

                        if self.mldp_partitioned_mdt_identifier is not None:
                            return True

                        if self.mldp_remote_head_lsm_identifier is not None:
                            return True

                        if self.mldp_remote_partitioned_mdt_configured is not None:
                            return True

                        if self.mldp_root_address is not None:
                            for child in self.mldp_root_address:
                                if child is not None:
                                    return True

                        if self.mldp_root_count is not None:
                            return True

                        if self.murib_id is not None:
                            return True

                        if self.neighbor_filter_name is not None:
                            return True

                        if self.non_default_vrf_count_on_socket is not None:
                            return True

                        if self.organization_unique_identifier is not None:
                            return True

                        if self.p2mpte_li_drop is not None:
                            return True

                        if self.redistribution_reset_count is not None:
                            return True

                        if self.remote_default_group is not None and self.remote_default_group._has_data():
                            return True

                        if self.remote_table_id is not None:
                            return True

                        if self.route_distinguisher is not None:
                            return True

                        if self.rpf_default_table is not None and self.rpf_default_table._has_data():
                            return True

                        if self.rpf_id is not None:
                            return True

                        if self.rpf_policy_name is not None:
                            return True

                        if self.rsvp_te_maximum_mdt_aggregation is not None:
                            return True

                        if self.rsvp_te_mdt_data_announce_interval is not None:
                            return True

                        if self.rsvp_te_mdt_data_switchover_interval is not None:
                            return True

                        if self.rsvp_te_mdt_interface is not None:
                            return True

                        if self.rsvp_te_mdt_mtu is not None:
                            return True

                        if self.rsvp_te_mdt_name is not None:
                            return True

                        if self.rsvp_te_mdt_rpf_identifier is not None:
                            return True

                        if self.rsvp_te_mdt_static_p2mp_count is not None:
                            return True

                        if self.rump_enabled is not None:
                            return True

                        if self.sg_expiry_time is not None:
                            return True

                        if self.sg_expiry_timer_configured is not None:
                            return True

                        if self.sg_expiry_timer_sg_list is not None:
                            return True

                        if self.stale_rd_present is not None:
                            return True

                        if self.suppress_pim_data_mdt_tlv is not None:
                            return True

                        if self.suppress_shared_tree_join is not None:
                            return True

                        if self.table_count is not None:
                            return True

                        if self.table_id is not None:
                            return True

                        if self.umh is not None:
                            return True

                        if self.valid_rd_present is not None:
                            return True

                        if self.vpn_index is not None:
                            return True

                        if self.vrf_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.Context']['meta_info']


                class TopologyEntryFlagRouteCounts(object):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: topology_entry_flag_route_count
                    
                    	Route count for topology with entry flag set
                    	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.topology_entry_flag_route_count = YList()
                        self.topology_entry_flag_route_count.parent = self
                        self.topology_entry_flag_route_count.name = 'topology_entry_flag_route_count'


                    class TopologyEntryFlagRouteCount(object):
                        """
                        Route count for topology with entry flag set
                        
                        .. attribute:: entry_flag  <key>
                        
                        	entry flag
                        	**type**\:   :py:class:`PimTopologyEntryFlagEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlagEnum>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.entry_flag = None
                            self.active_group_ranges = None
                            self.group_address = Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                            self.group_address.parent = self
                            self.group_ranges = None
                            self.groute_count = None
                            self.is_node_low_memory = None
                            self.sg_route_count = None
                            self.sgr_route_count = None


                        class GroupAddress(object):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.entry_flag is None:
                                raise YPYModelError('Key property entry_flag is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology-entry-flag-route-count[Cisco-IOS-XR-ipv4-pim-oper:entry-flag = ' + str(self.entry_flag) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.entry_flag is not None:
                                return True

                            if self.active_group_ranges is not None:
                                return True

                            if self.group_address is not None and self.group_address._has_data():
                                return True

                            if self.group_ranges is not None:
                                return True

                            if self.groute_count is not None:
                                return True

                            if self.is_node_low_memory is not None:
                                return True

                            if self.sg_route_count is not None:
                                return True

                            if self.sgr_route_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology-entry-flag-route-counts'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.topology_entry_flag_route_count is not None:
                            for child_ref in self.topology_entry_flag_route_count:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts']['meta_info']


                class RpfRedirect(object):
                    """
                    PIM ECMP RPF\-redirect bundle
                    
                    .. attribute:: bundle_interfaces
                    
                    	PIM ECMP RPF\-redirect bundle information
                    	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces>`
                    
                    .. attribute:: redirect_route_databases
                    
                    	PIM ECMP RPF\-redirect route database
                    	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bundle_interfaces = Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces()
                        self.bundle_interfaces.parent = self
                        self.redirect_route_databases = Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases()
                        self.redirect_route_databases.parent = self


                    class RedirectRouteDatabases(object):
                        """
                        PIM ECMP RPF\-redirect route database
                        
                        .. attribute:: redirect_route_database
                        
                        	PIM ECMP RPF\-redirect route information
                        	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.redirect_route_database = YList()
                            self.redirect_route_database.parent = self
                            self.redirect_route_database.name = 'redirect_route_database'


                        class RedirectRouteDatabase(object):
                            """
                            PIM ECMP RPF\-redirect route information
                            
                            .. attribute:: bandwidth
                            
                            	Bandwidth in Kbps
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Group ddress
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                            
                            .. attribute:: interface
                            
                            	Outgoing interface list
                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bandwidth = None
                                self.group_address = None
                                self.group_address_xr = Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self.interface = YList()
                                self.interface.parent = self
                                self.interface.name = 'interface'
                                self.source_address = None
                                self.source_address_xr = Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self.uptime = None


                            class GroupAddressXr(object):
                                """
                                Group ddress
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr']['meta_info']


                            class SourceAddressXr(object):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr']['meta_info']


                            class Interface(object):
                                """
                                Outgoing interface list
                                
                                .. attribute:: expiry
                                
                                	Expiry in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: is_outgoing_interface
                                
                                	Is outgoing Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface
                                
                                	Is RPF Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_snoop_interface
                                
                                	Is snooping Interface
                                	**type**\:  bool
                                
                                .. attribute:: rpf_address
                                
                                	RPF Address
                                	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                                
                                .. attribute:: uptime
                                
                                	Uptime in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.expiry = None
                                    self.interface_name = None
                                    self.is_outgoing_interface = None
                                    self.is_rpf_interface = None
                                    self.is_snoop_interface = None
                                    self.rpf_address = Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                    self.rpf_address.parent = self
                                    self.uptime = None


                                class RpfAddress(object):
                                    """
                                    RPF Address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.expiry is not None:
                                        return True

                                    if self.interface_name is not None:
                                        return True

                                    if self.is_outgoing_interface is not None:
                                        return True

                                    if self.is_rpf_interface is not None:
                                        return True

                                    if self.is_snoop_interface is not None:
                                        return True

                                    if self.rpf_address is not None and self.rpf_address._has_data():
                                        return True

                                    if self.uptime is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bandwidth is not None:
                                    return True

                                if self.group_address is not None:
                                    return True

                                if self.group_address_xr is not None and self.group_address_xr._has_data():
                                    return True

                                if self.interface is not None:
                                    for child_ref in self.interface:
                                        if child_ref._has_data():
                                            return True

                                if self.source_address is not None:
                                    return True

                                if self.source_address_xr is not None and self.source_address_xr._has_data():
                                    return True

                                if self.uptime is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.redirect_route_database is not None:
                                for child_ref in self.redirect_route_database:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases']['meta_info']


                    class BundleInterfaces(object):
                        """
                        PIM ECMP RPF\-redirect bundle information
                        
                        .. attribute:: bundle_interface
                        
                        	PIM ECMP RPF\-redirect bundle interface information
                        	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bundle_interface = YList()
                            self.bundle_interface.parent = self
                            self.bundle_interface.name = 'bundle_interface'


                        class BundleInterface(object):
                            """
                            PIM ECMP RPF\-redirect bundle interface
                            information
                            
                            .. attribute:: allocated_bandwidth
                            
                            	Bandwidth allocated in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: allocated_threshold_bandwidth
                            
                            	Configured threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_bandwidth
                            
                            	Bandwidth available in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_threshold_bandwidth
                            
                            	Available threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: bundle_name
                            
                            	Bundle name
                            	**type**\:  str
                            
                            	**length:** 1..32
                            
                            .. attribute:: interface_name
                            
                            	Bundle interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: rpf_redirect_bundle_name
                            
                            	RPF redirect bundle name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: rpf_redirect_interface_name
                            
                            	RPF redirect interface name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: snooping_bandwidth_used
                            
                            	Bandwidth used by snooped entries in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: topology_bandwidth_used
                            
                            	Bandwidth used by topology in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: total_bandwidth
                            
                            	Total bandwidth used in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.allocated_bandwidth = None
                                self.allocated_threshold_bandwidth = None
                                self.available_bandwidth = None
                                self.available_threshold_bandwidth = None
                                self.bundle_name = None
                                self.interface_name = None
                                self.rpf_redirect_bundle_name = None
                                self.rpf_redirect_interface_name = None
                                self.snooping_bandwidth_used = None
                                self.topology_bandwidth_used = None
                                self.total_bandwidth = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bundle-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.allocated_bandwidth is not None:
                                    return True

                                if self.allocated_threshold_bandwidth is not None:
                                    return True

                                if self.available_bandwidth is not None:
                                    return True

                                if self.available_threshold_bandwidth is not None:
                                    return True

                                if self.bundle_name is not None:
                                    return True

                                if self.interface_name is not None:
                                    return True

                                if self.rpf_redirect_bundle_name is not None:
                                    return True

                                if self.rpf_redirect_interface_name is not None:
                                    return True

                                if self.snooping_bandwidth_used is not None:
                                    return True

                                if self.topology_bandwidth_used is not None:
                                    return True

                                if self.total_bandwidth is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bundle-interfaces'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bundle_interface is not None:
                                for child_ref in self.bundle_interface:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bundle_interfaces is not None and self.bundle_interfaces._has_data():
                            return True

                        if self.redirect_route_databases is not None and self.redirect_route_databases._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.RpfRedirect']['meta_info']


                class Tunnels(object):
                    """
                    Tunnels information that PIM has
                    
                    .. attribute:: tunnel
                    
                    	PIM tunnel information
                    	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.tunnel = YList()
                        self.tunnel.parent = self
                        self.tunnel.name = 'tunnel'


                    class Tunnel(object):
                        """
                        PIM tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.tunnel_name = None
                            self.group_address_netio = Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self.rp_address = Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress()
                            self.rp_address.parent = self
                            self.source_address = Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress()
                            self.source_address.parent = self
                            self.source_address_netio = Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self.vrf_name = None


                        class SourceAddress(object):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress']['meta_info']


                        class RpAddress(object):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress']['meta_info']


                        class SourceAddressNetio(object):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-netio'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio']['meta_info']


                        class GroupAddressNetio(object):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-netio'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.tunnel_name is None:
                                raise YPYModelError('Key property tunnel_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:tunnel[Cisco-IOS-XR-ipv4-pim-oper:tunnel-name = ' + str(self.tunnel_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.tunnel_name is not None:
                                return True

                            if self.group_address_netio is not None and self.group_address_netio._has_data():
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            if self.source_address is not None and self.source_address._has_data():
                                return True

                            if self.source_address_netio is not None and self.source_address_netio._has_data():
                                return True

                            if self.vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:tunnels'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.tunnel is not None:
                            for child_ref in self.tunnel:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.Tunnels']['meta_info']


                class MulticastStaticRoutes(object):
                    """
                    PIM multicast static route table
                    
                    .. attribute:: multicast_static_route
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.multicast_static_route = YList()
                        self.multicast_static_route.parent = self
                        self.multicast_static_route.name = 'multicast_static_route'


                    class MulticastStaticRoute(object):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: address
                        
                        	Network address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: distance
                        
                        	Distance
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_via_lsm
                        
                        	LSM flag
                        	**type**\:  bool
                        
                        .. attribute:: nexthop
                        
                        	Next Hop
                        	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: prefix_length_xr
                        
                        	Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.address = None
                            self.distance = None
                            self.interface_name = None
                            self.is_via_lsm = None
                            self.nexthop = Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                            self.nexthop.parent = self
                            self.prefix = Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.prefix_length_xr = None


                        class Prefix(object):
                            """
                            Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix']['meta_info']


                        class Nexthop(object):
                            """
                            Next Hop
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:nexthop'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-route'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.address is not None:
                                return True

                            if self.distance is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.is_via_lsm is not None:
                                return True

                            if self.nexthop is not None and self.nexthop._has_data():
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.prefix_length_xr is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-routes'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.multicast_static_route is not None:
                            for child_ref in self.multicast_static_route:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes']['meta_info']


                class GroupMapMatchSources(object):
                    """
                    Find the matching group\-mapping with source
                    information on specified group address
                    
                    .. attribute:: group_map_match_source
                    
                    	PIM group\-matching mapping entry with source information
                    	**type**\: list of    :py:class:`GroupMapMatchSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_map_match_source = YList()
                        self.group_map_match_source.parent = self
                        self.group_map_match_source.name = 'group_map_match_source'


                    class GroupMapMatchSource(object):
                        """
                        PIM group\-matching mapping entry with source
                        information
                        
                        .. attribute:: group_address  <key>
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.group_address = None
                            self.expires = None
                            self.group_map_information = Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self.holdtime = None
                            self.source_of_information = Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self.uptime = None


                        class SourceOfInformation(object):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation']['meta_info']


                        class GroupMapInformation(object):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.client = None
                                self.group_count = None
                                self.is_override = None
                                self.is_used = None
                                self.mrib_active = None
                                self.prefix = Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self.prefix_length = None
                                self.priority = None
                                self.protocol = None
                                self.rp_address = Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self


                            class Prefix(object):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix']['meta_info']


                            class RpAddress(object):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.client is not None:
                                    return True

                                if self.group_count is not None:
                                    return True

                                if self.is_override is not None:
                                    return True

                                if self.is_used is not None:
                                    return True

                                if self.mrib_active is not None:
                                    return True

                                if self.prefix is not None and self.prefix._has_data():
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.priority is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.rp_address is not None and self.rp_address._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.group_address is None:
                                raise YPYModelError('Key property group_address is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-source[Cisco-IOS-XR-ipv4-pim-oper:group-address = ' + str(self.group_address) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.group_address is not None:
                                return True

                            if self.expires is not None:
                                return True

                            if self.group_map_information is not None and self.group_map_information._has_data():
                                return True

                            if self.holdtime is not None:
                                return True

                            if self.source_of_information is not None and self.source_of_information._has_data():
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-sources'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_map_match_source is not None:
                            for child_ref in self.group_map_match_source:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.GroupMapMatchSources']['meta_info']


                class Neighbors(object):
                    """
                    PIM neighbor table
                    
                    .. attribute:: neighbor
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.neighbor = YList()
                        self.neighbor.parent = self
                        self.neighbor.name = 'neighbor'


                    class Neighbor(object):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dr_priority = None
                            self.expires = None
                            self.expiry_timer = None
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.is_batch_asserts_capable = None
                            self.is_bfd_state = None
                            self.is_bidirectional_capable = None
                            self.is_dr_priority_capable = None
                            self.is_ecmp_redirect_capable = None
                            self.is_proxy_capable = None
                            self.is_this_neighbor_dr = None
                            self.is_this_neighbor_us = None
                            self.neighbor_address = None
                            self.neighbor_address_xr = YList()
                            self.neighbor_address_xr.parent = self
                            self.neighbor_address_xr.name = 'neighbor_address_xr'
                            self.override_interval = None
                            self.propagation_delay = None
                            self.uptime = None


                        class NeighborAddressXr(object):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dr_priority is not None:
                                return True

                            if self.expires is not None:
                                return True

                            if self.expiry_timer is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.is_batch_asserts_capable is not None:
                                return True

                            if self.is_bfd_state is not None:
                                return True

                            if self.is_bidirectional_capable is not None:
                                return True

                            if self.is_dr_priority_capable is not None:
                                return True

                            if self.is_ecmp_redirect_capable is not None:
                                return True

                            if self.is_proxy_capable is not None:
                                return True

                            if self.is_this_neighbor_dr is not None:
                                return True

                            if self.is_this_neighbor_us is not None:
                                return True

                            if self.neighbor_address is not None:
                                return True

                            if self.neighbor_address_xr is not None:
                                for child_ref in self.neighbor_address_xr:
                                    if child_ref._has_data():
                                        return True

                            if self.override_interval is not None:
                                return True

                            if self.propagation_delay is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbors'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.neighbor is not None:
                            for child_ref in self.neighbor:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Standby.Vrfs.Vrf.Neighbors']['meta_info']

                @property
                def _common_path(self):
                    if self.vrf_name is None:
                        raise YPYModelError('Key property vrf_name is None')

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:vrfs/Cisco-IOS-XR-ipv4-pim-oper:vrf[Cisco-IOS-XR-ipv4-pim-oper:vrf-name = ' + str(self.vrf_name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.vrf_name is not None:
                        return True

                    if self.auto_rp is not None and self.auto_rp._has_data():
                        return True

                    if self.bgp_afs is not None and self.bgp_afs._has_data():
                        return True

                    if self.bidir_df_states is not None and self.bidir_df_states._has_data():
                        return True

                    if self.bidir_df_winners is not None and self.bidir_df_winners._has_data():
                        return True

                    if self.bsr is not None and self.bsr._has_data():
                        return True

                    if self.context is not None and self.context._has_data():
                        return True

                    if self.gre is not None and self.gre._has_data():
                        return True

                    if self.group_map_match_rpfs is not None and self.group_map_match_rpfs._has_data():
                        return True

                    if self.group_map_match_sources is not None and self.group_map_match_sources._has_data():
                        return True

                    if self.group_map_rpfs is not None and self.group_map_rpfs._has_data():
                        return True

                    if self.group_map_sources is not None and self.group_map_sources._has_data():
                        return True

                    if self.ifrs_interfaces is not None and self.ifrs_interfaces._has_data():
                        return True

                    if self.ifrs_summary is not None and self.ifrs_summary._has_data():
                        return True

                    if self.interface_old_formats is not None and self.interface_old_formats._has_data():
                        return True

                    if self.interface_statistics is not None and self.interface_statistics._has_data():
                        return True

                    if self.interfaces is not None and self.interfaces._has_data():
                        return True

                    if self.jp_statistics is not None and self.jp_statistics._has_data():
                        return True

                    if self.mib_databases is not None and self.mib_databases._has_data():
                        return True

                    if self.multicast_static_routes is not None and self.multicast_static_routes._has_data():
                        return True

                    if self.neighbor_old_formats is not None and self.neighbor_old_formats._has_data():
                        return True

                    if self.neighbor_summaries is not None and self.neighbor_summaries._has_data():
                        return True

                    if self.neighbors is not None and self.neighbors._has_data():
                        return True

                    if self.net_io_tunnels is not None and self.net_io_tunnels._has_data():
                        return True

                    if self.ranges is not None and self.ranges._has_data():
                        return True

                    if self.route_policy is not None and self.route_policy._has_data():
                        return True

                    if self.rpf_redirect is not None and self.rpf_redirect._has_data():
                        return True

                    if self.rpf_summary is not None and self.rpf_summary._has_data():
                        return True

                    if self.safs is not None and self.safs._has_data():
                        return True

                    if self.summary is not None and self.summary._has_data():
                        return True

                    if self.table_contexts is not None and self.table_contexts._has_data():
                        return True

                    if self.topologies is not None and self.topologies._has_data():
                        return True

                    if self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts._has_data():
                        return True

                    if self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts._has_data():
                        return True

                    if self.topology_route_count is not None and self.topology_route_count._has_data():
                        return True

                    if self.traffic_counters is not None and self.traffic_counters._has_data():
                        return True

                    if self.tunnels is not None and self.tunnels._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Standby.Vrfs.Vrf']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:vrfs'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.vrf is not None:
                    for child_ref in self.vrf:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                return meta._meta_table['Pim.Standby.Vrfs']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:standby'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.default_context is not None and self.default_context._has_data():
                return True

            if self.process is not None and self.process._has_data():
                return True

            if self.vrfs is not None and self.vrfs._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
            return meta._meta_table['Pim.Standby']['meta_info']


    class Active(object):
        """
        Active Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:   :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:   :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.default_context = Pim.Active.DefaultContext()
            self.default_context.parent = self
            self.process = Pim.Active.Process()
            self.process.parent = self
            self.vrfs = Pim.Active.Vrfs()
            self.vrfs.parent = self


        class DefaultContext(object):
            """
            Default Context
            
            .. attribute:: auto_rp
            
            	PIM Auto\-RP information
            	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.AutoRp>`
            
            .. attribute:: bgp_afs
            
            	PIM BGP SAFI table
            	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BgpAfs>`
            
            .. attribute:: bidir_df_states
            
            	Bidirectional PIM DF election state table
            	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfStates>`
            
            .. attribute:: bidir_df_winners
            
            	Bidirectional PIM DF election winner table
            	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfWinners>`
            
            .. attribute:: bsr
            
            	PIM BSR information
            	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr>`
            
            .. attribute:: context
            
            	PIM context information
            	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context>`
            
            .. attribute:: global_interfaces
            
            	PIM global interface table
            	**type**\:   :py:class:`GlobalInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GlobalInterfaces>`
            
            .. attribute:: gre
            
            	GRE information
            	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre>`
            
            .. attribute:: group_map_match_rpfs
            
            	Find matching group\-mapping for the specified group address
            	**type**\:   :py:class:`GroupMapMatchRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchRpfs>`
            
            .. attribute:: group_map_match_sources
            
            	Find the matching group\-mapping with source information on specified group address
            	**type**\:   :py:class:`GroupMapMatchSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchSources>`
            
            .. attribute:: group_map_rpfs
            
            	PIM group mapping information
            	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs>`
            
            .. attribute:: group_map_sources
            
            	PIM group\-mapping with source information
            	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources>`
            
            .. attribute:: ifrs_interfaces
            
            	PIM interfaces in forward reference store table
            	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: ifrs_summary
            
            	PIM interfaces in forward reference store summary
            	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.IfrsSummary>`
            
            .. attribute:: interface_old_formats
            
            	PIM interfaces in old format
            	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceOldFormats>`
            
            .. attribute:: interface_statistics
            
            	PIM interface statistics
            	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceStatistics>`
            
            .. attribute:: interfaces
            
            	PIM interfaces
            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Interfaces>`
            
            .. attribute:: jp_statistics
            
            	PIM join prune statistics table
            	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.JpStatistics>`
            
            .. attribute:: mib_databases
            
            	PIM group database for mroute mibs table
            	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases>`
            
            .. attribute:: multicast_static_routes
            
            	PIM multicast static route table
            	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MulticastStaticRoutes>`
            
            .. attribute:: neighbor_old_formats
            
            	PIM neighbor table old format
            	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NeighborOldFormats>`
            
            .. attribute:: neighbor_summaries
            
            	PIM neighbor summary table
            	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NeighborSummaries>`
            
            .. attribute:: neighbors
            
            	PIM neighbor table
            	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Neighbors>`
            
            .. attribute:: net_io_tunnels
            
            	Tunnel information that NETIO has 
            	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels>`
            
            .. attribute:: ranges
            
            	PIM range list information
            	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges>`
            
            .. attribute:: route_policy
            
            	PIM route policy
            	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy>`
            
            .. attribute:: rpf_redirect
            
            	PIM ECMP RPF\-redirect bundle
            	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect>`
            
            .. attribute:: rpf_summary
            
            	PIM RPF registration summary
            	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfSummary>`
            
            .. attribute:: safs
            
            	SAFI table and type
            	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs>`
            
            .. attribute:: summary
            
            	PIM summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Summary>`
            
            .. attribute:: table_contexts
            
            	PIM table context list
            	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TableContexts>`
            
            .. attribute:: topologies
            
            	PIM topology table
            	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies>`
            
            .. attribute:: topology_entry_flag_route_counts
            
            	Route count for topology with entry flag set
            	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts>`
            
            .. attribute:: topology_interface_flag_route_counts
            
            	Route count for topology with interface flag set
            	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts>`
            
            .. attribute:: topology_route_count
            
            	Topology route count information from PIM topology table
            	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyRouteCount>`
            
            .. attribute:: traffic_counters
            
            	PIM message traffic counters
            	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TrafficCounters>`
            
            .. attribute:: tunnels
            
            	Tunnels information that PIM has
            	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.auto_rp = Pim.Active.DefaultContext.AutoRp()
                self.auto_rp.parent = self
                self.bgp_afs = Pim.Active.DefaultContext.BgpAfs()
                self.bgp_afs.parent = self
                self.bidir_df_states = Pim.Active.DefaultContext.BidirDfStates()
                self.bidir_df_states.parent = self
                self.bidir_df_winners = Pim.Active.DefaultContext.BidirDfWinners()
                self.bidir_df_winners.parent = self
                self.bsr = Pim.Active.DefaultContext.Bsr()
                self.bsr.parent = self
                self.context = Pim.Active.DefaultContext.Context()
                self.context.parent = self
                self.global_interfaces = Pim.Active.DefaultContext.GlobalInterfaces()
                self.global_interfaces.parent = self
                self.gre = Pim.Active.DefaultContext.Gre()
                self.gre.parent = self
                self.group_map_match_rpfs = Pim.Active.DefaultContext.GroupMapMatchRpfs()
                self.group_map_match_rpfs.parent = self
                self.group_map_match_sources = Pim.Active.DefaultContext.GroupMapMatchSources()
                self.group_map_match_sources.parent = self
                self.group_map_rpfs = Pim.Active.DefaultContext.GroupMapRpfs()
                self.group_map_rpfs.parent = self
                self.group_map_sources = Pim.Active.DefaultContext.GroupMapSources()
                self.group_map_sources.parent = self
                self.ifrs_interfaces = Pim.Active.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self.ifrs_summary = Pim.Active.DefaultContext.IfrsSummary()
                self.ifrs_summary.parent = self
                self.interface_old_formats = Pim.Active.DefaultContext.InterfaceOldFormats()
                self.interface_old_formats.parent = self
                self.interface_statistics = Pim.Active.DefaultContext.InterfaceStatistics()
                self.interface_statistics.parent = self
                self.interfaces = Pim.Active.DefaultContext.Interfaces()
                self.interfaces.parent = self
                self.jp_statistics = Pim.Active.DefaultContext.JpStatistics()
                self.jp_statistics.parent = self
                self.mib_databases = Pim.Active.DefaultContext.MibDatabases()
                self.mib_databases.parent = self
                self.multicast_static_routes = Pim.Active.DefaultContext.MulticastStaticRoutes()
                self.multicast_static_routes.parent = self
                self.neighbor_old_formats = Pim.Active.DefaultContext.NeighborOldFormats()
                self.neighbor_old_formats.parent = self
                self.neighbor_summaries = Pim.Active.DefaultContext.NeighborSummaries()
                self.neighbor_summaries.parent = self
                self.neighbors = Pim.Active.DefaultContext.Neighbors()
                self.neighbors.parent = self
                self.net_io_tunnels = Pim.Active.DefaultContext.NetIoTunnels()
                self.net_io_tunnels.parent = self
                self.ranges = Pim.Active.DefaultContext.Ranges()
                self.ranges.parent = self
                self.route_policy = Pim.Active.DefaultContext.RoutePolicy()
                self.route_policy.parent = self
                self.rpf_redirect = Pim.Active.DefaultContext.RpfRedirect()
                self.rpf_redirect.parent = self
                self.rpf_summary = Pim.Active.DefaultContext.RpfSummary()
                self.rpf_summary.parent = self
                self.safs = Pim.Active.DefaultContext.Safs()
                self.safs.parent = self
                self.summary = Pim.Active.DefaultContext.Summary()
                self.summary.parent = self
                self.table_contexts = Pim.Active.DefaultContext.TableContexts()
                self.table_contexts.parent = self
                self.topologies = Pim.Active.DefaultContext.Topologies()
                self.topologies.parent = self
                self.topology_entry_flag_route_counts = Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts()
                self.topology_entry_flag_route_counts.parent = self
                self.topology_interface_flag_route_counts = Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts()
                self.topology_interface_flag_route_counts.parent = self
                self.topology_route_count = Pim.Active.DefaultContext.TopologyRouteCount()
                self.topology_route_count.parent = self
                self.traffic_counters = Pim.Active.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self.tunnels = Pim.Active.DefaultContext.Tunnels()
                self.tunnels.parent = self


            class GlobalInterfaces(object):
                """
                PIM global interface table
                
                .. attribute:: global_interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`GlobalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.global_interface = YList()
                    self.global_interface.parent = self
                    self.global_interface.name = 'global_interface'


                class GlobalInterface(object):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.configured_override_interval = None
                        self.configured_propagation_delay = None
                        self.dr_address = Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress()
                        self.dr_address.parent = self
                        self.dr_priority = None
                        self.external_neighbor_count = None
                        self.generation_id = None
                        self.hello_expiry = None
                        self.hello_interval = None
                        self.idb_acl_name = None
                        self.idb_acl_provided = None
                        self.idb_current_count = None
                        self.idb_max_count = None
                        self.idb_oor_enabled = None
                        self.idb_threshold_count = None
                        self.interface_address = YList()
                        self.interface_address.parent = self
                        self.interface_address.name = 'interface_address'
                        self.interface_address_mask = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bidirectional_capable = None
                        self.is_enabled = None
                        self.is_proxy_capable = None
                        self.join_prune_interval = None
                        self.neighbor_count = None
                        self.neighbor_filter_name = None
                        self.override_interval = None
                        self.passive_interface = None
                        self.propagation_delay = None
                        self.prune_delay_enabled = None
                        self.virtual_interface = None


                    class DrAddress(object):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress']['meta_info']


                    class InterfaceAddress(object):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:global-interfaces/Cisco-IOS-XR-ipv4-pim-oper:global-interface[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.are_we_dr is not None:
                            return True

                        if self.bfd_enabled is not None:
                            return True

                        if self.bfd_interval is not None:
                            return True

                        if self.bfd_multiplier is not None:
                            return True

                        if self.configured_override_interval is not None:
                            return True

                        if self.configured_propagation_delay is not None:
                            return True

                        if self.dr_address is not None and self.dr_address._has_data():
                            return True

                        if self.dr_priority is not None:
                            return True

                        if self.external_neighbor_count is not None:
                            return True

                        if self.generation_id is not None:
                            return True

                        if self.hello_expiry is not None:
                            return True

                        if self.hello_interval is not None:
                            return True

                        if self.idb_acl_name is not None:
                            return True

                        if self.idb_acl_provided is not None:
                            return True

                        if self.idb_current_count is not None:
                            return True

                        if self.idb_max_count is not None:
                            return True

                        if self.idb_oor_enabled is not None:
                            return True

                        if self.idb_threshold_count is not None:
                            return True

                        if self.interface_address is not None:
                            for child_ref in self.interface_address:
                                if child_ref._has_data():
                                    return True

                        if self.interface_address_mask is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_enabled is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.join_prune_interval is not None:
                            return True

                        if self.neighbor_count is not None:
                            return True

                        if self.neighbor_filter_name is not None:
                            return True

                        if self.override_interval is not None:
                            return True

                        if self.passive_interface is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.prune_delay_enabled is not None:
                            return True

                        if self.virtual_interface is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:global-interfaces'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.global_interface is not None:
                        for child_ref in self.global_interface:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.GlobalInterfaces']['meta_info']


            class IfrsInterfaces(object):
                """
                PIM interfaces in forward reference store table
                
                .. attribute:: ifrs_interface
                
                	PIM IFRS interface information
                	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.ifrs_interface = YList()
                    self.ifrs_interface.parent = self
                    self.ifrs_interface.name = 'ifrs_interface'


                class IfrsInterface(object):
                    """
                    PIM IFRS interface information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.configured_override_interval = None
                        self.configured_propagation_delay = None
                        self.dr_address = Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress()
                        self.dr_address.parent = self
                        self.dr_priority = None
                        self.external_neighbor_count = None
                        self.generation_id = None
                        self.hello_expiry = None
                        self.hello_interval = None
                        self.idb_acl_name = None
                        self.idb_acl_provided = None
                        self.idb_current_count = None
                        self.idb_max_count = None
                        self.idb_oor_enabled = None
                        self.idb_threshold_count = None
                        self.interface_address = YList()
                        self.interface_address.parent = self
                        self.interface_address.name = 'interface_address'
                        self.interface_address_mask = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bidirectional_capable = None
                        self.is_enabled = None
                        self.is_proxy_capable = None
                        self.join_prune_interval = None
                        self.neighbor_count = None
                        self.neighbor_filter_name = None
                        self.override_interval = None
                        self.passive_interface = None
                        self.propagation_delay = None
                        self.prune_delay_enabled = None
                        self.virtual_interface = None


                    class DrAddress(object):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress']['meta_info']


                    class InterfaceAddress(object):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ifrs-interfaces/Cisco-IOS-XR-ipv4-pim-oper:ifrs-interface[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.are_we_dr is not None:
                            return True

                        if self.bfd_enabled is not None:
                            return True

                        if self.bfd_interval is not None:
                            return True

                        if self.bfd_multiplier is not None:
                            return True

                        if self.configured_override_interval is not None:
                            return True

                        if self.configured_propagation_delay is not None:
                            return True

                        if self.dr_address is not None and self.dr_address._has_data():
                            return True

                        if self.dr_priority is not None:
                            return True

                        if self.external_neighbor_count is not None:
                            return True

                        if self.generation_id is not None:
                            return True

                        if self.hello_expiry is not None:
                            return True

                        if self.hello_interval is not None:
                            return True

                        if self.idb_acl_name is not None:
                            return True

                        if self.idb_acl_provided is not None:
                            return True

                        if self.idb_current_count is not None:
                            return True

                        if self.idb_max_count is not None:
                            return True

                        if self.idb_oor_enabled is not None:
                            return True

                        if self.idb_threshold_count is not None:
                            return True

                        if self.interface_address is not None:
                            for child_ref in self.interface_address:
                                if child_ref._has_data():
                                    return True

                        if self.interface_address_mask is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_enabled is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.join_prune_interval is not None:
                            return True

                        if self.neighbor_count is not None:
                            return True

                        if self.neighbor_filter_name is not None:
                            return True

                        if self.override_interval is not None:
                            return True

                        if self.passive_interface is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.prune_delay_enabled is not None:
                            return True

                        if self.virtual_interface is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ifrs-interfaces'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.ifrs_interface is not None:
                        for child_ref in self.ifrs_interface:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.IfrsInterfaces']['meta_info']


            class Safs(object):
                """
                SAFI table and type
                
                .. attribute:: saf
                
                	SAF name 
                	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.saf = YList()
                    self.saf.parent = self
                    self.saf.name = 'saf'


                class Saf(object):
                    """
                    SAF name 
                    
                    .. attribute:: rpf_hash_source_groups
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups>`
                    
                    .. attribute:: rpf_hash_sources
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSources>`
                    
                    .. attribute:: rpfs
                    
                    	PIM RPF information table
                    	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs>`
                    
                    .. attribute:: saf_name
                    
                    	SAF name 
                    	**type**\:   :py:class:`PimSafiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafiEnum>`
                    
                    .. attribute:: topology_name
                    
                    	Topology name 
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.rpf_hash_source_groups = Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups()
                        self.rpf_hash_source_groups.parent = self
                        self.rpf_hash_sources = Pim.Active.DefaultContext.Safs.Saf.RpfHashSources()
                        self.rpf_hash_sources.parent = self
                        self.rpfs = Pim.Active.DefaultContext.Safs.Saf.Rpfs()
                        self.rpfs.parent = self
                        self.saf_name = None
                        self.topology_name = None


                    class RpfHashSourceGroups(object):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source_group
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rpf_hash_source_group = YList()
                            self.rpf_hash_source_group.parent = self
                            self.rpf_hash_source_group.name = 'rpf_hash_source_group'


                        class RpfHashSourceGroup(object):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: mask_length
                            
                            	Hash mask length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.group_address = None
                                self.mask_length = None
                                self.mofrr = None
                                self.next_hop_address = Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                self.next_hop_address.parent = self
                                self.next_hop_interface = None
                                self.next_hop_multipath_enabled = None
                                self.secondary_next_hop_address = Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self.secondary_next_hop_interface = None
                                self.source_address = None


                            class NextHopAddress(object):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-groups/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-group/Cisco-IOS-XR-ipv4-pim-oper:next-hop-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress']['meta_info']


                            class SecondaryNextHopAddress(object):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-groups/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-group/Cisco-IOS-XR-ipv4-pim-oper:secondary-next-hop-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-groups/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-group'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.group_address is not None:
                                    return True

                                if self.mask_length is not None:
                                    return True

                                if self.mofrr is not None:
                                    return True

                                if self.next_hop_address is not None and self.next_hop_address._has_data():
                                    return True

                                if self.next_hop_interface is not None:
                                    return True

                                if self.next_hop_multipath_enabled is not None:
                                    return True

                                if self.secondary_next_hop_address is not None and self.secondary_next_hop_address._has_data():
                                    return True

                                if self.secondary_next_hop_interface is not None:
                                    return True

                                if self.source_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-groups'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rpf_hash_source_group is not None:
                                for child_ref in self.rpf_hash_source_group:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups']['meta_info']


                    class RpfHashSources(object):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rpf_hash_source = YList()
                            self.rpf_hash_source.parent = self
                            self.rpf_hash_source.name = 'rpf_hash_source'


                        class RpfHashSource(object):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mofrr = None
                                self.next_hop_address = Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                self.next_hop_address.parent = self
                                self.next_hop_interface = None
                                self.next_hop_multipath_enabled = None
                                self.secondary_next_hop_address = Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self.secondary_next_hop_interface = None
                                self.source_address = None


                            class NextHopAddress(object):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-sources/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source/Cisco-IOS-XR-ipv4-pim-oper:next-hop-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress']['meta_info']


                            class SecondaryNextHopAddress(object):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-sources/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source/Cisco-IOS-XR-ipv4-pim-oper:secondary-next-hop-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-sources/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mofrr is not None:
                                    return True

                                if self.next_hop_address is not None and self.next_hop_address._has_data():
                                    return True

                                if self.next_hop_interface is not None:
                                    return True

                                if self.next_hop_multipath_enabled is not None:
                                    return True

                                if self.secondary_next_hop_address is not None and self.secondary_next_hop_address._has_data():
                                    return True

                                if self.secondary_next_hop_interface is not None:
                                    return True

                                if self.source_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-sources'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rpf_hash_source is not None:
                                for child_ref in self.rpf_hash_source:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Safs.Saf.RpfHashSources']['meta_info']


                    class Rpfs(object):
                        """
                        PIM RPF information table
                        
                        .. attribute:: rpf
                        
                        	PIM RPF information
                        	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rpf = YList()
                            self.rpf.parent = self
                            self.rpf.name = 'rpf'


                        class Rpf(object):
                            """
                            PIM RPF information
                            
                            .. attribute:: registered_address  <key>
                            
                            	Address for which RPF lookup
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: is_rpf_bgp_route
                            
                            	Is RPF through BGP route
                            	**type**\:  bool
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address_xr
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                            
                            .. attribute:: rpf_path
                            
                            	RPF Paths list
                            	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.registered_address = None
                                self.is_connected = None
                                self.is_rpf_bgp_route = None
                                self.metric = None
                                self.metric_preference = None
                                self.registered_address_xr = Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                self.registered_address_xr.parent = self
                                self.rpf_path = YList()
                                self.rpf_path.parent = self
                                self.rpf_path.name = 'rpf_path'


                            class RegisteredAddressXr(object):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:registered-address-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr']['meta_info']


                            class RpfPath(object):
                                """
                                RPF Paths list
                                
                                .. attribute:: connector
                                
                                	Connector Attribute
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface_disabled
                                
                                	Is the rpf interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                .. attribute:: is_via_mlsm
                                
                                	Via Mstatic LSM
                                	**type**\:  bool
                                
                                .. attribute:: rpf_interface_name
                                
                                	RPF Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: rpf_neighbor
                                
                                	RPF neighbor
                                	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                
                                .. attribute:: rpf_nexthop
                                
                                	RPF nexthop
                                	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.connector = None
                                    self.extranet_vrf_name = None
                                    self.is_connector_attribute_present = None
                                    self.is_rpf_interface_disabled = None
                                    self.is_via_lsm = None
                                    self.is_via_mlsm = None
                                    self.rpf_interface_name = None
                                    self.rpf_neighbor = Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self.rpf_nexthop = Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                    self.rpf_nexthop.parent = self


                                class RpfNeighbor(object):
                                    """
                                    RPF neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor']['meta_info']


                                class RpfNexthop(object):
                                    """
                                    RPF nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-nexthop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.connector is not None:
                                        return True

                                    if self.extranet_vrf_name is not None:
                                        return True

                                    if self.is_connector_attribute_present is not None:
                                        return True

                                    if self.is_rpf_interface_disabled is not None:
                                        return True

                                    if self.is_via_lsm is not None:
                                        return True

                                    if self.is_via_mlsm is not None:
                                        return True

                                    if self.rpf_interface_name is not None:
                                        return True

                                    if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                        return True

                                    if self.rpf_nexthop is not None and self.rpf_nexthop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath']['meta_info']

                            @property
                            def _common_path(self):
                                if self.registered_address is None:
                                    raise YPYModelError('Key property registered_address is None')

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpfs/Cisco-IOS-XR-ipv4-pim-oper:rpf[Cisco-IOS-XR-ipv4-pim-oper:registered-address = ' + str(self.registered_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.registered_address is not None:
                                    return True

                                if self.is_connected is not None:
                                    return True

                                if self.is_rpf_bgp_route is not None:
                                    return True

                                if self.metric is not None:
                                    return True

                                if self.metric_preference is not None:
                                    return True

                                if self.registered_address_xr is not None and self.registered_address_xr._has_data():
                                    return True

                                if self.rpf_path is not None:
                                    for child_ref in self.rpf_path:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpfs'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rpf is not None:
                                for child_ref in self.rpf:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Safs.Saf.Rpfs']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups._has_data():
                            return True

                        if self.rpf_hash_sources is not None and self.rpf_hash_sources._has_data():
                            return True

                        if self.rpfs is not None and self.rpfs._has_data():
                            return True

                        if self.saf_name is not None:
                            return True

                        if self.topology_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.Safs.Saf']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.saf is not None:
                        for child_ref in self.saf:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.Safs']['meta_info']


            class InterfaceStatistics(object):
                """
                PIM interface statistics
                
                .. attribute:: interface_statistic
                
                	PIM interface statistics
                	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_statistic = YList()
                    self.interface_statistic.parent = self
                    self.interface_statistic.name = 'interface_statistic'


                class InterfaceStatistic(object):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_ack_message
                    
                    	Input Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_message
                    
                    	Input Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_miscellaneous
                    
                    	Miscellaneous packet in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register
                    
                    	Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_ack_message
                    
                    	Output Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_message
                    
                    	Output Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register
                    
                    	Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.input_assert = None
                        self.input_bsr_message = None
                        self.input_candidate_rp_advertisement = None
                        self.input_df_election = None
                        self.input_graft_ack_message = None
                        self.input_graft_message = None
                        self.input_hello = None
                        self.input_jp = None
                        self.input_miscellaneous = None
                        self.input_register = None
                        self.input_register_stop = None
                        self.output_assert = None
                        self.output_bsr_message = None
                        self.output_candidate_rp_advertisement = None
                        self.output_df_election = None
                        self.output_graft_ack_message = None
                        self.output_graft_message = None
                        self.output_hello = None
                        self.output_jp = None
                        self.output_register = None
                        self.output_register_stop = None

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interface-statistics/Cisco-IOS-XR-ipv4-pim-oper:interface-statistic[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.input_assert is not None:
                            return True

                        if self.input_bsr_message is not None:
                            return True

                        if self.input_candidate_rp_advertisement is not None:
                            return True

                        if self.input_df_election is not None:
                            return True

                        if self.input_graft_ack_message is not None:
                            return True

                        if self.input_graft_message is not None:
                            return True

                        if self.input_hello is not None:
                            return True

                        if self.input_jp is not None:
                            return True

                        if self.input_miscellaneous is not None:
                            return True

                        if self.input_register is not None:
                            return True

                        if self.input_register_stop is not None:
                            return True

                        if self.output_assert is not None:
                            return True

                        if self.output_bsr_message is not None:
                            return True

                        if self.output_candidate_rp_advertisement is not None:
                            return True

                        if self.output_df_election is not None:
                            return True

                        if self.output_graft_ack_message is not None:
                            return True

                        if self.output_graft_message is not None:
                            return True

                        if self.output_hello is not None:
                            return True

                        if self.output_jp is not None:
                            return True

                        if self.output_register is not None:
                            return True

                        if self.output_register_stop is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interface-statistics'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_statistic is not None:
                        for child_ref in self.interface_statistic:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.InterfaceStatistics']['meta_info']


            class TopologyRouteCount(object):
                """
                Topology route count information from PIM
                topology table
                
                .. attribute:: active_group_ranges
                
                	No. of (\*,G/M) routes active in mrib
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_address
                
                	Group Address
                	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyRouteCount.GroupAddress>`
                
                .. attribute:: group_ranges
                
                	No. of (\*,G/M) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groute_count
                
                	No. of (\*,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: sg_route_count
                
                	No. of (S,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sgr_route_count
                
                	No. of (S,G)RPT routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.active_group_ranges = None
                    self.group_address = Pim.Active.DefaultContext.TopologyRouteCount.GroupAddress()
                    self.group_address.parent = self
                    self.group_ranges = None
                    self.groute_count = None
                    self.is_node_low_memory = None
                    self.sg_route_count = None
                    self.sgr_route_count = None


                class GroupAddress(object):
                    """
                    Group Address
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.af_name = None
                        self.ipv4_address = None
                        self.ipv6_address = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-route-count/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.af_name is not None:
                            return True

                        if self.ipv4_address is not None:
                            return True

                        if self.ipv6_address is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.TopologyRouteCount.GroupAddress']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-route-count'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.active_group_ranges is not None:
                        return True

                    if self.group_address is not None and self.group_address._has_data():
                        return True

                    if self.group_ranges is not None:
                        return True

                    if self.groute_count is not None:
                        return True

                    if self.is_node_low_memory is not None:
                        return True

                    if self.sg_route_count is not None:
                        return True

                    if self.sgr_route_count is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.TopologyRouteCount']['meta_info']


            class JpStatistics(object):
                """
                PIM join prune statistics table
                
                .. attribute:: jp_statistic
                
                	PIM Join Prune Statistics
                	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.JpStatistics.JpStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.jp_statistic = YList()
                    self.jp_statistic.parent = self
                    self.jp_statistic.name = 'jp_statistic'


                class JpStatistic(object):
                    """
                    PIM Join Prune Statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mtu
                    
                    	Interface MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received
                    
                    	Received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received100
                    
                    	Received 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_10k
                    
                    	Received 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_1k
                    
                    	Received 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_50k
                    
                    	Deprecated by Received100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted
                    
                    	Transmitted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: transmitted100
                    
                    	Transmitted 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_10k
                    
                    	Transmitted 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_1k
                    
                    	Transmitted 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_50k
                    
                    	Deprecated by Transmitted100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.mtu = None
                        self.received = None
                        self.received100 = None
                        self.received_10k = None
                        self.received_1k = None
                        self.received_50k = None
                        self.transmitted = None
                        self.transmitted100 = None
                        self.transmitted_10k = None
                        self.transmitted_1k = None
                        self.transmitted_50k = None

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:jp-statistics/Cisco-IOS-XR-ipv4-pim-oper:jp-statistic[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.mtu is not None:
                            return True

                        if self.received is not None:
                            return True

                        if self.received100 is not None:
                            return True

                        if self.received_10k is not None:
                            return True

                        if self.received_1k is not None:
                            return True

                        if self.received_50k is not None:
                            return True

                        if self.transmitted is not None:
                            return True

                        if self.transmitted100 is not None:
                            return True

                        if self.transmitted_10k is not None:
                            return True

                        if self.transmitted_1k is not None:
                            return True

                        if self.transmitted_50k is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.JpStatistics.JpStatistic']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:jp-statistics'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.jp_statistic is not None:
                        for child_ref in self.jp_statistic:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.JpStatistics']['meta_info']


            class MibDatabases(object):
                """
                PIM group database for mroute mibs table
                
                .. attribute:: mib_database
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases.MibDatabase>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.mib_database = YList()
                    self.mib_database.parent = self
                    self.mib_database.name = 'mib_database'


                class MibDatabase(object):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: assert_metric
                    
                    	Assert Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_metric_preference
                    
                    	Assert Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_rpt_bit
                    
                    	Assert RPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: bidirectional_route
                    
                    	Is this Bidir ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Multicast satic route group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr>`
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface name 
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_mask
                    
                    	Mask of the multicast root
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_neighbor
                    
                    	The RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor>`
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: source_address
                    
                    	Multicast static route source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr>`
                    
                    .. attribute:: source_netmask
                    
                    	Source mask
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: spt_bit
                    
                    	Is SPT bit set ?
                    	**type**\:  bool
                    
                    .. attribute:: upstream_assert_timer
                    
                    	Upstream Assert Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime of route
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.assert_metric = None
                        self.assert_metric_preference = None
                        self.assert_rpt_bit = None
                        self.bidirectional_route = None
                        self.group_address = None
                        self.group_address_xr = Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self.protocol = None
                        self.rpf_drop = None
                        self.rpf_extranet = None
                        self.rpf_interface_name = None
                        self.rpf_mask = None
                        self.rpf_neighbor = Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self.rpf_root = Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot()
                        self.rpf_root.parent = self
                        self.rpf_safi = None
                        self.rpf_table_name = None
                        self.rpf_vrf_name = None
                        self.source_address = None
                        self.source_address_xr = Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self.source_netmask = None
                        self.spt_bit = None
                        self.upstream_assert_timer = None
                        self.uptime = None


                    class SourceAddressXr(object):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases/Cisco-IOS-XR-ipv4-pim-oper:mib-database/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr']['meta_info']


                    class GroupAddressXr(object):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases/Cisco-IOS-XR-ipv4-pim-oper:mib-database/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr']['meta_info']


                    class RpfNeighbor(object):
                        """
                        The RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases/Cisco-IOS-XR-ipv4-pim-oper:mib-database/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor']['meta_info']


                    class RpfRoot(object):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases/Cisco-IOS-XR-ipv4-pim-oper:mib-database/Cisco-IOS-XR-ipv4-pim-oper:rpf-root'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases/Cisco-IOS-XR-ipv4-pim-oper:mib-database'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.assert_metric is not None:
                            return True

                        if self.assert_metric_preference is not None:
                            return True

                        if self.assert_rpt_bit is not None:
                            return True

                        if self.bidirectional_route is not None:
                            return True

                        if self.group_address is not None:
                            return True

                        if self.group_address_xr is not None and self.group_address_xr._has_data():
                            return True

                        if self.protocol is not None:
                            return True

                        if self.rpf_drop is not None:
                            return True

                        if self.rpf_extranet is not None:
                            return True

                        if self.rpf_interface_name is not None:
                            return True

                        if self.rpf_mask is not None:
                            return True

                        if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                            return True

                        if self.rpf_root is not None and self.rpf_root._has_data():
                            return True

                        if self.rpf_safi is not None:
                            return True

                        if self.rpf_table_name is not None:
                            return True

                        if self.rpf_vrf_name is not None:
                            return True

                        if self.source_address is not None:
                            return True

                        if self.source_address_xr is not None and self.source_address_xr._has_data():
                            return True

                        if self.source_netmask is not None:
                            return True

                        if self.spt_bit is not None:
                            return True

                        if self.upstream_assert_timer is not None:
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.MibDatabases.MibDatabase']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.mib_database is not None:
                        for child_ref in self.mib_database:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.MibDatabases']['meta_info']


            class GroupMapMatchRpfs(object):
                """
                Find matching group\-mapping for the specified
                group address
                
                .. attribute:: group_map_match_rpf
                
                	PIM group matching mapping entry
                	**type**\: list of    :py:class:`GroupMapMatchRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.group_map_match_rpf = YList()
                    self.group_map_match_rpf.parent = self
                    self.group_map_match_rpf.name = 'group_map_match_rpf'


                class GroupMapMatchRpf(object):
                    """
                    PIM group matching mapping entry
                    
                    .. attribute:: group_address  <key>
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\:  bool
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation>`
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor>`
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_address = None
                        self.are_we_rp = None
                        self.group_map_information = Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self.rpf_interface_name = None
                        self.rpf_neighbor = Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self.rpf_vrf_name = None


                    class RpfNeighbor(object):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor']['meta_info']


                    class GroupMapInformation(object):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.group_count = None
                            self.is_override = None
                            self.is_used = None
                            self.mrib_active = None
                            self.prefix = Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.priority = None
                            self.protocol = None
                            self.rp_address = Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self


                        class Prefix(object):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix']['meta_info']


                        class RpAddress(object):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.group_count is not None:
                                return True

                            if self.is_override is not None:
                                return True

                            if self.is_used is not None:
                                return True

                            if self.mrib_active is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation']['meta_info']

                    @property
                    def _common_path(self):
                        if self.group_address is None:
                            raise YPYModelError('Key property group_address is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-rpf[Cisco-IOS-XR-ipv4-pim-oper:group-address = ' + str(self.group_address) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_address is not None:
                            return True

                        if self.are_we_rp is not None:
                            return True

                        if self.group_map_information is not None and self.group_map_information._has_data():
                            return True

                        if self.rpf_interface_name is not None:
                            return True

                        if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                            return True

                        if self.rpf_vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-rpfs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.group_map_match_rpf is not None:
                        for child_ref in self.group_map_match_rpf:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.GroupMapMatchRpfs']['meta_info']


            class NeighborOldFormats(object):
                """
                PIM neighbor table old format
                
                .. attribute:: neighbor_old_format
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.neighbor_old_format = YList()
                    self.neighbor_old_format.parent = self
                    self.neighbor_old_format.name = 'neighbor_old_format'


                class NeighborOldFormat(object):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.dr_priority = None
                        self.expires = None
                        self.expiry_timer = None
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bfd_state = None
                        self.is_bidirectional_capable = None
                        self.is_dr_priority_capable = None
                        self.is_ecmp_redirect_capable = None
                        self.is_proxy_capable = None
                        self.is_this_neighbor_dr = None
                        self.is_this_neighbor_us = None
                        self.neighbor_address = None
                        self.neighbor_address_xr = YList()
                        self.neighbor_address_xr.parent = self
                        self.neighbor_address_xr.name = 'neighbor_address_xr'
                        self.override_interval = None
                        self.propagation_delay = None
                        self.uptime = None


                    class NeighborAddressXr(object):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-formats/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-format/Cisco-IOS-XR-ipv4-pim-oper:neighbor-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-formats/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-format'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.dr_priority is not None:
                            return True

                        if self.expires is not None:
                            return True

                        if self.expiry_timer is not None:
                            return True

                        if self.interface_name is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bfd_state is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_dr_priority_capable is not None:
                            return True

                        if self.is_ecmp_redirect_capable is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.is_this_neighbor_dr is not None:
                            return True

                        if self.is_this_neighbor_us is not None:
                            return True

                        if self.neighbor_address is not None:
                            return True

                        if self.neighbor_address_xr is not None:
                            for child_ref in self.neighbor_address_xr:
                                if child_ref._has_data():
                                    return True

                        if self.override_interval is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-formats'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.neighbor_old_format is not None:
                        for child_ref in self.neighbor_old_format:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.NeighborOldFormats']['meta_info']


            class IfrsSummary(object):
                """
                PIM interfaces in forward reference store
                summary
                
                .. attribute:: configuration_count
                
                	Configuration counts
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_count
                
                	Number of interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.configuration_count = None
                    self.interface_count = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ifrs-summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.configuration_count is not None:
                        return True

                    if self.interface_count is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.IfrsSummary']['meta_info']


            class Ranges(object):
                """
                PIM range list information
                
                .. attribute:: range
                
                	PIM range list information
                	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.range = YList()
                    self.range.parent = self
                    self.range.name = 'range'


                class Range(object):
                    """
                    PIM range list information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                    
                    .. attribute:: client_xr
                    
                    	Client mapping learnt via
                    	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                    
                    .. attribute:: expires
                    
                    	When mapping expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: group_range
                    
                    	List of group ranges
                    	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range.GroupRange>`
                    
                    .. attribute:: protocol
                    
                    	PIM protocol
                    	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	Rendezvous point address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range.RpAddressXr>`
                    
                    .. attribute:: source_of_information
                    
                    	Source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.client = None
                        self.client_xr = None
                        self.expires = None
                        self.group_range = YList()
                        self.group_range.parent = self
                        self.group_range.name = 'group_range'
                        self.protocol = None
                        self.rp_address = None
                        self.rp_address_xr = Pim.Active.DefaultContext.Ranges.Range.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self.source_of_information = Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation()
                        self.source_of_information.parent = self


                    class RpAddressXr(object):
                        """
                        Rendezvous point address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Ranges.Range.RpAddressXr']['meta_info']


                    class SourceOfInformation(object):
                        """
                        Source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation']['meta_info']


                    class GroupRange(object):
                        """
                        List of group ranges
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.expires = None
                            self.prefix = Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.source_of_information = Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation()
                            self.source_of_information.parent = self
                            self.uptime = None


                        class Prefix(object):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range/Cisco-IOS-XR-ipv4-pim-oper:group-range/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix']['meta_info']


                        class SourceOfInformation(object):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range/Cisco-IOS-XR-ipv4-pim-oper:group-range/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range/Cisco-IOS-XR-ipv4-pim-oper:group-range'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.expires is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.source_of_information is not None and self.source_of_information._has_data():
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Ranges.Range.GroupRange']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.client is not None:
                            return True

                        if self.client_xr is not None:
                            return True

                        if self.expires is not None:
                            return True

                        if self.group_range is not None:
                            for child_ref in self.group_range:
                                if child_ref._has_data():
                                    return True

                        if self.protocol is not None:
                            return True

                        if self.rp_address is not None:
                            return True

                        if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                            return True

                        if self.source_of_information is not None and self.source_of_information._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.Ranges.Range']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.range is not None:
                        for child_ref in self.range:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.Ranges']['meta_info']


            class InterfaceOldFormats(object):
                """
                PIM interfaces in old format
                
                .. attribute:: interface_old_format
                
                	PIM interface name
                	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_old_format = YList()
                    self.interface_old_format.parent = self
                    self.interface_old_format.name = 'interface_old_format'


                class InterfaceOldFormat(object):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.configured_override_interval = None
                        self.configured_propagation_delay = None
                        self.dr_address = Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                        self.dr_address.parent = self
                        self.dr_priority = None
                        self.external_neighbor_count = None
                        self.generation_id = None
                        self.hello_expiry = None
                        self.hello_interval = None
                        self.idb_acl_name = None
                        self.idb_acl_provided = None
                        self.idb_current_count = None
                        self.idb_max_count = None
                        self.idb_oor_enabled = None
                        self.idb_threshold_count = None
                        self.interface_address = YList()
                        self.interface_address.parent = self
                        self.interface_address.name = 'interface_address'
                        self.interface_address_mask = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bidirectional_capable = None
                        self.is_enabled = None
                        self.is_proxy_capable = None
                        self.join_prune_interval = None
                        self.neighbor_count = None
                        self.neighbor_filter_name = None
                        self.override_interval = None
                        self.passive_interface = None
                        self.propagation_delay = None
                        self.prune_delay_enabled = None
                        self.virtual_interface = None


                    class DrAddress(object):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress']['meta_info']


                    class InterfaceAddress(object):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interface-old-formats/Cisco-IOS-XR-ipv4-pim-oper:interface-old-format[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.are_we_dr is not None:
                            return True

                        if self.bfd_enabled is not None:
                            return True

                        if self.bfd_interval is not None:
                            return True

                        if self.bfd_multiplier is not None:
                            return True

                        if self.configured_override_interval is not None:
                            return True

                        if self.configured_propagation_delay is not None:
                            return True

                        if self.dr_address is not None and self.dr_address._has_data():
                            return True

                        if self.dr_priority is not None:
                            return True

                        if self.external_neighbor_count is not None:
                            return True

                        if self.generation_id is not None:
                            return True

                        if self.hello_expiry is not None:
                            return True

                        if self.hello_interval is not None:
                            return True

                        if self.idb_acl_name is not None:
                            return True

                        if self.idb_acl_provided is not None:
                            return True

                        if self.idb_current_count is not None:
                            return True

                        if self.idb_max_count is not None:
                            return True

                        if self.idb_oor_enabled is not None:
                            return True

                        if self.idb_threshold_count is not None:
                            return True

                        if self.interface_address is not None:
                            for child_ref in self.interface_address:
                                if child_ref._has_data():
                                    return True

                        if self.interface_address_mask is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_enabled is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.join_prune_interval is not None:
                            return True

                        if self.neighbor_count is not None:
                            return True

                        if self.neighbor_filter_name is not None:
                            return True

                        if self.override_interval is not None:
                            return True

                        if self.passive_interface is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.prune_delay_enabled is not None:
                            return True

                        if self.virtual_interface is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interface-old-formats'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_old_format is not None:
                        for child_ref in self.interface_old_format:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.InterfaceOldFormats']['meta_info']


            class Bsr(object):
                """
                PIM BSR information
                
                .. attribute:: bsr_elections
                
                	PIM BSR election state
                	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.BsrElections>`
                
                .. attribute:: candidate_rps
                
                	PIM candidate\-RP
                	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.CandidateRps>`
                
                .. attribute:: rp_caches
                
                	PIM BSR RP cache table
                	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bsr_elections = Pim.Active.DefaultContext.Bsr.BsrElections()
                    self.bsr_elections.parent = self
                    self.candidate_rps = Pim.Active.DefaultContext.Bsr.CandidateRps()
                    self.candidate_rps.parent = self
                    self.rp_caches = Pim.Active.DefaultContext.Bsr.RpCaches()
                    self.rp_caches.parent = self


                class RpCaches(object):
                    """
                    PIM BSR RP cache table
                    
                    .. attribute:: rp_cache
                    
                    	PIM BSR RP cache
                    	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches.RpCache>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.rp_cache = YList()
                        self.rp_cache.parent = self
                        self.rp_cache.name = 'rp_cache'


                    class RpCache(object):
                        """
                        PIM BSR RP cache
                        
                        .. attribute:: group_prefix  <key>
                        
                        	Group prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: candidate_rp_group_count
                        
                        	C\-RP count for this Prefix
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: candidate_rp_list
                        
                        	C\-RP list for this prefix
                        	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList>`
                        
                        .. attribute:: group_prefix_length
                        
                        	Group Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_prefix_xr
                        
                        	Group Prefix
                        	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.group_prefix = None
                            self.candidate_rp_group_count = None
                            self.candidate_rp_list = Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList()
                            self.candidate_rp_list.parent = self
                            self.group_prefix_length = None
                            self.group_prefix_xr = Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr()
                            self.group_prefix_xr.parent = self


                        class GroupPrefixXr(object):
                            """
                            Group Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-prefix-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr']['meta_info']


                        class CandidateRpList(object):
                            """
                            C\-RP list for this prefix
                            
                            .. attribute:: pim_bsr_crp_bag
                            
                            	pim bsr crp bag
                            	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pim_bsr_crp_bag = YList()
                                self.pim_bsr_crp_bag.parent = self
                                self.pim_bsr_crp_bag.name = 'pim_bsr_crp_bag'


                            class PimBsrCrpBag(object):
                                """
                                pim bsr crp bag
                                
                                .. attribute:: candidate_rp_address
                                
                                	C\-RP address
                                	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                
                                .. attribute:: candidate_rp_expires
                                
                                	C\-RP Expires
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_holdtime
                                
                                	C\-RP Holdtime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_priority
                                
                                	C\-RP Priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: candidate_rp_up_time
                                
                                	C\-RP Uptime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: protocol
                                
                                	PIM Protocol
                                	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.candidate_rp_address = Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                    self.candidate_rp_address.parent = self
                                    self.candidate_rp_expires = None
                                    self.candidate_rp_holdtime = None
                                    self.candidate_rp_priority = None
                                    self.candidate_rp_up_time = None
                                    self.protocol = None


                                class CandidateRpAddress(object):
                                    """
                                    C\-RP address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:pim-bsr-crp-bag'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.candidate_rp_address is not None and self.candidate_rp_address._has_data():
                                        return True

                                    if self.candidate_rp_expires is not None:
                                        return True

                                    if self.candidate_rp_holdtime is not None:
                                        return True

                                    if self.candidate_rp_priority is not None:
                                        return True

                                    if self.candidate_rp_up_time is not None:
                                        return True

                                    if self.protocol is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp-list'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pim_bsr_crp_bag is not None:
                                    for child_ref in self.pim_bsr_crp_bag:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList']['meta_info']

                        @property
                        def _common_path(self):
                            if self.group_prefix is None:
                                raise YPYModelError('Key property group_prefix is None')

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:rp-caches/Cisco-IOS-XR-ipv4-pim-oper:rp-cache[Cisco-IOS-XR-ipv4-pim-oper:group-prefix = ' + str(self.group_prefix) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.group_prefix is not None:
                                return True

                            if self.candidate_rp_group_count is not None:
                                return True

                            if self.candidate_rp_list is not None and self.candidate_rp_list._has_data():
                                return True

                            if self.group_prefix_length is not None:
                                return True

                            if self.group_prefix_xr is not None and self.group_prefix_xr._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Bsr.RpCaches.RpCache']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:rp-caches'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.rp_cache is not None:
                            for child_ref in self.rp_cache:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.Bsr.RpCaches']['meta_info']


                class CandidateRps(object):
                    """
                    PIM candidate\-RP
                    
                    .. attribute:: candidate_rp
                    
                    	PIM BSR candidate RP information
                    	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.candidate_rp = YList()
                        self.candidate_rp.parent = self
                        self.candidate_rp.name = 'candidate_rp'


                    class CandidateRp(object):
                        """
                        PIM BSR candidate RP information
                        
                        .. attribute:: rp_address  <key>
                        
                        	Candidate\-RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: acl_name
                        
                        	Group Access\-List Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: candidate_rp
                        
                        	Cand\-RP Address
                        	**type**\:   :py:class:`CandidateRp_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_>`
                        
                        .. attribute:: candidate_rp_advance_interval
                        
                        	Cand\-RP Adv Interval in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: candidate_rp_mode
                        
                        	Cand\-RP Mode
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: candidate_rp_scope
                        
                        	Cand\-RP Scope
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: candidate_rp_uptime
                        
                        	Cand\-RP uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_access
                        
                        	Group Ranges Using this Cand\-RP
                        	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                        
                        .. attribute:: crp_holdtime
                        
                        	Cand\-RP Holdtime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_priority
                        
                        	Cand\-RP Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rp_address = None
                            self.acl_name = None
                            self.candidate_rp = Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_()
                            self.candidate_rp.parent = self
                            self.candidate_rp_advance_interval = None
                            self.candidate_rp_mode = None
                            self.candidate_rp_scope = None
                            self.candidate_rp_uptime = None
                            self.crp_access = YList()
                            self.crp_access.parent = self
                            self.crp_access.name = 'crp_access'
                            self.crp_holdtime = None
                            self.crp_priority = None


                        class CandidateRp_(object):
                            """
                            Cand\-RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_']['meta_info']


                        class CrpAccess(object):
                            """
                            Group Ranges Using this Cand\-RP
                            
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.acl_name = None
                                self.candidate_rp_mode = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:crp-access'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.acl_name is not None:
                                    return True

                                if self.candidate_rp_mode is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess']['meta_info']

                        @property
                        def _common_path(self):
                            if self.rp_address is None:
                                raise YPYModelError('Key property rp_address is None')

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:candidate-rps/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp[Cisco-IOS-XR-ipv4-pim-oper:rp-address = ' + str(self.rp_address) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rp_address is not None:
                                return True

                            if self.acl_name is not None:
                                return True

                            if self.candidate_rp is not None and self.candidate_rp._has_data():
                                return True

                            if self.candidate_rp_advance_interval is not None:
                                return True

                            if self.candidate_rp_mode is not None:
                                return True

                            if self.candidate_rp_scope is not None:
                                return True

                            if self.candidate_rp_uptime is not None:
                                return True

                            if self.crp_access is not None:
                                for child_ref in self.crp_access:
                                    if child_ref._has_data():
                                        return True

                            if self.crp_holdtime is not None:
                                return True

                            if self.crp_priority is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:candidate-rps'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.candidate_rp is not None:
                            for child_ref in self.candidate_rp:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.Bsr.CandidateRps']['meta_info']


                class BsrElections(object):
                    """
                    PIM BSR election state
                    
                    .. attribute:: bsr_election
                    
                    	PIM BSR information
                    	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bsr_election = YList()
                        self.bsr_election.parent = self
                        self.bsr_election.name = 'bsr_election'


                    class BsrElection(object):
                        """
                        PIM BSR information
                        
                        .. attribute:: pim_scope  <key>
                        
                        	BSR information
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: bootstrap_timeout
                        
                        	Bootstrap Timeout
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_address
                        
                        	BSR address
                        	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress>`
                        
                        .. attribute:: bsr_election_state
                        
                        	BSR Election State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_mask_length
                        
                        	Hash Function Mask Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_priority
                        
                        	BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_scope
                        
                        	BSR Scope
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_up_time
                        
                        	BSR Uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_bsr_address
                        
                        	C\-BSR address
                        	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                        
                        .. attribute:: candidate_bsr_flag
                        
                        	BSR Candidate Config Flag
                        	**type**\:  bool
                        
                        .. attribute:: candidate_bsr_mask_length
                        
                        	C\-BSR Hash Func. Mask Len
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_priority
                        
                        	C\-BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_state
                        
                        	BSR Candidate State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.pim_scope = None
                            self.bootstrap_timeout = None
                            self.bsr_address = Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress()
                            self.bsr_address.parent = self
                            self.bsr_election_state = None
                            self.bsr_mask_length = None
                            self.bsr_priority = None
                            self.bsr_scope = None
                            self.bsr_up_time = None
                            self.candidate_bsr_address = Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                            self.candidate_bsr_address.parent = self
                            self.candidate_bsr_flag = None
                            self.candidate_bsr_mask_length = None
                            self.candidate_bsr_priority = None
                            self.candidate_bsr_state = None


                        class BsrAddress(object):
                            """
                            BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bsr-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress']['meta_info']


                        class CandidateBsrAddress(object):
                            """
                            C\-BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-bsr-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.pim_scope is None:
                                raise YPYModelError('Key property pim_scope is None')

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:bsr-elections/Cisco-IOS-XR-ipv4-pim-oper:bsr-election[Cisco-IOS-XR-ipv4-pim-oper:pim-scope = ' + str(self.pim_scope) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.pim_scope is not None:
                                return True

                            if self.bootstrap_timeout is not None:
                                return True

                            if self.bsr_address is not None and self.bsr_address._has_data():
                                return True

                            if self.bsr_election_state is not None:
                                return True

                            if self.bsr_mask_length is not None:
                                return True

                            if self.bsr_priority is not None:
                                return True

                            if self.bsr_scope is not None:
                                return True

                            if self.bsr_up_time is not None:
                                return True

                            if self.candidate_bsr_address is not None and self.candidate_bsr_address._has_data():
                                return True

                            if self.candidate_bsr_flag is not None:
                                return True

                            if self.candidate_bsr_mask_length is not None:
                                return True

                            if self.candidate_bsr_priority is not None:
                                return True

                            if self.candidate_bsr_state is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:bsr-elections'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bsr_election is not None:
                            for child_ref in self.bsr_election:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.Bsr.BsrElections']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bsr_elections is not None and self.bsr_elections._has_data():
                        return True

                    if self.candidate_rps is not None and self.candidate_rps._has_data():
                        return True

                    if self.rp_caches is not None and self.rp_caches._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.Bsr']['meta_info']


            class RoutePolicy(object):
                """
                PIM route policy
                
                .. attribute:: route_policy_statistics
                
                	PIM route policy statistics
                	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics>`
                
                .. attribute:: route_policy_tests
                
                	PIM route policy test run table
                	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.route_policy_statistics = Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics()
                    self.route_policy_statistics.parent = self
                    self.route_policy_tests = Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests()
                    self.route_policy_tests.parent = self


                class RoutePolicyStatistics(object):
                    """
                    PIM route policy statistics
                    
                    .. attribute:: any_table
                    
                    	Number of RPF lookup in any Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table
                    
                    	Number of RPF lookup in default\-only Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop
                    
                    	Number of RPF drops
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pass_
                    
                    	Number of RPF pass
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: policy_name
                    
                    	RPF policy name
                    	**type**\:  str
                    
                    .. attribute:: requests
                    
                    	Number of RPF lookup requests
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.any_table = None
                        self.default_table = None
                        self.drop = None
                        self.pass_ = None
                        self.policy_name = None
                        self.requests = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy/Cisco-IOS-XR-ipv4-pim-oper:route-policy-statistics'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.any_table is not None:
                            return True

                        if self.default_table is not None:
                            return True

                        if self.drop is not None:
                            return True

                        if self.pass_ is not None:
                            return True

                        if self.policy_name is not None:
                            return True

                        if self.requests is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics']['meta_info']


                class RoutePolicyTests(object):
                    """
                    PIM route policy test run table
                    
                    .. attribute:: route_policy_test
                    
                    	PIM route policy test run
                    	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.route_policy_test = YList()
                        self.route_policy_test.parent = self
                        self.route_policy_test.name = 'route_policy_test'


                    class RoutePolicyTest(object):
                        """
                        PIM route policy test run
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Default table selected
                        	**type**\:  bool
                        
                        .. attribute:: ext_comm
                        
                        	Extended Community
                        	**type**\:  str
                        
                        	**length:** 1..8
                        
                        .. attribute:: extended_community_rt
                        
                        	Route Target
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                        
                        .. attribute:: pass_
                        
                        	Pass
                        	**type**\:  bool
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                        
                        .. attribute:: table_active
                        
                        	Table active
                        	**type**\:  bool
                        
                        .. attribute:: table_exists
                        
                        	Table exists
                        	**type**\:  bool
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_name
                        
                        	VRF name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.afi = None
                            self.default_table = None
                            self.ext_comm = None
                            self.extended_community_rt = None
                            self.group_address = None
                            self.group_address_xr = Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self.pass_ = None
                            self.policy_name = None
                            self.safi = None
                            self.source_address = None
                            self.source_address_xr = Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self.table_active = None
                            self.table_exists = None
                            self.table_name = None
                            self.vrf_name = None


                        class SourceAddressXr(object):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy/Cisco-IOS-XR-ipv4-pim-oper:route-policy-tests/Cisco-IOS-XR-ipv4-pim-oper:route-policy-test/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr']['meta_info']


                        class GroupAddressXr(object):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy/Cisco-IOS-XR-ipv4-pim-oper:route-policy-tests/Cisco-IOS-XR-ipv4-pim-oper:route-policy-test/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy/Cisco-IOS-XR-ipv4-pim-oper:route-policy-tests/Cisco-IOS-XR-ipv4-pim-oper:route-policy-test'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.afi is not None:
                                return True

                            if self.default_table is not None:
                                return True

                            if self.ext_comm is not None:
                                return True

                            if self.extended_community_rt is not None:
                                return True

                            if self.group_address is not None:
                                return True

                            if self.group_address_xr is not None and self.group_address_xr._has_data():
                                return True

                            if self.pass_ is not None:
                                return True

                            if self.policy_name is not None:
                                return True

                            if self.safi is not None:
                                return True

                            if self.source_address is not None:
                                return True

                            if self.source_address_xr is not None and self.source_address_xr._has_data():
                                return True

                            if self.table_active is not None:
                                return True

                            if self.table_exists is not None:
                                return True

                            if self.table_name is not None:
                                return True

                            if self.vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy/Cisco-IOS-XR-ipv4-pim-oper:route-policy-tests'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.route_policy_test is not None:
                            for child_ref in self.route_policy_test:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.route_policy_statistics is not None and self.route_policy_statistics._has_data():
                        return True

                    if self.route_policy_tests is not None and self.route_policy_tests._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.RoutePolicy']['meta_info']


            class RpfSummary(object):
                """
                PIM RPF registration summary
                
                .. attribute:: default_safi
                
                	Default RPF Table SAFI
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: default_table_name
                
                	Default RPF Table Name
                	**type**\:  str
                
                .. attribute:: is_isis_mtr_configured
                
                	Is ISIS MTR configured?
                	**type**\:  bool
                
                .. attribute:: is_isis_te_configured
                
                	Is ISIS TE configured?
                	**type**\:  bool
                
                .. attribute:: is_mbgp_configured
                
                	Is MBGP configured?
                	**type**\:  bool
                
                .. attribute:: is_multipath_enabled
                
                	Is Multipath Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_interface_hash_enabled
                
                	Is Multipath Interface Hash Extension Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_hash_enabled
                
                	Is Multipath Source based Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_next_hop_hash_enabled
                
                	Is Multipath Source\-Nexthop Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_ospf_te_configured
                
                	Is OSPF TE configured?
                	**type**\:  bool
                
                .. attribute:: is_rib_convergence
                
                	RIB Convergence status
                	**type**\:  bool
                
                .. attribute:: mo_frr_configured
                
                	Is MoFRR configured?
                	**type**\:  bool
                
                .. attribute:: rib_convergence_time_left
                
                	RIB convergence time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_convergence_timeout
                
                	RIB convergence timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_mo_frr_configured
                
                	Is MoFRR RIB configured?
                	**type**\:  bool
                
                .. attribute:: rpf_registrations
                
                	RPF Registration count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	Is RUMP MuRIB enabled?
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.default_safi = None
                    self.default_table_name = None
                    self.is_isis_mtr_configured = None
                    self.is_isis_te_configured = None
                    self.is_mbgp_configured = None
                    self.is_multipath_enabled = None
                    self.is_multipath_interface_hash_enabled = None
                    self.is_multipath_source_hash_enabled = None
                    self.is_multipath_source_next_hop_hash_enabled = None
                    self.is_ospf_te_configured = None
                    self.is_rib_convergence = None
                    self.mo_frr_configured = None
                    self.rib_convergence_time_left = None
                    self.rib_convergence_timeout = None
                    self.rib_mo_frr_configured = None
                    self.rpf_registrations = None
                    self.rump_enabled = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.default_safi is not None:
                        return True

                    if self.default_table_name is not None:
                        return True

                    if self.is_isis_mtr_configured is not None:
                        return True

                    if self.is_isis_te_configured is not None:
                        return True

                    if self.is_mbgp_configured is not None:
                        return True

                    if self.is_multipath_enabled is not None:
                        return True

                    if self.is_multipath_interface_hash_enabled is not None:
                        return True

                    if self.is_multipath_source_hash_enabled is not None:
                        return True

                    if self.is_multipath_source_next_hop_hash_enabled is not None:
                        return True

                    if self.is_ospf_te_configured is not None:
                        return True

                    if self.is_rib_convergence is not None:
                        return True

                    if self.mo_frr_configured is not None:
                        return True

                    if self.rib_convergence_time_left is not None:
                        return True

                    if self.rib_convergence_timeout is not None:
                        return True

                    if self.rib_mo_frr_configured is not None:
                        return True

                    if self.rpf_registrations is not None:
                        return True

                    if self.rump_enabled is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.RpfSummary']['meta_info']


            class Interfaces(object):
                """
                PIM interfaces
                
                .. attribute:: interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Interfaces.Interface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface = YList()
                    self.interface.parent = self
                    self.interface.name = 'interface'


                class Interface(object):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Interfaces.Interface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.configured_override_interval = None
                        self.configured_propagation_delay = None
                        self.dr_address = Pim.Active.DefaultContext.Interfaces.Interface.DrAddress()
                        self.dr_address.parent = self
                        self.dr_priority = None
                        self.external_neighbor_count = None
                        self.generation_id = None
                        self.hello_expiry = None
                        self.hello_interval = None
                        self.idb_acl_name = None
                        self.idb_acl_provided = None
                        self.idb_current_count = None
                        self.idb_max_count = None
                        self.idb_oor_enabled = None
                        self.idb_threshold_count = None
                        self.interface_address = YList()
                        self.interface_address.parent = self
                        self.interface_address.name = 'interface_address'
                        self.interface_address_mask = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bidirectional_capable = None
                        self.is_enabled = None
                        self.is_proxy_capable = None
                        self.join_prune_interval = None
                        self.neighbor_count = None
                        self.neighbor_filter_name = None
                        self.override_interval = None
                        self.passive_interface = None
                        self.propagation_delay = None
                        self.prune_delay_enabled = None
                        self.virtual_interface = None


                    class DrAddress(object):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Interfaces.Interface.DrAddress']['meta_info']


                    class InterfaceAddress(object):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interfaces/Cisco-IOS-XR-ipv4-pim-oper:interface[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.are_we_dr is not None:
                            return True

                        if self.bfd_enabled is not None:
                            return True

                        if self.bfd_interval is not None:
                            return True

                        if self.bfd_multiplier is not None:
                            return True

                        if self.configured_override_interval is not None:
                            return True

                        if self.configured_propagation_delay is not None:
                            return True

                        if self.dr_address is not None and self.dr_address._has_data():
                            return True

                        if self.dr_priority is not None:
                            return True

                        if self.external_neighbor_count is not None:
                            return True

                        if self.generation_id is not None:
                            return True

                        if self.hello_expiry is not None:
                            return True

                        if self.hello_interval is not None:
                            return True

                        if self.idb_acl_name is not None:
                            return True

                        if self.idb_acl_provided is not None:
                            return True

                        if self.idb_current_count is not None:
                            return True

                        if self.idb_max_count is not None:
                            return True

                        if self.idb_oor_enabled is not None:
                            return True

                        if self.idb_threshold_count is not None:
                            return True

                        if self.interface_address is not None:
                            for child_ref in self.interface_address:
                                if child_ref._has_data():
                                    return True

                        if self.interface_address_mask is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_enabled is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.join_prune_interval is not None:
                            return True

                        if self.neighbor_count is not None:
                            return True

                        if self.neighbor_filter_name is not None:
                            return True

                        if self.override_interval is not None:
                            return True

                        if self.passive_interface is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.prune_delay_enabled is not None:
                            return True

                        if self.virtual_interface is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.Interfaces.Interface']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interfaces'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface is not None:
                        for child_ref in self.interface:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.Interfaces']['meta_info']


            class NetIoTunnels(object):
                """
                Tunnel information that NETIO has 
                
                .. attribute:: net_io_tunnel
                
                	PIM netio tunnel information
                	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.net_io_tunnel = YList()
                    self.net_io_tunnel.parent = self
                    self.net_io_tunnel.name = 'net_io_tunnel'


                class NetIoTunnel(object):
                    """
                    PIM netio tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.tunnel_name = None
                        self.group_address_netio = Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self.rp_address = Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress()
                        self.rp_address.parent = self
                        self.source_address = Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress()
                        self.source_address.parent = self
                        self.source_address_netio = Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self.vrf_name = None


                    class SourceAddress(object):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress']['meta_info']


                    class RpAddress(object):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress']['meta_info']


                    class SourceAddressNetio(object):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-netio'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio']['meta_info']


                    class GroupAddressNetio(object):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-netio'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio']['meta_info']

                    @property
                    def _common_path(self):
                        if self.tunnel_name is None:
                            raise YPYModelError('Key property tunnel_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:net-io-tunnels/Cisco-IOS-XR-ipv4-pim-oper:net-io-tunnel[Cisco-IOS-XR-ipv4-pim-oper:tunnel-name = ' + str(self.tunnel_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.tunnel_name is not None:
                            return True

                        if self.group_address_netio is not None and self.group_address_netio._has_data():
                            return True

                        if self.rp_address is not None and self.rp_address._has_data():
                            return True

                        if self.source_address is not None and self.source_address._has_data():
                            return True

                        if self.source_address_netio is not None and self.source_address_netio._has_data():
                            return True

                        if self.vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:net-io-tunnels'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.net_io_tunnel is not None:
                        for child_ref in self.net_io_tunnel:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.NetIoTunnels']['meta_info']


            class BidirDfStates(object):
                """
                Bidirectional PIM DF election state table
                
                .. attribute:: bidir_df_state
                
                	Bidirectional PIM DF Election Table Entry
                	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfStates.BidirDfState>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bidir_df_state = YList()
                    self.bidir_df_state.parent = self
                    self.bidir_df_state.name = 'bidir_df_state'


                class BidirDfState(object):
                    """
                    Bidirectional PIM DF Election Table Entry
                    
                    .. attribute:: election_state
                    
                    	DF Election State
                    	**type**\:  str
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: our_metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: our_metric_preference
                    
                    	MetricPreference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr>`
                    
                    .. attribute:: time_nano_seconds
                    
                    	Timer expires (nseconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: time_seconds
                    
                    	Timer expires (seconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.election_state = None
                        self.interface_name = None
                        self.our_metric = None
                        self.our_metric_preference = None
                        self.pim_interface_name = None
                        self.rp_address = None
                        self.rp_address_xr = Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self.time_nano_seconds = None
                        self.time_seconds = None


                    class RpAddressXr(object):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-states/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-state/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-states/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-state'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.election_state is not None:
                            return True

                        if self.interface_name is not None:
                            return True

                        if self.our_metric is not None:
                            return True

                        if self.our_metric_preference is not None:
                            return True

                        if self.pim_interface_name is not None:
                            return True

                        if self.rp_address is not None:
                            return True

                        if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                            return True

                        if self.time_nano_seconds is not None:
                            return True

                        if self.time_seconds is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.BidirDfStates.BidirDfState']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-states'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bidir_df_state is not None:
                        for child_ref in self.bidir_df_state:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.BidirDfStates']['meta_info']


            class Topologies(object):
                """
                PIM topology table
                
                .. attribute:: topology
                
                	PIM topology information
                	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.topology = YList()
                    self.topology.parent = self
                    self.topology.name = 'topology'


                class Topology(object):
                    """
                    PIM topology information
                    
                    .. attribute:: alive
                    
                    	Alive time in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: anycast_rp_match
                    
                    	Group matches Anycast\-RP policy
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_route_target
                    
                    	Anycast\-RP RT
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: assume_alive
                    
                    	The Assume Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: bgp_join
                    
                    	BGP C JOIN
                    	**type**\:  bool
                    
                    .. attribute:: bgpjp_time
                    
                    	BGP C JP Time
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: connected
                    
                    	Is Connected ?
                    	**type**\:  bool
                    
                    .. attribute:: customer_routing_type
                    
                    	Type of Customer Routing in the MVPN
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: dont_check_connected
                    
                    	Do we need to make the connected check on this route ?
                    	**type**\:  bool
                    
                    .. attribute:: expiry
                    
                    	When this entry expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: extranet_route
                    
                    	Is a Extranet route ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr>`
                    
                    .. attribute:: inherit_alive
                    
                    	The Inherit Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: inherit_spt
                    
                    	The Inherit SPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: is_via_lsm
                    
                    	Via LSM
                    	**type**\:  bool
                    
                    .. attribute:: jp_status
                    
                    	Join\-Prune Status
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: jp_timer
                    
                    	Join\-Prune Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: last_hop
                    
                    	Are we last hop ?
                    	**type**\:  bool
                    
                    .. attribute:: limit_reached
                    
                    	Have we throttled the creation of routes or interfaces ?
                    	**type**\:  bool
                    
                    .. attribute:: low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_active
                    
                    	Is MoFRR Active?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_backup
                    
                    	Is this Mofrr Backup?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_primary
                    
                    	Is this Mofrr Primary?
                    	**type**\:  bool
                    
                    .. attribute:: orig_src_address
                    
                    	Orig Src Address
                    	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress>`
                    
                    .. attribute:: outgoing_interface
                    
                    	Outgoing interface list
                    	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface>`
                    
                    .. attribute:: probe_alive
                    
                    	The Probe Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                    
                    .. attribute:: proxy
                    
                    	Is the RPF target a proxy?
                    	**type**\:  bool
                    
                    .. attribute:: proxy_address
                    
                    	RPF Proxy address
                    	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress>`
                    
                    .. attribute:: really_alive
                    
                    	The Really Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: register_received
                    
                    	Have registers been received for this source ?
                    	**type**\:  bool
                    
                    .. attribute:: register_received_timer
                    
                    	Register Received Timer in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: remote_source
                    
                    	MSDP told us
                    	**type**\:  bool
                    
                    .. attribute:: rib_mo_frr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rp_address
                    
                    	RP Address (If rpt)
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.RpAddress>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor>`
                    
                    .. attribute:: rpf_proxy_enabled
                    
                    	Is rpf if proxy enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: rpt
                    
                    	RPT bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpt_xr
                    
                    	Is this on the RPT ?
                    	**type**\:  bool
                    
                    .. attribute:: sa_joined
                    
                    	BGP SA join
                    	**type**\:  bool
                    
                    .. attribute:: sa_received
                    
                    	BGP SA received
                    	**type**\:  bool
                    
                    .. attribute:: sa_sent
                    
                    	BGP SA sent
                    	**type**\:  bool
                    
                    .. attribute:: secondary_rpf_interface_name
                    
                    	Secondary Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: secondary_rpf_neighbor
                    
                    	Secondary RPF Neighbor
                    	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor>`
                    
                    .. attribute:: sending_null_registers
                    
                    	Are we sending null registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: sending_registers
                    
                    	Are we sending registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: signal_sources
                    
                    	Signal Sources on route?
                    	**type**\:  bool
                    
                    .. attribute:: source_address
                    
                    	Source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr>`
                    
                    .. attribute:: spt
                    
                    	Is this on the SPT ?
                    	**type**\:  bool
                    
                    .. attribute:: suppress_registers
                    
                    	When the Null register probe expires
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: vxlan
                    
                    	Is this VXLAN?
                    	**type**\:  bool
                    
                    .. attribute:: wildcard
                    
                    	WC \-Wildcard
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.alive = None
                        self.anycast_rp_match = None
                        self.anycast_rp_route_target = None
                        self.assume_alive = None
                        self.bgp_join = None
                        self.bgpjp_time = None
                        self.connected = None
                        self.customer_routing_type = None
                        self.dont_check_connected = None
                        self.expiry = None
                        self.extranet_route = None
                        self.group_address = None
                        self.group_address_xr = Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self.inherit_alive = None
                        self.inherit_spt = None
                        self.is_via_lsm = None
                        self.jp_status = None
                        self.jp_timer = None
                        self.last_hop = None
                        self.limit_reached = None
                        self.low_memory = None
                        self.mofrr_active = None
                        self.mofrr_backup = None
                        self.mofrr_enabled = None
                        self.mofrr_primary = None
                        self.orig_src_address = Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress()
                        self.orig_src_address.parent = self
                        self.outgoing_interface = YList()
                        self.outgoing_interface.parent = self
                        self.outgoing_interface.name = 'outgoing_interface'
                        self.probe_alive = None
                        self.protocol = None
                        self.proxy = None
                        self.proxy_address = Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress()
                        self.proxy_address.parent = self
                        self.really_alive = None
                        self.register_received = None
                        self.register_received_timer = None
                        self.remote_source = None
                        self.rib_mo_frr_enabled = None
                        self.rp_address = Pim.Active.DefaultContext.Topologies.Topology.RpAddress()
                        self.rp_address.parent = self
                        self.rpf_drop = None
                        self.rpf_extranet = None
                        self.rpf_interface_name = None
                        self.rpf_neighbor = Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self.rpf_proxy_enabled = None
                        self.rpf_root = Pim.Active.DefaultContext.Topologies.Topology.RpfRoot()
                        self.rpf_root.parent = self
                        self.rpf_safi = None
                        self.rpf_table_name = None
                        self.rpf_vrf_name = None
                        self.rpt = None
                        self.rpt_xr = None
                        self.sa_joined = None
                        self.sa_received = None
                        self.sa_sent = None
                        self.secondary_rpf_interface_name = None
                        self.secondary_rpf_neighbor = Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor()
                        self.secondary_rpf_neighbor.parent = self
                        self.sending_null_registers = None
                        self.sending_registers = None
                        self.signal_sources = None
                        self.source_address = None
                        self.source_address_xr = Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self.spt = None
                        self.suppress_registers = None
                        self.uptime = None
                        self.vxlan = None
                        self.wildcard = None


                    class GroupAddressXr(object):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr']['meta_info']


                    class SourceAddressXr(object):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr']['meta_info']


                    class RpAddress(object):
                        """
                        RP Address (If rpt)
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Topologies.Topology.RpAddress']['meta_info']


                    class RpfNeighbor(object):
                        """
                        RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor']['meta_info']


                    class SecondaryRpfNeighbor(object):
                        """
                        Secondary RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:secondary-rpf-neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor']['meta_info']


                    class RpfRoot(object):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:rpf-root'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Topologies.Topology.RpfRoot']['meta_info']


                    class ProxyAddress(object):
                        """
                        RPF Proxy address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:proxy-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress']['meta_info']


                    class OrigSrcAddress(object):
                        """
                        Orig Src Address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:orig-src-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress']['meta_info']


                    class OutgoingInterface(object):
                        """
                        Outgoing interface list
                        
                        .. attribute:: admin_boundary
                        
                        	Is this an administrative boundary ?
                        	**type**\:  bool
                        
                        .. attribute:: assert_timer
                        
                        	Assert Timer in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: assert_winner
                        
                        	Assert Winner
                        	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner>`
                        
                        .. attribute:: bgp_c_mcast_join
                        
                        	BGP C\-Mcast join
                        	**type**\:  bool
                        
                        .. attribute:: bgp_c_mcast_prune_delay_timer
                        
                        	BGP C\-MCAST Prune Suppression in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: data_mdt_join
                        
                        	Data MDT join
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	Expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: extranet_interface
                        
                        	Is this an Extranet Interface ?
                        	**type**\:  bool
                        
                        .. attribute:: forwarding_state
                        
                        	Forward or Prune
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: igmp_membership
                        
                        	IGMP membership
                        	**type**\:  bool
                        
                        .. attribute:: immediate_state
                        
                        	Immediate fwding state
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_interest_info
                        
                        	Internal Interest
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_state
                        
                        	Join\-Prune State
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer (secs)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: local_mdt_join
                        
                        	Default MDT Join
                        	**type**\:  bool
                        
                        .. attribute:: local_members
                        
                        	Local Information
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: mdt_safi_join
                        
                        	MDT Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mldp_inband_mdt
                        
                        	MLDP Inband MDT interface
                        	**type**\:  bool
                        
                        .. attribute:: mldp_stale
                        
                        	OLE is stale
                        	**type**\:  bool
                        
                        .. attribute:: mvp_nv6_safi_join
                        
                        	MVPN IPv6 Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mvpn_safi_join
                        
                        	MVPN Safi join
                        	**type**\:  bool
                        
                        .. attribute:: sa_prune
                        
                        	BGP SA Prune state
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vrf_name
                        
                        	VRF which physically owns
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.admin_boundary = None
                            self.assert_timer = None
                            self.assert_winner = Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner()
                            self.assert_winner.parent = self
                            self.bgp_c_mcast_join = None
                            self.bgp_c_mcast_prune_delay_timer = None
                            self.data_mdt_join = None
                            self.expiry = None
                            self.extranet_interface = None
                            self.forwarding_state = None
                            self.igmp_membership = None
                            self.immediate_state = None
                            self.interface_name = None
                            self.internal_interest_info = None
                            self.jp_state = None
                            self.jp_timer = None
                            self.last_hop = None
                            self.local_mdt_join = None
                            self.local_members = None
                            self.mdt_safi_join = None
                            self.mldp_inband_mdt = None
                            self.mldp_stale = None
                            self.mvp_nv6_safi_join = None
                            self.mvpn_safi_join = None
                            self.sa_prune = None
                            self.uptime = None
                            self.vrf_name = None


                        class AssertWinner(object):
                            """
                            Assert Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:outgoing-interface/Cisco-IOS-XR-ipv4-pim-oper:assert-winner'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:outgoing-interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.admin_boundary is not None:
                                return True

                            if self.assert_timer is not None:
                                return True

                            if self.assert_winner is not None and self.assert_winner._has_data():
                                return True

                            if self.bgp_c_mcast_join is not None:
                                return True

                            if self.bgp_c_mcast_prune_delay_timer is not None:
                                return True

                            if self.data_mdt_join is not None:
                                return True

                            if self.expiry is not None:
                                return True

                            if self.extranet_interface is not None:
                                return True

                            if self.forwarding_state is not None:
                                return True

                            if self.igmp_membership is not None:
                                return True

                            if self.immediate_state is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.internal_interest_info is not None:
                                return True

                            if self.jp_state is not None:
                                return True

                            if self.jp_timer is not None:
                                return True

                            if self.last_hop is not None:
                                return True

                            if self.local_mdt_join is not None:
                                return True

                            if self.local_members is not None:
                                return True

                            if self.mdt_safi_join is not None:
                                return True

                            if self.mldp_inband_mdt is not None:
                                return True

                            if self.mldp_stale is not None:
                                return True

                            if self.mvp_nv6_safi_join is not None:
                                return True

                            if self.mvpn_safi_join is not None:
                                return True

                            if self.sa_prune is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            if self.vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.alive is not None:
                            return True

                        if self.anycast_rp_match is not None:
                            return True

                        if self.anycast_rp_route_target is not None:
                            return True

                        if self.assume_alive is not None:
                            return True

                        if self.bgp_join is not None:
                            return True

                        if self.bgpjp_time is not None:
                            return True

                        if self.connected is not None:
                            return True

                        if self.customer_routing_type is not None:
                            return True

                        if self.dont_check_connected is not None:
                            return True

                        if self.expiry is not None:
                            return True

                        if self.extranet_route is not None:
                            return True

                        if self.group_address is not None:
                            return True

                        if self.group_address_xr is not None and self.group_address_xr._has_data():
                            return True

                        if self.inherit_alive is not None:
                            return True

                        if self.inherit_spt is not None:
                            return True

                        if self.is_via_lsm is not None:
                            return True

                        if self.jp_status is not None:
                            return True

                        if self.jp_timer is not None:
                            return True

                        if self.last_hop is not None:
                            return True

                        if self.limit_reached is not None:
                            return True

                        if self.low_memory is not None:
                            return True

                        if self.mofrr_active is not None:
                            return True

                        if self.mofrr_backup is not None:
                            return True

                        if self.mofrr_enabled is not None:
                            return True

                        if self.mofrr_primary is not None:
                            return True

                        if self.orig_src_address is not None and self.orig_src_address._has_data():
                            return True

                        if self.outgoing_interface is not None:
                            for child_ref in self.outgoing_interface:
                                if child_ref._has_data():
                                    return True

                        if self.probe_alive is not None:
                            return True

                        if self.protocol is not None:
                            return True

                        if self.proxy is not None:
                            return True

                        if self.proxy_address is not None and self.proxy_address._has_data():
                            return True

                        if self.really_alive is not None:
                            return True

                        if self.register_received is not None:
                            return True

                        if self.register_received_timer is not None:
                            return True

                        if self.remote_source is not None:
                            return True

                        if self.rib_mo_frr_enabled is not None:
                            return True

                        if self.rp_address is not None and self.rp_address._has_data():
                            return True

                        if self.rpf_drop is not None:
                            return True

                        if self.rpf_extranet is not None:
                            return True

                        if self.rpf_interface_name is not None:
                            return True

                        if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                            return True

                        if self.rpf_proxy_enabled is not None:
                            return True

                        if self.rpf_root is not None and self.rpf_root._has_data():
                            return True

                        if self.rpf_safi is not None:
                            return True

                        if self.rpf_table_name is not None:
                            return True

                        if self.rpf_vrf_name is not None:
                            return True

                        if self.rpt is not None:
                            return True

                        if self.rpt_xr is not None:
                            return True

                        if self.sa_joined is not None:
                            return True

                        if self.sa_received is not None:
                            return True

                        if self.sa_sent is not None:
                            return True

                        if self.secondary_rpf_interface_name is not None:
                            return True

                        if self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor._has_data():
                            return True

                        if self.sending_null_registers is not None:
                            return True

                        if self.sending_registers is not None:
                            return True

                        if self.signal_sources is not None:
                            return True

                        if self.source_address is not None:
                            return True

                        if self.source_address_xr is not None and self.source_address_xr._has_data():
                            return True

                        if self.spt is not None:
                            return True

                        if self.suppress_registers is not None:
                            return True

                        if self.uptime is not None:
                            return True

                        if self.vxlan is not None:
                            return True

                        if self.wildcard is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.Topologies.Topology']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.topology is not None:
                        for child_ref in self.topology:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.Topologies']['meta_info']


            class BgpAfs(object):
                """
                PIM BGP SAFI table
                
                .. attribute:: bgp_af
                
                	PIM BGP SAFI information
                	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BgpAfs.BgpAf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bgp_af = YList()
                    self.bgp_af.parent = self
                    self.bgp_af.name = 'bgp_af'


                class BgpAf(object):
                    """
                    PIM BGP SAFI information
                    
                    .. attribute:: extranet_path_count
                    
                    	Count of dependent extranet paths
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group
                    
                    	Group address
                    	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BgpAfs.BgpAf.Group>`
                    
                    .. attribute:: group_address
                    
                    	Group IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: is_bgp_added
                    
                    	SAFI learnt from BGP
                    	**type**\:  bool
                    
                    .. attribute:: next_hop
                    
                    	Next hop address
                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop>`
                    
                    .. attribute:: route_distinguisher
                    
                    	Router ID
                    	**type**\:  str
                    
                    	**length:** 0..256
                    
                    .. attribute:: source
                    
                    	Source address
                    	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BgpAfs.BgpAf.Source>`
                    
                    .. attribute:: source_address
                    
                    	Source IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.extranet_path_count = None
                        self.group = Pim.Active.DefaultContext.BgpAfs.BgpAf.Group()
                        self.group.parent = self
                        self.group_address = None
                        self.is_bgp_added = None
                        self.next_hop = Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop()
                        self.next_hop.parent = self
                        self.route_distinguisher = None
                        self.source = Pim.Active.DefaultContext.BgpAfs.BgpAf.Source()
                        self.source.parent = self
                        self.source_address = None


                    class Source(object):
                        """
                        Source address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs/Cisco-IOS-XR-ipv4-pim-oper:bgp-af/Cisco-IOS-XR-ipv4-pim-oper:source'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.BgpAfs.BgpAf.Source']['meta_info']


                    class Group(object):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs/Cisco-IOS-XR-ipv4-pim-oper:bgp-af/Cisco-IOS-XR-ipv4-pim-oper:group'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.BgpAfs.BgpAf.Group']['meta_info']


                    class NextHop(object):
                        """
                        Next hop address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs/Cisco-IOS-XR-ipv4-pim-oper:bgp-af/Cisco-IOS-XR-ipv4-pim-oper:next-hop'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs/Cisco-IOS-XR-ipv4-pim-oper:bgp-af'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.extranet_path_count is not None:
                            return True

                        if self.group is not None and self.group._has_data():
                            return True

                        if self.group_address is not None:
                            return True

                        if self.is_bgp_added is not None:
                            return True

                        if self.next_hop is not None and self.next_hop._has_data():
                            return True

                        if self.route_distinguisher is not None:
                            return True

                        if self.source is not None and self.source._has_data():
                            return True

                        if self.source_address is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.BgpAfs.BgpAf']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bgp_af is not None:
                        for child_ref in self.bgp_af:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.BgpAfs']['meta_info']


            class AutoRp(object):
                """
                PIM Auto\-RP information
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:auto-rp'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.AutoRp']['meta_info']


            class TopologyInterfaceFlagRouteCounts(object):
                """
                Route count for topology with interface flag set
                
                .. attribute:: topology_interface_flag_route_count
                
                	Route count for topology with interface flag set
                	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.topology_interface_flag_route_count = YList()
                    self.topology_interface_flag_route_count.parent = self
                    self.topology_interface_flag_route_count.name = 'topology_interface_flag_route_count'


                class TopologyInterfaceFlagRouteCount(object):
                    """
                    Route count for topology with interface flag
                    set
                    
                    .. attribute:: interface_flag  <key>
                    
                    	Interface flag
                    	**type**\:   :py:class:`PimTopologyInterfaceFlagEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlagEnum>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_flag = None
                        self.active_group_ranges = None
                        self.group_address = Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self.group_ranges = None
                        self.groute_count = None
                        self.is_node_low_memory = None
                        self.sg_route_count = None
                        self.sgr_route_count = None


                    class GroupAddress(object):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_flag is None:
                            raise YPYModelError('Key property interface_flag is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-interface-flag-route-counts/Cisco-IOS-XR-ipv4-pim-oper:topology-interface-flag-route-count[Cisco-IOS-XR-ipv4-pim-oper:interface-flag = ' + str(self.interface_flag) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_flag is not None:
                            return True

                        if self.active_group_ranges is not None:
                            return True

                        if self.group_address is not None and self.group_address._has_data():
                            return True

                        if self.group_ranges is not None:
                            return True

                        if self.groute_count is not None:
                            return True

                        if self.is_node_low_memory is not None:
                            return True

                        if self.sg_route_count is not None:
                            return True

                        if self.sgr_route_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-interface-flag-route-counts'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.topology_interface_flag_route_count is not None:
                        for child_ref in self.topology_interface_flag_route_count:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts']['meta_info']


            class GroupMapSources(object):
                """
                PIM group\-mapping with source information
                
                .. attribute:: group_map_source
                
                	PIM Group Mapping Entry with source information
                	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources.GroupMapSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.group_map_source = YList()
                    self.group_map_source.parent = self
                    self.group_map_source.name = 'group_map_source'


                class GroupMapSource(object):
                    """
                    PIM Group Mapping Entry with source information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                    
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: priority
                    
                    	RP Priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocolEnum>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation>`
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.client = None
                        self.expires = None
                        self.group_map_information = Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self.holdtime = None
                        self.prefix = None
                        self.prefix_length = None
                        self.priority = None
                        self.protocol = None
                        self.rp_address = None
                        self.source_of_information = Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self.uptime = None


                    class SourceOfInformation(object):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-source/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation']['meta_info']


                    class GroupMapInformation(object):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.group_count = None
                            self.is_override = None
                            self.is_used = None
                            self.mrib_active = None
                            self.prefix = Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.priority = None
                            self.protocol = None
                            self.rp_address = Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self


                        class Prefix(object):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-source/Cisco-IOS-XR-ipv4-pim-oper:group-map-information/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix']['meta_info']


                        class RpAddress(object):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-source/Cisco-IOS-XR-ipv4-pim-oper:group-map-information/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-source/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.group_count is not None:
                                return True

                            if self.is_override is not None:
                                return True

                            if self.is_used is not None:
                                return True

                            if self.mrib_active is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-source'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.client is not None:
                            return True

                        if self.expires is not None:
                            return True

                        if self.group_map_information is not None and self.group_map_information._has_data():
                            return True

                        if self.holdtime is not None:
                            return True

                        if self.prefix is not None:
                            return True

                        if self.prefix_length is not None:
                            return True

                        if self.priority is not None:
                            return True

                        if self.protocol is not None:
                            return True

                        if self.rp_address is not None:
                            return True

                        if self.source_of_information is not None and self.source_of_information._has_data():
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.GroupMapSources.GroupMapSource']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.group_map_source is not None:
                        for child_ref in self.group_map_source:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.GroupMapSources']['meta_info']


            class TrafficCounters(object):
                """
                PIM message traffic counters
                
                .. attribute:: boundary_acl_rx_drop
                
                	Inc. JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: boundary_acl_tx_drop
                
                	Out JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_error
                
                	Checksum errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: elapsed_time
                
                	Running time for counters in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: format_error
                
                	Malformed packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert
                
                	Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert_batched
                
                	Batched Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_bsr_message
                
                	Input BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_candidate_rp_advertisement
                
                	Input Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_data_register
                
                	Data Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_df_election
                
                	DF Election packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_ecmp_redirect
                
                	Input Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_hello
                
                	Hello packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_jp
                
                	Join Prune packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb_error
                
                	No IDB for intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_pim_error
                
                	PIM Disabled on intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_error
                
                	No VRF for idb error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_null_register
                
                	Null Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim_version_error
                
                	Invalid PIM version error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_register_stop
                
                	Register Stop packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: inputs
                
                	Packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_destination_packets
                
                	Control Packets with Invalid Destination
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_join_prunes
                
                	PIM invalid Join/Prunes received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_registers
                
                	PIM invalid registers received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_local_source_address
                
                	Data MDT Join msgs dropped due to local source addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_idb
                
                	Data MDT Join msgs dropped due to idb missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_vrf
                
                	Data MDT Join msgs dropped due to vrf missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_null_local_address
                
                	Data MDT Join msgs dropped due to null local addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_bad_type
                
                	Data MDT TLV bad type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_received
                
                	Data MDT Join Msgs received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_sent
                
                	Data MDT Join Msgs sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_joins_drop_multiple_encapsulation
                
                	MDT Join msgs dropped due to multiple Encap limitation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_send_queue_full
                
                	Packets dropped since mdt send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_socket_error
                
                	MDT Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_invalid_lsm_identifier
                
                	 Invalid LSM ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_mdt_socket_connection
                
                	Packets dropped since no mdt socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_source_address
                
                	Packets dropped since no source address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: non_supported_packets
                
                	PIM non supported pckets
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert
                
                	Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert_batched
                
                	Batched Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_bsr_message
                
                	Output BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_candidate_rp_advertisement
                
                	Output Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_data_register
                
                	Data Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_df_election
                
                	DF Election packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_ecmp_redirect
                
                	Output Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello
                
                	Hello packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello_bytes
                
                	Output Hello Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_join_group
                
                	Output Join Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_join_prune_bytes
                
                	Output JP Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_jp
                
                	Join Prune packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_loop_error
                
                	Output on loopback error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_null_register
                
                	Null Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_prune_group
                
                	Output Prune Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_register_stop
                
                	Register Stop packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: outputs
                
                	Packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_dequeued
                
                	Packets Dequeued per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_enqueued
                
                	Packets Enqueued per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_packman_error
                
                	Packets Dropped due to Pakman Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue
                
                	Packet queue state and statistics
                	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TrafficCounters.PacketQueue>`
                
                .. attribute:: packet_queue_last_clear
                
                	Time in seconds since the last clear of all packet queues stats
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: packet_queue_length
                
                	Packet Queue Length per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue_size
                
                	Packet Queue Size per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_read_socket_error
                
                	Packet Read Socket Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_tail_drop
                
                	Packet Tail Drop per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_standby
                
                	Packets Dropped due to Standby Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pakman_error
                
                	Pakman packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_queue_full
                
                	Packets dropped since send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_error
                
                	Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_packets_error
                
                	Packets received in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: truncated_pim_packets
                
                	Packets dropped due to truncated Joins or Prunes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.boundary_acl_rx_drop = None
                    self.boundary_acl_tx_drop = None
                    self.checksum_error = None
                    self.elapsed_time = None
                    self.format_error = None
                    self.input_assert = None
                    self.input_assert_batched = None
                    self.input_bsr_message = None
                    self.input_candidate_rp_advertisement = None
                    self.input_data_register = None
                    self.input_df_election = None
                    self.input_ecmp_redirect = None
                    self.input_hello = None
                    self.input_jp = None
                    self.input_no_idb_error = None
                    self.input_no_pim_error = None
                    self.input_no_vrf_error = None
                    self.input_null_register = None
                    self.input_pim_version_error = None
                    self.input_register_stop = None
                    self.inputs = None
                    self.invalid_destination_packets = None
                    self.invalid_join_prunes = None
                    self.invalid_registers = None
                    self.mdt_drop_local_source_address = None
                    self.mdt_drop_no_idb = None
                    self.mdt_drop_no_vrf = None
                    self.mdt_drop_null_local_address = None
                    self.mdt_join_bad_type = None
                    self.mdt_join_tlv_received = None
                    self.mdt_join_tlv_sent = None
                    self.mdt_joins_drop_multiple_encapsulation = None
                    self.mdt_send_queue_full = None
                    self.mdt_socket_error = None
                    self.mldp_mdt_invalid_lsm_identifier = None
                    self.no_mdt_socket_connection = None
                    self.no_socket_connection = None
                    self.no_source_address = None
                    self.non_supported_packets = None
                    self.output_assert = None
                    self.output_assert_batched = None
                    self.output_bsr_message = None
                    self.output_candidate_rp_advertisement = None
                    self.output_data_register = None
                    self.output_df_election = None
                    self.output_ecmp_redirect = None
                    self.output_hello = None
                    self.output_hello_bytes = None
                    self.output_join_group = None
                    self.output_join_prune_bytes = None
                    self.output_jp = None
                    self.output_loop_error = None
                    self.output_null_register = None
                    self.output_prune_group = None
                    self.output_register_stop = None
                    self.outputs = None
                    self.packet_dequeued = YLeafList()
                    self.packet_dequeued.parent = self
                    self.packet_dequeued.name = 'packet_dequeued'
                    self.packet_enqueued = YLeafList()
                    self.packet_enqueued.parent = self
                    self.packet_enqueued.name = 'packet_enqueued'
                    self.packet_packman_error = None
                    self.packet_queue = YList()
                    self.packet_queue.parent = self
                    self.packet_queue.name = 'packet_queue'
                    self.packet_queue_last_clear = None
                    self.packet_queue_length = YLeafList()
                    self.packet_queue_length.parent = self
                    self.packet_queue_length.name = 'packet_queue_length'
                    self.packet_queue_size = YLeafList()
                    self.packet_queue_size.parent = self
                    self.packet_queue_size.name = 'packet_queue_size'
                    self.packet_read_socket_error = None
                    self.packet_tail_drop = YLeafList()
                    self.packet_tail_drop.parent = self
                    self.packet_tail_drop.name = 'packet_tail_drop'
                    self.packets_standby = None
                    self.pakman_error = None
                    self.send_queue_full = None
                    self.socket_error = None
                    self.standby_packets_error = None
                    self.truncated_pim_packets = None


                class PacketQueue(object):
                    """
                    Packet queue state and statistics
                    
                    .. attribute:: packet_queue_priority
                    
                    	Priority of this packet queue
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_state
                    
                    	State of the queue
                    	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState>`
                    
                    .. attribute:: packet_queue_stats
                    
                    	Statistics about the queue
                    	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.packet_queue_priority = None
                        self.packet_queue_state = Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState()
                        self.packet_queue_state.parent = self
                        self.packet_queue_stats = Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats()
                        self.packet_queue_stats.parent = self


                    class PacketQueueState(object):
                        """
                        State of the queue
                        
                        .. attribute:: max_queue_size
                        
                        	Maximum size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_bytes
                        
                        	Size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_packets
                        
                        	Size of queue in number of packets
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.max_queue_size = None
                            self.queue_size_bytes = None
                            self.queue_size_packets = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:traffic-counters/Cisco-IOS-XR-ipv4-pim-oper:packet-queue/Cisco-IOS-XR-ipv4-pim-oper:packet-queue-state'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.max_queue_size is not None:
                                return True

                            if self.queue_size_bytes is not None:
                                return True

                            if self.queue_size_packets is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState']['meta_info']


                    class PacketQueueStats(object):
                        """
                        Statistics about the queue
                        
                        .. attribute:: dequeued_packets
                        
                        	Total number of packets dequeued from this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: enqueued_packets
                        
                        	Total number of packets enqueued to this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: high_water_mark_bytes
                        
                        	Highest number of bytes enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: high_water_mark_packets
                        
                        	Highest number of packets enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tail_drops
                        
                        	Number packets dropped from this queue due to max size
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dequeued_packets = None
                            self.enqueued_packets = None
                            self.high_water_mark_bytes = None
                            self.high_water_mark_packets = None
                            self.tail_drops = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:traffic-counters/Cisco-IOS-XR-ipv4-pim-oper:packet-queue/Cisco-IOS-XR-ipv4-pim-oper:packet-queue-stats'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dequeued_packets is not None:
                                return True

                            if self.enqueued_packets is not None:
                                return True

                            if self.high_water_mark_bytes is not None:
                                return True

                            if self.high_water_mark_packets is not None:
                                return True

                            if self.tail_drops is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:traffic-counters/Cisco-IOS-XR-ipv4-pim-oper:packet-queue'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.packet_queue_priority is not None:
                            return True

                        if self.packet_queue_state is not None and self.packet_queue_state._has_data():
                            return True

                        if self.packet_queue_stats is not None and self.packet_queue_stats._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.TrafficCounters.PacketQueue']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:traffic-counters'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.boundary_acl_rx_drop is not None:
                        return True

                    if self.boundary_acl_tx_drop is not None:
                        return True

                    if self.checksum_error is not None:
                        return True

                    if self.elapsed_time is not None:
                        return True

                    if self.format_error is not None:
                        return True

                    if self.input_assert is not None:
                        return True

                    if self.input_assert_batched is not None:
                        return True

                    if self.input_bsr_message is not None:
                        return True

                    if self.input_candidate_rp_advertisement is not None:
                        return True

                    if self.input_data_register is not None:
                        return True

                    if self.input_df_election is not None:
                        return True

                    if self.input_ecmp_redirect is not None:
                        return True

                    if self.input_hello is not None:
                        return True

                    if self.input_jp is not None:
                        return True

                    if self.input_no_idb_error is not None:
                        return True

                    if self.input_no_pim_error is not None:
                        return True

                    if self.input_no_vrf_error is not None:
                        return True

                    if self.input_null_register is not None:
                        return True

                    if self.input_pim_version_error is not None:
                        return True

                    if self.input_register_stop is not None:
                        return True

                    if self.inputs is not None:
                        return True

                    if self.invalid_destination_packets is not None:
                        return True

                    if self.invalid_join_prunes is not None:
                        return True

                    if self.invalid_registers is not None:
                        return True

                    if self.mdt_drop_local_source_address is not None:
                        return True

                    if self.mdt_drop_no_idb is not None:
                        return True

                    if self.mdt_drop_no_vrf is not None:
                        return True

                    if self.mdt_drop_null_local_address is not None:
                        return True

                    if self.mdt_join_bad_type is not None:
                        return True

                    if self.mdt_join_tlv_received is not None:
                        return True

                    if self.mdt_join_tlv_sent is not None:
                        return True

                    if self.mdt_joins_drop_multiple_encapsulation is not None:
                        return True

                    if self.mdt_send_queue_full is not None:
                        return True

                    if self.mdt_socket_error is not None:
                        return True

                    if self.mldp_mdt_invalid_lsm_identifier is not None:
                        return True

                    if self.no_mdt_socket_connection is not None:
                        return True

                    if self.no_socket_connection is not None:
                        return True

                    if self.no_source_address is not None:
                        return True

                    if self.non_supported_packets is not None:
                        return True

                    if self.output_assert is not None:
                        return True

                    if self.output_assert_batched is not None:
                        return True

                    if self.output_bsr_message is not None:
                        return True

                    if self.output_candidate_rp_advertisement is not None:
                        return True

                    if self.output_data_register is not None:
                        return True

                    if self.output_df_election is not None:
                        return True

                    if self.output_ecmp_redirect is not None:
                        return True

                    if self.output_hello is not None:
                        return True

                    if self.output_hello_bytes is not None:
                        return True

                    if self.output_join_group is not None:
                        return True

                    if self.output_join_prune_bytes is not None:
                        return True

                    if self.output_jp is not None:
                        return True

                    if self.output_loop_error is not None:
                        return True

                    if self.output_null_register is not None:
                        return True

                    if self.output_prune_group is not None:
                        return True

                    if self.output_register_stop is not None:
                        return True

                    if self.outputs is not None:
                        return True

                    if self.packet_dequeued is not None:
                        for child in self.packet_dequeued:
                            if child is not None:
                                return True

                    if self.packet_enqueued is not None:
                        for child in self.packet_enqueued:
                            if child is not None:
                                return True

                    if self.packet_packman_error is not None:
                        return True

                    if self.packet_queue is not None:
                        for child_ref in self.packet_queue:
                            if child_ref._has_data():
                                return True

                    if self.packet_queue_last_clear is not None:
                        return True

                    if self.packet_queue_length is not None:
                        for child in self.packet_queue_length:
                            if child is not None:
                                return True

                    if self.packet_queue_size is not None:
                        for child in self.packet_queue_size:
                            if child is not None:
                                return True

                    if self.packet_read_socket_error is not None:
                        return True

                    if self.packet_tail_drop is not None:
                        for child in self.packet_tail_drop:
                            if child is not None:
                                return True

                    if self.packets_standby is not None:
                        return True

                    if self.pakman_error is not None:
                        return True

                    if self.send_queue_full is not None:
                        return True

                    if self.socket_error is not None:
                        return True

                    if self.standby_packets_error is not None:
                        return True

                    if self.truncated_pim_packets is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.TrafficCounters']['meta_info']


            class GroupMapRpfs(object):
                """
                PIM group mapping information
                
                .. attribute:: group_map_rpf
                
                	PIM group mapping entry
                	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.group_map_rpf = YList()
                    self.group_map_rpf.parent = self
                    self.group_map_rpf.name = 'group_map_rpf'


                class GroupMapRpf(object):
                    """
                    PIM group mapping entry
                    
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\:  bool
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocolEnum>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_priority
                    
                    	RP priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.are_we_rp = None
                        self.client = None
                        self.group_map_information = Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self.prefix = None
                        self.prefix_length = None
                        self.protocol = None
                        self.rp_address = None
                        self.rp_priority = None
                        self.rpf_interface_name = None
                        self.rpf_neighbor = Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self.rpf_vrf_name = None


                    class RpfNeighbor(object):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor']['meta_info']


                    class GroupMapInformation(object):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.group_count = None
                            self.is_override = None
                            self.is_used = None
                            self.mrib_active = None
                            self.prefix = Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.priority = None
                            self.protocol = None
                            self.rp_address = Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self


                        class Prefix(object):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf/Cisco-IOS-XR-ipv4-pim-oper:group-map-information/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix']['meta_info']


                        class RpAddress(object):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf/Cisco-IOS-XR-ipv4-pim-oper:group-map-information/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.group_count is not None:
                                return True

                            if self.is_override is not None:
                                return True

                            if self.is_used is not None:
                                return True

                            if self.mrib_active is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.are_we_rp is not None:
                            return True

                        if self.client is not None:
                            return True

                        if self.group_map_information is not None and self.group_map_information._has_data():
                            return True

                        if self.prefix is not None:
                            return True

                        if self.prefix_length is not None:
                            return True

                        if self.protocol is not None:
                            return True

                        if self.rp_address is not None:
                            return True

                        if self.rp_priority is not None:
                            return True

                        if self.rpf_interface_name is not None:
                            return True

                        if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                            return True

                        if self.rpf_vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.group_map_rpf is not None:
                        for child_ref in self.group_map_rpf:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.GroupMapRpfs']['meta_info']


            class Summary(object):
                """
                PIM summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bsr_candidate_rp_set_count = None
                    self.bsr_candidate_rp_set_limit = None
                    self.bsr_candidate_rp_set_threshold = None
                    self.bsr_range_threshold = None
                    self.bsr_ranges_count = None
                    self.bsr_ranges_limit = None
                    self.global_auto_rp_ranges_limit = None
                    self.global_bsr_candidate_rp_set_count = None
                    self.global_bsr_candidate_rp_set_limit = None
                    self.global_bsr_candidate_rp_set_threshold = None
                    self.global_bsr_ranges_count = None
                    self.global_bsr_ranges_limit = None
                    self.global_bsr_ranges_threshold = None
                    self.global_register_limit = None
                    self.is_bsr_ranges_threshold_reached = None
                    self.is_global_auto_rp_ranges_limit_reached = None
                    self.is_global_bsr_ranges_limit_reached = None
                    self.is_global_register_limit_reached = None
                    self.is_global_route_limit_reached = None
                    self.is_global_rxi_limit_reached = None
                    self.is_maximum_enforcement_disabled = None
                    self.is_node_low_memory = None
                    self.is_ranges_limit_reached = None
                    self.is_route_limit_reached = None
                    self.ranges_count = None
                    self.ranges_limit = None
                    self.ranges_threshold = None
                    self.register_count = None
                    self.register_limit = None
                    self.register_limit_reached = None
                    self.register_threshold = None
                    self.route_count = None
                    self.route_limit = None
                    self.route_low_water_mark = None
                    self.route_threshold = None
                    self.rxi_limit_reached = None
                    self.rxi_low_water_mark = None
                    self.topology_interface_state_count = None
                    self.topology_interface_state_limit = None
                    self.topology_interface_state_threshold = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bsr_candidate_rp_set_count is not None:
                        return True

                    if self.bsr_candidate_rp_set_limit is not None:
                        return True

                    if self.bsr_candidate_rp_set_threshold is not None:
                        return True

                    if self.bsr_range_threshold is not None:
                        return True

                    if self.bsr_ranges_count is not None:
                        return True

                    if self.bsr_ranges_limit is not None:
                        return True

                    if self.global_auto_rp_ranges_limit is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_count is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_limit is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_threshold is not None:
                        return True

                    if self.global_bsr_ranges_count is not None:
                        return True

                    if self.global_bsr_ranges_limit is not None:
                        return True

                    if self.global_bsr_ranges_threshold is not None:
                        return True

                    if self.global_register_limit is not None:
                        return True

                    if self.is_bsr_ranges_threshold_reached is not None:
                        return True

                    if self.is_global_auto_rp_ranges_limit_reached is not None:
                        return True

                    if self.is_global_bsr_ranges_limit_reached is not None:
                        return True

                    if self.is_global_register_limit_reached is not None:
                        return True

                    if self.is_global_route_limit_reached is not None:
                        return True

                    if self.is_global_rxi_limit_reached is not None:
                        return True

                    if self.is_maximum_enforcement_disabled is not None:
                        return True

                    if self.is_node_low_memory is not None:
                        return True

                    if self.is_ranges_limit_reached is not None:
                        return True

                    if self.is_route_limit_reached is not None:
                        return True

                    if self.ranges_count is not None:
                        return True

                    if self.ranges_limit is not None:
                        return True

                    if self.ranges_threshold is not None:
                        return True

                    if self.register_count is not None:
                        return True

                    if self.register_limit is not None:
                        return True

                    if self.register_limit_reached is not None:
                        return True

                    if self.register_threshold is not None:
                        return True

                    if self.route_count is not None:
                        return True

                    if self.route_limit is not None:
                        return True

                    if self.route_low_water_mark is not None:
                        return True

                    if self.route_threshold is not None:
                        return True

                    if self.rxi_limit_reached is not None:
                        return True

                    if self.rxi_low_water_mark is not None:
                        return True

                    if self.topology_interface_state_count is not None:
                        return True

                    if self.topology_interface_state_limit is not None:
                        return True

                    if self.topology_interface_state_threshold is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.Summary']['meta_info']


            class Gre(object):
                """
                GRE information
                
                .. attribute:: gre_hashes
                
                	GRE hash
                	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreHashes>`
                
                .. attribute:: gre_next_hops
                
                	GRE destination neighbor table
                	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.gre_hashes = Pim.Active.DefaultContext.Gre.GreHashes()
                    self.gre_hashes.parent = self
                    self.gre_next_hops = Pim.Active.DefaultContext.Gre.GreNextHops()
                    self.gre_next_hops.parent = self


                class GreHashes(object):
                    """
                    GRE hash
                    
                    .. attribute:: gre_hash
                    
                    	PIM GRE Hashed Underlying Interface
                    	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreHashes.GreHash>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.gre_hash = YList()
                        self.gre_hash.parent = self
                        self.gre_hash.name = 'gre_hash'


                    class GreHash(object):
                        """
                        PIM GRE Hashed Underlying Interface
                        
                        .. attribute:: destination_address  <key>
                        
                        	Destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: ifname  <key>
                        
                        	GRE Tunnel Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: source_address  <key>
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: next_hop_interface
                        
                        	Next hop neighbor interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.destination_address = None
                            self.ifname = None
                            self.source_address = None
                            self.next_hop_interface = None

                        @property
                        def _common_path(self):
                            if self.destination_address is None:
                                raise YPYModelError('Key property destination_address is None')
                            if self.ifname is None:
                                raise YPYModelError('Key property ifname is None')
                            if self.source_address is None:
                                raise YPYModelError('Key property source_address is None')

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:gre/Cisco-IOS-XR-ipv4-pim-oper:gre-hashes/Cisco-IOS-XR-ipv4-pim-oper:gre-hash[Cisco-IOS-XR-ipv4-pim-oper:destination-address = ' + str(self.destination_address) + '][Cisco-IOS-XR-ipv4-pim-oper:ifname = ' + str(self.ifname) + '][Cisco-IOS-XR-ipv4-pim-oper:source-address = ' + str(self.source_address) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.destination_address is not None:
                                return True

                            if self.ifname is not None:
                                return True

                            if self.source_address is not None:
                                return True

                            if self.next_hop_interface is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Gre.GreHashes.GreHash']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:gre/Cisco-IOS-XR-ipv4-pim-oper:gre-hashes'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.gre_hash is not None:
                            for child_ref in self.gre_hash:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.Gre.GreHashes']['meta_info']


                class GreNextHops(object):
                    """
                    GRE destination neighbor table
                    
                    .. attribute:: gre_next_hop
                    
                    	PIM GRE address next\-hop information
                    	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.gre_next_hop = YList()
                        self.gre_next_hop.parent = self
                        self.gre_next_hop.name = 'gre_next_hop'


                    class GreNextHop(object):
                        """
                        PIM GRE address next\-hop information
                        
                        .. attribute:: destination_address  <key>
                        
                        	GRE destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: gre_path
                        
                        	GRE Paths list
                        	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath>`
                        
                        .. attribute:: is_connected
                        
                        	Are we connected ?
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: registered_address
                        
                        	Address registered
                        	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.destination_address = None
                            self.gre_path = YList()
                            self.gre_path.parent = self
                            self.gre_path.name = 'gre_path'
                            self.is_connected = None
                            self.metric = None
                            self.metric_preference = None
                            self.registered_address = Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                            self.registered_address.parent = self


                        class RegisteredAddress(object):
                            """
                            Address registered
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:registered-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress']['meta_info']


                        class GrePath(object):
                            """
                            GRE Paths list
                            
                            .. attribute:: extranet_vrf_name
                            
                            	Extranet VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: gre_interface_name
                            
                            	GRE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: gre_neighbor
                            
                            	GRE neighbor
                            	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                            
                            .. attribute:: gre_next_hop
                            
                            	GRE nexthop
                            	**type**\:   :py:class:`GreNextHop_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_>`
                            
                            .. attribute:: is_connector_attribute_present
                            
                            	Connector attribute present
                            	**type**\:  bool
                            
                            .. attribute:: is_gre_interface_disabled
                            
                            	Is the gre interface disabled ?
                            	**type**\:  bool
                            
                            .. attribute:: is_via_lsm
                            
                            	Via LSM
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.extranet_vrf_name = None
                                self.gre_interface_name = None
                                self.gre_neighbor = Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                self.gre_neighbor.parent = self
                                self.gre_next_hop = Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_()
                                self.gre_next_hop.parent = self
                                self.is_connector_attribute_present = None
                                self.is_gre_interface_disabled = None
                                self.is_via_lsm = None


                            class GreNeighbor(object):
                                """
                                GRE neighbor
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-neighbor'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor']['meta_info']


                            class GreNextHop_(object):
                                """
                                GRE nexthop
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-path'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.extranet_vrf_name is not None:
                                    return True

                                if self.gre_interface_name is not None:
                                    return True

                                if self.gre_neighbor is not None and self.gre_neighbor._has_data():
                                    return True

                                if self.gre_next_hop is not None and self.gre_next_hop._has_data():
                                    return True

                                if self.is_connector_attribute_present is not None:
                                    return True

                                if self.is_gre_interface_disabled is not None:
                                    return True

                                if self.is_via_lsm is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath']['meta_info']

                        @property
                        def _common_path(self):
                            if self.destination_address is None:
                                raise YPYModelError('Key property destination_address is None')

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:gre/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hops/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hop[Cisco-IOS-XR-ipv4-pim-oper:destination-address = ' + str(self.destination_address) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.destination_address is not None:
                                return True

                            if self.gre_path is not None:
                                for child_ref in self.gre_path:
                                    if child_ref._has_data():
                                        return True

                            if self.is_connected is not None:
                                return True

                            if self.metric is not None:
                                return True

                            if self.metric_preference is not None:
                                return True

                            if self.registered_address is not None and self.registered_address._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:gre/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hops'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.gre_next_hop is not None:
                            for child_ref in self.gre_next_hop:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.Gre.GreNextHops']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:gre'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.gre_hashes is not None and self.gre_hashes._has_data():
                        return True

                    if self.gre_next_hops is not None and self.gre_next_hops._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.Gre']['meta_info']


            class BidirDfWinners(object):
                """
                Bidirectional PIM DF election winner table
                
                .. attribute:: bidir_df_winner
                
                	Bidirectional PIM DF election table entry
                	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bidir_df_winner = YList()
                    self.bidir_df_winner.parent = self
                    self.bidir_df_winner.name = 'bidir_df_winner'


                class BidirDfWinner(object):
                    """
                    Bidirectional PIM DF election table entry
                    
                    .. attribute:: are_we_df
                    
                    	Are we DF
                    	**type**\:  bool
                    
                    .. attribute:: df_winner
                    
                    	DF Winner
                    	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner>`
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_preference
                    
                    	Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                    
                    .. attribute:: rp_lan
                    
                    	Is this the RP LAN
                    	**type**\:  bool
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.are_we_df = None
                        self.df_winner = Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner()
                        self.df_winner.parent = self
                        self.interface_name = None
                        self.metric = None
                        self.metric_preference = None
                        self.pim_interface_name = None
                        self.rp_address = None
                        self.rp_address_xr = Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self.rp_lan = None
                        self.uptime = None


                    class RpAddressXr(object):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winners/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winner/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr']['meta_info']


                    class DfWinner(object):
                        """
                        DF Winner
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winners/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winner/Cisco-IOS-XR-ipv4-pim-oper:df-winner'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winners/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winner'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.are_we_df is not None:
                            return True

                        if self.df_winner is not None and self.df_winner._has_data():
                            return True

                        if self.interface_name is not None:
                            return True

                        if self.metric is not None:
                            return True

                        if self.metric_preference is not None:
                            return True

                        if self.pim_interface_name is not None:
                            return True

                        if self.rp_address is not None:
                            return True

                        if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                            return True

                        if self.rp_lan is not None:
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winners'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bidir_df_winner is not None:
                        for child_ref in self.bidir_df_winner:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.BidirDfWinners']['meta_info']


            class TableContexts(object):
                """
                PIM table context list
                
                .. attribute:: table_context
                
                	PIM table context information
                	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TableContexts.TableContext>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.table_context = YList()
                    self.table_context.parent = self
                    self.table_context.name = 'table_context'


                class TableContext(object):
                    """
                    PIM table context information
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: saf_name
                    
                    	SAF name
                    	**type**\:   :py:class:`PimSafiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafiEnum>`
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: topology_name
                    
                    	Topology name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.afi = None
                        self.is_active = None
                        self.is_ital_registration_done = None
                        self.is_rib_convergence = None
                        self.is_rib_convergence_received = None
                        self.is_rib_registration_done = None
                        self.rpf_registrations = None
                        self.saf_name = None
                        self.safi = None
                        self.table_id = None
                        self.table_name = None
                        self.topology_name = None
                        self.vrf_id = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:table-contexts/Cisco-IOS-XR-ipv4-pim-oper:table-context'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.afi is not None:
                            return True

                        if self.is_active is not None:
                            return True

                        if self.is_ital_registration_done is not None:
                            return True

                        if self.is_rib_convergence is not None:
                            return True

                        if self.is_rib_convergence_received is not None:
                            return True

                        if self.is_rib_registration_done is not None:
                            return True

                        if self.rpf_registrations is not None:
                            return True

                        if self.saf_name is not None:
                            return True

                        if self.safi is not None:
                            return True

                        if self.table_id is not None:
                            return True

                        if self.table_name is not None:
                            return True

                        if self.topology_name is not None:
                            return True

                        if self.vrf_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.TableContexts.TableContext']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:table-contexts'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.table_context is not None:
                        for child_ref in self.table_context:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.TableContexts']['meta_info']


            class NeighborSummaries(object):
                """
                PIM neighbor summary table
                
                .. attribute:: neighbor_summary
                
                	PIM neighbor summary information
                	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.neighbor_summary = YList()
                    self.neighbor_summary.parent = self
                    self.neighbor_summary.name = 'neighbor_summary'


                class NeighborSummary(object):
                    """
                    PIM neighbor summary information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: number_of_external_neighbors
                    
                    	Number of external neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: number_of_neighbors
                    
                    	Number of neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.number_of_external_neighbors = None
                        self.number_of_neighbors = None

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbor-summaries/Cisco-IOS-XR-ipv4-pim-oper:neighbor-summary[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.number_of_external_neighbors is not None:
                            return True

                        if self.number_of_neighbors is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbor-summaries'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.neighbor_summary is not None:
                        for child_ref in self.neighbor_summary:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.NeighborSummaries']['meta_info']


            class Context(object):
                """
                PIM context information
                
                .. attribute:: active_table_count
                
                	Number of active Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: allow_rp_configured
                
                	Allow RP Configured
                	**type**\:  bool
                
                .. attribute:: allow_rp_group_list
                
                	Allow RP Group\-List ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: allow_rp_rp_list
                
                	Allow RP RP\-list ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: anycast_rp_configured
                
                	Anycast\-RP config
                	**type**\:  bool
                
                .. attribute:: anycast_rp_policy_name
                
                	Anycast\-RP Policy Name
                	**type**\:  str
                
                .. attribute:: anycast_rp_range
                
                	Anycast\-RP Ranges
                	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.AnycastRpRange>`
                
                .. attribute:: bgp_auto_discovery_configured
                
                	BGP Auto\-Discovery configured
                	**type**\:  bool
                
                .. attribute:: bgp_auto_discovery_type
                
                	BGP Auto Discovery Type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_i_pmsi_added
                
                	BGP I\-PMSI Added
                	**type**\:  bool
                
                .. attribute:: bgp_remote_address
                
                	BGP remote interface address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: bgp_remote_interface
                
                	BGP remote interface handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: bgp_remote_interface_name
                
                	BGP remote interface name
                	**type**\:  str
                
                .. attribute:: bgp_remote_on
                
                	BGP remote interface status
                	**type**\:  bool
                
                .. attribute:: bgp_remote_state
                
                	BGP remote interface state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_source_active_announce
                
                	Send BGP Source\-Active Announcements
                	**type**\:  bool
                
                .. attribute:: export_route_target
                
                	Export Route Targets
                	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.ExportRouteTarget>`
                
                .. attribute:: gin_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: gin_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: gin_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: import_route_target
                
                	Import Route Targets
                	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.ImportRouteTarget>`
                
                .. attribute:: in_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: in_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: in_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_signaling_local_enabled
                
                	Inband signaling Local enabled
                	**type**\:  bool
                
                .. attribute:: in_band_signaling_remote_enabled
                
                	Inband signaling Remote enabled
                	**type**\:  bool
                
                .. attribute:: inter_autonomous_system_enabled
                
                	Inter\-AS Enabled
                	**type**\:  bool
                
                .. attribute:: ir_maximum_mdt_aggregation
                
                	IR MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_announce_interval
                
                	IR Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_switchover_interval
                
                	IR Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_interface
                
                	IRMDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: ir_mdt_mtu
                
                	IRMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_name
                
                	IR MDT Name
                	**type**\:  str
                
                .. attribute:: ir_mdt_rpf_identifier
                
                	IR RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_tail_label
                
                	IR Tail Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_active
                
                	Active
                	**type**\:  bool
                
                .. attribute:: is_active_ital
                
                	Active ITAL
                	**type**\:  bool
                
                .. attribute:: is_all_interface_disable_operation
                
                	PIM all interface disable operation
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_enabled
                
                	Auto RP Listen Enabled
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_sock_add
                
                	Auto RP listen sock add
                	**type**\:  bool
                
                .. attribute:: is_create_gin_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_in_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_ir_mdt_interface
                
                	Create IR MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mdt_interface
                
                	Create MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mldp_mdt_interface
                
                	Create MLDP MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_rsvp_te_mdt_interface
                
                	Create RSVP\-TE MDT interface
                	**type**\:  bool
                
                .. attribute:: is_default_granges
                
                	Default granges
                	**type**\:  bool
                
                .. attribute:: is_gin_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_in_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_ir_mdt_owner
                
                	IR MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_add_required
                
                	VRF LPTS filter required on Socket
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_added
                
                	VRF LPTS filter added on Socket
                	**type**\:  bool
                
                .. attribute:: is_m_host_publish_pending
                
                	Publish pending for MHost Default interface
                	**type**\:  bool
                
                .. attribute:: is_mdt_owner
                
                	MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mldp_mdt_owner
                
                	MLDP MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mrib_register
                
                	MRIB Register
                	**type**\:  bool
                
                .. attribute:: is_multicast_rib_registration
                
                	Mcast RIB Registration
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converge_received
                
                	PIM NSF RIB converge received
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converged
                
                	PIM NSF RIB converged
                	**type**\:  bool
                
                .. attribute:: is_redistribution_reset
                
                	Pending redist reset
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_add_required
                
                	VRF LPTS filter required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_added
                
                	VRF LPTS filter added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_add_required
                
                	VRF required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_added
                
                	VRF added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_enabled
                
                	PIM RIB multiplath enabled
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_interface_hash
                
                	PIM RIB multipath interface hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_hash
                
                	PIM RIB multipath source based hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_next_hop_hash
                
                	PIM RIB multipath source\-nexthop hash
                	**type**\:  bool
                
                .. attribute:: is_routing_enabled
                
                	Routing Enabled
                	**type**\:  bool
                
                .. attribute:: is_rsvp_te_mdt_owner
                
                	RSVP\-TE MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_socket_add_required
                
                	VRF required on Socket
                	**type**\:  bool
                
                .. attribute:: is_socket_added
                
                	VRF added on Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_add_required
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_added
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind
                
                	VRF bound on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind_required
                
                	VRF bind required on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_unicast_rib_registration
                
                	Ucast RIB Registration
                	**type**\:  bool
                
                .. attribute:: maximum_mdt_aggregation
                
                	MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_announce_interval
                
                	Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_switchover_interval
                
                	Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_default_group
                
                	MDT Default group
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_gre_remote_rpf_identifier
                
                	GRE\-MDT Remote RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_gre_rpf_identifier
                
                	GRE\-MDT RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_interface
                
                	MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mdt_mtu
                
                	MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_neighbor_filter_name
                
                	MDT Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: mdt_partitioned_ir_control_identifier
                
                	Partitioned IR MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_partitioned_mdt_control_identifier
                
                	Partitioned MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mhost_default_interface_config
                
                	Configured Mhost Defint
                	**type**\:  str
                
                .. attribute:: mhost_interface
                
                	MHost handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mldp_auto_rp_announce_tree_added
                
                	MLDP Autorp Announce Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_auto_rp_discovery_tree_added
                
                	MLDP Autorp Discovery Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_bsr_control_tree_added
                
                	MLDP BSR Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_control_head_lsm_identifier
                
                	MLDP MVPN Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_local_label
                
                	Partitioned MDT Head local label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_lsm_identifier
                
                	MLDP Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_maximum_mdt_aggregation
                
                	MLDP MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_announce_interval
                
                	MLDP Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_switchover_interval
                
                	MLDP Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_interface
                
                	MLDP MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mldp_mdt_mtu
                
                	MLDP MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_name
                
                	MLDP MDT Name
                	**type**\:  str
                
                .. attribute:: mldp_mdt_remote_rpf_identifier
                
                	MLDP Remote RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_rpf_identifier
                
                	MLDP RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partioned_mp2m_ptree
                
                	MP2MP Partitioned MDT tree
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_head_lsm_identifier
                
                	Partitioned MDT Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partitioned_mdt_configured
                
                	MLDP Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_mdt_identifier
                
                	MLDP Partitioned MDT Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_head_lsm_identifier
                
                	MLDP Remote Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_partitioned_mdt_configured
                
                	MLDP Remote Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_root_address
                
                	MLDP Root addresses
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_root_count
                
                	MLDP Root count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: murib_id
                
                	MURIB ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: neighbor_filter_name
                
                	Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: non_default_vrf_count_on_socket
                
                	Count of non\-default vrfs on raw socket
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: organization_unique_identifier
                
                	OUI for VPN\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: p2mpte_li_drop
                
                	Route LI updates dropped for P2MP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: redistribution_reset_count
                
                	Redist reset count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_default_group
                
                	Remote Default Group
                	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.RemoteDefaultGroup>`
                
                .. attribute:: remote_table_id
                
                	Remote Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_distinguisher
                
                	RD value
                	**type**\:  str
                
                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                
                .. attribute:: rpf_default_table
                
                	RPF Default Table
                	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.RpfDefaultTable>`
                
                .. attribute:: rpf_id
                
                	RPF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rpf_policy_name
                
                	RPF topology selection route\-policy name
                	**type**\:  str
                
                .. attribute:: rsvp_te_maximum_mdt_aggregation
                
                	RSVP\-TE MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_announce_interval
                
                	RSVP\-TE Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_switchover_interval
                
                	RSVP\-TE Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_interface
                
                	RSVP\-TEMDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: rsvp_te_mdt_mtu
                
                	RSVP\-TEMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_name
                
                	RSVP\-TE MDT Name
                	**type**\:  str
                
                .. attribute:: rsvp_te_mdt_rpf_identifier
                
                	RSVP\-TE RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_static_p2mp_count
                
                	Number of Static P2MP\-TE MDT
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	PIM is using MuRIB
                	**type**\:  bool
                
                .. attribute:: sg_expiry_time
                
                	S,G Expiry Time Configured, in seconds
                	**type**\:  int
                
                	**range:** 0..65535
                
                	**units**\: second
                
                .. attribute:: sg_expiry_timer_configured
                
                	S,G Expiry Timer Configured
                	**type**\:  bool
                
                .. attribute:: sg_expiry_timer_sg_list
                
                	S,G expiry timer ACL name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: stale_rd_present
                
                	RD is stale
                	**type**\:  bool
                
                .. attribute:: suppress_pim_data_mdt_tlv
                
                	Suppress PIM Data\-MDT TLV Announcements
                	**type**\:  bool
                
                .. attribute:: suppress_shared_tree_join
                
                	Suppress Shared\-Tree Joins
                	**type**\:  bool
                
                .. attribute:: table_count
                
                	Number of configured Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: table_id
                
                	Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: umh
                
                	Join UMH Core\-Tree
                	**type**\:  bool
                
                .. attribute:: valid_rd_present
                
                	RD is valid
                	**type**\:  bool
                
                .. attribute:: vpn_index
                
                	VPN Index
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vrf_id
                
                	VRF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.active_table_count = None
                    self.allow_rp_configured = None
                    self.allow_rp_group_list = None
                    self.allow_rp_rp_list = None
                    self.anycast_rp_configured = None
                    self.anycast_rp_policy_name = None
                    self.anycast_rp_range = YList()
                    self.anycast_rp_range.parent = self
                    self.anycast_rp_range.name = 'anycast_rp_range'
                    self.bgp_auto_discovery_configured = None
                    self.bgp_auto_discovery_type = None
                    self.bgp_i_pmsi_added = None
                    self.bgp_remote_address = None
                    self.bgp_remote_interface = None
                    self.bgp_remote_interface_name = None
                    self.bgp_remote_on = None
                    self.bgp_remote_state = None
                    self.bgp_source_active_announce = None
                    self.export_route_target = YList()
                    self.export_route_target.parent = self
                    self.export_route_target.name = 'export_route_target'
                    self.gin_b_and_mdt_data_announce_interval = None
                    self.gin_b_and_mdt_data_switchover_interval = None
                    self.gin_b_and_mdt_interface = None
                    self.gin_b_and_mdt_mtu = None
                    self.gin_b_and_mdt_name = None
                    self.gin_b_and_mdt_rpf_identifier = None
                    self.gin_band_maximum_mdt_aggregation = None
                    self.import_route_target = YList()
                    self.import_route_target.parent = self
                    self.import_route_target.name = 'import_route_target'
                    self.in_b_and_mdt_data_announce_interval = None
                    self.in_b_and_mdt_data_switchover_interval = None
                    self.in_b_and_mdt_interface = None
                    self.in_b_and_mdt_mtu = None
                    self.in_b_and_mdt_name = None
                    self.in_b_and_mdt_rpf_identifier = None
                    self.in_band_maximum_mdt_aggregation = None
                    self.in_band_signaling_local_enabled = None
                    self.in_band_signaling_remote_enabled = None
                    self.inter_autonomous_system_enabled = None
                    self.ir_maximum_mdt_aggregation = None
                    self.ir_mdt_data_announce_interval = None
                    self.ir_mdt_data_switchover_interval = None
                    self.ir_mdt_interface = None
                    self.ir_mdt_mtu = None
                    self.ir_mdt_name = None
                    self.ir_mdt_rpf_identifier = None
                    self.ir_mdt_tail_label = None
                    self.is_active = None
                    self.is_active_ital = None
                    self.is_all_interface_disable_operation = None
                    self.is_auto_rp_listen_enabled = None
                    self.is_auto_rp_listen_sock_add = None
                    self.is_create_gin_b_and_mdt_interface = None
                    self.is_create_in_b_and_mdt_interface = None
                    self.is_create_ir_mdt_interface = None
                    self.is_create_mdt_interface = None
                    self.is_create_mldp_mdt_interface = None
                    self.is_create_rsvp_te_mdt_interface = None
                    self.is_default_granges = None
                    self.is_gin_b_and_mdt_owner = None
                    self.is_in_b_and_mdt_owner = None
                    self.is_ir_mdt_owner = None
                    self.is_lpts_socket_add_required = None
                    self.is_lpts_socket_added = None
                    self.is_m_host_publish_pending = None
                    self.is_mdt_owner = None
                    self.is_mldp_mdt_owner = None
                    self.is_mrib_register = None
                    self.is_multicast_rib_registration = None
                    self.is_pim_nsf_rib_converge_received = None
                    self.is_pim_nsf_rib_converged = None
                    self.is_redistribution_reset = None
                    self.is_register_injection_lpts_socket_add_required = None
                    self.is_register_injection_lpts_socket_added = None
                    self.is_register_injection_socket_add_required = None
                    self.is_register_injection_socket_added = None
                    self.is_rib_multipath_enabled = None
                    self.is_rib_multipath_interface_hash = None
                    self.is_rib_multipath_source_hash = None
                    self.is_rib_multipath_source_next_hop_hash = None
                    self.is_routing_enabled = None
                    self.is_rsvp_te_mdt_owner = None
                    self.is_socket_add_required = None
                    self.is_socket_added = None
                    self.is_udp_socket_add_required = None
                    self.is_udp_socket_added = None
                    self.is_udp_socket_bind = None
                    self.is_udp_socket_bind_required = None
                    self.is_unicast_rib_registration = None
                    self.maximum_mdt_aggregation = None
                    self.mdt_data_announce_interval = None
                    self.mdt_data_switchover_interval = None
                    self.mdt_default_group = None
                    self.mdt_gre_remote_rpf_identifier = None
                    self.mdt_gre_rpf_identifier = None
                    self.mdt_interface = None
                    self.mdt_mtu = None
                    self.mdt_neighbor_filter_name = None
                    self.mdt_partitioned_ir_control_identifier = None
                    self.mdt_partitioned_mdt_control_identifier = None
                    self.mhost_default_interface_config = None
                    self.mhost_interface = None
                    self.mldp_auto_rp_announce_tree_added = None
                    self.mldp_auto_rp_discovery_tree_added = None
                    self.mldp_bsr_control_tree_added = None
                    self.mldp_control_head_lsm_identifier = None
                    self.mldp_head_local_label = None
                    self.mldp_head_lsm_identifier = None
                    self.mldp_maximum_mdt_aggregation = None
                    self.mldp_mdt_data_announce_interval = None
                    self.mldp_mdt_data_switchover_interval = None
                    self.mldp_mdt_interface = None
                    self.mldp_mdt_mtu = None
                    self.mldp_mdt_name = None
                    self.mldp_mdt_remote_rpf_identifier = None
                    self.mldp_mdt_rpf_identifier = None
                    self.mldp_partioned_mp2m_ptree = None
                    self.mldp_partitioned_head_lsm_identifier = None
                    self.mldp_partitioned_mdt_configured = None
                    self.mldp_partitioned_mdt_identifier = None
                    self.mldp_remote_head_lsm_identifier = None
                    self.mldp_remote_partitioned_mdt_configured = None
                    self.mldp_root_address = YLeafList()
                    self.mldp_root_address.parent = self
                    self.mldp_root_address.name = 'mldp_root_address'
                    self.mldp_root_count = None
                    self.murib_id = None
                    self.neighbor_filter_name = None
                    self.non_default_vrf_count_on_socket = None
                    self.organization_unique_identifier = None
                    self.p2mpte_li_drop = None
                    self.redistribution_reset_count = None
                    self.remote_default_group = Pim.Active.DefaultContext.Context.RemoteDefaultGroup()
                    self.remote_default_group.parent = self
                    self.remote_table_id = None
                    self.route_distinguisher = None
                    self.rpf_default_table = Pim.Active.DefaultContext.Context.RpfDefaultTable()
                    self.rpf_default_table.parent = self
                    self.rpf_id = None
                    self.rpf_policy_name = None
                    self.rsvp_te_maximum_mdt_aggregation = None
                    self.rsvp_te_mdt_data_announce_interval = None
                    self.rsvp_te_mdt_data_switchover_interval = None
                    self.rsvp_te_mdt_interface = None
                    self.rsvp_te_mdt_mtu = None
                    self.rsvp_te_mdt_name = None
                    self.rsvp_te_mdt_rpf_identifier = None
                    self.rsvp_te_mdt_static_p2mp_count = None
                    self.rump_enabled = None
                    self.sg_expiry_time = None
                    self.sg_expiry_timer_configured = None
                    self.sg_expiry_timer_sg_list = None
                    self.stale_rd_present = None
                    self.suppress_pim_data_mdt_tlv = None
                    self.suppress_shared_tree_join = None
                    self.table_count = None
                    self.table_id = None
                    self.umh = None
                    self.valid_rd_present = None
                    self.vpn_index = None
                    self.vrf_id = None


                class RemoteDefaultGroup(object):
                    """
                    Remote Default Group
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.af_name = None
                        self.ipv4_address = None
                        self.ipv6_address = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:remote-default-group'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.af_name is not None:
                            return True

                        if self.ipv4_address is not None:
                            return True

                        if self.ipv6_address is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.Context.RemoteDefaultGroup']['meta_info']


                class RpfDefaultTable(object):
                    """
                    RPF Default Table
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.afi = None
                        self.is_active = None
                        self.is_ital_registration_done = None
                        self.is_rib_convergence = None
                        self.is_rib_convergence_received = None
                        self.is_rib_registration_done = None
                        self.rpf_registrations = None
                        self.safi = None
                        self.table_id = None
                        self.table_name = None
                        self.vrf_id = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:rpf-default-table'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.afi is not None:
                            return True

                        if self.is_active is not None:
                            return True

                        if self.is_ital_registration_done is not None:
                            return True

                        if self.is_rib_convergence is not None:
                            return True

                        if self.is_rib_convergence_received is not None:
                            return True

                        if self.is_rib_registration_done is not None:
                            return True

                        if self.rpf_registrations is not None:
                            return True

                        if self.safi is not None:
                            return True

                        if self.table_id is not None:
                            return True

                        if self.table_name is not None:
                            return True

                        if self.vrf_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.Context.RpfDefaultTable']['meta_info']


                class ExportRouteTarget(object):
                    """
                    Export Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.anycast_rp = None
                        self.anycast_rp_marked = None
                        self.bgp_auto_discovery = None
                        self.configured = None
                        self.route_target = None
                        self.segment_border = None
                        self.update_pending = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:export-route-target'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.anycast_rp is not None:
                            return True

                        if self.anycast_rp_marked is not None:
                            return True

                        if self.bgp_auto_discovery is not None:
                            return True

                        if self.configured is not None:
                            return True

                        if self.route_target is not None:
                            return True

                        if self.segment_border is not None:
                            return True

                        if self.update_pending is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.Context.ExportRouteTarget']['meta_info']


                class ImportRouteTarget(object):
                    """
                    Import Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.anycast_rp = None
                        self.anycast_rp_marked = None
                        self.bgp_auto_discovery = None
                        self.configured = None
                        self.route_target = None
                        self.segment_border = None
                        self.update_pending = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:import-route-target'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.anycast_rp is not None:
                            return True

                        if self.anycast_rp_marked is not None:
                            return True

                        if self.bgp_auto_discovery is not None:
                            return True

                        if self.configured is not None:
                            return True

                        if self.route_target is not None:
                            return True

                        if self.segment_border is not None:
                            return True

                        if self.update_pending is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.Context.ImportRouteTarget']['meta_info']


                class AnycastRpRange(object):
                    """
                    Anycast\-RP Ranges
                    
                    .. attribute:: ancast_rp_marked
                    
                    	Anycast\-RP Range marked
                    	**type**\:  bool
                    
                    .. attribute:: prefix
                    
                    	Anycast\-RP Range Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Anycast\-RP Range Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ancast_rp_marked = None
                        self.prefix = Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix()
                        self.prefix.parent = self
                        self.prefix_length = None


                    class Prefix(object):
                        """
                        Anycast\-RP Range Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:anycast-rp-range/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:anycast-rp-range'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ancast_rp_marked is not None:
                            return True

                        if self.prefix is not None and self.prefix._has_data():
                            return True

                        if self.prefix_length is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.Context.AnycastRpRange']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.active_table_count is not None:
                        return True

                    if self.allow_rp_configured is not None:
                        return True

                    if self.allow_rp_group_list is not None:
                        return True

                    if self.allow_rp_rp_list is not None:
                        return True

                    if self.anycast_rp_configured is not None:
                        return True

                    if self.anycast_rp_policy_name is not None:
                        return True

                    if self.anycast_rp_range is not None:
                        for child_ref in self.anycast_rp_range:
                            if child_ref._has_data():
                                return True

                    if self.bgp_auto_discovery_configured is not None:
                        return True

                    if self.bgp_auto_discovery_type is not None:
                        return True

                    if self.bgp_i_pmsi_added is not None:
                        return True

                    if self.bgp_remote_address is not None:
                        return True

                    if self.bgp_remote_interface is not None:
                        return True

                    if self.bgp_remote_interface_name is not None:
                        return True

                    if self.bgp_remote_on is not None:
                        return True

                    if self.bgp_remote_state is not None:
                        return True

                    if self.bgp_source_active_announce is not None:
                        return True

                    if self.export_route_target is not None:
                        for child_ref in self.export_route_target:
                            if child_ref._has_data():
                                return True

                    if self.gin_b_and_mdt_data_announce_interval is not None:
                        return True

                    if self.gin_b_and_mdt_data_switchover_interval is not None:
                        return True

                    if self.gin_b_and_mdt_interface is not None:
                        return True

                    if self.gin_b_and_mdt_mtu is not None:
                        return True

                    if self.gin_b_and_mdt_name is not None:
                        return True

                    if self.gin_b_and_mdt_rpf_identifier is not None:
                        return True

                    if self.gin_band_maximum_mdt_aggregation is not None:
                        return True

                    if self.import_route_target is not None:
                        for child_ref in self.import_route_target:
                            if child_ref._has_data():
                                return True

                    if self.in_b_and_mdt_data_announce_interval is not None:
                        return True

                    if self.in_b_and_mdt_data_switchover_interval is not None:
                        return True

                    if self.in_b_and_mdt_interface is not None:
                        return True

                    if self.in_b_and_mdt_mtu is not None:
                        return True

                    if self.in_b_and_mdt_name is not None:
                        return True

                    if self.in_b_and_mdt_rpf_identifier is not None:
                        return True

                    if self.in_band_maximum_mdt_aggregation is not None:
                        return True

                    if self.in_band_signaling_local_enabled is not None:
                        return True

                    if self.in_band_signaling_remote_enabled is not None:
                        return True

                    if self.inter_autonomous_system_enabled is not None:
                        return True

                    if self.ir_maximum_mdt_aggregation is not None:
                        return True

                    if self.ir_mdt_data_announce_interval is not None:
                        return True

                    if self.ir_mdt_data_switchover_interval is not None:
                        return True

                    if self.ir_mdt_interface is not None:
                        return True

                    if self.ir_mdt_mtu is not None:
                        return True

                    if self.ir_mdt_name is not None:
                        return True

                    if self.ir_mdt_rpf_identifier is not None:
                        return True

                    if self.ir_mdt_tail_label is not None:
                        return True

                    if self.is_active is not None:
                        return True

                    if self.is_active_ital is not None:
                        return True

                    if self.is_all_interface_disable_operation is not None:
                        return True

                    if self.is_auto_rp_listen_enabled is not None:
                        return True

                    if self.is_auto_rp_listen_sock_add is not None:
                        return True

                    if self.is_create_gin_b_and_mdt_interface is not None:
                        return True

                    if self.is_create_in_b_and_mdt_interface is not None:
                        return True

                    if self.is_create_ir_mdt_interface is not None:
                        return True

                    if self.is_create_mdt_interface is not None:
                        return True

                    if self.is_create_mldp_mdt_interface is not None:
                        return True

                    if self.is_create_rsvp_te_mdt_interface is not None:
                        return True

                    if self.is_default_granges is not None:
                        return True

                    if self.is_gin_b_and_mdt_owner is not None:
                        return True

                    if self.is_in_b_and_mdt_owner is not None:
                        return True

                    if self.is_ir_mdt_owner is not None:
                        return True

                    if self.is_lpts_socket_add_required is not None:
                        return True

                    if self.is_lpts_socket_added is not None:
                        return True

                    if self.is_m_host_publish_pending is not None:
                        return True

                    if self.is_mdt_owner is not None:
                        return True

                    if self.is_mldp_mdt_owner is not None:
                        return True

                    if self.is_mrib_register is not None:
                        return True

                    if self.is_multicast_rib_registration is not None:
                        return True

                    if self.is_pim_nsf_rib_converge_received is not None:
                        return True

                    if self.is_pim_nsf_rib_converged is not None:
                        return True

                    if self.is_redistribution_reset is not None:
                        return True

                    if self.is_register_injection_lpts_socket_add_required is not None:
                        return True

                    if self.is_register_injection_lpts_socket_added is not None:
                        return True

                    if self.is_register_injection_socket_add_required is not None:
                        return True

                    if self.is_register_injection_socket_added is not None:
                        return True

                    if self.is_rib_multipath_enabled is not None:
                        return True

                    if self.is_rib_multipath_interface_hash is not None:
                        return True

                    if self.is_rib_multipath_source_hash is not None:
                        return True

                    if self.is_rib_multipath_source_next_hop_hash is not None:
                        return True

                    if self.is_routing_enabled is not None:
                        return True

                    if self.is_rsvp_te_mdt_owner is not None:
                        return True

                    if self.is_socket_add_required is not None:
                        return True

                    if self.is_socket_added is not None:
                        return True

                    if self.is_udp_socket_add_required is not None:
                        return True

                    if self.is_udp_socket_added is not None:
                        return True

                    if self.is_udp_socket_bind is not None:
                        return True

                    if self.is_udp_socket_bind_required is not None:
                        return True

                    if self.is_unicast_rib_registration is not None:
                        return True

                    if self.maximum_mdt_aggregation is not None:
                        return True

                    if self.mdt_data_announce_interval is not None:
                        return True

                    if self.mdt_data_switchover_interval is not None:
                        return True

                    if self.mdt_default_group is not None:
                        return True

                    if self.mdt_gre_remote_rpf_identifier is not None:
                        return True

                    if self.mdt_gre_rpf_identifier is not None:
                        return True

                    if self.mdt_interface is not None:
                        return True

                    if self.mdt_mtu is not None:
                        return True

                    if self.mdt_neighbor_filter_name is not None:
                        return True

                    if self.mdt_partitioned_ir_control_identifier is not None:
                        return True

                    if self.mdt_partitioned_mdt_control_identifier is not None:
                        return True

                    if self.mhost_default_interface_config is not None:
                        return True

                    if self.mhost_interface is not None:
                        return True

                    if self.mldp_auto_rp_announce_tree_added is not None:
                        return True

                    if self.mldp_auto_rp_discovery_tree_added is not None:
                        return True

                    if self.mldp_bsr_control_tree_added is not None:
                        return True

                    if self.mldp_control_head_lsm_identifier is not None:
                        return True

                    if self.mldp_head_local_label is not None:
                        return True

                    if self.mldp_head_lsm_identifier is not None:
                        return True

                    if self.mldp_maximum_mdt_aggregation is not None:
                        return True

                    if self.mldp_mdt_data_announce_interval is not None:
                        return True

                    if self.mldp_mdt_data_switchover_interval is not None:
                        return True

                    if self.mldp_mdt_interface is not None:
                        return True

                    if self.mldp_mdt_mtu is not None:
                        return True

                    if self.mldp_mdt_name is not None:
                        return True

                    if self.mldp_mdt_remote_rpf_identifier is not None:
                        return True

                    if self.mldp_mdt_rpf_identifier is not None:
                        return True

                    if self.mldp_partioned_mp2m_ptree is not None:
                        return True

                    if self.mldp_partitioned_head_lsm_identifier is not None:
                        return True

                    if self.mldp_partitioned_mdt_configured is not None:
                        return True

                    if self.mldp_partitioned_mdt_identifier is not None:
                        return True

                    if self.mldp_remote_head_lsm_identifier is not None:
                        return True

                    if self.mldp_remote_partitioned_mdt_configured is not None:
                        return True

                    if self.mldp_root_address is not None:
                        for child in self.mldp_root_address:
                            if child is not None:
                                return True

                    if self.mldp_root_count is not None:
                        return True

                    if self.murib_id is not None:
                        return True

                    if self.neighbor_filter_name is not None:
                        return True

                    if self.non_default_vrf_count_on_socket is not None:
                        return True

                    if self.organization_unique_identifier is not None:
                        return True

                    if self.p2mpte_li_drop is not None:
                        return True

                    if self.redistribution_reset_count is not None:
                        return True

                    if self.remote_default_group is not None and self.remote_default_group._has_data():
                        return True

                    if self.remote_table_id is not None:
                        return True

                    if self.route_distinguisher is not None:
                        return True

                    if self.rpf_default_table is not None and self.rpf_default_table._has_data():
                        return True

                    if self.rpf_id is not None:
                        return True

                    if self.rpf_policy_name is not None:
                        return True

                    if self.rsvp_te_maximum_mdt_aggregation is not None:
                        return True

                    if self.rsvp_te_mdt_data_announce_interval is not None:
                        return True

                    if self.rsvp_te_mdt_data_switchover_interval is not None:
                        return True

                    if self.rsvp_te_mdt_interface is not None:
                        return True

                    if self.rsvp_te_mdt_mtu is not None:
                        return True

                    if self.rsvp_te_mdt_name is not None:
                        return True

                    if self.rsvp_te_mdt_rpf_identifier is not None:
                        return True

                    if self.rsvp_te_mdt_static_p2mp_count is not None:
                        return True

                    if self.rump_enabled is not None:
                        return True

                    if self.sg_expiry_time is not None:
                        return True

                    if self.sg_expiry_timer_configured is not None:
                        return True

                    if self.sg_expiry_timer_sg_list is not None:
                        return True

                    if self.stale_rd_present is not None:
                        return True

                    if self.suppress_pim_data_mdt_tlv is not None:
                        return True

                    if self.suppress_shared_tree_join is not None:
                        return True

                    if self.table_count is not None:
                        return True

                    if self.table_id is not None:
                        return True

                    if self.umh is not None:
                        return True

                    if self.valid_rd_present is not None:
                        return True

                    if self.vpn_index is not None:
                        return True

                    if self.vrf_id is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.Context']['meta_info']


            class TopologyEntryFlagRouteCounts(object):
                """
                Route count for topology with entry flag set
                
                .. attribute:: topology_entry_flag_route_count
                
                	Route count for topology with entry flag set
                	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.topology_entry_flag_route_count = YList()
                    self.topology_entry_flag_route_count.parent = self
                    self.topology_entry_flag_route_count.name = 'topology_entry_flag_route_count'


                class TopologyEntryFlagRouteCount(object):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: entry_flag  <key>
                    
                    	entry flag
                    	**type**\:   :py:class:`PimTopologyEntryFlagEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlagEnum>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.entry_flag = None
                        self.active_group_ranges = None
                        self.group_address = Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self.group_ranges = None
                        self.groute_count = None
                        self.is_node_low_memory = None
                        self.sg_route_count = None
                        self.sgr_route_count = None


                    class GroupAddress(object):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.entry_flag is None:
                            raise YPYModelError('Key property entry_flag is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-entry-flag-route-counts/Cisco-IOS-XR-ipv4-pim-oper:topology-entry-flag-route-count[Cisco-IOS-XR-ipv4-pim-oper:entry-flag = ' + str(self.entry_flag) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.entry_flag is not None:
                            return True

                        if self.active_group_ranges is not None:
                            return True

                        if self.group_address is not None and self.group_address._has_data():
                            return True

                        if self.group_ranges is not None:
                            return True

                        if self.groute_count is not None:
                            return True

                        if self.is_node_low_memory is not None:
                            return True

                        if self.sg_route_count is not None:
                            return True

                        if self.sgr_route_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-entry-flag-route-counts'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.topology_entry_flag_route_count is not None:
                        for child_ref in self.topology_entry_flag_route_count:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts']['meta_info']


            class RpfRedirect(object):
                """
                PIM ECMP RPF\-redirect bundle
                
                .. attribute:: bundle_interfaces
                
                	PIM ECMP RPF\-redirect bundle information
                	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces>`
                
                .. attribute:: redirect_route_databases
                
                	PIM ECMP RPF\-redirect route database
                	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bundle_interfaces = Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces()
                    self.bundle_interfaces.parent = self
                    self.redirect_route_databases = Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases()
                    self.redirect_route_databases.parent = self


                class RedirectRouteDatabases(object):
                    """
                    PIM ECMP RPF\-redirect route database
                    
                    .. attribute:: redirect_route_database
                    
                    	PIM ECMP RPF\-redirect route information
                    	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.redirect_route_database = YList()
                        self.redirect_route_database.parent = self
                        self.redirect_route_database.name = 'redirect_route_database'


                    class RedirectRouteDatabase(object):
                        """
                        PIM ECMP RPF\-redirect route information
                        
                        .. attribute:: bandwidth
                        
                        	Bandwidth in Kbps
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group ddress
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                        
                        .. attribute:: interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bandwidth = None
                            self.group_address = None
                            self.group_address_xr = Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self.interface = YList()
                            self.interface.parent = self
                            self.interface.name = 'interface'
                            self.source_address = None
                            self.source_address_xr = Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self.uptime = None


                        class GroupAddressXr(object):
                            """
                            Group ddress
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr']['meta_info']


                        class SourceAddressXr(object):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr']['meta_info']


                        class Interface(object):
                            """
                            Outgoing interface list
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_outgoing_interface
                            
                            	Is outgoing Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_rpf_interface
                            
                            	Is RPF Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_snoop_interface
                            
                            	Is snooping Interface
                            	**type**\:  bool
                            
                            .. attribute:: rpf_address
                            
                            	RPF Address
                            	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.expiry = None
                                self.interface_name = None
                                self.is_outgoing_interface = None
                                self.is_rpf_interface = None
                                self.is_snoop_interface = None
                                self.rpf_address = Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                self.rpf_address.parent = self
                                self.uptime = None


                            class RpfAddress(object):
                                """
                                RPF Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database/Cisco-IOS-XR-ipv4-pim-oper:interface/Cisco-IOS-XR-ipv4-pim-oper:rpf-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database/Cisco-IOS-XR-ipv4-pim-oper:interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.expiry is not None:
                                    return True

                                if self.interface_name is not None:
                                    return True

                                if self.is_outgoing_interface is not None:
                                    return True

                                if self.is_rpf_interface is not None:
                                    return True

                                if self.is_snoop_interface is not None:
                                    return True

                                if self.rpf_address is not None and self.rpf_address._has_data():
                                    return True

                                if self.uptime is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bandwidth is not None:
                                return True

                            if self.group_address is not None:
                                return True

                            if self.group_address_xr is not None and self.group_address_xr._has_data():
                                return True

                            if self.interface is not None:
                                for child_ref in self.interface:
                                    if child_ref._has_data():
                                        return True

                            if self.source_address is not None:
                                return True

                            if self.source_address_xr is not None and self.source_address_xr._has_data():
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.redirect_route_database is not None:
                            for child_ref in self.redirect_route_database:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases']['meta_info']


                class BundleInterfaces(object):
                    """
                    PIM ECMP RPF\-redirect bundle information
                    
                    .. attribute:: bundle_interface
                    
                    	PIM ECMP RPF\-redirect bundle interface information
                    	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bundle_interface = YList()
                        self.bundle_interface.parent = self
                        self.bundle_interface.name = 'bundle_interface'


                    class BundleInterface(object):
                        """
                        PIM ECMP RPF\-redirect bundle interface
                        information
                        
                        .. attribute:: allocated_bandwidth
                        
                        	Bandwidth allocated in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: allocated_threshold_bandwidth
                        
                        	Configured threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_bandwidth
                        
                        	Bandwidth available in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_threshold_bandwidth
                        
                        	Available threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: bundle_name
                        
                        	Bundle name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: interface_name
                        
                        	Bundle interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_redirect_bundle_name
                        
                        	RPF redirect bundle name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpf_redirect_interface_name
                        
                        	RPF redirect interface name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: snooping_bandwidth_used
                        
                        	Bandwidth used by snooped entries in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: topology_bandwidth_used
                        
                        	Bandwidth used by topology in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: total_bandwidth
                        
                        	Total bandwidth used in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.allocated_bandwidth = None
                            self.allocated_threshold_bandwidth = None
                            self.available_bandwidth = None
                            self.available_threshold_bandwidth = None
                            self.bundle_name = None
                            self.interface_name = None
                            self.rpf_redirect_bundle_name = None
                            self.rpf_redirect_interface_name = None
                            self.snooping_bandwidth_used = None
                            self.topology_bandwidth_used = None
                            self.total_bandwidth = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:bundle-interfaces/Cisco-IOS-XR-ipv4-pim-oper:bundle-interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.allocated_bandwidth is not None:
                                return True

                            if self.allocated_threshold_bandwidth is not None:
                                return True

                            if self.available_bandwidth is not None:
                                return True

                            if self.available_threshold_bandwidth is not None:
                                return True

                            if self.bundle_name is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.rpf_redirect_bundle_name is not None:
                                return True

                            if self.rpf_redirect_interface_name is not None:
                                return True

                            if self.snooping_bandwidth_used is not None:
                                return True

                            if self.topology_bandwidth_used is not None:
                                return True

                            if self.total_bandwidth is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:bundle-interfaces'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bundle_interface is not None:
                            for child_ref in self.bundle_interface:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bundle_interfaces is not None and self.bundle_interfaces._has_data():
                        return True

                    if self.redirect_route_databases is not None and self.redirect_route_databases._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.RpfRedirect']['meta_info']


            class Tunnels(object):
                """
                Tunnels information that PIM has
                
                .. attribute:: tunnel
                
                	PIM tunnel information
                	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels.Tunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.tunnel = YList()
                    self.tunnel.parent = self
                    self.tunnel.name = 'tunnel'


                class Tunnel(object):
                    """
                    PIM tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.tunnel_name = None
                        self.group_address_netio = Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self.rp_address = Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress()
                        self.rp_address.parent = self
                        self.source_address = Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress()
                        self.source_address.parent = self
                        self.source_address_netio = Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self.vrf_name = None


                    class SourceAddress(object):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress']['meta_info']


                    class RpAddress(object):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress']['meta_info']


                    class SourceAddressNetio(object):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-netio'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio']['meta_info']


                    class GroupAddressNetio(object):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-netio'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio']['meta_info']

                    @property
                    def _common_path(self):
                        if self.tunnel_name is None:
                            raise YPYModelError('Key property tunnel_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:tunnels/Cisco-IOS-XR-ipv4-pim-oper:tunnel[Cisco-IOS-XR-ipv4-pim-oper:tunnel-name = ' + str(self.tunnel_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.tunnel_name is not None:
                            return True

                        if self.group_address_netio is not None and self.group_address_netio._has_data():
                            return True

                        if self.rp_address is not None and self.rp_address._has_data():
                            return True

                        if self.source_address is not None and self.source_address._has_data():
                            return True

                        if self.source_address_netio is not None and self.source_address_netio._has_data():
                            return True

                        if self.vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.Tunnels.Tunnel']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:tunnels'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.tunnel is not None:
                        for child_ref in self.tunnel:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.Tunnels']['meta_info']


            class MulticastStaticRoutes(object):
                """
                PIM multicast static route table
                
                .. attribute:: multicast_static_route
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.multicast_static_route = YList()
                    self.multicast_static_route.parent = self
                    self.multicast_static_route.name = 'multicast_static_route'


                class MulticastStaticRoute(object):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: address
                    
                    	Network address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: distance
                    
                    	Distance
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_via_lsm
                    
                    	LSM flag
                    	**type**\:  bool
                    
                    .. attribute:: nexthop
                    
                    	Next Hop
                    	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: prefix_length_xr
                    
                    	Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.address = None
                        self.distance = None
                        self.interface_name = None
                        self.is_via_lsm = None
                        self.nexthop = Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                        self.nexthop.parent = self
                        self.prefix = Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                        self.prefix.parent = self
                        self.prefix_length = None
                        self.prefix_length_xr = None


                    class Prefix(object):
                        """
                        Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-routes/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-route/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix']['meta_info']


                    class Nexthop(object):
                        """
                        Next Hop
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-routes/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-route/Cisco-IOS-XR-ipv4-pim-oper:nexthop'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-routes/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-route'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.address is not None:
                            return True

                        if self.distance is not None:
                            return True

                        if self.interface_name is not None:
                            return True

                        if self.is_via_lsm is not None:
                            return True

                        if self.nexthop is not None and self.nexthop._has_data():
                            return True

                        if self.prefix is not None and self.prefix._has_data():
                            return True

                        if self.prefix_length is not None:
                            return True

                        if self.prefix_length_xr is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-routes'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.multicast_static_route is not None:
                        for child_ref in self.multicast_static_route:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.MulticastStaticRoutes']['meta_info']


            class GroupMapMatchSources(object):
                """
                Find the matching group\-mapping with source
                information on specified group address
                
                .. attribute:: group_map_match_source
                
                	PIM group\-matching mapping entry with source information
                	**type**\: list of    :py:class:`GroupMapMatchSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.group_map_match_source = YList()
                    self.group_map_match_source.parent = self
                    self.group_map_match_source.name = 'group_map_match_source'


                class GroupMapMatchSource(object):
                    """
                    PIM group\-matching mapping entry with source
                    information
                    
                    .. attribute:: group_address  <key>
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation>`
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_address = None
                        self.expires = None
                        self.group_map_information = Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self.holdtime = None
                        self.source_of_information = Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self.uptime = None


                    class SourceOfInformation(object):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation']['meta_info']


                    class GroupMapInformation(object):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.group_count = None
                            self.is_override = None
                            self.is_used = None
                            self.mrib_active = None
                            self.prefix = Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.priority = None
                            self.protocol = None
                            self.rp_address = Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self


                        class Prefix(object):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix']['meta_info']


                        class RpAddress(object):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.group_count is not None:
                                return True

                            if self.is_override is not None:
                                return True

                            if self.is_used is not None:
                                return True

                            if self.mrib_active is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation']['meta_info']

                    @property
                    def _common_path(self):
                        if self.group_address is None:
                            raise YPYModelError('Key property group_address is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-source[Cisco-IOS-XR-ipv4-pim-oper:group-address = ' + str(self.group_address) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_address is not None:
                            return True

                        if self.expires is not None:
                            return True

                        if self.group_map_information is not None and self.group_map_information._has_data():
                            return True

                        if self.holdtime is not None:
                            return True

                        if self.source_of_information is not None and self.source_of_information._has_data():
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-sources'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.group_map_match_source is not None:
                        for child_ref in self.group_map_match_source:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.GroupMapMatchSources']['meta_info']


            class Neighbors(object):
                """
                PIM neighbor table
                
                .. attribute:: neighbor
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Neighbors.Neighbor>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.neighbor = YList()
                    self.neighbor.parent = self
                    self.neighbor.name = 'neighbor'


                class Neighbor(object):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.dr_priority = None
                        self.expires = None
                        self.expiry_timer = None
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bfd_state = None
                        self.is_bidirectional_capable = None
                        self.is_dr_priority_capable = None
                        self.is_ecmp_redirect_capable = None
                        self.is_proxy_capable = None
                        self.is_this_neighbor_dr = None
                        self.is_this_neighbor_us = None
                        self.neighbor_address = None
                        self.neighbor_address_xr = YList()
                        self.neighbor_address_xr.parent = self
                        self.neighbor_address_xr.name = 'neighbor_address_xr'
                        self.override_interval = None
                        self.propagation_delay = None
                        self.uptime = None


                    class NeighborAddressXr(object):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbors/Cisco-IOS-XR-ipv4-pim-oper:neighbor/Cisco-IOS-XR-ipv4-pim-oper:neighbor-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbors/Cisco-IOS-XR-ipv4-pim-oper:neighbor'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.dr_priority is not None:
                            return True

                        if self.expires is not None:
                            return True

                        if self.expiry_timer is not None:
                            return True

                        if self.interface_name is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bfd_state is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_dr_priority_capable is not None:
                            return True

                        if self.is_ecmp_redirect_capable is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.is_this_neighbor_dr is not None:
                            return True

                        if self.is_this_neighbor_us is not None:
                            return True

                        if self.neighbor_address is not None:
                            return True

                        if self.neighbor_address_xr is not None:
                            for child_ref in self.neighbor_address_xr:
                                if child_ref._has_data():
                                    return True

                        if self.override_interval is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.DefaultContext.Neighbors.Neighbor']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbors'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.neighbor is not None:
                        for child_ref in self.neighbor:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.DefaultContext.Neighbors']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.auto_rp is not None and self.auto_rp._has_data():
                    return True

                if self.bgp_afs is not None and self.bgp_afs._has_data():
                    return True

                if self.bidir_df_states is not None and self.bidir_df_states._has_data():
                    return True

                if self.bidir_df_winners is not None and self.bidir_df_winners._has_data():
                    return True

                if self.bsr is not None and self.bsr._has_data():
                    return True

                if self.context is not None and self.context._has_data():
                    return True

                if self.global_interfaces is not None and self.global_interfaces._has_data():
                    return True

                if self.gre is not None and self.gre._has_data():
                    return True

                if self.group_map_match_rpfs is not None and self.group_map_match_rpfs._has_data():
                    return True

                if self.group_map_match_sources is not None and self.group_map_match_sources._has_data():
                    return True

                if self.group_map_rpfs is not None and self.group_map_rpfs._has_data():
                    return True

                if self.group_map_sources is not None and self.group_map_sources._has_data():
                    return True

                if self.ifrs_interfaces is not None and self.ifrs_interfaces._has_data():
                    return True

                if self.ifrs_summary is not None and self.ifrs_summary._has_data():
                    return True

                if self.interface_old_formats is not None and self.interface_old_formats._has_data():
                    return True

                if self.interface_statistics is not None and self.interface_statistics._has_data():
                    return True

                if self.interfaces is not None and self.interfaces._has_data():
                    return True

                if self.jp_statistics is not None and self.jp_statistics._has_data():
                    return True

                if self.mib_databases is not None and self.mib_databases._has_data():
                    return True

                if self.multicast_static_routes is not None and self.multicast_static_routes._has_data():
                    return True

                if self.neighbor_old_formats is not None and self.neighbor_old_formats._has_data():
                    return True

                if self.neighbor_summaries is not None and self.neighbor_summaries._has_data():
                    return True

                if self.neighbors is not None and self.neighbors._has_data():
                    return True

                if self.net_io_tunnels is not None and self.net_io_tunnels._has_data():
                    return True

                if self.ranges is not None and self.ranges._has_data():
                    return True

                if self.route_policy is not None and self.route_policy._has_data():
                    return True

                if self.rpf_redirect is not None and self.rpf_redirect._has_data():
                    return True

                if self.rpf_summary is not None and self.rpf_summary._has_data():
                    return True

                if self.safs is not None and self.safs._has_data():
                    return True

                if self.summary is not None and self.summary._has_data():
                    return True

                if self.table_contexts is not None and self.table_contexts._has_data():
                    return True

                if self.topologies is not None and self.topologies._has_data():
                    return True

                if self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts._has_data():
                    return True

                if self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts._has_data():
                    return True

                if self.topology_route_count is not None and self.topology_route_count._has_data():
                    return True

                if self.traffic_counters is not None and self.traffic_counters._has_data():
                    return True

                if self.tunnels is not None and self.tunnels._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                return meta._meta_table['Pim.Active.DefaultContext']['meta_info']


        class Process(object):
            """
            Process
            
            .. attribute:: checkpoint_statistics
            
            	Checkpoint Statistics
            	**type**\:   :py:class:`CheckpointStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process.CheckpointStatistics>`
            
            .. attribute:: issu
            
            	ISSU Information
            	**type**\:   :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process.Issu>`
            
            .. attribute:: nsf
            
            	PIM NSF information
            	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process.Nsf>`
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process.Nsr>`
            
            .. attribute:: summary
            
            	PIM Global Summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process.Summary>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.checkpoint_statistics = Pim.Active.Process.CheckpointStatistics()
                self.checkpoint_statistics.parent = self
                self.issu = Pim.Active.Process.Issu()
                self.issu.parent = self
                self.nsf = Pim.Active.Process.Nsf()
                self.nsf.parent = self
                self.nsr = Pim.Active.Process.Nsr()
                self.nsr.parent = self
                self.summary = Pim.Active.Process.Summary()
                self.summary.parent = self


            class CheckpointStatistics(object):
                """
                Checkpoint Statistics
                
                .. attribute:: checkpoint_table
                
                	Array of chkpt table stats
                	**type**\: list of    :py:class:`CheckpointTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process.CheckpointStatistics.CheckpointTable>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.checkpoint_table = YList()
                    self.checkpoint_table.parent = self
                    self.checkpoint_table.name = 'checkpoint_table'


                class CheckpointTable(object):
                    """
                    Array of chkpt table stats
                    
                    .. attribute:: is_mirrored
                    
                    	Table mirrored
                    	**type**\:  bool
                    
                    .. attribute:: statistic
                    
                    	Stats array
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_description
                    
                    	Table description
                    	**type**\:  str
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.is_mirrored = None
                        self.statistic = YLeafList()
                        self.statistic.parent = self
                        self.statistic.name = 'statistic'
                        self.table_description = None
                        self.table_name = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:checkpoint-statistics/Cisco-IOS-XR-ipv4-pim-oper:checkpoint-table'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.is_mirrored is not None:
                            return True

                        if self.statistic is not None:
                            for child in self.statistic:
                                if child is not None:
                                    return True

                        if self.table_description is not None:
                            return True

                        if self.table_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Process.CheckpointStatistics.CheckpointTable']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:checkpoint-statistics'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.checkpoint_table is not None:
                        for child_ref in self.checkpoint_table:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.Process.CheckpointStatistics']['meta_info']


            class Nsr(object):
                """
                NSR Information
                
                .. attribute:: count_connection_dn
                
                	No. of times connection went down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_connection_up
                
                	No. of times connection went up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_connection_dn
                
                	Time when connection went down
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_connection_up
                
                	Time when connection went up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: partner_connected
                
                	Partner process connected
                	**type**\:  bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\:  bool
                
                .. attribute:: rmf_timer_expiry
                
                	Time for RMF timer to expire
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: rmf_timer_valid
                
                	Is RMF timer running ?
                	**type**\:  bool
                
                .. attribute:: state
                
                	NSR state
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.count_connection_dn = None
                    self.count_connection_up = None
                    self.count_rmf_not_ready = None
                    self.count_rmf_ready = None
                    self.last_connection_dn = None
                    self.last_connection_up = None
                    self.last_rmf_not_ready = None
                    self.last_rmf_ready = None
                    self.partner_connected = None
                    self.rmf_notification_done = None
                    self.rmf_timer_expiry = None
                    self.rmf_timer_valid = None
                    self.state = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:nsr'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.count_connection_dn is not None:
                        return True

                    if self.count_connection_up is not None:
                        return True

                    if self.count_rmf_not_ready is not None:
                        return True

                    if self.count_rmf_ready is not None:
                        return True

                    if self.last_connection_dn is not None:
                        return True

                    if self.last_connection_up is not None:
                        return True

                    if self.last_rmf_not_ready is not None:
                        return True

                    if self.last_rmf_ready is not None:
                        return True

                    if self.partner_connected is not None:
                        return True

                    if self.rmf_notification_done is not None:
                        return True

                    if self.rmf_timer_expiry is not None:
                        return True

                    if self.rmf_timer_valid is not None:
                        return True

                    if self.state is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.Process.Nsr']['meta_info']


            class Summary(object):
                """
                PIM Global Summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bsr_candidate_rp_set_count = None
                    self.bsr_candidate_rp_set_limit = None
                    self.bsr_candidate_rp_set_threshold = None
                    self.bsr_range_threshold = None
                    self.bsr_ranges_count = None
                    self.bsr_ranges_limit = None
                    self.global_auto_rp_ranges_limit = None
                    self.global_bsr_candidate_rp_set_count = None
                    self.global_bsr_candidate_rp_set_limit = None
                    self.global_bsr_candidate_rp_set_threshold = None
                    self.global_bsr_ranges_count = None
                    self.global_bsr_ranges_limit = None
                    self.global_bsr_ranges_threshold = None
                    self.global_register_limit = None
                    self.is_bsr_ranges_threshold_reached = None
                    self.is_global_auto_rp_ranges_limit_reached = None
                    self.is_global_bsr_ranges_limit_reached = None
                    self.is_global_register_limit_reached = None
                    self.is_global_route_limit_reached = None
                    self.is_global_rxi_limit_reached = None
                    self.is_maximum_enforcement_disabled = None
                    self.is_node_low_memory = None
                    self.is_ranges_limit_reached = None
                    self.is_route_limit_reached = None
                    self.ranges_count = None
                    self.ranges_limit = None
                    self.ranges_threshold = None
                    self.register_count = None
                    self.register_limit = None
                    self.register_limit_reached = None
                    self.register_threshold = None
                    self.route_count = None
                    self.route_limit = None
                    self.route_low_water_mark = None
                    self.route_threshold = None
                    self.rxi_limit_reached = None
                    self.rxi_low_water_mark = None
                    self.topology_interface_state_count = None
                    self.topology_interface_state_limit = None
                    self.topology_interface_state_threshold = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bsr_candidate_rp_set_count is not None:
                        return True

                    if self.bsr_candidate_rp_set_limit is not None:
                        return True

                    if self.bsr_candidate_rp_set_threshold is not None:
                        return True

                    if self.bsr_range_threshold is not None:
                        return True

                    if self.bsr_ranges_count is not None:
                        return True

                    if self.bsr_ranges_limit is not None:
                        return True

                    if self.global_auto_rp_ranges_limit is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_count is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_limit is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_threshold is not None:
                        return True

                    if self.global_bsr_ranges_count is not None:
                        return True

                    if self.global_bsr_ranges_limit is not None:
                        return True

                    if self.global_bsr_ranges_threshold is not None:
                        return True

                    if self.global_register_limit is not None:
                        return True

                    if self.is_bsr_ranges_threshold_reached is not None:
                        return True

                    if self.is_global_auto_rp_ranges_limit_reached is not None:
                        return True

                    if self.is_global_bsr_ranges_limit_reached is not None:
                        return True

                    if self.is_global_register_limit_reached is not None:
                        return True

                    if self.is_global_route_limit_reached is not None:
                        return True

                    if self.is_global_rxi_limit_reached is not None:
                        return True

                    if self.is_maximum_enforcement_disabled is not None:
                        return True

                    if self.is_node_low_memory is not None:
                        return True

                    if self.is_ranges_limit_reached is not None:
                        return True

                    if self.is_route_limit_reached is not None:
                        return True

                    if self.ranges_count is not None:
                        return True

                    if self.ranges_limit is not None:
                        return True

                    if self.ranges_threshold is not None:
                        return True

                    if self.register_count is not None:
                        return True

                    if self.register_limit is not None:
                        return True

                    if self.register_limit_reached is not None:
                        return True

                    if self.register_threshold is not None:
                        return True

                    if self.route_count is not None:
                        return True

                    if self.route_limit is not None:
                        return True

                    if self.route_low_water_mark is not None:
                        return True

                    if self.route_threshold is not None:
                        return True

                    if self.rxi_limit_reached is not None:
                        return True

                    if self.rxi_low_water_mark is not None:
                        return True

                    if self.topology_interface_state_count is not None:
                        return True

                    if self.topology_interface_state_limit is not None:
                        return True

                    if self.topology_interface_state_threshold is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.Process.Summary']['meta_info']


            class Nsf(object):
                """
                PIM NSF information
                
                .. attribute:: configured_state
                
                	Is Multicast NSF Configured
                	**type**\:  bool
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_sec
                
                	Last ICD Notif Recv in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off_sec
                
                	Last NSF time OFF in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_sec
                
                	Last NSF time ON in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: nsf_state
                
                	Are we currently in NSF
                	**type**\:  bool
                
                .. attribute:: nsf_time_left
                
                	Multicast NSF time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: nsf_timeout
                
                	Multicast NSF timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: waiting_membership
                
                	Waiting for IGMP/MLD
                	**type**\:  bool
                
                .. attribute:: waiting_timer
                
                	Waiting for NSF timer expiry
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.configured_state = None
                    self.last_icd_notif_recv = None
                    self.last_icd_notif_recv_sec = None
                    self.last_nsf_off = None
                    self.last_nsf_off_sec = None
                    self.last_nsf_on = None
                    self.last_nsf_on_sec = None
                    self.nsf_state = None
                    self.nsf_time_left = None
                    self.nsf_timeout = None
                    self.respawn_count = None
                    self.waiting_membership = None
                    self.waiting_timer = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:nsf'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.configured_state is not None:
                        return True

                    if self.last_icd_notif_recv is not None:
                        return True

                    if self.last_icd_notif_recv_sec is not None:
                        return True

                    if self.last_nsf_off is not None:
                        return True

                    if self.last_nsf_off_sec is not None:
                        return True

                    if self.last_nsf_on is not None:
                        return True

                    if self.last_nsf_on_sec is not None:
                        return True

                    if self.nsf_state is not None:
                        return True

                    if self.nsf_time_left is not None:
                        return True

                    if self.nsf_timeout is not None:
                        return True

                    if self.respawn_count is not None:
                        return True

                    if self.waiting_membership is not None:
                        return True

                    if self.waiting_timer is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.Process.Nsf']['meta_info']


            class Issu(object):
                """
                ISSU Information
                
                .. attribute:: checkpoint_idt_timestamp
                
                	Time when Checkpoint IDT done
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: eoc_received_timestamp
                
                	Time when EOC was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: ihms_received_timestamp
                
                	Time when IHMS done was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: informationvalid
                
                	Is Information valid ?
                	**type**\:  bool
                
                .. attribute:: is_checkpoint_idt_done
                
                	Was Checkpoint IDT done ?
                	**type**\:  bool
                
                .. attribute:: is_eoc_received
                
                	Was EOC received ?
                	**type**\:  bool
                
                .. attribute:: is_ihms_done_received
                
                	Was IHMS done received ?
                	**type**\:  bool
                
                .. attribute:: is_nbr_sync_received
                
                	Was NBR Sync achieved ?
                	**type**\:  bool
                
                .. attribute:: is_rib_sync_received
                
                	Was RIB Sync received ?
                	**type**\:  bool
                
                .. attribute:: last_ha_role_notification_received
                
                	Time when last HA role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_phase_notification_received
                
                	Time when last ISSU Phase nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_role_notification_received
                
                	Time when last ISSU role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: nbr_sync_received_timestamp
                
                	Time when NBR Sync was achieved
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: phase_issu
                
                	ISSU Phase
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: rib_sync_received_timestamp
                
                	Time when RIB Sync was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: role_ha
                
                	HA role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: role_issu
                
                	ISSU role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.checkpoint_idt_timestamp = None
                    self.eoc_received_timestamp = None
                    self.ihms_received_timestamp = None
                    self.informationvalid = None
                    self.is_checkpoint_idt_done = None
                    self.is_eoc_received = None
                    self.is_ihms_done_received = None
                    self.is_nbr_sync_received = None
                    self.is_rib_sync_received = None
                    self.last_ha_role_notification_received = None
                    self.last_issu_phase_notification_received = None
                    self.last_issu_role_notification_received = None
                    self.nbr_sync_received_timestamp = None
                    self.phase_issu = None
                    self.rib_sync_received_timestamp = None
                    self.role_ha = None
                    self.role_issu = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:issu'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.checkpoint_idt_timestamp is not None:
                        return True

                    if self.eoc_received_timestamp is not None:
                        return True

                    if self.ihms_received_timestamp is not None:
                        return True

                    if self.informationvalid is not None:
                        return True

                    if self.is_checkpoint_idt_done is not None:
                        return True

                    if self.is_eoc_received is not None:
                        return True

                    if self.is_ihms_done_received is not None:
                        return True

                    if self.is_nbr_sync_received is not None:
                        return True

                    if self.is_rib_sync_received is not None:
                        return True

                    if self.last_ha_role_notification_received is not None:
                        return True

                    if self.last_issu_phase_notification_received is not None:
                        return True

                    if self.last_issu_role_notification_received is not None:
                        return True

                    if self.nbr_sync_received_timestamp is not None:
                        return True

                    if self.phase_issu is not None:
                        return True

                    if self.rib_sync_received_timestamp is not None:
                        return True

                    if self.role_ha is not None:
                        return True

                    if self.role_issu is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.Process.Issu']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:process'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.checkpoint_statistics is not None and self.checkpoint_statistics._has_data():
                    return True

                if self.issu is not None and self.issu._has_data():
                    return True

                if self.nsf is not None and self.nsf._has_data():
                    return True

                if self.nsr is not None and self.nsr._has_data():
                    return True

                if self.summary is not None and self.summary._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                return meta._meta_table['Pim.Active.Process']['meta_info']


        class Vrfs(object):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF name
            	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.vrf = YList()
                self.vrf.parent = self
                self.vrf.name = 'vrf'


            class Vrf(object):
                """
                VRF name
                
                .. attribute:: vrf_name  <key>
                
                	VRF name 
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: auto_rp
                
                	PIM Auto\-RP information
                	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.AutoRp>`
                
                .. attribute:: bgp_afs
                
                	PIM BGP SAFI table
                	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BgpAfs>`
                
                .. attribute:: bidir_df_states
                
                	Bidirectional PIM DF election state table
                	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfStates>`
                
                .. attribute:: bidir_df_winners
                
                	Bidirectional PIM DF election winner table
                	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfWinners>`
                
                .. attribute:: bsr
                
                	PIM BSR information
                	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr>`
                
                .. attribute:: context
                
                	PIM context information
                	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context>`
                
                .. attribute:: gre
                
                	GRE information
                	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre>`
                
                .. attribute:: group_map_match_rpfs
                
                	Find matching group\-mapping for the specified group address
                	**type**\:   :py:class:`GroupMapMatchRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs>`
                
                .. attribute:: group_map_match_sources
                
                	Find the matching group\-mapping with source information on specified group address
                	**type**\:   :py:class:`GroupMapMatchSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchSources>`
                
                .. attribute:: group_map_rpfs
                
                	PIM group mapping information
                	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs>`
                
                .. attribute:: group_map_sources
                
                	PIM group\-mapping with source information
                	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources>`
                
                .. attribute:: ifrs_interfaces
                
                	PIM interfaces in forward reference store table
                	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: ifrs_summary
                
                	PIM interfaces in forward reference store summary
                	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.IfrsSummary>`
                
                .. attribute:: interface_old_formats
                
                	PIM interfaces in old format
                	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceOldFormats>`
                
                .. attribute:: interface_statistics
                
                	PIM interface statistics
                	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceStatistics>`
                
                .. attribute:: interfaces
                
                	PIM interfaces
                	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Interfaces>`
                
                .. attribute:: jp_statistics
                
                	PIM join prune statistics table
                	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.JpStatistics>`
                
                .. attribute:: mib_databases
                
                	PIM group database for mroute mibs table
                	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases>`
                
                .. attribute:: multicast_static_routes
                
                	PIM multicast static route table
                	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MulticastStaticRoutes>`
                
                .. attribute:: neighbor_old_formats
                
                	PIM neighbor table old format
                	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NeighborOldFormats>`
                
                .. attribute:: neighbor_summaries
                
                	PIM neighbor summary table
                	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NeighborSummaries>`
                
                .. attribute:: neighbors
                
                	PIM neighbor table
                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Neighbors>`
                
                .. attribute:: net_io_tunnels
                
                	Tunnel information that NETIO has 
                	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels>`
                
                .. attribute:: ranges
                
                	PIM range list information
                	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges>`
                
                .. attribute:: route_policy
                
                	PIM route policy
                	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy>`
                
                .. attribute:: rpf_redirect
                
                	PIM ECMP RPF\-redirect bundle
                	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect>`
                
                .. attribute:: rpf_summary
                
                	PIM RPF registration summary
                	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfSummary>`
                
                .. attribute:: safs
                
                	SAFI table and type
                	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs>`
                
                .. attribute:: summary
                
                	PIM summary
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Summary>`
                
                .. attribute:: table_contexts
                
                	PIM table context list
                	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TableContexts>`
                
                .. attribute:: topologies
                
                	PIM topology table
                	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies>`
                
                .. attribute:: topology_entry_flag_route_counts
                
                	Route count for topology with entry flag set
                	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts>`
                
                .. attribute:: topology_interface_flag_route_counts
                
                	Route count for topology with interface flag set
                	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts>`
                
                .. attribute:: topology_route_count
                
                	Topology route count information from PIM topology table
                	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyRouteCount>`
                
                .. attribute:: traffic_counters
                
                	PIM message traffic counters
                	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TrafficCounters>`
                
                .. attribute:: tunnels
                
                	Tunnels information that PIM has
                	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.vrf_name = None
                    self.auto_rp = Pim.Active.Vrfs.Vrf.AutoRp()
                    self.auto_rp.parent = self
                    self.bgp_afs = Pim.Active.Vrfs.Vrf.BgpAfs()
                    self.bgp_afs.parent = self
                    self.bidir_df_states = Pim.Active.Vrfs.Vrf.BidirDfStates()
                    self.bidir_df_states.parent = self
                    self.bidir_df_winners = Pim.Active.Vrfs.Vrf.BidirDfWinners()
                    self.bidir_df_winners.parent = self
                    self.bsr = Pim.Active.Vrfs.Vrf.Bsr()
                    self.bsr.parent = self
                    self.context = Pim.Active.Vrfs.Vrf.Context()
                    self.context.parent = self
                    self.gre = Pim.Active.Vrfs.Vrf.Gre()
                    self.gre.parent = self
                    self.group_map_match_rpfs = Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs()
                    self.group_map_match_rpfs.parent = self
                    self.group_map_match_sources = Pim.Active.Vrfs.Vrf.GroupMapMatchSources()
                    self.group_map_match_sources.parent = self
                    self.group_map_rpfs = Pim.Active.Vrfs.Vrf.GroupMapRpfs()
                    self.group_map_rpfs.parent = self
                    self.group_map_sources = Pim.Active.Vrfs.Vrf.GroupMapSources()
                    self.group_map_sources.parent = self
                    self.ifrs_interfaces = Pim.Active.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self.ifrs_summary = Pim.Active.Vrfs.Vrf.IfrsSummary()
                    self.ifrs_summary.parent = self
                    self.interface_old_formats = Pim.Active.Vrfs.Vrf.InterfaceOldFormats()
                    self.interface_old_formats.parent = self
                    self.interface_statistics = Pim.Active.Vrfs.Vrf.InterfaceStatistics()
                    self.interface_statistics.parent = self
                    self.interfaces = Pim.Active.Vrfs.Vrf.Interfaces()
                    self.interfaces.parent = self
                    self.jp_statistics = Pim.Active.Vrfs.Vrf.JpStatistics()
                    self.jp_statistics.parent = self
                    self.mib_databases = Pim.Active.Vrfs.Vrf.MibDatabases()
                    self.mib_databases.parent = self
                    self.multicast_static_routes = Pim.Active.Vrfs.Vrf.MulticastStaticRoutes()
                    self.multicast_static_routes.parent = self
                    self.neighbor_old_formats = Pim.Active.Vrfs.Vrf.NeighborOldFormats()
                    self.neighbor_old_formats.parent = self
                    self.neighbor_summaries = Pim.Active.Vrfs.Vrf.NeighborSummaries()
                    self.neighbor_summaries.parent = self
                    self.neighbors = Pim.Active.Vrfs.Vrf.Neighbors()
                    self.neighbors.parent = self
                    self.net_io_tunnels = Pim.Active.Vrfs.Vrf.NetIoTunnels()
                    self.net_io_tunnels.parent = self
                    self.ranges = Pim.Active.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self.route_policy = Pim.Active.Vrfs.Vrf.RoutePolicy()
                    self.route_policy.parent = self
                    self.rpf_redirect = Pim.Active.Vrfs.Vrf.RpfRedirect()
                    self.rpf_redirect.parent = self
                    self.rpf_summary = Pim.Active.Vrfs.Vrf.RpfSummary()
                    self.rpf_summary.parent = self
                    self.safs = Pim.Active.Vrfs.Vrf.Safs()
                    self.safs.parent = self
                    self.summary = Pim.Active.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self.table_contexts = Pim.Active.Vrfs.Vrf.TableContexts()
                    self.table_contexts.parent = self
                    self.topologies = Pim.Active.Vrfs.Vrf.Topologies()
                    self.topologies.parent = self
                    self.topology_entry_flag_route_counts = Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts()
                    self.topology_entry_flag_route_counts.parent = self
                    self.topology_interface_flag_route_counts = Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts()
                    self.topology_interface_flag_route_counts.parent = self
                    self.topology_route_count = Pim.Active.Vrfs.Vrf.TopologyRouteCount()
                    self.topology_route_count.parent = self
                    self.traffic_counters = Pim.Active.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self.tunnels = Pim.Active.Vrfs.Vrf.Tunnels()
                    self.tunnels.parent = self


                class IfrsInterfaces(object):
                    """
                    PIM interfaces in forward reference store table
                    
                    .. attribute:: ifrs_interface
                    
                    	PIM IFRS interface information
                    	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ifrs_interface = YList()
                        self.ifrs_interface.parent = self
                        self.ifrs_interface.name = 'ifrs_interface'


                    class IfrsInterface(object):
                        """
                        PIM IFRS interface information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.configured_override_interval = None
                            self.configured_propagation_delay = None
                            self.dr_address = Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress()
                            self.dr_address.parent = self
                            self.dr_priority = None
                            self.external_neighbor_count = None
                            self.generation_id = None
                            self.hello_expiry = None
                            self.hello_interval = None
                            self.idb_acl_name = None
                            self.idb_acl_provided = None
                            self.idb_current_count = None
                            self.idb_max_count = None
                            self.idb_oor_enabled = None
                            self.idb_threshold_count = None
                            self.interface_address = YList()
                            self.interface_address.parent = self
                            self.interface_address.name = 'interface_address'
                            self.interface_address_mask = None
                            self.interface_name_xr = None
                            self.is_batch_asserts_capable = None
                            self.is_bidirectional_capable = None
                            self.is_enabled = None
                            self.is_proxy_capable = None
                            self.join_prune_interval = None
                            self.neighbor_count = None
                            self.neighbor_filter_name = None
                            self.override_interval = None
                            self.passive_interface = None
                            self.propagation_delay = None
                            self.prune_delay_enabled = None
                            self.virtual_interface = None


                        class DrAddress(object):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress']['meta_info']


                        class InterfaceAddress(object):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:ifrs-interface[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.are_we_dr is not None:
                                return True

                            if self.bfd_enabled is not None:
                                return True

                            if self.bfd_interval is not None:
                                return True

                            if self.bfd_multiplier is not None:
                                return True

                            if self.configured_override_interval is not None:
                                return True

                            if self.configured_propagation_delay is not None:
                                return True

                            if self.dr_address is not None and self.dr_address._has_data():
                                return True

                            if self.dr_priority is not None:
                                return True

                            if self.external_neighbor_count is not None:
                                return True

                            if self.generation_id is not None:
                                return True

                            if self.hello_expiry is not None:
                                return True

                            if self.hello_interval is not None:
                                return True

                            if self.idb_acl_name is not None:
                                return True

                            if self.idb_acl_provided is not None:
                                return True

                            if self.idb_current_count is not None:
                                return True

                            if self.idb_max_count is not None:
                                return True

                            if self.idb_oor_enabled is not None:
                                return True

                            if self.idb_threshold_count is not None:
                                return True

                            if self.interface_address is not None:
                                for child_ref in self.interface_address:
                                    if child_ref._has_data():
                                        return True

                            if self.interface_address_mask is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.is_batch_asserts_capable is not None:
                                return True

                            if self.is_bidirectional_capable is not None:
                                return True

                            if self.is_enabled is not None:
                                return True

                            if self.is_proxy_capable is not None:
                                return True

                            if self.join_prune_interval is not None:
                                return True

                            if self.neighbor_count is not None:
                                return True

                            if self.neighbor_filter_name is not None:
                                return True

                            if self.override_interval is not None:
                                return True

                            if self.passive_interface is not None:
                                return True

                            if self.propagation_delay is not None:
                                return True

                            if self.prune_delay_enabled is not None:
                                return True

                            if self.virtual_interface is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:ifrs-interfaces'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ifrs_interface is not None:
                            for child_ref in self.ifrs_interface:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.IfrsInterfaces']['meta_info']


                class Safs(object):
                    """
                    SAFI table and type
                    
                    .. attribute:: saf
                    
                    	SAF name 
                    	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.saf = YList()
                        self.saf.parent = self
                        self.saf.name = 'saf'


                    class Saf(object):
                        """
                        SAF name 
                        
                        .. attribute:: rpf_hash_source_groups
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups>`
                        
                        .. attribute:: rpf_hash_sources
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources>`
                        
                        .. attribute:: rpfs
                        
                        	PIM RPF information table
                        	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs>`
                        
                        .. attribute:: saf_name
                        
                        	SAF name 
                        	**type**\:   :py:class:`PimSafiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafiEnum>`
                        
                        .. attribute:: topology_name
                        
                        	Topology name 
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rpf_hash_source_groups = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups()
                            self.rpf_hash_source_groups.parent = self
                            self.rpf_hash_sources = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources()
                            self.rpf_hash_sources.parent = self
                            self.rpfs = Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs()
                            self.rpfs.parent = self
                            self.saf_name = None
                            self.topology_name = None


                        class RpfHashSourceGroups(object):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source_group
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.rpf_hash_source_group = YList()
                                self.rpf_hash_source_group.parent = self
                                self.rpf_hash_source_group.name = 'rpf_hash_source_group'


                            class RpfHashSourceGroup(object):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: group_address
                                
                                	Group address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: mask_length
                                
                                	Hash mask length
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.group_address = None
                                    self.mask_length = None
                                    self.mofrr = None
                                    self.next_hop_address = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self.next_hop_interface = None
                                    self.next_hop_multipath_enabled = None
                                    self.secondary_next_hop_address = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self.secondary_next_hop_interface = None
                                    self.source_address = None


                                class NextHopAddress(object):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:next-hop-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress']['meta_info']


                                class SecondaryNextHopAddress(object):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:secondary-next-hop-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-group'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.group_address is not None:
                                        return True

                                    if self.mask_length is not None:
                                        return True

                                    if self.mofrr is not None:
                                        return True

                                    if self.next_hop_address is not None and self.next_hop_address._has_data():
                                        return True

                                    if self.next_hop_interface is not None:
                                        return True

                                    if self.next_hop_multipath_enabled is not None:
                                        return True

                                    if self.secondary_next_hop_address is not None and self.secondary_next_hop_address._has_data():
                                        return True

                                    if self.secondary_next_hop_interface is not None:
                                        return True

                                    if self.source_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-groups'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.rpf_hash_source_group is not None:
                                    for child_ref in self.rpf_hash_source_group:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups']['meta_info']


                        class RpfHashSources(object):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.rpf_hash_source = YList()
                                self.rpf_hash_source.parent = self
                                self.rpf_hash_source.name = 'rpf_hash_source'


                            class RpfHashSource(object):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mofrr = None
                                    self.next_hop_address = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self.next_hop_interface = None
                                    self.next_hop_multipath_enabled = None
                                    self.secondary_next_hop_address = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self.secondary_next_hop_interface = None
                                    self.source_address = None


                                class NextHopAddress(object):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:next-hop-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress']['meta_info']


                                class SecondaryNextHopAddress(object):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:secondary-next-hop-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mofrr is not None:
                                        return True

                                    if self.next_hop_address is not None and self.next_hop_address._has_data():
                                        return True

                                    if self.next_hop_interface is not None:
                                        return True

                                    if self.next_hop_multipath_enabled is not None:
                                        return True

                                    if self.secondary_next_hop_address is not None and self.secondary_next_hop_address._has_data():
                                        return True

                                    if self.secondary_next_hop_interface is not None:
                                        return True

                                    if self.source_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-sources'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.rpf_hash_source is not None:
                                    for child_ref in self.rpf_hash_source:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources']['meta_info']


                        class Rpfs(object):
                            """
                            PIM RPF information table
                            
                            .. attribute:: rpf
                            
                            	PIM RPF information
                            	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.rpf = YList()
                                self.rpf.parent = self
                                self.rpf.name = 'rpf'


                            class Rpf(object):
                                """
                                PIM RPF information
                                
                                .. attribute:: registered_address  <key>
                                
                                	Address for which RPF lookup
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: is_connected
                                
                                	Are we connected ?
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_rpf_bgp_route
                                
                                	Is RPF through BGP route
                                	**type**\:  bool
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_preference
                                
                                	Metric preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: registered_address_xr
                                
                                	Address registered
                                	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                                
                                .. attribute:: rpf_path
                                
                                	RPF Paths list
                                	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.registered_address = None
                                    self.is_connected = None
                                    self.is_rpf_bgp_route = None
                                    self.metric = None
                                    self.metric_preference = None
                                    self.registered_address_xr = Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                    self.registered_address_xr.parent = self
                                    self.rpf_path = YList()
                                    self.rpf_path.parent = self
                                    self.rpf_path.name = 'rpf_path'


                                class RegisteredAddressXr(object):
                                    """
                                    Address registered
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:registered-address-xr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr']['meta_info']


                                class RpfPath(object):
                                    """
                                    RPF Paths list
                                    
                                    .. attribute:: connector
                                    
                                    	Connector Attribute
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: extranet_vrf_name
                                    
                                    	Extranet VRF name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    .. attribute:: is_connector_attribute_present
                                    
                                    	Connector attribute present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rpf_interface_disabled
                                    
                                    	Is the rpf interface disabled ?
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_lsm
                                    
                                    	Via LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_mlsm
                                    
                                    	Via Mstatic LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpf_interface_name
                                    
                                    	RPF Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: rpf_neighbor
                                    
                                    	RPF neighbor
                                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                    
                                    .. attribute:: rpf_nexthop
                                    
                                    	RPF nexthop
                                    	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.connector = None
                                        self.extranet_vrf_name = None
                                        self.is_connector_attribute_present = None
                                        self.is_rpf_interface_disabled = None
                                        self.is_via_lsm = None
                                        self.is_via_mlsm = None
                                        self.rpf_interface_name = None
                                        self.rpf_neighbor = Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                        self.rpf_neighbor.parent = self
                                        self.rpf_nexthop = Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                        self.rpf_nexthop.parent = self


                                    class RpfNeighbor(object):
                                        """
                                        RPF neighbor
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                            return meta._meta_table['Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor']['meta_info']


                                    class RpfNexthop(object):
                                        """
                                        RPF nexthop
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-nexthop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                            return meta._meta_table['Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.connector is not None:
                                            return True

                                        if self.extranet_vrf_name is not None:
                                            return True

                                        if self.is_connector_attribute_present is not None:
                                            return True

                                        if self.is_rpf_interface_disabled is not None:
                                            return True

                                        if self.is_via_lsm is not None:
                                            return True

                                        if self.is_via_mlsm is not None:
                                            return True

                                        if self.rpf_interface_name is not None:
                                            return True

                                        if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                            return True

                                        if self.rpf_nexthop is not None and self.rpf_nexthop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.registered_address is None:
                                        raise YPYModelError('Key property registered_address is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf[Cisco-IOS-XR-ipv4-pim-oper:registered-address = ' + str(self.registered_address) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.registered_address is not None:
                                        return True

                                    if self.is_connected is not None:
                                        return True

                                    if self.is_rpf_bgp_route is not None:
                                        return True

                                    if self.metric is not None:
                                        return True

                                    if self.metric_preference is not None:
                                        return True

                                    if self.registered_address_xr is not None and self.registered_address_xr._has_data():
                                        return True

                                    if self.rpf_path is not None:
                                        for child_ref in self.rpf_path:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpfs'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.rpf is not None:
                                    for child_ref in self.rpf:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:saf'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups._has_data():
                                return True

                            if self.rpf_hash_sources is not None and self.rpf_hash_sources._has_data():
                                return True

                            if self.rpfs is not None and self.rpfs._has_data():
                                return True

                            if self.saf_name is not None:
                                return True

                            if self.topology_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.Safs.Saf']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:safs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.saf is not None:
                            for child_ref in self.saf:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.Safs']['meta_info']


                class InterfaceStatistics(object):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_statistic
                    
                    	PIM interface statistics
                    	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_statistic = YList()
                        self.interface_statistic.parent = self
                        self.interface_statistic.name = 'interface_statistic'


                    class InterfaceStatistic(object):
                        """
                        PIM interface statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: input_assert
                        
                        	Assert packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_bsr_message
                        
                        	Input BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_candidate_rp_advertisement
                        
                        	Input Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_df_election
                        
                        	DF Election packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_ack_message
                        
                        	Input Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_message
                        
                        	Input Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_hello
                        
                        	Hello packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_jp
                        
                        	Join Prune packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_miscellaneous
                        
                        	Miscellaneous packet in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register
                        
                        	Register packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register_stop
                        
                        	Register Stop packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_assert
                        
                        	Assert packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_bsr_message
                        
                        	Output BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_candidate_rp_advertisement
                        
                        	Output Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_df_election
                        
                        	DF Election packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_ack_message
                        
                        	Output Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_message
                        
                        	Output Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_hello
                        
                        	Hello packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_jp
                        
                        	Join Prune packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register
                        
                        	Register packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register_stop
                        
                        	Register Stop packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.input_assert = None
                            self.input_bsr_message = None
                            self.input_candidate_rp_advertisement = None
                            self.input_df_election = None
                            self.input_graft_ack_message = None
                            self.input_graft_message = None
                            self.input_hello = None
                            self.input_jp = None
                            self.input_miscellaneous = None
                            self.input_register = None
                            self.input_register_stop = None
                            self.output_assert = None
                            self.output_bsr_message = None
                            self.output_candidate_rp_advertisement = None
                            self.output_df_election = None
                            self.output_graft_ack_message = None
                            self.output_graft_message = None
                            self.output_hello = None
                            self.output_jp = None
                            self.output_register = None
                            self.output_register_stop = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-statistic[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.input_assert is not None:
                                return True

                            if self.input_bsr_message is not None:
                                return True

                            if self.input_candidate_rp_advertisement is not None:
                                return True

                            if self.input_df_election is not None:
                                return True

                            if self.input_graft_ack_message is not None:
                                return True

                            if self.input_graft_message is not None:
                                return True

                            if self.input_hello is not None:
                                return True

                            if self.input_jp is not None:
                                return True

                            if self.input_miscellaneous is not None:
                                return True

                            if self.input_register is not None:
                                return True

                            if self.input_register_stop is not None:
                                return True

                            if self.output_assert is not None:
                                return True

                            if self.output_bsr_message is not None:
                                return True

                            if self.output_candidate_rp_advertisement is not None:
                                return True

                            if self.output_df_election is not None:
                                return True

                            if self.output_graft_ack_message is not None:
                                return True

                            if self.output_graft_message is not None:
                                return True

                            if self.output_hello is not None:
                                return True

                            if self.output_jp is not None:
                                return True

                            if self.output_register is not None:
                                return True

                            if self.output_register_stop is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-statistics'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_statistic is not None:
                            for child_ref in self.interface_statistic:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.InterfaceStatistics']['meta_info']


                class TopologyRouteCount(object):
                    """
                    Topology route count information from PIM
                    topology table
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.active_group_ranges = None
                        self.group_address = Pim.Active.Vrfs.Vrf.TopologyRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self.group_ranges = None
                        self.groute_count = None
                        self.is_node_low_memory = None
                        self.sg_route_count = None
                        self.sgr_route_count = None


                    class GroupAddress(object):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.TopologyRouteCount.GroupAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology-route-count'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.active_group_ranges is not None:
                            return True

                        if self.group_address is not None and self.group_address._has_data():
                            return True

                        if self.group_ranges is not None:
                            return True

                        if self.groute_count is not None:
                            return True

                        if self.is_node_low_memory is not None:
                            return True

                        if self.sg_route_count is not None:
                            return True

                        if self.sgr_route_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.TopologyRouteCount']['meta_info']


                class JpStatistics(object):
                    """
                    PIM join prune statistics table
                    
                    .. attribute:: jp_statistic
                    
                    	PIM Join Prune Statistics
                    	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.jp_statistic = YList()
                        self.jp_statistic.parent = self
                        self.jp_statistic.name = 'jp_statistic'


                    class JpStatistic(object):
                        """
                        PIM Join Prune Statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received
                        
                        	Received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received100
                        
                        	Received 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_10k
                        
                        	Received 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_1k
                        
                        	Received 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_50k
                        
                        	Deprecated by Received100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted
                        
                        	Transmitted
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transmitted100
                        
                        	Transmitted 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_10k
                        
                        	Transmitted 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_1k
                        
                        	Transmitted 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_50k
                        
                        	Deprecated by Transmitted100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.mtu = None
                            self.received = None
                            self.received100 = None
                            self.received_10k = None
                            self.received_1k = None
                            self.received_50k = None
                            self.transmitted = None
                            self.transmitted100 = None
                            self.transmitted_10k = None
                            self.transmitted_1k = None
                            self.transmitted_50k = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:jp-statistic[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.mtu is not None:
                                return True

                            if self.received is not None:
                                return True

                            if self.received100 is not None:
                                return True

                            if self.received_10k is not None:
                                return True

                            if self.received_1k is not None:
                                return True

                            if self.received_50k is not None:
                                return True

                            if self.transmitted is not None:
                                return True

                            if self.transmitted100 is not None:
                                return True

                            if self.transmitted_10k is not None:
                                return True

                            if self.transmitted_1k is not None:
                                return True

                            if self.transmitted_50k is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:jp-statistics'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.jp_statistic is not None:
                            for child_ref in self.jp_statistic:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.JpStatistics']['meta_info']


                class MibDatabases(object):
                    """
                    PIM group database for mroute mibs table
                    
                    .. attribute:: mib_database
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.mib_database = YList()
                        self.mib_database.parent = self
                        self.mib_database.name = 'mib_database'


                    class MibDatabase(object):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: assert_metric
                        
                        	Assert Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_metric_preference
                        
                        	Assert Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_rpt_bit
                        
                        	Assert RPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: bidirectional_route
                        
                        	Is this Bidir ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Multicast satic route group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr>`
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface name 
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_mask
                        
                        	Mask of the multicast root
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rpf_neighbor
                        
                        	The RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor>`
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: source_address
                        
                        	Multicast static route source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr>`
                        
                        .. attribute:: source_netmask
                        
                        	Source mask
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: spt_bit
                        
                        	Is SPT bit set ?
                        	**type**\:  bool
                        
                        .. attribute:: upstream_assert_timer
                        
                        	Upstream Assert Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime of route
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.assert_metric = None
                            self.assert_metric_preference = None
                            self.assert_rpt_bit = None
                            self.bidirectional_route = None
                            self.group_address = None
                            self.group_address_xr = Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self.protocol = None
                            self.rpf_drop = None
                            self.rpf_extranet = None
                            self.rpf_interface_name = None
                            self.rpf_mask = None
                            self.rpf_neighbor = Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self.rpf_root = Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot()
                            self.rpf_root.parent = self
                            self.rpf_safi = None
                            self.rpf_table_name = None
                            self.rpf_vrf_name = None
                            self.source_address = None
                            self.source_address_xr = Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self.source_netmask = None
                            self.spt_bit = None
                            self.upstream_assert_timer = None
                            self.uptime = None


                        class SourceAddressXr(object):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr']['meta_info']


                        class GroupAddressXr(object):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr']['meta_info']


                        class RpfNeighbor(object):
                            """
                            The RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor']['meta_info']


                        class RpfRoot(object):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-root'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:mib-database'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.assert_metric is not None:
                                return True

                            if self.assert_metric_preference is not None:
                                return True

                            if self.assert_rpt_bit is not None:
                                return True

                            if self.bidirectional_route is not None:
                                return True

                            if self.group_address is not None:
                                return True

                            if self.group_address_xr is not None and self.group_address_xr._has_data():
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rpf_drop is not None:
                                return True

                            if self.rpf_extranet is not None:
                                return True

                            if self.rpf_interface_name is not None:
                                return True

                            if self.rpf_mask is not None:
                                return True

                            if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                return True

                            if self.rpf_root is not None and self.rpf_root._has_data():
                                return True

                            if self.rpf_safi is not None:
                                return True

                            if self.rpf_table_name is not None:
                                return True

                            if self.rpf_vrf_name is not None:
                                return True

                            if self.source_address is not None:
                                return True

                            if self.source_address_xr is not None and self.source_address_xr._has_data():
                                return True

                            if self.source_netmask is not None:
                                return True

                            if self.spt_bit is not None:
                                return True

                            if self.upstream_assert_timer is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:mib-databases'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.mib_database is not None:
                            for child_ref in self.mib_database:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.MibDatabases']['meta_info']


                class GroupMapMatchRpfs(object):
                    """
                    Find matching group\-mapping for the specified
                    group address
                    
                    .. attribute:: group_map_match_rpf
                    
                    	PIM group matching mapping entry
                    	**type**\: list of    :py:class:`GroupMapMatchRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_map_match_rpf = YList()
                        self.group_map_match_rpf.parent = self
                        self.group_map_match_rpf.name = 'group_map_match_rpf'


                    class GroupMapMatchRpf(object):
                        """
                        PIM group matching mapping entry
                        
                        .. attribute:: group_address  <key>
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\:  bool
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation>`
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor>`
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.group_address = None
                            self.are_we_rp = None
                            self.group_map_information = Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self.rpf_interface_name = None
                            self.rpf_neighbor = Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self.rpf_vrf_name = None


                        class RpfNeighbor(object):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor']['meta_info']


                        class GroupMapInformation(object):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.client = None
                                self.group_count = None
                                self.is_override = None
                                self.is_used = None
                                self.mrib_active = None
                                self.prefix = Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self.prefix_length = None
                                self.priority = None
                                self.protocol = None
                                self.rp_address = Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self


                            class Prefix(object):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix']['meta_info']


                            class RpAddress(object):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.client is not None:
                                    return True

                                if self.group_count is not None:
                                    return True

                                if self.is_override is not None:
                                    return True

                                if self.is_used is not None:
                                    return True

                                if self.mrib_active is not None:
                                    return True

                                if self.prefix is not None and self.prefix._has_data():
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.priority is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.rp_address is not None and self.rp_address._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.group_address is None:
                                raise YPYModelError('Key property group_address is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-rpf[Cisco-IOS-XR-ipv4-pim-oper:group-address = ' + str(self.group_address) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.group_address is not None:
                                return True

                            if self.are_we_rp is not None:
                                return True

                            if self.group_map_information is not None and self.group_map_information._has_data():
                                return True

                            if self.rpf_interface_name is not None:
                                return True

                            if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                return True

                            if self.rpf_vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-rpfs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_map_match_rpf is not None:
                            for child_ref in self.group_map_match_rpf:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs']['meta_info']


                class NeighborOldFormats(object):
                    """
                    PIM neighbor table old format
                    
                    .. attribute:: neighbor_old_format
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.neighbor_old_format = YList()
                        self.neighbor_old_format.parent = self
                        self.neighbor_old_format.name = 'neighbor_old_format'


                    class NeighborOldFormat(object):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dr_priority = None
                            self.expires = None
                            self.expiry_timer = None
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.is_batch_asserts_capable = None
                            self.is_bfd_state = None
                            self.is_bidirectional_capable = None
                            self.is_dr_priority_capable = None
                            self.is_ecmp_redirect_capable = None
                            self.is_proxy_capable = None
                            self.is_this_neighbor_dr = None
                            self.is_this_neighbor_us = None
                            self.neighbor_address = None
                            self.neighbor_address_xr = YList()
                            self.neighbor_address_xr.parent = self
                            self.neighbor_address_xr.name = 'neighbor_address_xr'
                            self.override_interval = None
                            self.propagation_delay = None
                            self.uptime = None


                        class NeighborAddressXr(object):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-format'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dr_priority is not None:
                                return True

                            if self.expires is not None:
                                return True

                            if self.expiry_timer is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.is_batch_asserts_capable is not None:
                                return True

                            if self.is_bfd_state is not None:
                                return True

                            if self.is_bidirectional_capable is not None:
                                return True

                            if self.is_dr_priority_capable is not None:
                                return True

                            if self.is_ecmp_redirect_capable is not None:
                                return True

                            if self.is_proxy_capable is not None:
                                return True

                            if self.is_this_neighbor_dr is not None:
                                return True

                            if self.is_this_neighbor_us is not None:
                                return True

                            if self.neighbor_address is not None:
                                return True

                            if self.neighbor_address_xr is not None:
                                for child_ref in self.neighbor_address_xr:
                                    if child_ref._has_data():
                                        return True

                            if self.override_interval is not None:
                                return True

                            if self.propagation_delay is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-formats'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.neighbor_old_format is not None:
                            for child_ref in self.neighbor_old_format:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.NeighborOldFormats']['meta_info']


                class IfrsSummary(object):
                    """
                    PIM interfaces in forward reference store
                    summary
                    
                    .. attribute:: configuration_count
                    
                    	Configuration counts
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Number of interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.configuration_count = None
                        self.interface_count = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:ifrs-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.configuration_count is not None:
                            return True

                        if self.interface_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.IfrsSummary']['meta_info']


                class Ranges(object):
                    """
                    PIM range list information
                    
                    .. attribute:: range
                    
                    	PIM range list information
                    	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.range = YList()
                        self.range.parent = self
                        self.range.name = 'range'


                    class Range(object):
                        """
                        PIM range list information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                        
                        .. attribute:: client_xr
                        
                        	Client mapping learnt via
                        	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: group_range
                        
                        	List of group ranges
                        	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange>`
                        
                        .. attribute:: protocol
                        
                        	PIM protocol
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	Rendezvous point address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr>`
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.client_xr = None
                            self.expires = None
                            self.group_range = YList()
                            self.group_range.parent = self
                            self.group_range.name = 'group_range'
                            self.protocol = None
                            self.rp_address = None
                            self.rp_address_xr = Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self.source_of_information = Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation()
                            self.source_of_information.parent = self


                        class RpAddressXr(object):
                            """
                            Rendezvous point address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr']['meta_info']


                        class SourceOfInformation(object):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation']['meta_info']


                        class GroupRange(object):
                            """
                            List of group ranges
                            
                            .. attribute:: expires
                            
                            	When mapping expires
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: source_of_information
                            
                            	Source of information
                            	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.expires = None
                                self.prefix = Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix()
                                self.prefix.parent = self
                                self.prefix_length = None
                                self.source_of_information = Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation()
                                self.source_of_information.parent = self
                                self.uptime = None


                            class Prefix(object):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix']['meta_info']


                            class SourceOfInformation(object):
                                """
                                Source of information
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-range'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.expires is not None:
                                    return True

                                if self.prefix is not None and self.prefix._has_data():
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.source_of_information is not None and self.source_of_information._has_data():
                                    return True

                                if self.uptime is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:range'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.client_xr is not None:
                                return True

                            if self.expires is not None:
                                return True

                            if self.group_range is not None:
                                for child_ref in self.group_range:
                                    if child_ref._has_data():
                                        return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None:
                                return True

                            if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                                return True

                            if self.source_of_information is not None and self.source_of_information._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.Ranges.Range']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:ranges'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.range is not None:
                            for child_ref in self.range:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.Ranges']['meta_info']


                class InterfaceOldFormats(object):
                    """
                    PIM interfaces in old format
                    
                    .. attribute:: interface_old_format
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_old_format = YList()
                        self.interface_old_format.parent = self
                        self.interface_old_format.name = 'interface_old_format'


                    class InterfaceOldFormat(object):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.configured_override_interval = None
                            self.configured_propagation_delay = None
                            self.dr_address = Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                            self.dr_address.parent = self
                            self.dr_priority = None
                            self.external_neighbor_count = None
                            self.generation_id = None
                            self.hello_expiry = None
                            self.hello_interval = None
                            self.idb_acl_name = None
                            self.idb_acl_provided = None
                            self.idb_current_count = None
                            self.idb_max_count = None
                            self.idb_oor_enabled = None
                            self.idb_threshold_count = None
                            self.interface_address = YList()
                            self.interface_address.parent = self
                            self.interface_address.name = 'interface_address'
                            self.interface_address_mask = None
                            self.interface_name_xr = None
                            self.is_batch_asserts_capable = None
                            self.is_bidirectional_capable = None
                            self.is_enabled = None
                            self.is_proxy_capable = None
                            self.join_prune_interval = None
                            self.neighbor_count = None
                            self.neighbor_filter_name = None
                            self.override_interval = None
                            self.passive_interface = None
                            self.propagation_delay = None
                            self.prune_delay_enabled = None
                            self.virtual_interface = None


                        class DrAddress(object):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress']['meta_info']


                        class InterfaceAddress(object):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-old-format[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.are_we_dr is not None:
                                return True

                            if self.bfd_enabled is not None:
                                return True

                            if self.bfd_interval is not None:
                                return True

                            if self.bfd_multiplier is not None:
                                return True

                            if self.configured_override_interval is not None:
                                return True

                            if self.configured_propagation_delay is not None:
                                return True

                            if self.dr_address is not None and self.dr_address._has_data():
                                return True

                            if self.dr_priority is not None:
                                return True

                            if self.external_neighbor_count is not None:
                                return True

                            if self.generation_id is not None:
                                return True

                            if self.hello_expiry is not None:
                                return True

                            if self.hello_interval is not None:
                                return True

                            if self.idb_acl_name is not None:
                                return True

                            if self.idb_acl_provided is not None:
                                return True

                            if self.idb_current_count is not None:
                                return True

                            if self.idb_max_count is not None:
                                return True

                            if self.idb_oor_enabled is not None:
                                return True

                            if self.idb_threshold_count is not None:
                                return True

                            if self.interface_address is not None:
                                for child_ref in self.interface_address:
                                    if child_ref._has_data():
                                        return True

                            if self.interface_address_mask is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.is_batch_asserts_capable is not None:
                                return True

                            if self.is_bidirectional_capable is not None:
                                return True

                            if self.is_enabled is not None:
                                return True

                            if self.is_proxy_capable is not None:
                                return True

                            if self.join_prune_interval is not None:
                                return True

                            if self.neighbor_count is not None:
                                return True

                            if self.neighbor_filter_name is not None:
                                return True

                            if self.override_interval is not None:
                                return True

                            if self.passive_interface is not None:
                                return True

                            if self.propagation_delay is not None:
                                return True

                            if self.prune_delay_enabled is not None:
                                return True

                            if self.virtual_interface is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-old-formats'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_old_format is not None:
                            for child_ref in self.interface_old_format:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.InterfaceOldFormats']['meta_info']


                class Bsr(object):
                    """
                    PIM BSR information
                    
                    .. attribute:: bsr_elections
                    
                    	PIM BSR election state
                    	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.BsrElections>`
                    
                    .. attribute:: candidate_rps
                    
                    	PIM candidate\-RP
                    	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.CandidateRps>`
                    
                    .. attribute:: rp_caches
                    
                    	PIM BSR RP cache table
                    	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bsr_elections = Pim.Active.Vrfs.Vrf.Bsr.BsrElections()
                        self.bsr_elections.parent = self
                        self.candidate_rps = Pim.Active.Vrfs.Vrf.Bsr.CandidateRps()
                        self.candidate_rps.parent = self
                        self.rp_caches = Pim.Active.Vrfs.Vrf.Bsr.RpCaches()
                        self.rp_caches.parent = self


                    class RpCaches(object):
                        """
                        PIM BSR RP cache table
                        
                        .. attribute:: rp_cache
                        
                        	PIM BSR RP cache
                        	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rp_cache = YList()
                            self.rp_cache.parent = self
                            self.rp_cache.name = 'rp_cache'


                        class RpCache(object):
                            """
                            PIM BSR RP cache
                            
                            .. attribute:: group_prefix  <key>
                            
                            	Group prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: candidate_rp_group_count
                            
                            	C\-RP count for this Prefix
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: candidate_rp_list
                            
                            	C\-RP list for this prefix
                            	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList>`
                            
                            .. attribute:: group_prefix_length
                            
                            	Group Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_prefix_xr
                            
                            	Group Prefix
                            	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.group_prefix = None
                                self.candidate_rp_group_count = None
                                self.candidate_rp_list = Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList()
                                self.candidate_rp_list.parent = self
                                self.group_prefix_length = None
                                self.group_prefix_xr = Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                self.group_prefix_xr.parent = self


                            class GroupPrefixXr(object):
                                """
                                Group Prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-prefix-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr']['meta_info']


                            class CandidateRpList(object):
                                """
                                C\-RP list for this prefix
                                
                                .. attribute:: pim_bsr_crp_bag
                                
                                	pim bsr crp bag
                                	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.pim_bsr_crp_bag = YList()
                                    self.pim_bsr_crp_bag.parent = self
                                    self.pim_bsr_crp_bag.name = 'pim_bsr_crp_bag'


                                class PimBsrCrpBag(object):
                                    """
                                    pim bsr crp bag
                                    
                                    .. attribute:: candidate_rp_address
                                    
                                    	C\-RP address
                                    	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                    
                                    .. attribute:: candidate_rp_expires
                                    
                                    	C\-RP Expires
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_holdtime
                                    
                                    	C\-RP Holdtime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_priority
                                    
                                    	C\-RP Priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: candidate_rp_up_time
                                    
                                    	C\-RP Uptime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: protocol
                                    
                                    	PIM Protocol
                                    	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.candidate_rp_address = Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                        self.candidate_rp_address.parent = self
                                        self.candidate_rp_expires = None
                                        self.candidate_rp_holdtime = None
                                        self.candidate_rp_priority = None
                                        self.candidate_rp_up_time = None
                                        self.protocol = None


                                    class CandidateRpAddress(object):
                                        """
                                        C\-RP address
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                            return meta._meta_table['Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:pim-bsr-crp-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.candidate_rp_address is not None and self.candidate_rp_address._has_data():
                                            return True

                                        if self.candidate_rp_expires is not None:
                                            return True

                                        if self.candidate_rp_holdtime is not None:
                                            return True

                                        if self.candidate_rp_priority is not None:
                                            return True

                                        if self.candidate_rp_up_time is not None:
                                            return True

                                        if self.protocol is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp-list'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.pim_bsr_crp_bag is not None:
                                        for child_ref in self.pim_bsr_crp_bag:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.group_prefix is None:
                                    raise YPYModelError('Key property group_prefix is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-cache[Cisco-IOS-XR-ipv4-pim-oper:group-prefix = ' + str(self.group_prefix) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.group_prefix is not None:
                                    return True

                                if self.candidate_rp_group_count is not None:
                                    return True

                                if self.candidate_rp_list is not None and self.candidate_rp_list._has_data():
                                    return True

                                if self.group_prefix_length is not None:
                                    return True

                                if self.group_prefix_xr is not None and self.group_prefix_xr._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-caches'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rp_cache is not None:
                                for child_ref in self.rp_cache:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.Bsr.RpCaches']['meta_info']


                    class CandidateRps(object):
                        """
                        PIM candidate\-RP
                        
                        .. attribute:: candidate_rp
                        
                        	PIM BSR candidate RP information
                        	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.candidate_rp = YList()
                            self.candidate_rp.parent = self
                            self.candidate_rp.name = 'candidate_rp'


                        class CandidateRp(object):
                            """
                            PIM BSR candidate RP information
                            
                            .. attribute:: rp_address  <key>
                            
                            	Candidate\-RP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp
                            
                            	Cand\-RP Address
                            	**type**\:   :py:class:`CandidateRp_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_>`
                            
                            .. attribute:: candidate_rp_advance_interval
                            
                            	Cand\-RP Adv Interval in seconds
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            .. attribute:: candidate_rp_scope
                            
                            	Cand\-RP Scope
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: candidate_rp_uptime
                            
                            	Cand\-RP uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_access
                            
                            	Group Ranges Using this Cand\-RP
                            	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                            
                            .. attribute:: crp_holdtime
                            
                            	Cand\-RP Holdtime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_priority
                            
                            	Cand\-RP Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.rp_address = None
                                self.acl_name = None
                                self.candidate_rp = Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_()
                                self.candidate_rp.parent = self
                                self.candidate_rp_advance_interval = None
                                self.candidate_rp_mode = None
                                self.candidate_rp_scope = None
                                self.candidate_rp_uptime = None
                                self.crp_access = YList()
                                self.crp_access.parent = self
                                self.crp_access.name = 'crp_access'
                                self.crp_holdtime = None
                                self.crp_priority = None


                            class CandidateRp_(object):
                                """
                                Cand\-RP Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_']['meta_info']


                            class CrpAccess(object):
                                """
                                Group Ranges Using this Cand\-RP
                                
                                .. attribute:: acl_name
                                
                                	Group Access\-List Name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: candidate_rp_mode
                                
                                	Cand\-RP Mode
                                	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.acl_name = None
                                    self.candidate_rp_mode = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:crp-access'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.acl_name is not None:
                                        return True

                                    if self.candidate_rp_mode is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.rp_address is None:
                                    raise YPYModelError('Key property rp_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp[Cisco-IOS-XR-ipv4-pim-oper:rp-address = ' + str(self.rp_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.rp_address is not None:
                                    return True

                                if self.acl_name is not None:
                                    return True

                                if self.candidate_rp is not None and self.candidate_rp._has_data():
                                    return True

                                if self.candidate_rp_advance_interval is not None:
                                    return True

                                if self.candidate_rp_mode is not None:
                                    return True

                                if self.candidate_rp_scope is not None:
                                    return True

                                if self.candidate_rp_uptime is not None:
                                    return True

                                if self.crp_access is not None:
                                    for child_ref in self.crp_access:
                                        if child_ref._has_data():
                                            return True

                                if self.crp_holdtime is not None:
                                    return True

                                if self.crp_priority is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rps'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.candidate_rp is not None:
                                for child_ref in self.candidate_rp:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.Bsr.CandidateRps']['meta_info']


                    class BsrElections(object):
                        """
                        PIM BSR election state
                        
                        .. attribute:: bsr_election
                        
                        	PIM BSR information
                        	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bsr_election = YList()
                            self.bsr_election.parent = self
                            self.bsr_election.name = 'bsr_election'


                        class BsrElection(object):
                            """
                            PIM BSR information
                            
                            .. attribute:: pim_scope  <key>
                            
                            	BSR information
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: bootstrap_timeout
                            
                            	Bootstrap Timeout
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_address
                            
                            	BSR address
                            	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress>`
                            
                            .. attribute:: bsr_election_state
                            
                            	BSR Election State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_mask_length
                            
                            	Hash Function Mask Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_priority
                            
                            	BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_scope
                            
                            	BSR Scope
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_up_time
                            
                            	BSR Uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_bsr_address
                            
                            	C\-BSR address
                            	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                            
                            .. attribute:: candidate_bsr_flag
                            
                            	BSR Candidate Config Flag
                            	**type**\:  bool
                            
                            .. attribute:: candidate_bsr_mask_length
                            
                            	C\-BSR Hash Func. Mask Len
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_priority
                            
                            	C\-BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_state
                            
                            	BSR Candidate State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pim_scope = None
                                self.bootstrap_timeout = None
                                self.bsr_address = Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress()
                                self.bsr_address.parent = self
                                self.bsr_election_state = None
                                self.bsr_mask_length = None
                                self.bsr_priority = None
                                self.bsr_scope = None
                                self.bsr_up_time = None
                                self.candidate_bsr_address = Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                self.candidate_bsr_address.parent = self
                                self.candidate_bsr_flag = None
                                self.candidate_bsr_mask_length = None
                                self.candidate_bsr_priority = None
                                self.candidate_bsr_state = None


                            class BsrAddress(object):
                                """
                                BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bsr-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress']['meta_info']


                            class CandidateBsrAddress(object):
                                """
                                C\-BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-bsr-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.pim_scope is None:
                                    raise YPYModelError('Key property pim_scope is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bsr-election[Cisco-IOS-XR-ipv4-pim-oper:pim-scope = ' + str(self.pim_scope) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pim_scope is not None:
                                    return True

                                if self.bootstrap_timeout is not None:
                                    return True

                                if self.bsr_address is not None and self.bsr_address._has_data():
                                    return True

                                if self.bsr_election_state is not None:
                                    return True

                                if self.bsr_mask_length is not None:
                                    return True

                                if self.bsr_priority is not None:
                                    return True

                                if self.bsr_scope is not None:
                                    return True

                                if self.bsr_up_time is not None:
                                    return True

                                if self.candidate_bsr_address is not None and self.candidate_bsr_address._has_data():
                                    return True

                                if self.candidate_bsr_flag is not None:
                                    return True

                                if self.candidate_bsr_mask_length is not None:
                                    return True

                                if self.candidate_bsr_priority is not None:
                                    return True

                                if self.candidate_bsr_state is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bsr-elections'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bsr_election is not None:
                                for child_ref in self.bsr_election:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.Bsr.BsrElections']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bsr'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bsr_elections is not None and self.bsr_elections._has_data():
                            return True

                        if self.candidate_rps is not None and self.candidate_rps._has_data():
                            return True

                        if self.rp_caches is not None and self.rp_caches._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.Bsr']['meta_info']


                class RoutePolicy(object):
                    """
                    PIM route policy
                    
                    .. attribute:: route_policy_statistics
                    
                    	PIM route policy statistics
                    	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics>`
                    
                    .. attribute:: route_policy_tests
                    
                    	PIM route policy test run table
                    	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.route_policy_statistics = Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics()
                        self.route_policy_statistics.parent = self
                        self.route_policy_tests = Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests()
                        self.route_policy_tests.parent = self


                    class RoutePolicyStatistics(object):
                        """
                        PIM route policy statistics
                        
                        .. attribute:: any_table
                        
                        	Number of RPF lookup in any Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Number of RPF lookup in default\-only Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: drop
                        
                        	Number of RPF drops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pass_
                        
                        	Number of RPF pass
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: requests
                        
                        	Number of RPF lookup requests
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.any_table = None
                            self.default_table = None
                            self.drop = None
                            self.pass_ = None
                            self.policy_name = None
                            self.requests = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:route-policy-statistics'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.any_table is not None:
                                return True

                            if self.default_table is not None:
                                return True

                            if self.drop is not None:
                                return True

                            if self.pass_ is not None:
                                return True

                            if self.policy_name is not None:
                                return True

                            if self.requests is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics']['meta_info']


                    class RoutePolicyTests(object):
                        """
                        PIM route policy test run table
                        
                        .. attribute:: route_policy_test
                        
                        	PIM route policy test run
                        	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.route_policy_test = YList()
                            self.route_policy_test.parent = self
                            self.route_policy_test.name = 'route_policy_test'


                        class RoutePolicyTest(object):
                            """
                            PIM route policy test run
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: default_table
                            
                            	Default table selected
                            	**type**\:  bool
                            
                            .. attribute:: ext_comm
                            
                            	Extended Community
                            	**type**\:  str
                            
                            	**length:** 1..8
                            
                            .. attribute:: extended_community_rt
                            
                            	Route Target
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: group_address
                            
                            	Group IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                            
                            .. attribute:: pass_
                            
                            	Pass
                            	**type**\:  bool
                            
                            .. attribute:: policy_name
                            
                            	RPF policy name
                            	**type**\:  str
                            
                            .. attribute:: safi
                            
                            	SAFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_address
                            
                            	Source IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                            
                            .. attribute:: table_active
                            
                            	Table active
                            	**type**\:  bool
                            
                            .. attribute:: table_exists
                            
                            	Table exists
                            	**type**\:  bool
                            
                            .. attribute:: table_name
                            
                            	Table name
                            	**type**\:  str
                            
                            .. attribute:: vrf_name
                            
                            	VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.afi = None
                                self.default_table = None
                                self.ext_comm = None
                                self.extended_community_rt = None
                                self.group_address = None
                                self.group_address_xr = Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self.pass_ = None
                                self.policy_name = None
                                self.safi = None
                                self.source_address = None
                                self.source_address_xr = Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self.table_active = None
                                self.table_exists = None
                                self.table_name = None
                                self.vrf_name = None


                            class SourceAddressXr(object):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr']['meta_info']


                            class GroupAddressXr(object):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:route-policy-test'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.afi is not None:
                                    return True

                                if self.default_table is not None:
                                    return True

                                if self.ext_comm is not None:
                                    return True

                                if self.extended_community_rt is not None:
                                    return True

                                if self.group_address is not None:
                                    return True

                                if self.group_address_xr is not None and self.group_address_xr._has_data():
                                    return True

                                if self.pass_ is not None:
                                    return True

                                if self.policy_name is not None:
                                    return True

                                if self.safi is not None:
                                    return True

                                if self.source_address is not None:
                                    return True

                                if self.source_address_xr is not None and self.source_address_xr._has_data():
                                    return True

                                if self.table_active is not None:
                                    return True

                                if self.table_exists is not None:
                                    return True

                                if self.table_name is not None:
                                    return True

                                if self.vrf_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:route-policy-tests'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.route_policy_test is not None:
                                for child_ref in self.route_policy_test:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:route-policy'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.route_policy_statistics is not None and self.route_policy_statistics._has_data():
                            return True

                        if self.route_policy_tests is not None and self.route_policy_tests._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.RoutePolicy']['meta_info']


                class RpfSummary(object):
                    """
                    PIM RPF registration summary
                    
                    .. attribute:: default_safi
                    
                    	Default RPF Table SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table_name
                    
                    	Default RPF Table Name
                    	**type**\:  str
                    
                    .. attribute:: is_isis_mtr_configured
                    
                    	Is ISIS MTR configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_isis_te_configured
                    
                    	Is ISIS TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_mbgp_configured
                    
                    	Is MBGP configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_enabled
                    
                    	Is Multipath Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_interface_hash_enabled
                    
                    	Is Multipath Interface Hash Extension Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_hash_enabled
                    
                    	Is Multipath Source based Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_next_hop_hash_enabled
                    
                    	Is Multipath Source\-Nexthop Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ospf_te_configured
                    
                    	Is OSPF TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: mo_frr_configured
                    
                    	Is MoFRR configured?
                    	**type**\:  bool
                    
                    .. attribute:: rib_convergence_time_left
                    
                    	RIB convergence time left in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_convergence_timeout
                    
                    	RIB convergence timeout in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_mo_frr_configured
                    
                    	Is MoFRR RIB configured?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	Is RUMP MuRIB enabled?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.default_safi = None
                        self.default_table_name = None
                        self.is_isis_mtr_configured = None
                        self.is_isis_te_configured = None
                        self.is_mbgp_configured = None
                        self.is_multipath_enabled = None
                        self.is_multipath_interface_hash_enabled = None
                        self.is_multipath_source_hash_enabled = None
                        self.is_multipath_source_next_hop_hash_enabled = None
                        self.is_ospf_te_configured = None
                        self.is_rib_convergence = None
                        self.mo_frr_configured = None
                        self.rib_convergence_time_left = None
                        self.rib_convergence_timeout = None
                        self.rib_mo_frr_configured = None
                        self.rpf_registrations = None
                        self.rump_enabled = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.default_safi is not None:
                            return True

                        if self.default_table_name is not None:
                            return True

                        if self.is_isis_mtr_configured is not None:
                            return True

                        if self.is_isis_te_configured is not None:
                            return True

                        if self.is_mbgp_configured is not None:
                            return True

                        if self.is_multipath_enabled is not None:
                            return True

                        if self.is_multipath_interface_hash_enabled is not None:
                            return True

                        if self.is_multipath_source_hash_enabled is not None:
                            return True

                        if self.is_multipath_source_next_hop_hash_enabled is not None:
                            return True

                        if self.is_ospf_te_configured is not None:
                            return True

                        if self.is_rib_convergence is not None:
                            return True

                        if self.mo_frr_configured is not None:
                            return True

                        if self.rib_convergence_time_left is not None:
                            return True

                        if self.rib_convergence_timeout is not None:
                            return True

                        if self.rib_mo_frr_configured is not None:
                            return True

                        if self.rpf_registrations is not None:
                            return True

                        if self.rump_enabled is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.RpfSummary']['meta_info']


                class Interfaces(object):
                    """
                    PIM interfaces
                    
                    .. attribute:: interface
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Interfaces.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface = YList()
                        self.interface.parent = self
                        self.interface.name = 'interface'


                    class Interface(object):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.configured_override_interval = None
                            self.configured_propagation_delay = None
                            self.dr_address = Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress()
                            self.dr_address.parent = self
                            self.dr_priority = None
                            self.external_neighbor_count = None
                            self.generation_id = None
                            self.hello_expiry = None
                            self.hello_interval = None
                            self.idb_acl_name = None
                            self.idb_acl_provided = None
                            self.idb_current_count = None
                            self.idb_max_count = None
                            self.idb_oor_enabled = None
                            self.idb_threshold_count = None
                            self.interface_address = YList()
                            self.interface_address.parent = self
                            self.interface_address.name = 'interface_address'
                            self.interface_address_mask = None
                            self.interface_name_xr = None
                            self.is_batch_asserts_capable = None
                            self.is_bidirectional_capable = None
                            self.is_enabled = None
                            self.is_proxy_capable = None
                            self.join_prune_interval = None
                            self.neighbor_count = None
                            self.neighbor_filter_name = None
                            self.override_interval = None
                            self.passive_interface = None
                            self.propagation_delay = None
                            self.prune_delay_enabled = None
                            self.virtual_interface = None


                        class DrAddress(object):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress']['meta_info']


                        class InterfaceAddress(object):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.are_we_dr is not None:
                                return True

                            if self.bfd_enabled is not None:
                                return True

                            if self.bfd_interval is not None:
                                return True

                            if self.bfd_multiplier is not None:
                                return True

                            if self.configured_override_interval is not None:
                                return True

                            if self.configured_propagation_delay is not None:
                                return True

                            if self.dr_address is not None and self.dr_address._has_data():
                                return True

                            if self.dr_priority is not None:
                                return True

                            if self.external_neighbor_count is not None:
                                return True

                            if self.generation_id is not None:
                                return True

                            if self.hello_expiry is not None:
                                return True

                            if self.hello_interval is not None:
                                return True

                            if self.idb_acl_name is not None:
                                return True

                            if self.idb_acl_provided is not None:
                                return True

                            if self.idb_current_count is not None:
                                return True

                            if self.idb_max_count is not None:
                                return True

                            if self.idb_oor_enabled is not None:
                                return True

                            if self.idb_threshold_count is not None:
                                return True

                            if self.interface_address is not None:
                                for child_ref in self.interface_address:
                                    if child_ref._has_data():
                                        return True

                            if self.interface_address_mask is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.is_batch_asserts_capable is not None:
                                return True

                            if self.is_bidirectional_capable is not None:
                                return True

                            if self.is_enabled is not None:
                                return True

                            if self.is_proxy_capable is not None:
                                return True

                            if self.join_prune_interval is not None:
                                return True

                            if self.neighbor_count is not None:
                                return True

                            if self.neighbor_filter_name is not None:
                                return True

                            if self.override_interval is not None:
                                return True

                            if self.passive_interface is not None:
                                return True

                            if self.propagation_delay is not None:
                                return True

                            if self.prune_delay_enabled is not None:
                                return True

                            if self.virtual_interface is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.Interfaces.Interface']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interfaces'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface is not None:
                            for child_ref in self.interface:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.Interfaces']['meta_info']


                class NetIoTunnels(object):
                    """
                    Tunnel information that NETIO has 
                    
                    .. attribute:: net_io_tunnel
                    
                    	PIM netio tunnel information
                    	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.net_io_tunnel = YList()
                        self.net_io_tunnel.parent = self
                        self.net_io_tunnel.name = 'net_io_tunnel'


                    class NetIoTunnel(object):
                        """
                        PIM netio tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.tunnel_name = None
                            self.group_address_netio = Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self.rp_address = Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress()
                            self.rp_address.parent = self
                            self.source_address = Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress()
                            self.source_address.parent = self
                            self.source_address_netio = Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self.vrf_name = None


                        class SourceAddress(object):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress']['meta_info']


                        class RpAddress(object):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress']['meta_info']


                        class SourceAddressNetio(object):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-netio'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio']['meta_info']


                        class GroupAddressNetio(object):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-netio'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.tunnel_name is None:
                                raise YPYModelError('Key property tunnel_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:net-io-tunnel[Cisco-IOS-XR-ipv4-pim-oper:tunnel-name = ' + str(self.tunnel_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.tunnel_name is not None:
                                return True

                            if self.group_address_netio is not None and self.group_address_netio._has_data():
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            if self.source_address is not None and self.source_address._has_data():
                                return True

                            if self.source_address_netio is not None and self.source_address_netio._has_data():
                                return True

                            if self.vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:net-io-tunnels'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.net_io_tunnel is not None:
                            for child_ref in self.net_io_tunnel:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.NetIoTunnels']['meta_info']


                class BidirDfStates(object):
                    """
                    Bidirectional PIM DF election state table
                    
                    .. attribute:: bidir_df_state
                    
                    	Bidirectional PIM DF Election Table Entry
                    	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bidir_df_state = YList()
                        self.bidir_df_state.parent = self
                        self.bidir_df_state.name = 'bidir_df_state'


                    class BidirDfState(object):
                        """
                        Bidirectional PIM DF Election Table Entry
                        
                        .. attribute:: election_state
                        
                        	DF Election State
                        	**type**\:  str
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: our_metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: our_metric_preference
                        
                        	MetricPreference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr>`
                        
                        .. attribute:: time_nano_seconds
                        
                        	Timer expires (nseconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: time_seconds
                        
                        	Timer expires (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.election_state = None
                            self.interface_name = None
                            self.our_metric = None
                            self.our_metric_preference = None
                            self.pim_interface_name = None
                            self.rp_address = None
                            self.rp_address_xr = Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self.time_nano_seconds = None
                            self.time_seconds = None


                        class RpAddressXr(object):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-state'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.election_state is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.our_metric is not None:
                                return True

                            if self.our_metric_preference is not None:
                                return True

                            if self.pim_interface_name is not None:
                                return True

                            if self.rp_address is not None:
                                return True

                            if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                                return True

                            if self.time_nano_seconds is not None:
                                return True

                            if self.time_seconds is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-states'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bidir_df_state is not None:
                            for child_ref in self.bidir_df_state:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.BidirDfStates']['meta_info']


                class Topologies(object):
                    """
                    PIM topology table
                    
                    .. attribute:: topology
                    
                    	PIM topology information
                    	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.topology = YList()
                        self.topology.parent = self
                        self.topology.name = 'topology'


                    class Topology(object):
                        """
                        PIM topology information
                        
                        .. attribute:: alive
                        
                        	Alive time in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: anycast_rp_match
                        
                        	Group matches Anycast\-RP policy
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_route_target
                        
                        	Anycast\-RP RT
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: assume_alive
                        
                        	The Assume Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: bgp_join
                        
                        	BGP C JOIN
                        	**type**\:  bool
                        
                        .. attribute:: bgpjp_time
                        
                        	BGP C JP Time
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: connected
                        
                        	Is Connected ?
                        	**type**\:  bool
                        
                        .. attribute:: customer_routing_type
                        
                        	Type of Customer Routing in the MVPN
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: dont_check_connected
                        
                        	Do we need to make the connected check on this route ?
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	When this entry expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: extranet_route
                        
                        	Is a Extranet route ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr>`
                        
                        .. attribute:: inherit_alive
                        
                        	The Inherit Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: inherit_spt
                        
                        	The Inherit SPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: is_via_lsm
                        
                        	Via LSM
                        	**type**\:  bool
                        
                        .. attribute:: jp_status
                        
                        	Join\-Prune Status
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: limit_reached
                        
                        	Have we throttled the creation of routes or interfaces ?
                        	**type**\:  bool
                        
                        .. attribute:: low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_active
                        
                        	Is MoFRR Active?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_backup
                        
                        	Is this Mofrr Backup?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_primary
                        
                        	Is this Mofrr Primary?
                        	**type**\:  bool
                        
                        .. attribute:: orig_src_address
                        
                        	Orig Src Address
                        	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress>`
                        
                        .. attribute:: outgoing_interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface>`
                        
                        .. attribute:: probe_alive
                        
                        	The Probe Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: proxy
                        
                        	Is the RPF target a proxy?
                        	**type**\:  bool
                        
                        .. attribute:: proxy_address
                        
                        	RPF Proxy address
                        	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress>`
                        
                        .. attribute:: really_alive
                        
                        	The Really Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: register_received
                        
                        	Have registers been received for this source ?
                        	**type**\:  bool
                        
                        .. attribute:: register_received_timer
                        
                        	Register Received Timer in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: remote_source
                        
                        	MSDP told us
                        	**type**\:  bool
                        
                        .. attribute:: rib_mo_frr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rp_address
                        
                        	RP Address (If rpt)
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor>`
                        
                        .. attribute:: rpf_proxy_enabled
                        
                        	Is rpf if proxy enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpt
                        
                        	RPT bit
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpt_xr
                        
                        	Is this on the RPT ?
                        	**type**\:  bool
                        
                        .. attribute:: sa_joined
                        
                        	BGP SA join
                        	**type**\:  bool
                        
                        .. attribute:: sa_received
                        
                        	BGP SA received
                        	**type**\:  bool
                        
                        .. attribute:: sa_sent
                        
                        	BGP SA sent
                        	**type**\:  bool
                        
                        .. attribute:: secondary_rpf_interface_name
                        
                        	Secondary Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: secondary_rpf_neighbor
                        
                        	Secondary RPF Neighbor
                        	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor>`
                        
                        .. attribute:: sending_null_registers
                        
                        	Are we sending null registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: sending_registers
                        
                        	Are we sending registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: signal_sources
                        
                        	Signal Sources on route?
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr>`
                        
                        .. attribute:: spt
                        
                        	Is this on the SPT ?
                        	**type**\:  bool
                        
                        .. attribute:: suppress_registers
                        
                        	When the Null register probe expires
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vxlan
                        
                        	Is this VXLAN?
                        	**type**\:  bool
                        
                        .. attribute:: wildcard
                        
                        	WC \-Wildcard
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.alive = None
                            self.anycast_rp_match = None
                            self.anycast_rp_route_target = None
                            self.assume_alive = None
                            self.bgp_join = None
                            self.bgpjp_time = None
                            self.connected = None
                            self.customer_routing_type = None
                            self.dont_check_connected = None
                            self.expiry = None
                            self.extranet_route = None
                            self.group_address = None
                            self.group_address_xr = Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self.inherit_alive = None
                            self.inherit_spt = None
                            self.is_via_lsm = None
                            self.jp_status = None
                            self.jp_timer = None
                            self.last_hop = None
                            self.limit_reached = None
                            self.low_memory = None
                            self.mofrr_active = None
                            self.mofrr_backup = None
                            self.mofrr_enabled = None
                            self.mofrr_primary = None
                            self.orig_src_address = Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress()
                            self.orig_src_address.parent = self
                            self.outgoing_interface = YList()
                            self.outgoing_interface.parent = self
                            self.outgoing_interface.name = 'outgoing_interface'
                            self.probe_alive = None
                            self.protocol = None
                            self.proxy = None
                            self.proxy_address = Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress()
                            self.proxy_address.parent = self
                            self.really_alive = None
                            self.register_received = None
                            self.register_received_timer = None
                            self.remote_source = None
                            self.rib_mo_frr_enabled = None
                            self.rp_address = Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress()
                            self.rp_address.parent = self
                            self.rpf_drop = None
                            self.rpf_extranet = None
                            self.rpf_interface_name = None
                            self.rpf_neighbor = Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self.rpf_proxy_enabled = None
                            self.rpf_root = Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot()
                            self.rpf_root.parent = self
                            self.rpf_safi = None
                            self.rpf_table_name = None
                            self.rpf_vrf_name = None
                            self.rpt = None
                            self.rpt_xr = None
                            self.sa_joined = None
                            self.sa_received = None
                            self.sa_sent = None
                            self.secondary_rpf_interface_name = None
                            self.secondary_rpf_neighbor = Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor()
                            self.secondary_rpf_neighbor.parent = self
                            self.sending_null_registers = None
                            self.sending_registers = None
                            self.signal_sources = None
                            self.source_address = None
                            self.source_address_xr = Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self.spt = None
                            self.suppress_registers = None
                            self.uptime = None
                            self.vxlan = None
                            self.wildcard = None


                        class GroupAddressXr(object):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr']['meta_info']


                        class SourceAddressXr(object):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr']['meta_info']


                        class RpAddress(object):
                            """
                            RP Address (If rpt)
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress']['meta_info']


                        class RpfNeighbor(object):
                            """
                            RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor']['meta_info']


                        class SecondaryRpfNeighbor(object):
                            """
                            Secondary RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:secondary-rpf-neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor']['meta_info']


                        class RpfRoot(object):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-root'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot']['meta_info']


                        class ProxyAddress(object):
                            """
                            RPF Proxy address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:proxy-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress']['meta_info']


                        class OrigSrcAddress(object):
                            """
                            Orig Src Address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:orig-src-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress']['meta_info']


                        class OutgoingInterface(object):
                            """
                            Outgoing interface list
                            
                            .. attribute:: admin_boundary
                            
                            	Is this an administrative boundary ?
                            	**type**\:  bool
                            
                            .. attribute:: assert_timer
                            
                            	Assert Timer in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: assert_winner
                            
                            	Assert Winner
                            	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner>`
                            
                            .. attribute:: bgp_c_mcast_join
                            
                            	BGP C\-Mcast join
                            	**type**\:  bool
                            
                            .. attribute:: bgp_c_mcast_prune_delay_timer
                            
                            	BGP C\-MCAST Prune Suppression in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: data_mdt_join
                            
                            	Data MDT join
                            	**type**\:  bool
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: extranet_interface
                            
                            	Is this an Extranet Interface ?
                            	**type**\:  bool
                            
                            .. attribute:: forwarding_state
                            
                            	Forward or Prune
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: igmp_membership
                            
                            	IGMP membership
                            	**type**\:  bool
                            
                            .. attribute:: immediate_state
                            
                            	Immediate fwding state
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: interface_name
                            
                            	Interface Identifier
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_interest_info
                            
                            	Internal Interest
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: jp_state
                            
                            	Join\-Prune State
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: jp_timer
                            
                            	Join\-Prune Timer (secs)
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: last_hop
                            
                            	Are we last hop ?
                            	**type**\:  bool
                            
                            .. attribute:: local_mdt_join
                            
                            	Default MDT Join
                            	**type**\:  bool
                            
                            .. attribute:: local_members
                            
                            	Local Information
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: mdt_safi_join
                            
                            	MDT Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mldp_inband_mdt
                            
                            	MLDP Inband MDT interface
                            	**type**\:  bool
                            
                            .. attribute:: mldp_stale
                            
                            	OLE is stale
                            	**type**\:  bool
                            
                            .. attribute:: mvp_nv6_safi_join
                            
                            	MVPN IPv6 Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mvpn_safi_join
                            
                            	MVPN Safi join
                            	**type**\:  bool
                            
                            .. attribute:: sa_prune
                            
                            	BGP SA Prune state
                            	**type**\:  bool
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: vrf_name
                            
                            	VRF which physically owns
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.admin_boundary = None
                                self.assert_timer = None
                                self.assert_winner = Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner()
                                self.assert_winner.parent = self
                                self.bgp_c_mcast_join = None
                                self.bgp_c_mcast_prune_delay_timer = None
                                self.data_mdt_join = None
                                self.expiry = None
                                self.extranet_interface = None
                                self.forwarding_state = None
                                self.igmp_membership = None
                                self.immediate_state = None
                                self.interface_name = None
                                self.internal_interest_info = None
                                self.jp_state = None
                                self.jp_timer = None
                                self.last_hop = None
                                self.local_mdt_join = None
                                self.local_members = None
                                self.mdt_safi_join = None
                                self.mldp_inband_mdt = None
                                self.mldp_stale = None
                                self.mvp_nv6_safi_join = None
                                self.mvpn_safi_join = None
                                self.sa_prune = None
                                self.uptime = None
                                self.vrf_name = None


                            class AssertWinner(object):
                                """
                                Assert Winner
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:assert-winner'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:outgoing-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.admin_boundary is not None:
                                    return True

                                if self.assert_timer is not None:
                                    return True

                                if self.assert_winner is not None and self.assert_winner._has_data():
                                    return True

                                if self.bgp_c_mcast_join is not None:
                                    return True

                                if self.bgp_c_mcast_prune_delay_timer is not None:
                                    return True

                                if self.data_mdt_join is not None:
                                    return True

                                if self.expiry is not None:
                                    return True

                                if self.extranet_interface is not None:
                                    return True

                                if self.forwarding_state is not None:
                                    return True

                                if self.igmp_membership is not None:
                                    return True

                                if self.immediate_state is not None:
                                    return True

                                if self.interface_name is not None:
                                    return True

                                if self.internal_interest_info is not None:
                                    return True

                                if self.jp_state is not None:
                                    return True

                                if self.jp_timer is not None:
                                    return True

                                if self.last_hop is not None:
                                    return True

                                if self.local_mdt_join is not None:
                                    return True

                                if self.local_members is not None:
                                    return True

                                if self.mdt_safi_join is not None:
                                    return True

                                if self.mldp_inband_mdt is not None:
                                    return True

                                if self.mldp_stale is not None:
                                    return True

                                if self.mvp_nv6_safi_join is not None:
                                    return True

                                if self.mvpn_safi_join is not None:
                                    return True

                                if self.sa_prune is not None:
                                    return True

                                if self.uptime is not None:
                                    return True

                                if self.vrf_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.alive is not None:
                                return True

                            if self.anycast_rp_match is not None:
                                return True

                            if self.anycast_rp_route_target is not None:
                                return True

                            if self.assume_alive is not None:
                                return True

                            if self.bgp_join is not None:
                                return True

                            if self.bgpjp_time is not None:
                                return True

                            if self.connected is not None:
                                return True

                            if self.customer_routing_type is not None:
                                return True

                            if self.dont_check_connected is not None:
                                return True

                            if self.expiry is not None:
                                return True

                            if self.extranet_route is not None:
                                return True

                            if self.group_address is not None:
                                return True

                            if self.group_address_xr is not None and self.group_address_xr._has_data():
                                return True

                            if self.inherit_alive is not None:
                                return True

                            if self.inherit_spt is not None:
                                return True

                            if self.is_via_lsm is not None:
                                return True

                            if self.jp_status is not None:
                                return True

                            if self.jp_timer is not None:
                                return True

                            if self.last_hop is not None:
                                return True

                            if self.limit_reached is not None:
                                return True

                            if self.low_memory is not None:
                                return True

                            if self.mofrr_active is not None:
                                return True

                            if self.mofrr_backup is not None:
                                return True

                            if self.mofrr_enabled is not None:
                                return True

                            if self.mofrr_primary is not None:
                                return True

                            if self.orig_src_address is not None and self.orig_src_address._has_data():
                                return True

                            if self.outgoing_interface is not None:
                                for child_ref in self.outgoing_interface:
                                    if child_ref._has_data():
                                        return True

                            if self.probe_alive is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.proxy is not None:
                                return True

                            if self.proxy_address is not None and self.proxy_address._has_data():
                                return True

                            if self.really_alive is not None:
                                return True

                            if self.register_received is not None:
                                return True

                            if self.register_received_timer is not None:
                                return True

                            if self.remote_source is not None:
                                return True

                            if self.rib_mo_frr_enabled is not None:
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            if self.rpf_drop is not None:
                                return True

                            if self.rpf_extranet is not None:
                                return True

                            if self.rpf_interface_name is not None:
                                return True

                            if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                return True

                            if self.rpf_proxy_enabled is not None:
                                return True

                            if self.rpf_root is not None and self.rpf_root._has_data():
                                return True

                            if self.rpf_safi is not None:
                                return True

                            if self.rpf_table_name is not None:
                                return True

                            if self.rpf_vrf_name is not None:
                                return True

                            if self.rpt is not None:
                                return True

                            if self.rpt_xr is not None:
                                return True

                            if self.sa_joined is not None:
                                return True

                            if self.sa_received is not None:
                                return True

                            if self.sa_sent is not None:
                                return True

                            if self.secondary_rpf_interface_name is not None:
                                return True

                            if self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor._has_data():
                                return True

                            if self.sending_null_registers is not None:
                                return True

                            if self.sending_registers is not None:
                                return True

                            if self.signal_sources is not None:
                                return True

                            if self.source_address is not None:
                                return True

                            if self.source_address_xr is not None and self.source_address_xr._has_data():
                                return True

                            if self.spt is not None:
                                return True

                            if self.suppress_registers is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            if self.vxlan is not None:
                                return True

                            if self.wildcard is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.Topologies.Topology']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topologies'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.topology is not None:
                            for child_ref in self.topology:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.Topologies']['meta_info']


                class BgpAfs(object):
                    """
                    PIM BGP SAFI table
                    
                    .. attribute:: bgp_af
                    
                    	PIM BGP SAFI information
                    	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bgp_af = YList()
                        self.bgp_af.parent = self
                        self.bgp_af.name = 'bgp_af'


                    class BgpAf(object):
                        """
                        PIM BGP SAFI information
                        
                        .. attribute:: extranet_path_count
                        
                        	Count of dependent extranet paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group
                        
                        	Group address
                        	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group>`
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: is_bgp_added
                        
                        	SAFI learnt from BGP
                        	**type**\:  bool
                        
                        .. attribute:: next_hop
                        
                        	Next hop address
                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop>`
                        
                        .. attribute:: route_distinguisher
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**length:** 0..256
                        
                        .. attribute:: source
                        
                        	Source address
                        	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source>`
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.extranet_path_count = None
                            self.group = Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group()
                            self.group.parent = self
                            self.group_address = None
                            self.is_bgp_added = None
                            self.next_hop = Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop()
                            self.next_hop.parent = self
                            self.route_distinguisher = None
                            self.source = Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source()
                            self.source.parent = self
                            self.source_address = None


                        class Source(object):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source']['meta_info']


                        class Group(object):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group']['meta_info']


                        class NextHop(object):
                            """
                            Next hop address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:next-hop'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bgp-af'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.extranet_path_count is not None:
                                return True

                            if self.group is not None and self.group._has_data():
                                return True

                            if self.group_address is not None:
                                return True

                            if self.is_bgp_added is not None:
                                return True

                            if self.next_hop is not None and self.next_hop._has_data():
                                return True

                            if self.route_distinguisher is not None:
                                return True

                            if self.source is not None and self.source._has_data():
                                return True

                            if self.source_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bgp_af is not None:
                            for child_ref in self.bgp_af:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.BgpAfs']['meta_info']


                class AutoRp(object):
                    """
                    PIM Auto\-RP information
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:auto-rp'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.AutoRp']['meta_info']


                class TopologyInterfaceFlagRouteCounts(object):
                    """
                    Route count for topology with interface flag set
                    
                    .. attribute:: topology_interface_flag_route_count
                    
                    	Route count for topology with interface flag set
                    	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.topology_interface_flag_route_count = YList()
                        self.topology_interface_flag_route_count.parent = self
                        self.topology_interface_flag_route_count.name = 'topology_interface_flag_route_count'


                    class TopologyInterfaceFlagRouteCount(object):
                        """
                        Route count for topology with interface flag
                        set
                        
                        .. attribute:: interface_flag  <key>
                        
                        	Interface flag
                        	**type**\:   :py:class:`PimTopologyInterfaceFlagEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlagEnum>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_flag = None
                            self.active_group_ranges = None
                            self.group_address = Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                            self.group_address.parent = self
                            self.group_ranges = None
                            self.groute_count = None
                            self.is_node_low_memory = None
                            self.sg_route_count = None
                            self.sgr_route_count = None


                        class GroupAddress(object):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_flag is None:
                                raise YPYModelError('Key property interface_flag is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology-interface-flag-route-count[Cisco-IOS-XR-ipv4-pim-oper:interface-flag = ' + str(self.interface_flag) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_flag is not None:
                                return True

                            if self.active_group_ranges is not None:
                                return True

                            if self.group_address is not None and self.group_address._has_data():
                                return True

                            if self.group_ranges is not None:
                                return True

                            if self.groute_count is not None:
                                return True

                            if self.is_node_low_memory is not None:
                                return True

                            if self.sg_route_count is not None:
                                return True

                            if self.sgr_route_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology-interface-flag-route-counts'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.topology_interface_flag_route_count is not None:
                            for child_ref in self.topology_interface_flag_route_count:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts']['meta_info']


                class GroupMapSources(object):
                    """
                    PIM group\-mapping with source information
                    
                    .. attribute:: group_map_source
                    
                    	PIM Group Mapping Entry with source information
                    	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_map_source = YList()
                        self.group_map_source.parent = self
                        self.group_map_source.name = 'group_map_source'


                    class GroupMapSource(object):
                        """
                        PIM Group Mapping Entry with source information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                        
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	RP Priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.expires = None
                            self.group_map_information = Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self.holdtime = None
                            self.prefix = None
                            self.prefix_length = None
                            self.priority = None
                            self.protocol = None
                            self.rp_address = None
                            self.source_of_information = Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self.uptime = None


                        class SourceOfInformation(object):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation']['meta_info']


                        class GroupMapInformation(object):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.client = None
                                self.group_count = None
                                self.is_override = None
                                self.is_used = None
                                self.mrib_active = None
                                self.prefix = Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self.prefix_length = None
                                self.priority = None
                                self.protocol = None
                                self.rp_address = Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self


                            class Prefix(object):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix']['meta_info']


                            class RpAddress(object):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.client is not None:
                                    return True

                                if self.group_count is not None:
                                    return True

                                if self.is_override is not None:
                                    return True

                                if self.is_used is not None:
                                    return True

                                if self.mrib_active is not None:
                                    return True

                                if self.prefix is not None and self.prefix._has_data():
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.priority is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.rp_address is not None and self.rp_address._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-source'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.expires is not None:
                                return True

                            if self.group_map_information is not None and self.group_map_information._has_data():
                                return True

                            if self.holdtime is not None:
                                return True

                            if self.prefix is not None:
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None:
                                return True

                            if self.source_of_information is not None and self.source_of_information._has_data():
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_map_source is not None:
                            for child_ref in self.group_map_source:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapSources']['meta_info']


                class TrafficCounters(object):
                    """
                    PIM message traffic counters
                    
                    .. attribute:: boundary_acl_rx_drop
                    
                    	Inc. JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: boundary_acl_tx_drop
                    
                    	Out JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_error
                    
                    	Checksum errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: format_error
                    
                    	Malformed packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert_batched
                    
                    	Batched Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_data_register
                    
                    	Data Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_ecmp_redirect
                    
                    	Input Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb_error
                    
                    	No IDB for intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_pim_error
                    
                    	PIM Disabled on intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_error
                    
                    	No VRF for idb error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_null_register
                    
                    	Null Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim_version_error
                    
                    	Invalid PIM version error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: inputs
                    
                    	Packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_destination_packets
                    
                    	Control Packets with Invalid Destination
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_join_prunes
                    
                    	PIM invalid Join/Prunes received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_registers
                    
                    	PIM invalid registers received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_local_source_address
                    
                    	Data MDT Join msgs dropped due to local source addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_idb
                    
                    	Data MDT Join msgs dropped due to idb missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_vrf
                    
                    	Data MDT Join msgs dropped due to vrf missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_null_local_address
                    
                    	Data MDT Join msgs dropped due to null local addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_bad_type
                    
                    	Data MDT TLV bad type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_received
                    
                    	Data MDT Join Msgs received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_sent
                    
                    	Data MDT Join Msgs sent
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_joins_drop_multiple_encapsulation
                    
                    	MDT Join msgs dropped due to multiple Encap limitation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_send_queue_full
                    
                    	Packets dropped since mdt send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_socket_error
                    
                    	MDT Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_invalid_lsm_identifier
                    
                    	 Invalid LSM ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_mdt_socket_connection
                    
                    	Packets dropped since no mdt socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_source_address
                    
                    	Packets dropped since no source address
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: non_supported_packets
                    
                    	PIM non supported pckets
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert_batched
                    
                    	Batched Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_data_register
                    
                    	Data Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_ecmp_redirect
                    
                    	Output Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello_bytes
                    
                    	Output Hello Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_join_group
                    
                    	Output Join Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_join_prune_bytes
                    
                    	Output JP Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_loop_error
                    
                    	Output on loopback error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_null_register
                    
                    	Null Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_prune_group
                    
                    	Output Prune Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: outputs
                    
                    	Packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_dequeued
                    
                    	Packets Dequeued per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_enqueued
                    
                    	Packets Enqueued per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_packman_error
                    
                    	Packets Dropped due to Pakman Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue
                    
                    	Packet queue state and statistics
                    	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue>`
                    
                    .. attribute:: packet_queue_last_clear
                    
                    	Time in seconds since the last clear of all packet queues stats
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: packet_queue_length
                    
                    	Packet Queue Length per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_size
                    
                    	Packet Queue Size per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_read_socket_error
                    
                    	Packet Read Socket Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_tail_drop
                    
                    	Packet Tail Drop per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_standby
                    
                    	Packets Dropped due to Standby Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pakman_error
                    
                    	Pakman packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: send_queue_full
                    
                    	Packets dropped since send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_error
                    
                    	Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: standby_packets_error
                    
                    	Packets received in standby state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: truncated_pim_packets
                    
                    	Packets dropped due to truncated Joins or Prunes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.boundary_acl_rx_drop = None
                        self.boundary_acl_tx_drop = None
                        self.checksum_error = None
                        self.elapsed_time = None
                        self.format_error = None
                        self.input_assert = None
                        self.input_assert_batched = None
                        self.input_bsr_message = None
                        self.input_candidate_rp_advertisement = None
                        self.input_data_register = None
                        self.input_df_election = None
                        self.input_ecmp_redirect = None
                        self.input_hello = None
                        self.input_jp = None
                        self.input_no_idb_error = None
                        self.input_no_pim_error = None
                        self.input_no_vrf_error = None
                        self.input_null_register = None
                        self.input_pim_version_error = None
                        self.input_register_stop = None
                        self.inputs = None
                        self.invalid_destination_packets = None
                        self.invalid_join_prunes = None
                        self.invalid_registers = None
                        self.mdt_drop_local_source_address = None
                        self.mdt_drop_no_idb = None
                        self.mdt_drop_no_vrf = None
                        self.mdt_drop_null_local_address = None
                        self.mdt_join_bad_type = None
                        self.mdt_join_tlv_received = None
                        self.mdt_join_tlv_sent = None
                        self.mdt_joins_drop_multiple_encapsulation = None
                        self.mdt_send_queue_full = None
                        self.mdt_socket_error = None
                        self.mldp_mdt_invalid_lsm_identifier = None
                        self.no_mdt_socket_connection = None
                        self.no_socket_connection = None
                        self.no_source_address = None
                        self.non_supported_packets = None
                        self.output_assert = None
                        self.output_assert_batched = None
                        self.output_bsr_message = None
                        self.output_candidate_rp_advertisement = None
                        self.output_data_register = None
                        self.output_df_election = None
                        self.output_ecmp_redirect = None
                        self.output_hello = None
                        self.output_hello_bytes = None
                        self.output_join_group = None
                        self.output_join_prune_bytes = None
                        self.output_jp = None
                        self.output_loop_error = None
                        self.output_null_register = None
                        self.output_prune_group = None
                        self.output_register_stop = None
                        self.outputs = None
                        self.packet_dequeued = YLeafList()
                        self.packet_dequeued.parent = self
                        self.packet_dequeued.name = 'packet_dequeued'
                        self.packet_enqueued = YLeafList()
                        self.packet_enqueued.parent = self
                        self.packet_enqueued.name = 'packet_enqueued'
                        self.packet_packman_error = None
                        self.packet_queue = YList()
                        self.packet_queue.parent = self
                        self.packet_queue.name = 'packet_queue'
                        self.packet_queue_last_clear = None
                        self.packet_queue_length = YLeafList()
                        self.packet_queue_length.parent = self
                        self.packet_queue_length.name = 'packet_queue_length'
                        self.packet_queue_size = YLeafList()
                        self.packet_queue_size.parent = self
                        self.packet_queue_size.name = 'packet_queue_size'
                        self.packet_read_socket_error = None
                        self.packet_tail_drop = YLeafList()
                        self.packet_tail_drop.parent = self
                        self.packet_tail_drop.name = 'packet_tail_drop'
                        self.packets_standby = None
                        self.pakman_error = None
                        self.send_queue_full = None
                        self.socket_error = None
                        self.standby_packets_error = None
                        self.truncated_pim_packets = None


                    class PacketQueue(object):
                        """
                        Packet queue state and statistics
                        
                        .. attribute:: packet_queue_priority
                        
                        	Priority of this packet queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: packet_queue_state
                        
                        	State of the queue
                        	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState>`
                        
                        .. attribute:: packet_queue_stats
                        
                        	Statistics about the queue
                        	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.packet_queue_priority = None
                            self.packet_queue_state = Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState()
                            self.packet_queue_state.parent = self
                            self.packet_queue_stats = Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats()
                            self.packet_queue_stats.parent = self


                        class PacketQueueState(object):
                            """
                            State of the queue
                            
                            .. attribute:: max_queue_size
                            
                            	Maximum size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_bytes
                            
                            	Size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_packets
                            
                            	Size of queue in number of packets
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.max_queue_size = None
                                self.queue_size_bytes = None
                                self.queue_size_packets = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:packet-queue-state'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.max_queue_size is not None:
                                    return True

                                if self.queue_size_bytes is not None:
                                    return True

                                if self.queue_size_packets is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState']['meta_info']


                        class PacketQueueStats(object):
                            """
                            Statistics about the queue
                            
                            .. attribute:: dequeued_packets
                            
                            	Total number of packets dequeued from this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: enqueued_packets
                            
                            	Total number of packets enqueued to this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high_water_mark_bytes
                            
                            	Highest number of bytes enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: high_water_mark_packets
                            
                            	Highest number of packets enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tail_drops
                            
                            	Number packets dropped from this queue due to max size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dequeued_packets = None
                                self.enqueued_packets = None
                                self.high_water_mark_bytes = None
                                self.high_water_mark_packets = None
                                self.tail_drops = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:packet-queue-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dequeued_packets is not None:
                                    return True

                                if self.enqueued_packets is not None:
                                    return True

                                if self.high_water_mark_bytes is not None:
                                    return True

                                if self.high_water_mark_packets is not None:
                                    return True

                                if self.tail_drops is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:packet-queue'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.packet_queue_priority is not None:
                                return True

                            if self.packet_queue_state is not None and self.packet_queue_state._has_data():
                                return True

                            if self.packet_queue_stats is not None and self.packet_queue_stats._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:traffic-counters'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.boundary_acl_rx_drop is not None:
                            return True

                        if self.boundary_acl_tx_drop is not None:
                            return True

                        if self.checksum_error is not None:
                            return True

                        if self.elapsed_time is not None:
                            return True

                        if self.format_error is not None:
                            return True

                        if self.input_assert is not None:
                            return True

                        if self.input_assert_batched is not None:
                            return True

                        if self.input_bsr_message is not None:
                            return True

                        if self.input_candidate_rp_advertisement is not None:
                            return True

                        if self.input_data_register is not None:
                            return True

                        if self.input_df_election is not None:
                            return True

                        if self.input_ecmp_redirect is not None:
                            return True

                        if self.input_hello is not None:
                            return True

                        if self.input_jp is not None:
                            return True

                        if self.input_no_idb_error is not None:
                            return True

                        if self.input_no_pim_error is not None:
                            return True

                        if self.input_no_vrf_error is not None:
                            return True

                        if self.input_null_register is not None:
                            return True

                        if self.input_pim_version_error is not None:
                            return True

                        if self.input_register_stop is not None:
                            return True

                        if self.inputs is not None:
                            return True

                        if self.invalid_destination_packets is not None:
                            return True

                        if self.invalid_join_prunes is not None:
                            return True

                        if self.invalid_registers is not None:
                            return True

                        if self.mdt_drop_local_source_address is not None:
                            return True

                        if self.mdt_drop_no_idb is not None:
                            return True

                        if self.mdt_drop_no_vrf is not None:
                            return True

                        if self.mdt_drop_null_local_address is not None:
                            return True

                        if self.mdt_join_bad_type is not None:
                            return True

                        if self.mdt_join_tlv_received is not None:
                            return True

                        if self.mdt_join_tlv_sent is not None:
                            return True

                        if self.mdt_joins_drop_multiple_encapsulation is not None:
                            return True

                        if self.mdt_send_queue_full is not None:
                            return True

                        if self.mdt_socket_error is not None:
                            return True

                        if self.mldp_mdt_invalid_lsm_identifier is not None:
                            return True

                        if self.no_mdt_socket_connection is not None:
                            return True

                        if self.no_socket_connection is not None:
                            return True

                        if self.no_source_address is not None:
                            return True

                        if self.non_supported_packets is not None:
                            return True

                        if self.output_assert is not None:
                            return True

                        if self.output_assert_batched is not None:
                            return True

                        if self.output_bsr_message is not None:
                            return True

                        if self.output_candidate_rp_advertisement is not None:
                            return True

                        if self.output_data_register is not None:
                            return True

                        if self.output_df_election is not None:
                            return True

                        if self.output_ecmp_redirect is not None:
                            return True

                        if self.output_hello is not None:
                            return True

                        if self.output_hello_bytes is not None:
                            return True

                        if self.output_join_group is not None:
                            return True

                        if self.output_join_prune_bytes is not None:
                            return True

                        if self.output_jp is not None:
                            return True

                        if self.output_loop_error is not None:
                            return True

                        if self.output_null_register is not None:
                            return True

                        if self.output_prune_group is not None:
                            return True

                        if self.output_register_stop is not None:
                            return True

                        if self.outputs is not None:
                            return True

                        if self.packet_dequeued is not None:
                            for child in self.packet_dequeued:
                                if child is not None:
                                    return True

                        if self.packet_enqueued is not None:
                            for child in self.packet_enqueued:
                                if child is not None:
                                    return True

                        if self.packet_packman_error is not None:
                            return True

                        if self.packet_queue is not None:
                            for child_ref in self.packet_queue:
                                if child_ref._has_data():
                                    return True

                        if self.packet_queue_last_clear is not None:
                            return True

                        if self.packet_queue_length is not None:
                            for child in self.packet_queue_length:
                                if child is not None:
                                    return True

                        if self.packet_queue_size is not None:
                            for child in self.packet_queue_size:
                                if child is not None:
                                    return True

                        if self.packet_read_socket_error is not None:
                            return True

                        if self.packet_tail_drop is not None:
                            for child in self.packet_tail_drop:
                                if child is not None:
                                    return True

                        if self.packets_standby is not None:
                            return True

                        if self.pakman_error is not None:
                            return True

                        if self.send_queue_full is not None:
                            return True

                        if self.socket_error is not None:
                            return True

                        if self.standby_packets_error is not None:
                            return True

                        if self.truncated_pim_packets is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.TrafficCounters']['meta_info']


                class GroupMapRpfs(object):
                    """
                    PIM group mapping information
                    
                    .. attribute:: group_map_rpf
                    
                    	PIM group mapping entry
                    	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_map_rpf = YList()
                        self.group_map_rpf.parent = self
                        self.group_map_rpf.name = 'group_map_rpf'


                    class GroupMapRpf(object):
                        """
                        PIM group mapping entry
                        
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\:  bool
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_priority
                        
                        	RP priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.are_we_rp = None
                            self.client = None
                            self.group_map_information = Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self.prefix = None
                            self.prefix_length = None
                            self.protocol = None
                            self.rp_address = None
                            self.rp_priority = None
                            self.rpf_interface_name = None
                            self.rpf_neighbor = Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self.rpf_vrf_name = None


                        class RpfNeighbor(object):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor']['meta_info']


                        class GroupMapInformation(object):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.client = None
                                self.group_count = None
                                self.is_override = None
                                self.is_used = None
                                self.mrib_active = None
                                self.prefix = Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self.prefix_length = None
                                self.priority = None
                                self.protocol = None
                                self.rp_address = Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self


                            class Prefix(object):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix']['meta_info']


                            class RpAddress(object):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.client is not None:
                                    return True

                                if self.group_count is not None:
                                    return True

                                if self.is_override is not None:
                                    return True

                                if self.is_used is not None:
                                    return True

                                if self.mrib_active is not None:
                                    return True

                                if self.prefix is not None and self.prefix._has_data():
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.priority is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.rp_address is not None and self.rp_address._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.are_we_rp is not None:
                                return True

                            if self.client is not None:
                                return True

                            if self.group_map_information is not None and self.group_map_information._has_data():
                                return True

                            if self.prefix is not None:
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None:
                                return True

                            if self.rp_priority is not None:
                                return True

                            if self.rpf_interface_name is not None:
                                return True

                            if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                return True

                            if self.rpf_vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_map_rpf is not None:
                            for child_ref in self.group_map_rpf:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapRpfs']['meta_info']


                class Summary(object):
                    """
                    PIM summary
                    
                    .. attribute:: bsr_candidate_rp_set_count
                    
                    	Current crp\-set count from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_limit
                    
                    	Maximum crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_threshold
                    
                    	Threshold crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_range_threshold
                    
                    	Threshold group range from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_count
                    
                    	Current group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_limit
                    
                    	Maximum group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_auto_rp_ranges_limit
                    
                    	Global Auto\-RP maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_count
                    
                    	Global BSR current crp\-set count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_limit
                    
                    	Global BSR maximum crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_threshold
                    
                    	Global BSR Threshold crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_count
                    
                    	Global BSR current group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_limit
                    
                    	Global BSR maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_threshold
                    
                    	Global BSR Threshold group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_register_limit
                    
                    	Maximum global registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bsr_ranges_threshold_reached
                    
                    	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_auto_rp_ranges_limit_reached
                    
                    	Is global AutoRP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_bsr_ranges_limit_reached
                    
                    	Is global BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_register_limit_reached
                    
                    	Is global PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_route_limit_reached
                    
                    	Is global route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_rxi_limit_reached
                    
                    	Is global interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_maximum_enforcement_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\:  bool
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: is_ranges_limit_reached
                    
                    	Is Auto\-RP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_route_limit_reached
                    
                    	Is route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: ranges_count
                    
                    	Current group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_limit
                    
                    	Maximum group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_threshold
                    
                    	OOR theshold of grange ranges from AutoRP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_count
                    
                    	Current registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit
                    
                    	Maximum registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit_reached
                    
                    	Is PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: register_threshold
                    
                    	Threshold registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_count
                    
                    	Current routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_limit
                    
                    	Maximum routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_low_water_mark
                    
                    	The number of routes below which the throttle on route creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_threshold
                    
                    	Threshold routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rxi_limit_reached
                    
                    	Is interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: rxi_low_water_mark
                    
                    	The rxi below which the throttle on interface creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_count
                    
                    	Current Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_limit
                    
                    	Maximum Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_threshold
                    
                    	Topology Interface State threshold
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bsr_candidate_rp_set_count = None
                        self.bsr_candidate_rp_set_limit = None
                        self.bsr_candidate_rp_set_threshold = None
                        self.bsr_range_threshold = None
                        self.bsr_ranges_count = None
                        self.bsr_ranges_limit = None
                        self.global_auto_rp_ranges_limit = None
                        self.global_bsr_candidate_rp_set_count = None
                        self.global_bsr_candidate_rp_set_limit = None
                        self.global_bsr_candidate_rp_set_threshold = None
                        self.global_bsr_ranges_count = None
                        self.global_bsr_ranges_limit = None
                        self.global_bsr_ranges_threshold = None
                        self.global_register_limit = None
                        self.is_bsr_ranges_threshold_reached = None
                        self.is_global_auto_rp_ranges_limit_reached = None
                        self.is_global_bsr_ranges_limit_reached = None
                        self.is_global_register_limit_reached = None
                        self.is_global_route_limit_reached = None
                        self.is_global_rxi_limit_reached = None
                        self.is_maximum_enforcement_disabled = None
                        self.is_node_low_memory = None
                        self.is_ranges_limit_reached = None
                        self.is_route_limit_reached = None
                        self.ranges_count = None
                        self.ranges_limit = None
                        self.ranges_threshold = None
                        self.register_count = None
                        self.register_limit = None
                        self.register_limit_reached = None
                        self.register_threshold = None
                        self.route_count = None
                        self.route_limit = None
                        self.route_low_water_mark = None
                        self.route_threshold = None
                        self.rxi_limit_reached = None
                        self.rxi_low_water_mark = None
                        self.topology_interface_state_count = None
                        self.topology_interface_state_limit = None
                        self.topology_interface_state_threshold = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bsr_candidate_rp_set_count is not None:
                            return True

                        if self.bsr_candidate_rp_set_limit is not None:
                            return True

                        if self.bsr_candidate_rp_set_threshold is not None:
                            return True

                        if self.bsr_range_threshold is not None:
                            return True

                        if self.bsr_ranges_count is not None:
                            return True

                        if self.bsr_ranges_limit is not None:
                            return True

                        if self.global_auto_rp_ranges_limit is not None:
                            return True

                        if self.global_bsr_candidate_rp_set_count is not None:
                            return True

                        if self.global_bsr_candidate_rp_set_limit is not None:
                            return True

                        if self.global_bsr_candidate_rp_set_threshold is not None:
                            return True

                        if self.global_bsr_ranges_count is not None:
                            return True

                        if self.global_bsr_ranges_limit is not None:
                            return True

                        if self.global_bsr_ranges_threshold is not None:
                            return True

                        if self.global_register_limit is not None:
                            return True

                        if self.is_bsr_ranges_threshold_reached is not None:
                            return True

                        if self.is_global_auto_rp_ranges_limit_reached is not None:
                            return True

                        if self.is_global_bsr_ranges_limit_reached is not None:
                            return True

                        if self.is_global_register_limit_reached is not None:
                            return True

                        if self.is_global_route_limit_reached is not None:
                            return True

                        if self.is_global_rxi_limit_reached is not None:
                            return True

                        if self.is_maximum_enforcement_disabled is not None:
                            return True

                        if self.is_node_low_memory is not None:
                            return True

                        if self.is_ranges_limit_reached is not None:
                            return True

                        if self.is_route_limit_reached is not None:
                            return True

                        if self.ranges_count is not None:
                            return True

                        if self.ranges_limit is not None:
                            return True

                        if self.ranges_threshold is not None:
                            return True

                        if self.register_count is not None:
                            return True

                        if self.register_limit is not None:
                            return True

                        if self.register_limit_reached is not None:
                            return True

                        if self.register_threshold is not None:
                            return True

                        if self.route_count is not None:
                            return True

                        if self.route_limit is not None:
                            return True

                        if self.route_low_water_mark is not None:
                            return True

                        if self.route_threshold is not None:
                            return True

                        if self.rxi_limit_reached is not None:
                            return True

                        if self.rxi_low_water_mark is not None:
                            return True

                        if self.topology_interface_state_count is not None:
                            return True

                        if self.topology_interface_state_limit is not None:
                            return True

                        if self.topology_interface_state_threshold is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.Summary']['meta_info']


                class Gre(object):
                    """
                    GRE information
                    
                    .. attribute:: gre_hashes
                    
                    	GRE hash
                    	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreHashes>`
                    
                    .. attribute:: gre_next_hops
                    
                    	GRE destination neighbor table
                    	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.gre_hashes = Pim.Active.Vrfs.Vrf.Gre.GreHashes()
                        self.gre_hashes.parent = self
                        self.gre_next_hops = Pim.Active.Vrfs.Vrf.Gre.GreNextHops()
                        self.gre_next_hops.parent = self


                    class GreHashes(object):
                        """
                        GRE hash
                        
                        .. attribute:: gre_hash
                        
                        	PIM GRE Hashed Underlying Interface
                        	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.gre_hash = YList()
                            self.gre_hash.parent = self
                            self.gre_hash.name = 'gre_hash'


                        class GreHash(object):
                            """
                            PIM GRE Hashed Underlying Interface
                            
                            .. attribute:: destination_address  <key>
                            
                            	Destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: ifname  <key>
                            
                            	GRE Tunnel Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_address  <key>
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.destination_address = None
                                self.ifname = None
                                self.source_address = None
                                self.next_hop_interface = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.destination_address is None:
                                    raise YPYModelError('Key property destination_address is None')
                                if self.ifname is None:
                                    raise YPYModelError('Key property ifname is None')
                                if self.source_address is None:
                                    raise YPYModelError('Key property source_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-hash[Cisco-IOS-XR-ipv4-pim-oper:destination-address = ' + str(self.destination_address) + '][Cisco-IOS-XR-ipv4-pim-oper:ifname = ' + str(self.ifname) + '][Cisco-IOS-XR-ipv4-pim-oper:source-address = ' + str(self.source_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.destination_address is not None:
                                    return True

                                if self.ifname is not None:
                                    return True

                                if self.source_address is not None:
                                    return True

                                if self.next_hop_interface is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-hashes'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.gre_hash is not None:
                                for child_ref in self.gre_hash:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.Gre.GreHashes']['meta_info']


                    class GreNextHops(object):
                        """
                        GRE destination neighbor table
                        
                        .. attribute:: gre_next_hop
                        
                        	PIM GRE address next\-hop information
                        	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.gre_next_hop = YList()
                            self.gre_next_hop.parent = self
                            self.gre_next_hop.name = 'gre_next_hop'


                        class GreNextHop(object):
                            """
                            PIM GRE address next\-hop information
                            
                            .. attribute:: destination_address  <key>
                            
                            	GRE destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: gre_path
                            
                            	GRE Paths list
                            	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath>`
                            
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.destination_address = None
                                self.gre_path = YList()
                                self.gre_path.parent = self
                                self.gre_path.name = 'gre_path'
                                self.is_connected = None
                                self.metric = None
                                self.metric_preference = None
                                self.registered_address = Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                self.registered_address.parent = self


                            class RegisteredAddress(object):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:registered-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress']['meta_info']


                            class GrePath(object):
                                """
                                GRE Paths list
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: gre_interface_name
                                
                                	GRE Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: gre_neighbor
                                
                                	GRE neighbor
                                	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                                
                                .. attribute:: gre_next_hop
                                
                                	GRE nexthop
                                	**type**\:   :py:class:`GreNextHop_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_>`
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_gre_interface_disabled
                                
                                	Is the gre interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.extranet_vrf_name = None
                                    self.gre_interface_name = None
                                    self.gre_neighbor = Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                    self.gre_neighbor.parent = self
                                    self.gre_next_hop = Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_()
                                    self.gre_next_hop.parent = self
                                    self.is_connector_attribute_present = None
                                    self.is_gre_interface_disabled = None
                                    self.is_via_lsm = None


                                class GreNeighbor(object):
                                    """
                                    GRE neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-neighbor'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor']['meta_info']


                                class GreNextHop_(object):
                                    """
                                    GRE nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.extranet_vrf_name is not None:
                                        return True

                                    if self.gre_interface_name is not None:
                                        return True

                                    if self.gre_neighbor is not None and self.gre_neighbor._has_data():
                                        return True

                                    if self.gre_next_hop is not None and self.gre_next_hop._has_data():
                                        return True

                                    if self.is_connector_attribute_present is not None:
                                        return True

                                    if self.is_gre_interface_disabled is not None:
                                        return True

                                    if self.is_via_lsm is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.destination_address is None:
                                    raise YPYModelError('Key property destination_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hop[Cisco-IOS-XR-ipv4-pim-oper:destination-address = ' + str(self.destination_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.destination_address is not None:
                                    return True

                                if self.gre_path is not None:
                                    for child_ref in self.gre_path:
                                        if child_ref._has_data():
                                            return True

                                if self.is_connected is not None:
                                    return True

                                if self.metric is not None:
                                    return True

                                if self.metric_preference is not None:
                                    return True

                                if self.registered_address is not None and self.registered_address._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hops'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.gre_next_hop is not None:
                                for child_ref in self.gre_next_hop:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.Gre.GreNextHops']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.gre_hashes is not None and self.gre_hashes._has_data():
                            return True

                        if self.gre_next_hops is not None and self.gre_next_hops._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.Gre']['meta_info']


                class BidirDfWinners(object):
                    """
                    Bidirectional PIM DF election winner table
                    
                    .. attribute:: bidir_df_winner
                    
                    	Bidirectional PIM DF election table entry
                    	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bidir_df_winner = YList()
                        self.bidir_df_winner.parent = self
                        self.bidir_df_winner.name = 'bidir_df_winner'


                    class BidirDfWinner(object):
                        """
                        Bidirectional PIM DF election table entry
                        
                        .. attribute:: are_we_df
                        
                        	Are we DF
                        	**type**\:  bool
                        
                        .. attribute:: df_winner
                        
                        	DF Winner
                        	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner>`
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                        
                        .. attribute:: rp_lan
                        
                        	Is this the RP LAN
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.are_we_df = None
                            self.df_winner = Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner()
                            self.df_winner.parent = self
                            self.interface_name = None
                            self.metric = None
                            self.metric_preference = None
                            self.pim_interface_name = None
                            self.rp_address = None
                            self.rp_address_xr = Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self.rp_lan = None
                            self.uptime = None


                        class RpAddressXr(object):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr']['meta_info']


                        class DfWinner(object):
                            """
                            DF Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:df-winner'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winner'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.are_we_df is not None:
                                return True

                            if self.df_winner is not None and self.df_winner._has_data():
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.metric is not None:
                                return True

                            if self.metric_preference is not None:
                                return True

                            if self.pim_interface_name is not None:
                                return True

                            if self.rp_address is not None:
                                return True

                            if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                                return True

                            if self.rp_lan is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winners'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bidir_df_winner is not None:
                            for child_ref in self.bidir_df_winner:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.BidirDfWinners']['meta_info']


                class TableContexts(object):
                    """
                    PIM table context list
                    
                    .. attribute:: table_context
                    
                    	PIM table context information
                    	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TableContexts.TableContext>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.table_context = YList()
                        self.table_context.parent = self
                        self.table_context.name = 'table_context'


                    class TableContext(object):
                        """
                        PIM table context information
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: saf_name
                        
                        	SAF name
                        	**type**\:   :py:class:`PimSafiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafiEnum>`
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: topology_name
                        
                        	Topology name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.afi = None
                            self.is_active = None
                            self.is_ital_registration_done = None
                            self.is_rib_convergence = None
                            self.is_rib_convergence_received = None
                            self.is_rib_registration_done = None
                            self.rpf_registrations = None
                            self.saf_name = None
                            self.safi = None
                            self.table_id = None
                            self.table_name = None
                            self.topology_name = None
                            self.vrf_id = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:table-context'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.afi is not None:
                                return True

                            if self.is_active is not None:
                                return True

                            if self.is_ital_registration_done is not None:
                                return True

                            if self.is_rib_convergence is not None:
                                return True

                            if self.is_rib_convergence_received is not None:
                                return True

                            if self.is_rib_registration_done is not None:
                                return True

                            if self.rpf_registrations is not None:
                                return True

                            if self.saf_name is not None:
                                return True

                            if self.safi is not None:
                                return True

                            if self.table_id is not None:
                                return True

                            if self.table_name is not None:
                                return True

                            if self.topology_name is not None:
                                return True

                            if self.vrf_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.TableContexts.TableContext']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:table-contexts'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.table_context is not None:
                            for child_ref in self.table_context:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.TableContexts']['meta_info']


                class NeighborSummaries(object):
                    """
                    PIM neighbor summary table
                    
                    .. attribute:: neighbor_summary
                    
                    	PIM neighbor summary information
                    	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.neighbor_summary = YList()
                        self.neighbor_summary.parent = self
                        self.neighbor_summary.name = 'neighbor_summary'


                    class NeighborSummary(object):
                        """
                        PIM neighbor summary information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: number_of_external_neighbors
                        
                        	Number of external neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: number_of_neighbors
                        
                        	Number of neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.number_of_external_neighbors = None
                            self.number_of_neighbors = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-summary[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.number_of_external_neighbors is not None:
                                return True

                            if self.number_of_neighbors is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-summaries'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.neighbor_summary is not None:
                            for child_ref in self.neighbor_summary:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.NeighborSummaries']['meta_info']


                class Context(object):
                    """
                    PIM context information
                    
                    .. attribute:: active_table_count
                    
                    	Number of active Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: allow_rp_configured
                    
                    	Allow RP Configured
                    	**type**\:  bool
                    
                    .. attribute:: allow_rp_group_list
                    
                    	Allow RP Group\-List ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: allow_rp_rp_list
                    
                    	Allow RP RP\-list ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: anycast_rp_configured
                    
                    	Anycast\-RP config
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_policy_name
                    
                    	Anycast\-RP Policy Name
                    	**type**\:  str
                    
                    .. attribute:: anycast_rp_range
                    
                    	Anycast\-RP Ranges
                    	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.AnycastRpRange>`
                    
                    .. attribute:: bgp_auto_discovery_configured
                    
                    	BGP Auto\-Discovery configured
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery_type
                    
                    	BGP Auto Discovery Type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_i_pmsi_added
                    
                    	BGP I\-PMSI Added
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_address
                    
                    	BGP remote interface address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: bgp_remote_interface
                    
                    	BGP remote interface handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: bgp_remote_interface_name
                    
                    	BGP remote interface name
                    	**type**\:  str
                    
                    .. attribute:: bgp_remote_on
                    
                    	BGP remote interface status
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_state
                    
                    	BGP remote interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_source_active_announce
                    
                    	Send BGP Source\-Active Announcements
                    	**type**\:  bool
                    
                    .. attribute:: export_route_target
                    
                    	Export Route Targets
                    	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget>`
                    
                    .. attribute:: gin_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: gin_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: gin_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: import_route_target
                    
                    	Import Route Targets
                    	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget>`
                    
                    .. attribute:: in_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: in_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: in_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_signaling_local_enabled
                    
                    	Inband signaling Local enabled
                    	**type**\:  bool
                    
                    .. attribute:: in_band_signaling_remote_enabled
                    
                    	Inband signaling Remote enabled
                    	**type**\:  bool
                    
                    .. attribute:: inter_autonomous_system_enabled
                    
                    	Inter\-AS Enabled
                    	**type**\:  bool
                    
                    .. attribute:: ir_maximum_mdt_aggregation
                    
                    	IR MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_announce_interval
                    
                    	IR Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_switchover_interval
                    
                    	IR Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_interface
                    
                    	IRMDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: ir_mdt_mtu
                    
                    	IRMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_name
                    
                    	IR MDT Name
                    	**type**\:  str
                    
                    .. attribute:: ir_mdt_rpf_identifier
                    
                    	IR RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_tail_label
                    
                    	IR Tail Label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active
                    	**type**\:  bool
                    
                    .. attribute:: is_active_ital
                    
                    	Active ITAL
                    	**type**\:  bool
                    
                    .. attribute:: is_all_interface_disable_operation
                    
                    	PIM all interface disable operation
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_enabled
                    
                    	Auto RP Listen Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_sock_add
                    
                    	Auto RP listen sock add
                    	**type**\:  bool
                    
                    .. attribute:: is_create_gin_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_in_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_ir_mdt_interface
                    
                    	Create IR MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mdt_interface
                    
                    	Create MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mldp_mdt_interface
                    
                    	Create MLDP MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_rsvp_te_mdt_interface
                    
                    	Create RSVP\-TE MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_default_granges
                    
                    	Default granges
                    	**type**\:  bool
                    
                    .. attribute:: is_gin_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_in_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_ir_mdt_owner
                    
                    	IR MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_added
                    
                    	VRF LPTS filter added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_m_host_publish_pending
                    
                    	Publish pending for MHost Default interface
                    	**type**\:  bool
                    
                    .. attribute:: is_mdt_owner
                    
                    	MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mldp_mdt_owner
                    
                    	MLDP MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mrib_register
                    
                    	MRIB Register
                    	**type**\:  bool
                    
                    .. attribute:: is_multicast_rib_registration
                    
                    	Mcast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converge_received
                    
                    	PIM NSF RIB converge received
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converged
                    
                    	PIM NSF RIB converged
                    	**type**\:  bool
                    
                    .. attribute:: is_redistribution_reset
                    
                    	Pending redist reset
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_added
                    
                    	VRF LPTS filter added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_add_required
                    
                    	VRF required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_added
                    
                    	VRF added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_enabled
                    
                    	PIM RIB multiplath enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_interface_hash
                    
                    	PIM RIB multipath interface hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_hash
                    
                    	PIM RIB multipath source based hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_next_hop_hash
                    
                    	PIM RIB multipath source\-nexthop hash
                    	**type**\:  bool
                    
                    .. attribute:: is_routing_enabled
                    
                    	Routing Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rsvp_te_mdt_owner
                    
                    	RSVP\-TE MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_add_required
                    
                    	VRF required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_added
                    
                    	VRF added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_add_required
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_added
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind
                    
                    	VRF bound on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind_required
                    
                    	VRF bind required on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_unicast_rib_registration
                    
                    	Ucast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: maximum_mdt_aggregation
                    
                    	MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_announce_interval
                    
                    	Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_switchover_interval
                    
                    	Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_default_group
                    
                    	MDT Default group
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_gre_remote_rpf_identifier
                    
                    	GRE\-MDT Remote RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_gre_rpf_identifier
                    
                    	GRE\-MDT RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_interface
                    
                    	MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mdt_mtu
                    
                    	MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_neighbor_filter_name
                    
                    	MDT Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: mdt_partitioned_ir_control_identifier
                    
                    	Partitioned IR MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_partitioned_mdt_control_identifier
                    
                    	Partitioned MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mhost_default_interface_config
                    
                    	Configured Mhost Defint
                    	**type**\:  str
                    
                    .. attribute:: mhost_interface
                    
                    	MHost handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mldp_auto_rp_announce_tree_added
                    
                    	MLDP Autorp Announce Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_auto_rp_discovery_tree_added
                    
                    	MLDP Autorp Discovery Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_bsr_control_tree_added
                    
                    	MLDP BSR Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_control_head_lsm_identifier
                    
                    	MLDP MVPN Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_local_label
                    
                    	Partitioned MDT Head local label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_lsm_identifier
                    
                    	MLDP Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_maximum_mdt_aggregation
                    
                    	MLDP MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_announce_interval
                    
                    	MLDP Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_switchover_interval
                    
                    	MLDP Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_interface
                    
                    	MLDP MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mldp_mdt_mtu
                    
                    	MLDP MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_name
                    
                    	MLDP MDT Name
                    	**type**\:  str
                    
                    .. attribute:: mldp_mdt_remote_rpf_identifier
                    
                    	MLDP Remote RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_rpf_identifier
                    
                    	MLDP RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partioned_mp2m_ptree
                    
                    	MP2MP Partitioned MDT tree
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_head_lsm_identifier
                    
                    	Partitioned MDT Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partitioned_mdt_configured
                    
                    	MLDP Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_mdt_identifier
                    
                    	MLDP Partitioned MDT Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_head_lsm_identifier
                    
                    	MLDP Remote Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_partitioned_mdt_configured
                    
                    	MLDP Remote Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_root_address
                    
                    	MLDP Root addresses
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_root_count
                    
                    	MLDP Root count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: murib_id
                    
                    	MURIB ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: non_default_vrf_count_on_socket
                    
                    	Count of non\-default vrfs on raw socket
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: organization_unique_identifier
                    
                    	OUI for VPN\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mpte_li_drop
                    
                    	Route LI updates dropped for P2MP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redistribution_reset_count
                    
                    	Redist reset count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_default_group
                    
                    	Remote Default Group
                    	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup>`
                    
                    .. attribute:: remote_table_id
                    
                    	Remote Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_distinguisher
                    
                    	RD value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: rpf_default_table
                    
                    	RPF Default Table
                    	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable>`
                    
                    .. attribute:: rpf_id
                    
                    	RPF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_policy_name
                    
                    	RPF topology selection route\-policy name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_maximum_mdt_aggregation
                    
                    	RSVP\-TE MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_announce_interval
                    
                    	RSVP\-TE Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_switchover_interval
                    
                    	RSVP\-TE Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_interface
                    
                    	RSVP\-TEMDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rsvp_te_mdt_mtu
                    
                    	RSVP\-TEMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_name
                    
                    	RSVP\-TE MDT Name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_mdt_rpf_identifier
                    
                    	RSVP\-TE RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_static_p2mp_count
                    
                    	Number of Static P2MP\-TE MDT
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	PIM is using MuRIB
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_time
                    
                    	S,G Expiry Time Configured, in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: sg_expiry_timer_configured
                    
                    	S,G Expiry Timer Configured
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_timer_sg_list
                    
                    	S,G expiry timer ACL name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: stale_rd_present
                    
                    	RD is stale
                    	**type**\:  bool
                    
                    .. attribute:: suppress_pim_data_mdt_tlv
                    
                    	Suppress PIM Data\-MDT TLV Announcements
                    	**type**\:  bool
                    
                    .. attribute:: suppress_shared_tree_join
                    
                    	Suppress Shared\-Tree Joins
                    	**type**\:  bool
                    
                    .. attribute:: table_count
                    
                    	Number of configured Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: umh
                    
                    	Join UMH Core\-Tree
                    	**type**\:  bool
                    
                    .. attribute:: valid_rd_present
                    
                    	RD is valid
                    	**type**\:  bool
                    
                    .. attribute:: vpn_index
                    
                    	VPN Index
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.active_table_count = None
                        self.allow_rp_configured = None
                        self.allow_rp_group_list = None
                        self.allow_rp_rp_list = None
                        self.anycast_rp_configured = None
                        self.anycast_rp_policy_name = None
                        self.anycast_rp_range = YList()
                        self.anycast_rp_range.parent = self
                        self.anycast_rp_range.name = 'anycast_rp_range'
                        self.bgp_auto_discovery_configured = None
                        self.bgp_auto_discovery_type = None
                        self.bgp_i_pmsi_added = None
                        self.bgp_remote_address = None
                        self.bgp_remote_interface = None
                        self.bgp_remote_interface_name = None
                        self.bgp_remote_on = None
                        self.bgp_remote_state = None
                        self.bgp_source_active_announce = None
                        self.export_route_target = YList()
                        self.export_route_target.parent = self
                        self.export_route_target.name = 'export_route_target'
                        self.gin_b_and_mdt_data_announce_interval = None
                        self.gin_b_and_mdt_data_switchover_interval = None
                        self.gin_b_and_mdt_interface = None
                        self.gin_b_and_mdt_mtu = None
                        self.gin_b_and_mdt_name = None
                        self.gin_b_and_mdt_rpf_identifier = None
                        self.gin_band_maximum_mdt_aggregation = None
                        self.import_route_target = YList()
                        self.import_route_target.parent = self
                        self.import_route_target.name = 'import_route_target'
                        self.in_b_and_mdt_data_announce_interval = None
                        self.in_b_and_mdt_data_switchover_interval = None
                        self.in_b_and_mdt_interface = None
                        self.in_b_and_mdt_mtu = None
                        self.in_b_and_mdt_name = None
                        self.in_b_and_mdt_rpf_identifier = None
                        self.in_band_maximum_mdt_aggregation = None
                        self.in_band_signaling_local_enabled = None
                        self.in_band_signaling_remote_enabled = None
                        self.inter_autonomous_system_enabled = None
                        self.ir_maximum_mdt_aggregation = None
                        self.ir_mdt_data_announce_interval = None
                        self.ir_mdt_data_switchover_interval = None
                        self.ir_mdt_interface = None
                        self.ir_mdt_mtu = None
                        self.ir_mdt_name = None
                        self.ir_mdt_rpf_identifier = None
                        self.ir_mdt_tail_label = None
                        self.is_active = None
                        self.is_active_ital = None
                        self.is_all_interface_disable_operation = None
                        self.is_auto_rp_listen_enabled = None
                        self.is_auto_rp_listen_sock_add = None
                        self.is_create_gin_b_and_mdt_interface = None
                        self.is_create_in_b_and_mdt_interface = None
                        self.is_create_ir_mdt_interface = None
                        self.is_create_mdt_interface = None
                        self.is_create_mldp_mdt_interface = None
                        self.is_create_rsvp_te_mdt_interface = None
                        self.is_default_granges = None
                        self.is_gin_b_and_mdt_owner = None
                        self.is_in_b_and_mdt_owner = None
                        self.is_ir_mdt_owner = None
                        self.is_lpts_socket_add_required = None
                        self.is_lpts_socket_added = None
                        self.is_m_host_publish_pending = None
                        self.is_mdt_owner = None
                        self.is_mldp_mdt_owner = None
                        self.is_mrib_register = None
                        self.is_multicast_rib_registration = None
                        self.is_pim_nsf_rib_converge_received = None
                        self.is_pim_nsf_rib_converged = None
                        self.is_redistribution_reset = None
                        self.is_register_injection_lpts_socket_add_required = None
                        self.is_register_injection_lpts_socket_added = None
                        self.is_register_injection_socket_add_required = None
                        self.is_register_injection_socket_added = None
                        self.is_rib_multipath_enabled = None
                        self.is_rib_multipath_interface_hash = None
                        self.is_rib_multipath_source_hash = None
                        self.is_rib_multipath_source_next_hop_hash = None
                        self.is_routing_enabled = None
                        self.is_rsvp_te_mdt_owner = None
                        self.is_socket_add_required = None
                        self.is_socket_added = None
                        self.is_udp_socket_add_required = None
                        self.is_udp_socket_added = None
                        self.is_udp_socket_bind = None
                        self.is_udp_socket_bind_required = None
                        self.is_unicast_rib_registration = None
                        self.maximum_mdt_aggregation = None
                        self.mdt_data_announce_interval = None
                        self.mdt_data_switchover_interval = None
                        self.mdt_default_group = None
                        self.mdt_gre_remote_rpf_identifier = None
                        self.mdt_gre_rpf_identifier = None
                        self.mdt_interface = None
                        self.mdt_mtu = None
                        self.mdt_neighbor_filter_name = None
                        self.mdt_partitioned_ir_control_identifier = None
                        self.mdt_partitioned_mdt_control_identifier = None
                        self.mhost_default_interface_config = None
                        self.mhost_interface = None
                        self.mldp_auto_rp_announce_tree_added = None
                        self.mldp_auto_rp_discovery_tree_added = None
                        self.mldp_bsr_control_tree_added = None
                        self.mldp_control_head_lsm_identifier = None
                        self.mldp_head_local_label = None
                        self.mldp_head_lsm_identifier = None
                        self.mldp_maximum_mdt_aggregation = None
                        self.mldp_mdt_data_announce_interval = None
                        self.mldp_mdt_data_switchover_interval = None
                        self.mldp_mdt_interface = None
                        self.mldp_mdt_mtu = None
                        self.mldp_mdt_name = None
                        self.mldp_mdt_remote_rpf_identifier = None
                        self.mldp_mdt_rpf_identifier = None
                        self.mldp_partioned_mp2m_ptree = None
                        self.mldp_partitioned_head_lsm_identifier = None
                        self.mldp_partitioned_mdt_configured = None
                        self.mldp_partitioned_mdt_identifier = None
                        self.mldp_remote_head_lsm_identifier = None
                        self.mldp_remote_partitioned_mdt_configured = None
                        self.mldp_root_address = YLeafList()
                        self.mldp_root_address.parent = self
                        self.mldp_root_address.name = 'mldp_root_address'
                        self.mldp_root_count = None
                        self.murib_id = None
                        self.neighbor_filter_name = None
                        self.non_default_vrf_count_on_socket = None
                        self.organization_unique_identifier = None
                        self.p2mpte_li_drop = None
                        self.redistribution_reset_count = None
                        self.remote_default_group = Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup()
                        self.remote_default_group.parent = self
                        self.remote_table_id = None
                        self.route_distinguisher = None
                        self.rpf_default_table = Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable()
                        self.rpf_default_table.parent = self
                        self.rpf_id = None
                        self.rpf_policy_name = None
                        self.rsvp_te_maximum_mdt_aggregation = None
                        self.rsvp_te_mdt_data_announce_interval = None
                        self.rsvp_te_mdt_data_switchover_interval = None
                        self.rsvp_te_mdt_interface = None
                        self.rsvp_te_mdt_mtu = None
                        self.rsvp_te_mdt_name = None
                        self.rsvp_te_mdt_rpf_identifier = None
                        self.rsvp_te_mdt_static_p2mp_count = None
                        self.rump_enabled = None
                        self.sg_expiry_time = None
                        self.sg_expiry_timer_configured = None
                        self.sg_expiry_timer_sg_list = None
                        self.stale_rd_present = None
                        self.suppress_pim_data_mdt_tlv = None
                        self.suppress_shared_tree_join = None
                        self.table_count = None
                        self.table_id = None
                        self.umh = None
                        self.valid_rd_present = None
                        self.vpn_index = None
                        self.vrf_id = None


                    class RemoteDefaultGroup(object):
                        """
                        Remote Default Group
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:remote-default-group'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup']['meta_info']


                    class RpfDefaultTable(object):
                        """
                        RPF Default Table
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.afi = None
                            self.is_active = None
                            self.is_ital_registration_done = None
                            self.is_rib_convergence = None
                            self.is_rib_convergence_received = None
                            self.is_rib_registration_done = None
                            self.rpf_registrations = None
                            self.safi = None
                            self.table_id = None
                            self.table_name = None
                            self.vrf_id = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-default-table'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.afi is not None:
                                return True

                            if self.is_active is not None:
                                return True

                            if self.is_ital_registration_done is not None:
                                return True

                            if self.is_rib_convergence is not None:
                                return True

                            if self.is_rib_convergence_received is not None:
                                return True

                            if self.is_rib_registration_done is not None:
                                return True

                            if self.rpf_registrations is not None:
                                return True

                            if self.safi is not None:
                                return True

                            if self.table_id is not None:
                                return True

                            if self.table_name is not None:
                                return True

                            if self.vrf_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable']['meta_info']


                    class ExportRouteTarget(object):
                        """
                        Export Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.anycast_rp = None
                            self.anycast_rp_marked = None
                            self.bgp_auto_discovery = None
                            self.configured = None
                            self.route_target = None
                            self.segment_border = None
                            self.update_pending = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:export-route-target'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.anycast_rp is not None:
                                return True

                            if self.anycast_rp_marked is not None:
                                return True

                            if self.bgp_auto_discovery is not None:
                                return True

                            if self.configured is not None:
                                return True

                            if self.route_target is not None:
                                return True

                            if self.segment_border is not None:
                                return True

                            if self.update_pending is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget']['meta_info']


                    class ImportRouteTarget(object):
                        """
                        Import Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.anycast_rp = None
                            self.anycast_rp_marked = None
                            self.bgp_auto_discovery = None
                            self.configured = None
                            self.route_target = None
                            self.segment_border = None
                            self.update_pending = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:import-route-target'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.anycast_rp is not None:
                                return True

                            if self.anycast_rp_marked is not None:
                                return True

                            if self.bgp_auto_discovery is not None:
                                return True

                            if self.configured is not None:
                                return True

                            if self.route_target is not None:
                                return True

                            if self.segment_border is not None:
                                return True

                            if self.update_pending is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget']['meta_info']


                    class AnycastRpRange(object):
                        """
                        Anycast\-RP Ranges
                        
                        .. attribute:: ancast_rp_marked
                        
                        	Anycast\-RP Range marked
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Anycast\-RP Range Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Anycast\-RP Range Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ancast_rp_marked = None
                            self.prefix = Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None


                        class Prefix(object):
                            """
                            Anycast\-RP Range Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:anycast-rp-range'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ancast_rp_marked is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.Context.AnycastRpRange']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:context'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.active_table_count is not None:
                            return True

                        if self.allow_rp_configured is not None:
                            return True

                        if self.allow_rp_group_list is not None:
                            return True

                        if self.allow_rp_rp_list is not None:
                            return True

                        if self.anycast_rp_configured is not None:
                            return True

                        if self.anycast_rp_policy_name is not None:
                            return True

                        if self.anycast_rp_range is not None:
                            for child_ref in self.anycast_rp_range:
                                if child_ref._has_data():
                                    return True

                        if self.bgp_auto_discovery_configured is not None:
                            return True

                        if self.bgp_auto_discovery_type is not None:
                            return True

                        if self.bgp_i_pmsi_added is not None:
                            return True

                        if self.bgp_remote_address is not None:
                            return True

                        if self.bgp_remote_interface is not None:
                            return True

                        if self.bgp_remote_interface_name is not None:
                            return True

                        if self.bgp_remote_on is not None:
                            return True

                        if self.bgp_remote_state is not None:
                            return True

                        if self.bgp_source_active_announce is not None:
                            return True

                        if self.export_route_target is not None:
                            for child_ref in self.export_route_target:
                                if child_ref._has_data():
                                    return True

                        if self.gin_b_and_mdt_data_announce_interval is not None:
                            return True

                        if self.gin_b_and_mdt_data_switchover_interval is not None:
                            return True

                        if self.gin_b_and_mdt_interface is not None:
                            return True

                        if self.gin_b_and_mdt_mtu is not None:
                            return True

                        if self.gin_b_and_mdt_name is not None:
                            return True

                        if self.gin_b_and_mdt_rpf_identifier is not None:
                            return True

                        if self.gin_band_maximum_mdt_aggregation is not None:
                            return True

                        if self.import_route_target is not None:
                            for child_ref in self.import_route_target:
                                if child_ref._has_data():
                                    return True

                        if self.in_b_and_mdt_data_announce_interval is not None:
                            return True

                        if self.in_b_and_mdt_data_switchover_interval is not None:
                            return True

                        if self.in_b_and_mdt_interface is not None:
                            return True

                        if self.in_b_and_mdt_mtu is not None:
                            return True

                        if self.in_b_and_mdt_name is not None:
                            return True

                        if self.in_b_and_mdt_rpf_identifier is not None:
                            return True

                        if self.in_band_maximum_mdt_aggregation is not None:
                            return True

                        if self.in_band_signaling_local_enabled is not None:
                            return True

                        if self.in_band_signaling_remote_enabled is not None:
                            return True

                        if self.inter_autonomous_system_enabled is not None:
                            return True

                        if self.ir_maximum_mdt_aggregation is not None:
                            return True

                        if self.ir_mdt_data_announce_interval is not None:
                            return True

                        if self.ir_mdt_data_switchover_interval is not None:
                            return True

                        if self.ir_mdt_interface is not None:
                            return True

                        if self.ir_mdt_mtu is not None:
                            return True

                        if self.ir_mdt_name is not None:
                            return True

                        if self.ir_mdt_rpf_identifier is not None:
                            return True

                        if self.ir_mdt_tail_label is not None:
                            return True

                        if self.is_active is not None:
                            return True

                        if self.is_active_ital is not None:
                            return True

                        if self.is_all_interface_disable_operation is not None:
                            return True

                        if self.is_auto_rp_listen_enabled is not None:
                            return True

                        if self.is_auto_rp_listen_sock_add is not None:
                            return True

                        if self.is_create_gin_b_and_mdt_interface is not None:
                            return True

                        if self.is_create_in_b_and_mdt_interface is not None:
                            return True

                        if self.is_create_ir_mdt_interface is not None:
                            return True

                        if self.is_create_mdt_interface is not None:
                            return True

                        if self.is_create_mldp_mdt_interface is not None:
                            return True

                        if self.is_create_rsvp_te_mdt_interface is not None:
                            return True

                        if self.is_default_granges is not None:
                            return True

                        if self.is_gin_b_and_mdt_owner is not None:
                            return True

                        if self.is_in_b_and_mdt_owner is not None:
                            return True

                        if self.is_ir_mdt_owner is not None:
                            return True

                        if self.is_lpts_socket_add_required is not None:
                            return True

                        if self.is_lpts_socket_added is not None:
                            return True

                        if self.is_m_host_publish_pending is not None:
                            return True

                        if self.is_mdt_owner is not None:
                            return True

                        if self.is_mldp_mdt_owner is not None:
                            return True

                        if self.is_mrib_register is not None:
                            return True

                        if self.is_multicast_rib_registration is not None:
                            return True

                        if self.is_pim_nsf_rib_converge_received is not None:
                            return True

                        if self.is_pim_nsf_rib_converged is not None:
                            return True

                        if self.is_redistribution_reset is not None:
                            return True

                        if self.is_register_injection_lpts_socket_add_required is not None:
                            return True

                        if self.is_register_injection_lpts_socket_added is not None:
                            return True

                        if self.is_register_injection_socket_add_required is not None:
                            return True

                        if self.is_register_injection_socket_added is not None:
                            return True

                        if self.is_rib_multipath_enabled is not None:
                            return True

                        if self.is_rib_multipath_interface_hash is not None:
                            return True

                        if self.is_rib_multipath_source_hash is not None:
                            return True

                        if self.is_rib_multipath_source_next_hop_hash is not None:
                            return True

                        if self.is_routing_enabled is not None:
                            return True

                        if self.is_rsvp_te_mdt_owner is not None:
                            return True

                        if self.is_socket_add_required is not None:
                            return True

                        if self.is_socket_added is not None:
                            return True

                        if self.is_udp_socket_add_required is not None:
                            return True

                        if self.is_udp_socket_added is not None:
                            return True

                        if self.is_udp_socket_bind is not None:
                            return True

                        if self.is_udp_socket_bind_required is not None:
                            return True

                        if self.is_unicast_rib_registration is not None:
                            return True

                        if self.maximum_mdt_aggregation is not None:
                            return True

                        if self.mdt_data_announce_interval is not None:
                            return True

                        if self.mdt_data_switchover_interval is not None:
                            return True

                        if self.mdt_default_group is not None:
                            return True

                        if self.mdt_gre_remote_rpf_identifier is not None:
                            return True

                        if self.mdt_gre_rpf_identifier is not None:
                            return True

                        if self.mdt_interface is not None:
                            return True

                        if self.mdt_mtu is not None:
                            return True

                        if self.mdt_neighbor_filter_name is not None:
                            return True

                        if self.mdt_partitioned_ir_control_identifier is not None:
                            return True

                        if self.mdt_partitioned_mdt_control_identifier is not None:
                            return True

                        if self.mhost_default_interface_config is not None:
                            return True

                        if self.mhost_interface is not None:
                            return True

                        if self.mldp_auto_rp_announce_tree_added is not None:
                            return True

                        if self.mldp_auto_rp_discovery_tree_added is not None:
                            return True

                        if self.mldp_bsr_control_tree_added is not None:
                            return True

                        if self.mldp_control_head_lsm_identifier is not None:
                            return True

                        if self.mldp_head_local_label is not None:
                            return True

                        if self.mldp_head_lsm_identifier is not None:
                            return True

                        if self.mldp_maximum_mdt_aggregation is not None:
                            return True

                        if self.mldp_mdt_data_announce_interval is not None:
                            return True

                        if self.mldp_mdt_data_switchover_interval is not None:
                            return True

                        if self.mldp_mdt_interface is not None:
                            return True

                        if self.mldp_mdt_mtu is not None:
                            return True

                        if self.mldp_mdt_name is not None:
                            return True

                        if self.mldp_mdt_remote_rpf_identifier is not None:
                            return True

                        if self.mldp_mdt_rpf_identifier is not None:
                            return True

                        if self.mldp_partioned_mp2m_ptree is not None:
                            return True

                        if self.mldp_partitioned_head_lsm_identifier is not None:
                            return True

                        if self.mldp_partitioned_mdt_configured is not None:
                            return True

                        if self.mldp_partitioned_mdt_identifier is not None:
                            return True

                        if self.mldp_remote_head_lsm_identifier is not None:
                            return True

                        if self.mldp_remote_partitioned_mdt_configured is not None:
                            return True

                        if self.mldp_root_address is not None:
                            for child in self.mldp_root_address:
                                if child is not None:
                                    return True

                        if self.mldp_root_count is not None:
                            return True

                        if self.murib_id is not None:
                            return True

                        if self.neighbor_filter_name is not None:
                            return True

                        if self.non_default_vrf_count_on_socket is not None:
                            return True

                        if self.organization_unique_identifier is not None:
                            return True

                        if self.p2mpte_li_drop is not None:
                            return True

                        if self.redistribution_reset_count is not None:
                            return True

                        if self.remote_default_group is not None and self.remote_default_group._has_data():
                            return True

                        if self.remote_table_id is not None:
                            return True

                        if self.route_distinguisher is not None:
                            return True

                        if self.rpf_default_table is not None and self.rpf_default_table._has_data():
                            return True

                        if self.rpf_id is not None:
                            return True

                        if self.rpf_policy_name is not None:
                            return True

                        if self.rsvp_te_maximum_mdt_aggregation is not None:
                            return True

                        if self.rsvp_te_mdt_data_announce_interval is not None:
                            return True

                        if self.rsvp_te_mdt_data_switchover_interval is not None:
                            return True

                        if self.rsvp_te_mdt_interface is not None:
                            return True

                        if self.rsvp_te_mdt_mtu is not None:
                            return True

                        if self.rsvp_te_mdt_name is not None:
                            return True

                        if self.rsvp_te_mdt_rpf_identifier is not None:
                            return True

                        if self.rsvp_te_mdt_static_p2mp_count is not None:
                            return True

                        if self.rump_enabled is not None:
                            return True

                        if self.sg_expiry_time is not None:
                            return True

                        if self.sg_expiry_timer_configured is not None:
                            return True

                        if self.sg_expiry_timer_sg_list is not None:
                            return True

                        if self.stale_rd_present is not None:
                            return True

                        if self.suppress_pim_data_mdt_tlv is not None:
                            return True

                        if self.suppress_shared_tree_join is not None:
                            return True

                        if self.table_count is not None:
                            return True

                        if self.table_id is not None:
                            return True

                        if self.umh is not None:
                            return True

                        if self.valid_rd_present is not None:
                            return True

                        if self.vpn_index is not None:
                            return True

                        if self.vrf_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.Context']['meta_info']


                class TopologyEntryFlagRouteCounts(object):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: topology_entry_flag_route_count
                    
                    	Route count for topology with entry flag set
                    	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.topology_entry_flag_route_count = YList()
                        self.topology_entry_flag_route_count.parent = self
                        self.topology_entry_flag_route_count.name = 'topology_entry_flag_route_count'


                    class TopologyEntryFlagRouteCount(object):
                        """
                        Route count for topology with entry flag set
                        
                        .. attribute:: entry_flag  <key>
                        
                        	entry flag
                        	**type**\:   :py:class:`PimTopologyEntryFlagEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlagEnum>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.entry_flag = None
                            self.active_group_ranges = None
                            self.group_address = Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                            self.group_address.parent = self
                            self.group_ranges = None
                            self.groute_count = None
                            self.is_node_low_memory = None
                            self.sg_route_count = None
                            self.sgr_route_count = None


                        class GroupAddress(object):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.entry_flag is None:
                                raise YPYModelError('Key property entry_flag is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology-entry-flag-route-count[Cisco-IOS-XR-ipv4-pim-oper:entry-flag = ' + str(self.entry_flag) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.entry_flag is not None:
                                return True

                            if self.active_group_ranges is not None:
                                return True

                            if self.group_address is not None and self.group_address._has_data():
                                return True

                            if self.group_ranges is not None:
                                return True

                            if self.groute_count is not None:
                                return True

                            if self.is_node_low_memory is not None:
                                return True

                            if self.sg_route_count is not None:
                                return True

                            if self.sgr_route_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology-entry-flag-route-counts'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.topology_entry_flag_route_count is not None:
                            for child_ref in self.topology_entry_flag_route_count:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts']['meta_info']


                class RpfRedirect(object):
                    """
                    PIM ECMP RPF\-redirect bundle
                    
                    .. attribute:: bundle_interfaces
                    
                    	PIM ECMP RPF\-redirect bundle information
                    	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces>`
                    
                    .. attribute:: redirect_route_databases
                    
                    	PIM ECMP RPF\-redirect route database
                    	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bundle_interfaces = Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces()
                        self.bundle_interfaces.parent = self
                        self.redirect_route_databases = Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases()
                        self.redirect_route_databases.parent = self


                    class RedirectRouteDatabases(object):
                        """
                        PIM ECMP RPF\-redirect route database
                        
                        .. attribute:: redirect_route_database
                        
                        	PIM ECMP RPF\-redirect route information
                        	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.redirect_route_database = YList()
                            self.redirect_route_database.parent = self
                            self.redirect_route_database.name = 'redirect_route_database'


                        class RedirectRouteDatabase(object):
                            """
                            PIM ECMP RPF\-redirect route information
                            
                            .. attribute:: bandwidth
                            
                            	Bandwidth in Kbps
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Group ddress
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                            
                            .. attribute:: interface
                            
                            	Outgoing interface list
                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bandwidth = None
                                self.group_address = None
                                self.group_address_xr = Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self.interface = YList()
                                self.interface.parent = self
                                self.interface.name = 'interface'
                                self.source_address = None
                                self.source_address_xr = Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self.uptime = None


                            class GroupAddressXr(object):
                                """
                                Group ddress
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr']['meta_info']


                            class SourceAddressXr(object):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr']['meta_info']


                            class Interface(object):
                                """
                                Outgoing interface list
                                
                                .. attribute:: expiry
                                
                                	Expiry in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: is_outgoing_interface
                                
                                	Is outgoing Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface
                                
                                	Is RPF Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_snoop_interface
                                
                                	Is snooping Interface
                                	**type**\:  bool
                                
                                .. attribute:: rpf_address
                                
                                	RPF Address
                                	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                                
                                .. attribute:: uptime
                                
                                	Uptime in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.expiry = None
                                    self.interface_name = None
                                    self.is_outgoing_interface = None
                                    self.is_rpf_interface = None
                                    self.is_snoop_interface = None
                                    self.rpf_address = Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                    self.rpf_address.parent = self
                                    self.uptime = None


                                class RpfAddress(object):
                                    """
                                    RPF Address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.expiry is not None:
                                        return True

                                    if self.interface_name is not None:
                                        return True

                                    if self.is_outgoing_interface is not None:
                                        return True

                                    if self.is_rpf_interface is not None:
                                        return True

                                    if self.is_snoop_interface is not None:
                                        return True

                                    if self.rpf_address is not None and self.rpf_address._has_data():
                                        return True

                                    if self.uptime is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bandwidth is not None:
                                    return True

                                if self.group_address is not None:
                                    return True

                                if self.group_address_xr is not None and self.group_address_xr._has_data():
                                    return True

                                if self.interface is not None:
                                    for child_ref in self.interface:
                                        if child_ref._has_data():
                                            return True

                                if self.source_address is not None:
                                    return True

                                if self.source_address_xr is not None and self.source_address_xr._has_data():
                                    return True

                                if self.uptime is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.redirect_route_database is not None:
                                for child_ref in self.redirect_route_database:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases']['meta_info']


                    class BundleInterfaces(object):
                        """
                        PIM ECMP RPF\-redirect bundle information
                        
                        .. attribute:: bundle_interface
                        
                        	PIM ECMP RPF\-redirect bundle interface information
                        	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bundle_interface = YList()
                            self.bundle_interface.parent = self
                            self.bundle_interface.name = 'bundle_interface'


                        class BundleInterface(object):
                            """
                            PIM ECMP RPF\-redirect bundle interface
                            information
                            
                            .. attribute:: allocated_bandwidth
                            
                            	Bandwidth allocated in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: allocated_threshold_bandwidth
                            
                            	Configured threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_bandwidth
                            
                            	Bandwidth available in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_threshold_bandwidth
                            
                            	Available threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: bundle_name
                            
                            	Bundle name
                            	**type**\:  str
                            
                            	**length:** 1..32
                            
                            .. attribute:: interface_name
                            
                            	Bundle interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: rpf_redirect_bundle_name
                            
                            	RPF redirect bundle name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: rpf_redirect_interface_name
                            
                            	RPF redirect interface name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: snooping_bandwidth_used
                            
                            	Bandwidth used by snooped entries in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: topology_bandwidth_used
                            
                            	Bandwidth used by topology in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: total_bandwidth
                            
                            	Total bandwidth used in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.allocated_bandwidth = None
                                self.allocated_threshold_bandwidth = None
                                self.available_bandwidth = None
                                self.available_threshold_bandwidth = None
                                self.bundle_name = None
                                self.interface_name = None
                                self.rpf_redirect_bundle_name = None
                                self.rpf_redirect_interface_name = None
                                self.snooping_bandwidth_used = None
                                self.topology_bandwidth_used = None
                                self.total_bandwidth = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bundle-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.allocated_bandwidth is not None:
                                    return True

                                if self.allocated_threshold_bandwidth is not None:
                                    return True

                                if self.available_bandwidth is not None:
                                    return True

                                if self.available_threshold_bandwidth is not None:
                                    return True

                                if self.bundle_name is not None:
                                    return True

                                if self.interface_name is not None:
                                    return True

                                if self.rpf_redirect_bundle_name is not None:
                                    return True

                                if self.rpf_redirect_interface_name is not None:
                                    return True

                                if self.snooping_bandwidth_used is not None:
                                    return True

                                if self.topology_bandwidth_used is not None:
                                    return True

                                if self.total_bandwidth is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bundle-interfaces'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bundle_interface is not None:
                                for child_ref in self.bundle_interface:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bundle_interfaces is not None and self.bundle_interfaces._has_data():
                            return True

                        if self.redirect_route_databases is not None and self.redirect_route_databases._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.RpfRedirect']['meta_info']


                class Tunnels(object):
                    """
                    Tunnels information that PIM has
                    
                    .. attribute:: tunnel
                    
                    	PIM tunnel information
                    	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels.Tunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.tunnel = YList()
                        self.tunnel.parent = self
                        self.tunnel.name = 'tunnel'


                    class Tunnel(object):
                        """
                        PIM tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.tunnel_name = None
                            self.group_address_netio = Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self.rp_address = Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress()
                            self.rp_address.parent = self
                            self.source_address = Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress()
                            self.source_address.parent = self
                            self.source_address_netio = Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self.vrf_name = None


                        class SourceAddress(object):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress']['meta_info']


                        class RpAddress(object):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress']['meta_info']


                        class SourceAddressNetio(object):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-netio'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio']['meta_info']


                        class GroupAddressNetio(object):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-netio'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.tunnel_name is None:
                                raise YPYModelError('Key property tunnel_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:tunnel[Cisco-IOS-XR-ipv4-pim-oper:tunnel-name = ' + str(self.tunnel_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.tunnel_name is not None:
                                return True

                            if self.group_address_netio is not None and self.group_address_netio._has_data():
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            if self.source_address is not None and self.source_address._has_data():
                                return True

                            if self.source_address_netio is not None and self.source_address_netio._has_data():
                                return True

                            if self.vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.Tunnels.Tunnel']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:tunnels'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.tunnel is not None:
                            for child_ref in self.tunnel:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.Tunnels']['meta_info']


                class MulticastStaticRoutes(object):
                    """
                    PIM multicast static route table
                    
                    .. attribute:: multicast_static_route
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.multicast_static_route = YList()
                        self.multicast_static_route.parent = self
                        self.multicast_static_route.name = 'multicast_static_route'


                    class MulticastStaticRoute(object):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: address
                        
                        	Network address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: distance
                        
                        	Distance
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_via_lsm
                        
                        	LSM flag
                        	**type**\:  bool
                        
                        .. attribute:: nexthop
                        
                        	Next Hop
                        	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: prefix_length_xr
                        
                        	Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.address = None
                            self.distance = None
                            self.interface_name = None
                            self.is_via_lsm = None
                            self.nexthop = Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                            self.nexthop.parent = self
                            self.prefix = Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.prefix_length_xr = None


                        class Prefix(object):
                            """
                            Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix']['meta_info']


                        class Nexthop(object):
                            """
                            Next Hop
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:nexthop'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-route'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.address is not None:
                                return True

                            if self.distance is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.is_via_lsm is not None:
                                return True

                            if self.nexthop is not None and self.nexthop._has_data():
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.prefix_length_xr is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-routes'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.multicast_static_route is not None:
                            for child_ref in self.multicast_static_route:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.MulticastStaticRoutes']['meta_info']


                class GroupMapMatchSources(object):
                    """
                    Find the matching group\-mapping with source
                    information on specified group address
                    
                    .. attribute:: group_map_match_source
                    
                    	PIM group\-matching mapping entry with source information
                    	**type**\: list of    :py:class:`GroupMapMatchSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_map_match_source = YList()
                        self.group_map_match_source.parent = self
                        self.group_map_match_source.name = 'group_map_match_source'


                    class GroupMapMatchSource(object):
                        """
                        PIM group\-matching mapping entry with source
                        information
                        
                        .. attribute:: group_address  <key>
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.group_address = None
                            self.expires = None
                            self.group_map_information = Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self.holdtime = None
                            self.source_of_information = Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self.uptime = None


                        class SourceOfInformation(object):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation']['meta_info']


                        class GroupMapInformation(object):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.client = None
                                self.group_count = None
                                self.is_override = None
                                self.is_used = None
                                self.mrib_active = None
                                self.prefix = Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self.prefix_length = None
                                self.priority = None
                                self.protocol = None
                                self.rp_address = Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self


                            class Prefix(object):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix']['meta_info']


                            class RpAddress(object):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.client is not None:
                                    return True

                                if self.group_count is not None:
                                    return True

                                if self.is_override is not None:
                                    return True

                                if self.is_used is not None:
                                    return True

                                if self.mrib_active is not None:
                                    return True

                                if self.prefix is not None and self.prefix._has_data():
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.priority is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.rp_address is not None and self.rp_address._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.group_address is None:
                                raise YPYModelError('Key property group_address is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-source[Cisco-IOS-XR-ipv4-pim-oper:group-address = ' + str(self.group_address) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.group_address is not None:
                                return True

                            if self.expires is not None:
                                return True

                            if self.group_map_information is not None and self.group_map_information._has_data():
                                return True

                            if self.holdtime is not None:
                                return True

                            if self.source_of_information is not None and self.source_of_information._has_data():
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-sources'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_map_match_source is not None:
                            for child_ref in self.group_map_match_source:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.GroupMapMatchSources']['meta_info']


                class Neighbors(object):
                    """
                    PIM neighbor table
                    
                    .. attribute:: neighbor
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Neighbors.Neighbor>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.neighbor = YList()
                        self.neighbor.parent = self
                        self.neighbor.name = 'neighbor'


                    class Neighbor(object):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dr_priority = None
                            self.expires = None
                            self.expiry_timer = None
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.is_batch_asserts_capable = None
                            self.is_bfd_state = None
                            self.is_bidirectional_capable = None
                            self.is_dr_priority_capable = None
                            self.is_ecmp_redirect_capable = None
                            self.is_proxy_capable = None
                            self.is_this_neighbor_dr = None
                            self.is_this_neighbor_us = None
                            self.neighbor_address = None
                            self.neighbor_address_xr = YList()
                            self.neighbor_address_xr.parent = self
                            self.neighbor_address_xr.name = 'neighbor_address_xr'
                            self.override_interval = None
                            self.propagation_delay = None
                            self.uptime = None


                        class NeighborAddressXr(object):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dr_priority is not None:
                                return True

                            if self.expires is not None:
                                return True

                            if self.expiry_timer is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.is_batch_asserts_capable is not None:
                                return True

                            if self.is_bfd_state is not None:
                                return True

                            if self.is_bidirectional_capable is not None:
                                return True

                            if self.is_dr_priority_capable is not None:
                                return True

                            if self.is_ecmp_redirect_capable is not None:
                                return True

                            if self.is_proxy_capable is not None:
                                return True

                            if self.is_this_neighbor_dr is not None:
                                return True

                            if self.is_this_neighbor_us is not None:
                                return True

                            if self.neighbor_address is not None:
                                return True

                            if self.neighbor_address_xr is not None:
                                for child_ref in self.neighbor_address_xr:
                                    if child_ref._has_data():
                                        return True

                            if self.override_interval is not None:
                                return True

                            if self.propagation_delay is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim.Active.Vrfs.Vrf.Neighbors.Neighbor']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbors'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.neighbor is not None:
                            for child_ref in self.neighbor:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim.Active.Vrfs.Vrf.Neighbors']['meta_info']

                @property
                def _common_path(self):
                    if self.vrf_name is None:
                        raise YPYModelError('Key property vrf_name is None')

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:vrfs/Cisco-IOS-XR-ipv4-pim-oper:vrf[Cisco-IOS-XR-ipv4-pim-oper:vrf-name = ' + str(self.vrf_name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.vrf_name is not None:
                        return True

                    if self.auto_rp is not None and self.auto_rp._has_data():
                        return True

                    if self.bgp_afs is not None and self.bgp_afs._has_data():
                        return True

                    if self.bidir_df_states is not None and self.bidir_df_states._has_data():
                        return True

                    if self.bidir_df_winners is not None and self.bidir_df_winners._has_data():
                        return True

                    if self.bsr is not None and self.bsr._has_data():
                        return True

                    if self.context is not None and self.context._has_data():
                        return True

                    if self.gre is not None and self.gre._has_data():
                        return True

                    if self.group_map_match_rpfs is not None and self.group_map_match_rpfs._has_data():
                        return True

                    if self.group_map_match_sources is not None and self.group_map_match_sources._has_data():
                        return True

                    if self.group_map_rpfs is not None and self.group_map_rpfs._has_data():
                        return True

                    if self.group_map_sources is not None and self.group_map_sources._has_data():
                        return True

                    if self.ifrs_interfaces is not None and self.ifrs_interfaces._has_data():
                        return True

                    if self.ifrs_summary is not None and self.ifrs_summary._has_data():
                        return True

                    if self.interface_old_formats is not None and self.interface_old_formats._has_data():
                        return True

                    if self.interface_statistics is not None and self.interface_statistics._has_data():
                        return True

                    if self.interfaces is not None and self.interfaces._has_data():
                        return True

                    if self.jp_statistics is not None and self.jp_statistics._has_data():
                        return True

                    if self.mib_databases is not None and self.mib_databases._has_data():
                        return True

                    if self.multicast_static_routes is not None and self.multicast_static_routes._has_data():
                        return True

                    if self.neighbor_old_formats is not None and self.neighbor_old_formats._has_data():
                        return True

                    if self.neighbor_summaries is not None and self.neighbor_summaries._has_data():
                        return True

                    if self.neighbors is not None and self.neighbors._has_data():
                        return True

                    if self.net_io_tunnels is not None and self.net_io_tunnels._has_data():
                        return True

                    if self.ranges is not None and self.ranges._has_data():
                        return True

                    if self.route_policy is not None and self.route_policy._has_data():
                        return True

                    if self.rpf_redirect is not None and self.rpf_redirect._has_data():
                        return True

                    if self.rpf_summary is not None and self.rpf_summary._has_data():
                        return True

                    if self.safs is not None and self.safs._has_data():
                        return True

                    if self.summary is not None and self.summary._has_data():
                        return True

                    if self.table_contexts is not None and self.table_contexts._has_data():
                        return True

                    if self.topologies is not None and self.topologies._has_data():
                        return True

                    if self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts._has_data():
                        return True

                    if self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts._has_data():
                        return True

                    if self.topology_route_count is not None and self.topology_route_count._has_data():
                        return True

                    if self.traffic_counters is not None and self.traffic_counters._has_data():
                        return True

                    if self.tunnels is not None and self.tunnels._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim.Active.Vrfs.Vrf']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:vrfs'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.vrf is not None:
                    for child_ref in self.vrf:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                return meta._meta_table['Pim.Active.Vrfs']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-ipv4-pim-oper:pim/Cisco-IOS-XR-ipv4-pim-oper:active'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.default_context is not None and self.default_context._has_data():
                return True

            if self.process is not None and self.process._has_data():
                return True

            if self.vrfs is not None and self.vrfs._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
            return meta._meta_table['Pim.Active']['meta_info']

    @property
    def _common_path(self):

        return '/Cisco-IOS-XR-ipv4-pim-oper:pim'

    def is_config(self):
        ''' Returns True if this instance represents config data else returns False '''
        return False

    def _has_data(self):
        if not self.is_config():
            return False
        if self.active is not None and self.active._has_data():
            return True

        if self.standby is not None and self.standby._has_data():
            return True

        return False

    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
        return meta._meta_table['Pim']['meta_info']


class Ipv6Pim(object):
    """
    ipv6 pim
    
    .. attribute:: active
    
    	Active Process
    	**type**\:   :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active>`
    
    .. attribute:: standby
    
    	Standby Process
    	**type**\:   :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby>`
    
    

    """

    _prefix = 'ipv4-pim-oper'
    _revision = '2015-11-09'

    def __init__(self):
        self.active = Ipv6Pim.Active()
        self.active.parent = self
        self.standby = Ipv6Pim.Standby()
        self.standby.parent = self


    class Standby(object):
        """
        Standby Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:   :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:   :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.default_context = Ipv6Pim.Standby.DefaultContext()
            self.default_context.parent = self
            self.process = Ipv6Pim.Standby.Process()
            self.process.parent = self
            self.vrfs = Ipv6Pim.Standby.Vrfs()
            self.vrfs.parent = self


        class DefaultContext(object):
            """
            Default Context
            
            .. attribute:: auto_rp
            
            	PIM Auto\-RP information
            	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.AutoRp>`
            
            .. attribute:: bgp_afs
            
            	PIM BGP SAFI table
            	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BgpAfs>`
            
            .. attribute:: bidir_df_states
            
            	Bidirectional PIM DF election state table
            	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfStates>`
            
            .. attribute:: bidir_df_winners
            
            	Bidirectional PIM DF election winner table
            	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfWinners>`
            
            .. attribute:: bsr
            
            	PIM BSR information
            	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr>`
            
            .. attribute:: context
            
            	PIM context information
            	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context>`
            
            .. attribute:: global_interfaces
            
            	PIM global interface table
            	**type**\:   :py:class:`GlobalInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GlobalInterfaces>`
            
            .. attribute:: gre
            
            	GRE information
            	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre>`
            
            .. attribute:: group_map_match_rpfs
            
            	Find matching group\-mapping for the specified group address
            	**type**\:   :py:class:`GroupMapMatchRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs>`
            
            .. attribute:: group_map_match_sources
            
            	Find the matching group\-mapping with source information on specified group address
            	**type**\:   :py:class:`GroupMapMatchSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources>`
            
            .. attribute:: group_map_rpfs
            
            	PIM group mapping information
            	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs>`
            
            .. attribute:: group_map_sources
            
            	PIM group\-mapping with source information
            	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources>`
            
            .. attribute:: ifrs_interfaces
            
            	PIM interfaces in forward reference store table
            	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: ifrs_summary
            
            	PIM interfaces in forward reference store summary
            	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.IfrsSummary>`
            
            .. attribute:: interface_old_formats
            
            	PIM interfaces in old format
            	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats>`
            
            .. attribute:: interface_statistics
            
            	PIM interface statistics
            	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceStatistics>`
            
            .. attribute:: interfaces
            
            	PIM interfaces
            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Interfaces>`
            
            .. attribute:: jp_statistics
            
            	PIM join prune statistics table
            	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.JpStatistics>`
            
            .. attribute:: mib_databases
            
            	PIM group database for mroute mibs table
            	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases>`
            
            .. attribute:: multicast_static_routes
            
            	PIM multicast static route table
            	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes>`
            
            .. attribute:: neighbor_old_formats
            
            	PIM neighbor table old format
            	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NeighborOldFormats>`
            
            .. attribute:: neighbor_summaries
            
            	PIM neighbor summary table
            	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NeighborSummaries>`
            
            .. attribute:: neighbors
            
            	PIM neighbor table
            	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Neighbors>`
            
            .. attribute:: net_io_tunnels
            
            	Tunnel information that NETIO has 
            	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels>`
            
            .. attribute:: ranges
            
            	PIM range list information
            	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges>`
            
            .. attribute:: route_policy
            
            	PIM route policy
            	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy>`
            
            .. attribute:: rpf_redirect
            
            	PIM ECMP RPF\-redirect bundle
            	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect>`
            
            .. attribute:: rpf_summary
            
            	PIM RPF registration summary
            	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfSummary>`
            
            .. attribute:: safs
            
            	SAFI table and type
            	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs>`
            
            .. attribute:: summary
            
            	PIM summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Summary>`
            
            .. attribute:: table_contexts
            
            	PIM table context list
            	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TableContexts>`
            
            .. attribute:: topologies
            
            	PIM topology table
            	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies>`
            
            .. attribute:: topology_entry_flag_route_counts
            
            	Route count for topology with entry flag set
            	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts>`
            
            .. attribute:: topology_interface_flag_route_counts
            
            	Route count for topology with interface flag set
            	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts>`
            
            .. attribute:: topology_route_count
            
            	Topology route count information from PIM topology table
            	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyRouteCount>`
            
            .. attribute:: traffic_counters
            
            	PIM message traffic counters
            	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TrafficCounters>`
            
            .. attribute:: tunnels
            
            	Tunnels information that PIM has
            	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.auto_rp = Ipv6Pim.Standby.DefaultContext.AutoRp()
                self.auto_rp.parent = self
                self.bgp_afs = Ipv6Pim.Standby.DefaultContext.BgpAfs()
                self.bgp_afs.parent = self
                self.bidir_df_states = Ipv6Pim.Standby.DefaultContext.BidirDfStates()
                self.bidir_df_states.parent = self
                self.bidir_df_winners = Ipv6Pim.Standby.DefaultContext.BidirDfWinners()
                self.bidir_df_winners.parent = self
                self.bsr = Ipv6Pim.Standby.DefaultContext.Bsr()
                self.bsr.parent = self
                self.context = Ipv6Pim.Standby.DefaultContext.Context()
                self.context.parent = self
                self.global_interfaces = Ipv6Pim.Standby.DefaultContext.GlobalInterfaces()
                self.global_interfaces.parent = self
                self.gre = Ipv6Pim.Standby.DefaultContext.Gre()
                self.gre.parent = self
                self.group_map_match_rpfs = Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs()
                self.group_map_match_rpfs.parent = self
                self.group_map_match_sources = Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources()
                self.group_map_match_sources.parent = self
                self.group_map_rpfs = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs()
                self.group_map_rpfs.parent = self
                self.group_map_sources = Ipv6Pim.Standby.DefaultContext.GroupMapSources()
                self.group_map_sources.parent = self
                self.ifrs_interfaces = Ipv6Pim.Standby.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self.ifrs_summary = Ipv6Pim.Standby.DefaultContext.IfrsSummary()
                self.ifrs_summary.parent = self
                self.interface_old_formats = Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats()
                self.interface_old_formats.parent = self
                self.interface_statistics = Ipv6Pim.Standby.DefaultContext.InterfaceStatistics()
                self.interface_statistics.parent = self
                self.interfaces = Ipv6Pim.Standby.DefaultContext.Interfaces()
                self.interfaces.parent = self
                self.jp_statistics = Ipv6Pim.Standby.DefaultContext.JpStatistics()
                self.jp_statistics.parent = self
                self.mib_databases = Ipv6Pim.Standby.DefaultContext.MibDatabases()
                self.mib_databases.parent = self
                self.multicast_static_routes = Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes()
                self.multicast_static_routes.parent = self
                self.neighbor_old_formats = Ipv6Pim.Standby.DefaultContext.NeighborOldFormats()
                self.neighbor_old_formats.parent = self
                self.neighbor_summaries = Ipv6Pim.Standby.DefaultContext.NeighborSummaries()
                self.neighbor_summaries.parent = self
                self.neighbors = Ipv6Pim.Standby.DefaultContext.Neighbors()
                self.neighbors.parent = self
                self.net_io_tunnels = Ipv6Pim.Standby.DefaultContext.NetIoTunnels()
                self.net_io_tunnels.parent = self
                self.ranges = Ipv6Pim.Standby.DefaultContext.Ranges()
                self.ranges.parent = self
                self.route_policy = Ipv6Pim.Standby.DefaultContext.RoutePolicy()
                self.route_policy.parent = self
                self.rpf_redirect = Ipv6Pim.Standby.DefaultContext.RpfRedirect()
                self.rpf_redirect.parent = self
                self.rpf_summary = Ipv6Pim.Standby.DefaultContext.RpfSummary()
                self.rpf_summary.parent = self
                self.safs = Ipv6Pim.Standby.DefaultContext.Safs()
                self.safs.parent = self
                self.summary = Ipv6Pim.Standby.DefaultContext.Summary()
                self.summary.parent = self
                self.table_contexts = Ipv6Pim.Standby.DefaultContext.TableContexts()
                self.table_contexts.parent = self
                self.topologies = Ipv6Pim.Standby.DefaultContext.Topologies()
                self.topologies.parent = self
                self.topology_entry_flag_route_counts = Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts()
                self.topology_entry_flag_route_counts.parent = self
                self.topology_interface_flag_route_counts = Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts()
                self.topology_interface_flag_route_counts.parent = self
                self.topology_route_count = Ipv6Pim.Standby.DefaultContext.TopologyRouteCount()
                self.topology_route_count.parent = self
                self.traffic_counters = Ipv6Pim.Standby.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self.tunnels = Ipv6Pim.Standby.DefaultContext.Tunnels()
                self.tunnels.parent = self


            class GlobalInterfaces(object):
                """
                PIM global interface table
                
                .. attribute:: global_interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`GlobalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.global_interface = YList()
                    self.global_interface.parent = self
                    self.global_interface.name = 'global_interface'


                class GlobalInterface(object):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.configured_override_interval = None
                        self.configured_propagation_delay = None
                        self.dr_address = Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress()
                        self.dr_address.parent = self
                        self.dr_priority = None
                        self.external_neighbor_count = None
                        self.generation_id = None
                        self.hello_expiry = None
                        self.hello_interval = None
                        self.idb_acl_name = None
                        self.idb_acl_provided = None
                        self.idb_current_count = None
                        self.idb_max_count = None
                        self.idb_oor_enabled = None
                        self.idb_threshold_count = None
                        self.interface_address = YList()
                        self.interface_address.parent = self
                        self.interface_address.name = 'interface_address'
                        self.interface_address_mask = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bidirectional_capable = None
                        self.is_enabled = None
                        self.is_proxy_capable = None
                        self.join_prune_interval = None
                        self.neighbor_count = None
                        self.neighbor_filter_name = None
                        self.override_interval = None
                        self.passive_interface = None
                        self.propagation_delay = None
                        self.prune_delay_enabled = None
                        self.virtual_interface = None


                    class DrAddress(object):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress']['meta_info']


                    class InterfaceAddress(object):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:global-interfaces/Cisco-IOS-XR-ipv4-pim-oper:global-interface[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.are_we_dr is not None:
                            return True

                        if self.bfd_enabled is not None:
                            return True

                        if self.bfd_interval is not None:
                            return True

                        if self.bfd_multiplier is not None:
                            return True

                        if self.configured_override_interval is not None:
                            return True

                        if self.configured_propagation_delay is not None:
                            return True

                        if self.dr_address is not None and self.dr_address._has_data():
                            return True

                        if self.dr_priority is not None:
                            return True

                        if self.external_neighbor_count is not None:
                            return True

                        if self.generation_id is not None:
                            return True

                        if self.hello_expiry is not None:
                            return True

                        if self.hello_interval is not None:
                            return True

                        if self.idb_acl_name is not None:
                            return True

                        if self.idb_acl_provided is not None:
                            return True

                        if self.idb_current_count is not None:
                            return True

                        if self.idb_max_count is not None:
                            return True

                        if self.idb_oor_enabled is not None:
                            return True

                        if self.idb_threshold_count is not None:
                            return True

                        if self.interface_address is not None:
                            for child_ref in self.interface_address:
                                if child_ref._has_data():
                                    return True

                        if self.interface_address_mask is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_enabled is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.join_prune_interval is not None:
                            return True

                        if self.neighbor_count is not None:
                            return True

                        if self.neighbor_filter_name is not None:
                            return True

                        if self.override_interval is not None:
                            return True

                        if self.passive_interface is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.prune_delay_enabled is not None:
                            return True

                        if self.virtual_interface is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:global-interfaces'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.global_interface is not None:
                        for child_ref in self.global_interface:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GlobalInterfaces']['meta_info']


            class IfrsInterfaces(object):
                """
                PIM interfaces in forward reference store table
                
                .. attribute:: ifrs_interface
                
                	PIM IFRS interface information
                	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.ifrs_interface = YList()
                    self.ifrs_interface.parent = self
                    self.ifrs_interface.name = 'ifrs_interface'


                class IfrsInterface(object):
                    """
                    PIM IFRS interface information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.configured_override_interval = None
                        self.configured_propagation_delay = None
                        self.dr_address = Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress()
                        self.dr_address.parent = self
                        self.dr_priority = None
                        self.external_neighbor_count = None
                        self.generation_id = None
                        self.hello_expiry = None
                        self.hello_interval = None
                        self.idb_acl_name = None
                        self.idb_acl_provided = None
                        self.idb_current_count = None
                        self.idb_max_count = None
                        self.idb_oor_enabled = None
                        self.idb_threshold_count = None
                        self.interface_address = YList()
                        self.interface_address.parent = self
                        self.interface_address.name = 'interface_address'
                        self.interface_address_mask = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bidirectional_capable = None
                        self.is_enabled = None
                        self.is_proxy_capable = None
                        self.join_prune_interval = None
                        self.neighbor_count = None
                        self.neighbor_filter_name = None
                        self.override_interval = None
                        self.passive_interface = None
                        self.propagation_delay = None
                        self.prune_delay_enabled = None
                        self.virtual_interface = None


                    class DrAddress(object):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress']['meta_info']


                    class InterfaceAddress(object):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ifrs-interfaces/Cisco-IOS-XR-ipv4-pim-oper:ifrs-interface[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.are_we_dr is not None:
                            return True

                        if self.bfd_enabled is not None:
                            return True

                        if self.bfd_interval is not None:
                            return True

                        if self.bfd_multiplier is not None:
                            return True

                        if self.configured_override_interval is not None:
                            return True

                        if self.configured_propagation_delay is not None:
                            return True

                        if self.dr_address is not None and self.dr_address._has_data():
                            return True

                        if self.dr_priority is not None:
                            return True

                        if self.external_neighbor_count is not None:
                            return True

                        if self.generation_id is not None:
                            return True

                        if self.hello_expiry is not None:
                            return True

                        if self.hello_interval is not None:
                            return True

                        if self.idb_acl_name is not None:
                            return True

                        if self.idb_acl_provided is not None:
                            return True

                        if self.idb_current_count is not None:
                            return True

                        if self.idb_max_count is not None:
                            return True

                        if self.idb_oor_enabled is not None:
                            return True

                        if self.idb_threshold_count is not None:
                            return True

                        if self.interface_address is not None:
                            for child_ref in self.interface_address:
                                if child_ref._has_data():
                                    return True

                        if self.interface_address_mask is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_enabled is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.join_prune_interval is not None:
                            return True

                        if self.neighbor_count is not None:
                            return True

                        if self.neighbor_filter_name is not None:
                            return True

                        if self.override_interval is not None:
                            return True

                        if self.passive_interface is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.prune_delay_enabled is not None:
                            return True

                        if self.virtual_interface is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ifrs-interfaces'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.ifrs_interface is not None:
                        for child_ref in self.ifrs_interface:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.IfrsInterfaces']['meta_info']


            class Safs(object):
                """
                SAFI table and type
                
                .. attribute:: saf
                
                	SAF name 
                	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.saf = YList()
                    self.saf.parent = self
                    self.saf.name = 'saf'


                class Saf(object):
                    """
                    SAF name 
                    
                    .. attribute:: rpf_hash_source_groups
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups>`
                    
                    .. attribute:: rpf_hash_sources
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources>`
                    
                    .. attribute:: rpfs
                    
                    	PIM RPF information table
                    	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs>`
                    
                    .. attribute:: saf_name
                    
                    	SAF name 
                    	**type**\:   :py:class:`PimSafiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafiEnum>`
                    
                    .. attribute:: topology_name
                    
                    	Topology name 
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.rpf_hash_source_groups = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups()
                        self.rpf_hash_source_groups.parent = self
                        self.rpf_hash_sources = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources()
                        self.rpf_hash_sources.parent = self
                        self.rpfs = Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs()
                        self.rpfs.parent = self
                        self.saf_name = None
                        self.topology_name = None


                    class RpfHashSourceGroups(object):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source_group
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rpf_hash_source_group = YList()
                            self.rpf_hash_source_group.parent = self
                            self.rpf_hash_source_group.name = 'rpf_hash_source_group'


                        class RpfHashSourceGroup(object):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: mask_length
                            
                            	Hash mask length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.group_address = None
                                self.mask_length = None
                                self.mofrr = None
                                self.next_hop_address = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                self.next_hop_address.parent = self
                                self.next_hop_interface = None
                                self.next_hop_multipath_enabled = None
                                self.secondary_next_hop_address = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self.secondary_next_hop_interface = None
                                self.source_address = None


                            class NextHopAddress(object):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-groups/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-group/Cisco-IOS-XR-ipv4-pim-oper:next-hop-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress']['meta_info']


                            class SecondaryNextHopAddress(object):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-groups/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-group/Cisco-IOS-XR-ipv4-pim-oper:secondary-next-hop-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-groups/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-group'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.group_address is not None:
                                    return True

                                if self.mask_length is not None:
                                    return True

                                if self.mofrr is not None:
                                    return True

                                if self.next_hop_address is not None and self.next_hop_address._has_data():
                                    return True

                                if self.next_hop_interface is not None:
                                    return True

                                if self.next_hop_multipath_enabled is not None:
                                    return True

                                if self.secondary_next_hop_address is not None and self.secondary_next_hop_address._has_data():
                                    return True

                                if self.secondary_next_hop_interface is not None:
                                    return True

                                if self.source_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-groups'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rpf_hash_source_group is not None:
                                for child_ref in self.rpf_hash_source_group:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups']['meta_info']


                    class RpfHashSources(object):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rpf_hash_source = YList()
                            self.rpf_hash_source.parent = self
                            self.rpf_hash_source.name = 'rpf_hash_source'


                        class RpfHashSource(object):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mofrr = None
                                self.next_hop_address = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                self.next_hop_address.parent = self
                                self.next_hop_interface = None
                                self.next_hop_multipath_enabled = None
                                self.secondary_next_hop_address = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self.secondary_next_hop_interface = None
                                self.source_address = None


                            class NextHopAddress(object):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-sources/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source/Cisco-IOS-XR-ipv4-pim-oper:next-hop-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress']['meta_info']


                            class SecondaryNextHopAddress(object):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-sources/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source/Cisco-IOS-XR-ipv4-pim-oper:secondary-next-hop-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-sources/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mofrr is not None:
                                    return True

                                if self.next_hop_address is not None and self.next_hop_address._has_data():
                                    return True

                                if self.next_hop_interface is not None:
                                    return True

                                if self.next_hop_multipath_enabled is not None:
                                    return True

                                if self.secondary_next_hop_address is not None and self.secondary_next_hop_address._has_data():
                                    return True

                                if self.secondary_next_hop_interface is not None:
                                    return True

                                if self.source_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-sources'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rpf_hash_source is not None:
                                for child_ref in self.rpf_hash_source:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources']['meta_info']


                    class Rpfs(object):
                        """
                        PIM RPF information table
                        
                        .. attribute:: rpf
                        
                        	PIM RPF information
                        	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rpf = YList()
                            self.rpf.parent = self
                            self.rpf.name = 'rpf'


                        class Rpf(object):
                            """
                            PIM RPF information
                            
                            .. attribute:: registered_address  <key>
                            
                            	Address for which RPF lookup
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: is_rpf_bgp_route
                            
                            	Is RPF through BGP route
                            	**type**\:  bool
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address_xr
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                            
                            .. attribute:: rpf_path
                            
                            	RPF Paths list
                            	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.registered_address = None
                                self.is_connected = None
                                self.is_rpf_bgp_route = None
                                self.metric = None
                                self.metric_preference = None
                                self.registered_address_xr = Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                self.registered_address_xr.parent = self
                                self.rpf_path = YList()
                                self.rpf_path.parent = self
                                self.rpf_path.name = 'rpf_path'


                            class RegisteredAddressXr(object):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:registered-address-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr']['meta_info']


                            class RpfPath(object):
                                """
                                RPF Paths list
                                
                                .. attribute:: connector
                                
                                	Connector Attribute
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface_disabled
                                
                                	Is the rpf interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                .. attribute:: is_via_mlsm
                                
                                	Via Mstatic LSM
                                	**type**\:  bool
                                
                                .. attribute:: rpf_interface_name
                                
                                	RPF Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: rpf_neighbor
                                
                                	RPF neighbor
                                	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                
                                .. attribute:: rpf_nexthop
                                
                                	RPF nexthop
                                	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.connector = None
                                    self.extranet_vrf_name = None
                                    self.is_connector_attribute_present = None
                                    self.is_rpf_interface_disabled = None
                                    self.is_via_lsm = None
                                    self.is_via_mlsm = None
                                    self.rpf_interface_name = None
                                    self.rpf_neighbor = Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self.rpf_nexthop = Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                    self.rpf_nexthop.parent = self


                                class RpfNeighbor(object):
                                    """
                                    RPF neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor']['meta_info']


                                class RpfNexthop(object):
                                    """
                                    RPF nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-nexthop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.connector is not None:
                                        return True

                                    if self.extranet_vrf_name is not None:
                                        return True

                                    if self.is_connector_attribute_present is not None:
                                        return True

                                    if self.is_rpf_interface_disabled is not None:
                                        return True

                                    if self.is_via_lsm is not None:
                                        return True

                                    if self.is_via_mlsm is not None:
                                        return True

                                    if self.rpf_interface_name is not None:
                                        return True

                                    if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                        return True

                                    if self.rpf_nexthop is not None and self.rpf_nexthop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath']['meta_info']

                            @property
                            def _common_path(self):
                                if self.registered_address is None:
                                    raise YPYModelError('Key property registered_address is None')

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpfs/Cisco-IOS-XR-ipv4-pim-oper:rpf[Cisco-IOS-XR-ipv4-pim-oper:registered-address = ' + str(self.registered_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.registered_address is not None:
                                    return True

                                if self.is_connected is not None:
                                    return True

                                if self.is_rpf_bgp_route is not None:
                                    return True

                                if self.metric is not None:
                                    return True

                                if self.metric_preference is not None:
                                    return True

                                if self.registered_address_xr is not None and self.registered_address_xr._has_data():
                                    return True

                                if self.rpf_path is not None:
                                    for child_ref in self.rpf_path:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpfs'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rpf is not None:
                                for child_ref in self.rpf:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups._has_data():
                            return True

                        if self.rpf_hash_sources is not None and self.rpf_hash_sources._has_data():
                            return True

                        if self.rpfs is not None and self.rpfs._has_data():
                            return True

                        if self.saf_name is not None:
                            return True

                        if self.topology_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Safs.Saf']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.saf is not None:
                        for child_ref in self.saf:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Safs']['meta_info']


            class InterfaceStatistics(object):
                """
                PIM interface statistics
                
                .. attribute:: interface_statistic
                
                	PIM interface statistics
                	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_statistic = YList()
                    self.interface_statistic.parent = self
                    self.interface_statistic.name = 'interface_statistic'


                class InterfaceStatistic(object):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_ack_message
                    
                    	Input Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_message
                    
                    	Input Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_miscellaneous
                    
                    	Miscellaneous packet in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register
                    
                    	Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_ack_message
                    
                    	Output Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_message
                    
                    	Output Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register
                    
                    	Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.input_assert = None
                        self.input_bsr_message = None
                        self.input_candidate_rp_advertisement = None
                        self.input_df_election = None
                        self.input_graft_ack_message = None
                        self.input_graft_message = None
                        self.input_hello = None
                        self.input_jp = None
                        self.input_miscellaneous = None
                        self.input_register = None
                        self.input_register_stop = None
                        self.output_assert = None
                        self.output_bsr_message = None
                        self.output_candidate_rp_advertisement = None
                        self.output_df_election = None
                        self.output_graft_ack_message = None
                        self.output_graft_message = None
                        self.output_hello = None
                        self.output_jp = None
                        self.output_register = None
                        self.output_register_stop = None

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interface-statistics/Cisco-IOS-XR-ipv4-pim-oper:interface-statistic[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.input_assert is not None:
                            return True

                        if self.input_bsr_message is not None:
                            return True

                        if self.input_candidate_rp_advertisement is not None:
                            return True

                        if self.input_df_election is not None:
                            return True

                        if self.input_graft_ack_message is not None:
                            return True

                        if self.input_graft_message is not None:
                            return True

                        if self.input_hello is not None:
                            return True

                        if self.input_jp is not None:
                            return True

                        if self.input_miscellaneous is not None:
                            return True

                        if self.input_register is not None:
                            return True

                        if self.input_register_stop is not None:
                            return True

                        if self.output_assert is not None:
                            return True

                        if self.output_bsr_message is not None:
                            return True

                        if self.output_candidate_rp_advertisement is not None:
                            return True

                        if self.output_df_election is not None:
                            return True

                        if self.output_graft_ack_message is not None:
                            return True

                        if self.output_graft_message is not None:
                            return True

                        if self.output_hello is not None:
                            return True

                        if self.output_jp is not None:
                            return True

                        if self.output_register is not None:
                            return True

                        if self.output_register_stop is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interface-statistics'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_statistic is not None:
                        for child_ref in self.interface_statistic:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.InterfaceStatistics']['meta_info']


            class TopologyRouteCount(object):
                """
                Topology route count information from PIM
                topology table
                
                .. attribute:: active_group_ranges
                
                	No. of (\*,G/M) routes active in mrib
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_address
                
                	Group Address
                	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyRouteCount.GroupAddress>`
                
                .. attribute:: group_ranges
                
                	No. of (\*,G/M) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groute_count
                
                	No. of (\*,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: sg_route_count
                
                	No. of (S,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sgr_route_count
                
                	No. of (S,G)RPT routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.active_group_ranges = None
                    self.group_address = Ipv6Pim.Standby.DefaultContext.TopologyRouteCount.GroupAddress()
                    self.group_address.parent = self
                    self.group_ranges = None
                    self.groute_count = None
                    self.is_node_low_memory = None
                    self.sg_route_count = None
                    self.sgr_route_count = None


                class GroupAddress(object):
                    """
                    Group Address
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.af_name = None
                        self.ipv4_address = None
                        self.ipv6_address = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-route-count/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.af_name is not None:
                            return True

                        if self.ipv4_address is not None:
                            return True

                        if self.ipv6_address is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.TopologyRouteCount.GroupAddress']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-route-count'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.active_group_ranges is not None:
                        return True

                    if self.group_address is not None and self.group_address._has_data():
                        return True

                    if self.group_ranges is not None:
                        return True

                    if self.groute_count is not None:
                        return True

                    if self.is_node_low_memory is not None:
                        return True

                    if self.sg_route_count is not None:
                        return True

                    if self.sgr_route_count is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.TopologyRouteCount']['meta_info']


            class JpStatistics(object):
                """
                PIM join prune statistics table
                
                .. attribute:: jp_statistic
                
                	PIM Join Prune Statistics
                	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.JpStatistics.JpStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.jp_statistic = YList()
                    self.jp_statistic.parent = self
                    self.jp_statistic.name = 'jp_statistic'


                class JpStatistic(object):
                    """
                    PIM Join Prune Statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mtu
                    
                    	Interface MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received
                    
                    	Received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received100
                    
                    	Received 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_10k
                    
                    	Received 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_1k
                    
                    	Received 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_50k
                    
                    	Deprecated by Received100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted
                    
                    	Transmitted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: transmitted100
                    
                    	Transmitted 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_10k
                    
                    	Transmitted 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_1k
                    
                    	Transmitted 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_50k
                    
                    	Deprecated by Transmitted100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.mtu = None
                        self.received = None
                        self.received100 = None
                        self.received_10k = None
                        self.received_1k = None
                        self.received_50k = None
                        self.transmitted = None
                        self.transmitted100 = None
                        self.transmitted_10k = None
                        self.transmitted_1k = None
                        self.transmitted_50k = None

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:jp-statistics/Cisco-IOS-XR-ipv4-pim-oper:jp-statistic[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.mtu is not None:
                            return True

                        if self.received is not None:
                            return True

                        if self.received100 is not None:
                            return True

                        if self.received_10k is not None:
                            return True

                        if self.received_1k is not None:
                            return True

                        if self.received_50k is not None:
                            return True

                        if self.transmitted is not None:
                            return True

                        if self.transmitted100 is not None:
                            return True

                        if self.transmitted_10k is not None:
                            return True

                        if self.transmitted_1k is not None:
                            return True

                        if self.transmitted_50k is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.JpStatistics.JpStatistic']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:jp-statistics'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.jp_statistic is not None:
                        for child_ref in self.jp_statistic:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.JpStatistics']['meta_info']


            class MibDatabases(object):
                """
                PIM group database for mroute mibs table
                
                .. attribute:: mib_database
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.mib_database = YList()
                    self.mib_database.parent = self
                    self.mib_database.name = 'mib_database'


                class MibDatabase(object):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: assert_metric
                    
                    	Assert Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_metric_preference
                    
                    	Assert Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_rpt_bit
                    
                    	Assert RPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: bidirectional_route
                    
                    	Is this Bidir ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Multicast satic route group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr>`
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface name 
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_mask
                    
                    	Mask of the multicast root
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_neighbor
                    
                    	The RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor>`
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: source_address
                    
                    	Multicast static route source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr>`
                    
                    .. attribute:: source_netmask
                    
                    	Source mask
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: spt_bit
                    
                    	Is SPT bit set ?
                    	**type**\:  bool
                    
                    .. attribute:: upstream_assert_timer
                    
                    	Upstream Assert Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime of route
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.assert_metric = None
                        self.assert_metric_preference = None
                        self.assert_rpt_bit = None
                        self.bidirectional_route = None
                        self.group_address = None
                        self.group_address_xr = Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self.protocol = None
                        self.rpf_drop = None
                        self.rpf_extranet = None
                        self.rpf_interface_name = None
                        self.rpf_mask = None
                        self.rpf_neighbor = Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self.rpf_root = Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot()
                        self.rpf_root.parent = self
                        self.rpf_safi = None
                        self.rpf_table_name = None
                        self.rpf_vrf_name = None
                        self.source_address = None
                        self.source_address_xr = Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self.source_netmask = None
                        self.spt_bit = None
                        self.upstream_assert_timer = None
                        self.uptime = None


                    class SourceAddressXr(object):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases/Cisco-IOS-XR-ipv4-pim-oper:mib-database/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr']['meta_info']


                    class GroupAddressXr(object):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases/Cisco-IOS-XR-ipv4-pim-oper:mib-database/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr']['meta_info']


                    class RpfNeighbor(object):
                        """
                        The RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases/Cisco-IOS-XR-ipv4-pim-oper:mib-database/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor']['meta_info']


                    class RpfRoot(object):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases/Cisco-IOS-XR-ipv4-pim-oper:mib-database/Cisco-IOS-XR-ipv4-pim-oper:rpf-root'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases/Cisco-IOS-XR-ipv4-pim-oper:mib-database'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.assert_metric is not None:
                            return True

                        if self.assert_metric_preference is not None:
                            return True

                        if self.assert_rpt_bit is not None:
                            return True

                        if self.bidirectional_route is not None:
                            return True

                        if self.group_address is not None:
                            return True

                        if self.group_address_xr is not None and self.group_address_xr._has_data():
                            return True

                        if self.protocol is not None:
                            return True

                        if self.rpf_drop is not None:
                            return True

                        if self.rpf_extranet is not None:
                            return True

                        if self.rpf_interface_name is not None:
                            return True

                        if self.rpf_mask is not None:
                            return True

                        if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                            return True

                        if self.rpf_root is not None and self.rpf_root._has_data():
                            return True

                        if self.rpf_safi is not None:
                            return True

                        if self.rpf_table_name is not None:
                            return True

                        if self.rpf_vrf_name is not None:
                            return True

                        if self.source_address is not None:
                            return True

                        if self.source_address_xr is not None and self.source_address_xr._has_data():
                            return True

                        if self.source_netmask is not None:
                            return True

                        if self.spt_bit is not None:
                            return True

                        if self.upstream_assert_timer is not None:
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.mib_database is not None:
                        for child_ref in self.mib_database:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.MibDatabases']['meta_info']


            class GroupMapMatchRpfs(object):
                """
                Find matching group\-mapping for the specified
                group address
                
                .. attribute:: group_map_match_rpf
                
                	PIM group matching mapping entry
                	**type**\: list of    :py:class:`GroupMapMatchRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.group_map_match_rpf = YList()
                    self.group_map_match_rpf.parent = self
                    self.group_map_match_rpf.name = 'group_map_match_rpf'


                class GroupMapMatchRpf(object):
                    """
                    PIM group matching mapping entry
                    
                    .. attribute:: group_address  <key>
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\:  bool
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation>`
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor>`
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_address = None
                        self.are_we_rp = None
                        self.group_map_information = Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self.rpf_interface_name = None
                        self.rpf_neighbor = Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self.rpf_vrf_name = None


                    class RpfNeighbor(object):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor']['meta_info']


                    class GroupMapInformation(object):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.group_count = None
                            self.is_override = None
                            self.is_used = None
                            self.mrib_active = None
                            self.prefix = Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.priority = None
                            self.protocol = None
                            self.rp_address = Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self


                        class Prefix(object):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix']['meta_info']


                        class RpAddress(object):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.group_count is not None:
                                return True

                            if self.is_override is not None:
                                return True

                            if self.is_used is not None:
                                return True

                            if self.mrib_active is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation']['meta_info']

                    @property
                    def _common_path(self):
                        if self.group_address is None:
                            raise YPYModelError('Key property group_address is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-rpf[Cisco-IOS-XR-ipv4-pim-oper:group-address = ' + str(self.group_address) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_address is not None:
                            return True

                        if self.are_we_rp is not None:
                            return True

                        if self.group_map_information is not None and self.group_map_information._has_data():
                            return True

                        if self.rpf_interface_name is not None:
                            return True

                        if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                            return True

                        if self.rpf_vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-rpfs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.group_map_match_rpf is not None:
                        for child_ref in self.group_map_match_rpf:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs']['meta_info']


            class NeighborOldFormats(object):
                """
                PIM neighbor table old format
                
                .. attribute:: neighbor_old_format
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.neighbor_old_format = YList()
                    self.neighbor_old_format.parent = self
                    self.neighbor_old_format.name = 'neighbor_old_format'


                class NeighborOldFormat(object):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.dr_priority = None
                        self.expires = None
                        self.expiry_timer = None
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bfd_state = None
                        self.is_bidirectional_capable = None
                        self.is_dr_priority_capable = None
                        self.is_ecmp_redirect_capable = None
                        self.is_proxy_capable = None
                        self.is_this_neighbor_dr = None
                        self.is_this_neighbor_us = None
                        self.neighbor_address = None
                        self.neighbor_address_xr = YList()
                        self.neighbor_address_xr.parent = self
                        self.neighbor_address_xr.name = 'neighbor_address_xr'
                        self.override_interval = None
                        self.propagation_delay = None
                        self.uptime = None


                    class NeighborAddressXr(object):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-formats/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-format/Cisco-IOS-XR-ipv4-pim-oper:neighbor-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-formats/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-format'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.dr_priority is not None:
                            return True

                        if self.expires is not None:
                            return True

                        if self.expiry_timer is not None:
                            return True

                        if self.interface_name is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bfd_state is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_dr_priority_capable is not None:
                            return True

                        if self.is_ecmp_redirect_capable is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.is_this_neighbor_dr is not None:
                            return True

                        if self.is_this_neighbor_us is not None:
                            return True

                        if self.neighbor_address is not None:
                            return True

                        if self.neighbor_address_xr is not None:
                            for child_ref in self.neighbor_address_xr:
                                if child_ref._has_data():
                                    return True

                        if self.override_interval is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-formats'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.neighbor_old_format is not None:
                        for child_ref in self.neighbor_old_format:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.NeighborOldFormats']['meta_info']


            class IfrsSummary(object):
                """
                PIM interfaces in forward reference store
                summary
                
                .. attribute:: configuration_count
                
                	Configuration counts
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_count
                
                	Number of interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.configuration_count = None
                    self.interface_count = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ifrs-summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.configuration_count is not None:
                        return True

                    if self.interface_count is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.IfrsSummary']['meta_info']


            class Ranges(object):
                """
                PIM range list information
                
                .. attribute:: range
                
                	PIM range list information
                	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.range = YList()
                    self.range.parent = self
                    self.range.name = 'range'


                class Range(object):
                    """
                    PIM range list information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                    
                    .. attribute:: client_xr
                    
                    	Client mapping learnt via
                    	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                    
                    .. attribute:: expires
                    
                    	When mapping expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: group_range
                    
                    	List of group ranges
                    	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange>`
                    
                    .. attribute:: protocol
                    
                    	PIM protocol
                    	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	Rendezvous point address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr>`
                    
                    .. attribute:: source_of_information
                    
                    	Source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.client = None
                        self.client_xr = None
                        self.expires = None
                        self.group_range = YList()
                        self.group_range.parent = self
                        self.group_range.name = 'group_range'
                        self.protocol = None
                        self.rp_address = None
                        self.rp_address_xr = Ipv6Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self.source_of_information = Ipv6Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation()
                        self.source_of_information.parent = self


                    class RpAddressXr(object):
                        """
                        Rendezvous point address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr']['meta_info']


                    class SourceOfInformation(object):
                        """
                        Source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation']['meta_info']


                    class GroupRange(object):
                        """
                        List of group ranges
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.expires = None
                            self.prefix = Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.source_of_information = Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation()
                            self.source_of_information.parent = self
                            self.uptime = None


                        class Prefix(object):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range/Cisco-IOS-XR-ipv4-pim-oper:group-range/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix']['meta_info']


                        class SourceOfInformation(object):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range/Cisco-IOS-XR-ipv4-pim-oper:group-range/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range/Cisco-IOS-XR-ipv4-pim-oper:group-range'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.expires is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.source_of_information is not None and self.source_of_information._has_data():
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.client is not None:
                            return True

                        if self.client_xr is not None:
                            return True

                        if self.expires is not None:
                            return True

                        if self.group_range is not None:
                            for child_ref in self.group_range:
                                if child_ref._has_data():
                                    return True

                        if self.protocol is not None:
                            return True

                        if self.rp_address is not None:
                            return True

                        if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                            return True

                        if self.source_of_information is not None and self.source_of_information._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Ranges.Range']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.range is not None:
                        for child_ref in self.range:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Ranges']['meta_info']


            class InterfaceOldFormats(object):
                """
                PIM interfaces in old format
                
                .. attribute:: interface_old_format
                
                	PIM interface name
                	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_old_format = YList()
                    self.interface_old_format.parent = self
                    self.interface_old_format.name = 'interface_old_format'


                class InterfaceOldFormat(object):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.configured_override_interval = None
                        self.configured_propagation_delay = None
                        self.dr_address = Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                        self.dr_address.parent = self
                        self.dr_priority = None
                        self.external_neighbor_count = None
                        self.generation_id = None
                        self.hello_expiry = None
                        self.hello_interval = None
                        self.idb_acl_name = None
                        self.idb_acl_provided = None
                        self.idb_current_count = None
                        self.idb_max_count = None
                        self.idb_oor_enabled = None
                        self.idb_threshold_count = None
                        self.interface_address = YList()
                        self.interface_address.parent = self
                        self.interface_address.name = 'interface_address'
                        self.interface_address_mask = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bidirectional_capable = None
                        self.is_enabled = None
                        self.is_proxy_capable = None
                        self.join_prune_interval = None
                        self.neighbor_count = None
                        self.neighbor_filter_name = None
                        self.override_interval = None
                        self.passive_interface = None
                        self.propagation_delay = None
                        self.prune_delay_enabled = None
                        self.virtual_interface = None


                    class DrAddress(object):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress']['meta_info']


                    class InterfaceAddress(object):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interface-old-formats/Cisco-IOS-XR-ipv4-pim-oper:interface-old-format[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.are_we_dr is not None:
                            return True

                        if self.bfd_enabled is not None:
                            return True

                        if self.bfd_interval is not None:
                            return True

                        if self.bfd_multiplier is not None:
                            return True

                        if self.configured_override_interval is not None:
                            return True

                        if self.configured_propagation_delay is not None:
                            return True

                        if self.dr_address is not None and self.dr_address._has_data():
                            return True

                        if self.dr_priority is not None:
                            return True

                        if self.external_neighbor_count is not None:
                            return True

                        if self.generation_id is not None:
                            return True

                        if self.hello_expiry is not None:
                            return True

                        if self.hello_interval is not None:
                            return True

                        if self.idb_acl_name is not None:
                            return True

                        if self.idb_acl_provided is not None:
                            return True

                        if self.idb_current_count is not None:
                            return True

                        if self.idb_max_count is not None:
                            return True

                        if self.idb_oor_enabled is not None:
                            return True

                        if self.idb_threshold_count is not None:
                            return True

                        if self.interface_address is not None:
                            for child_ref in self.interface_address:
                                if child_ref._has_data():
                                    return True

                        if self.interface_address_mask is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_enabled is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.join_prune_interval is not None:
                            return True

                        if self.neighbor_count is not None:
                            return True

                        if self.neighbor_filter_name is not None:
                            return True

                        if self.override_interval is not None:
                            return True

                        if self.passive_interface is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.prune_delay_enabled is not None:
                            return True

                        if self.virtual_interface is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interface-old-formats'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_old_format is not None:
                        for child_ref in self.interface_old_format:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats']['meta_info']


            class Bsr(object):
                """
                PIM BSR information
                
                .. attribute:: bsr_elections
                
                	PIM BSR election state
                	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections>`
                
                .. attribute:: candidate_rps
                
                	PIM candidate\-RP
                	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps>`
                
                .. attribute:: rp_caches
                
                	PIM BSR RP cache table
                	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bsr_elections = Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections()
                    self.bsr_elections.parent = self
                    self.candidate_rps = Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps()
                    self.candidate_rps.parent = self
                    self.rp_caches = Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches()
                    self.rp_caches.parent = self


                class RpCaches(object):
                    """
                    PIM BSR RP cache table
                    
                    .. attribute:: rp_cache
                    
                    	PIM BSR RP cache
                    	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.rp_cache = YList()
                        self.rp_cache.parent = self
                        self.rp_cache.name = 'rp_cache'


                    class RpCache(object):
                        """
                        PIM BSR RP cache
                        
                        .. attribute:: group_prefix  <key>
                        
                        	Group prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: candidate_rp_group_count
                        
                        	C\-RP count for this Prefix
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: candidate_rp_list
                        
                        	C\-RP list for this prefix
                        	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList>`
                        
                        .. attribute:: group_prefix_length
                        
                        	Group Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_prefix_xr
                        
                        	Group Prefix
                        	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.group_prefix = None
                            self.candidate_rp_group_count = None
                            self.candidate_rp_list = Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList()
                            self.candidate_rp_list.parent = self
                            self.group_prefix_length = None
                            self.group_prefix_xr = Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr()
                            self.group_prefix_xr.parent = self


                        class GroupPrefixXr(object):
                            """
                            Group Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-prefix-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr']['meta_info']


                        class CandidateRpList(object):
                            """
                            C\-RP list for this prefix
                            
                            .. attribute:: pim_bsr_crp_bag
                            
                            	pim bsr crp bag
                            	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pim_bsr_crp_bag = YList()
                                self.pim_bsr_crp_bag.parent = self
                                self.pim_bsr_crp_bag.name = 'pim_bsr_crp_bag'


                            class PimBsrCrpBag(object):
                                """
                                pim bsr crp bag
                                
                                .. attribute:: candidate_rp_address
                                
                                	C\-RP address
                                	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                
                                .. attribute:: candidate_rp_expires
                                
                                	C\-RP Expires
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_holdtime
                                
                                	C\-RP Holdtime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_priority
                                
                                	C\-RP Priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: candidate_rp_up_time
                                
                                	C\-RP Uptime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: protocol
                                
                                	PIM Protocol
                                	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.candidate_rp_address = Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                    self.candidate_rp_address.parent = self
                                    self.candidate_rp_expires = None
                                    self.candidate_rp_holdtime = None
                                    self.candidate_rp_priority = None
                                    self.candidate_rp_up_time = None
                                    self.protocol = None


                                class CandidateRpAddress(object):
                                    """
                                    C\-RP address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:pim-bsr-crp-bag'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.candidate_rp_address is not None and self.candidate_rp_address._has_data():
                                        return True

                                    if self.candidate_rp_expires is not None:
                                        return True

                                    if self.candidate_rp_holdtime is not None:
                                        return True

                                    if self.candidate_rp_priority is not None:
                                        return True

                                    if self.candidate_rp_up_time is not None:
                                        return True

                                    if self.protocol is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp-list'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pim_bsr_crp_bag is not None:
                                    for child_ref in self.pim_bsr_crp_bag:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList']['meta_info']

                        @property
                        def _common_path(self):
                            if self.group_prefix is None:
                                raise YPYModelError('Key property group_prefix is None')

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:rp-caches/Cisco-IOS-XR-ipv4-pim-oper:rp-cache[Cisco-IOS-XR-ipv4-pim-oper:group-prefix = ' + str(self.group_prefix) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.group_prefix is not None:
                                return True

                            if self.candidate_rp_group_count is not None:
                                return True

                            if self.candidate_rp_list is not None and self.candidate_rp_list._has_data():
                                return True

                            if self.group_prefix_length is not None:
                                return True

                            if self.group_prefix_xr is not None and self.group_prefix_xr._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:rp-caches'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.rp_cache is not None:
                            for child_ref in self.rp_cache:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches']['meta_info']


                class CandidateRps(object):
                    """
                    PIM candidate\-RP
                    
                    .. attribute:: candidate_rp
                    
                    	PIM BSR candidate RP information
                    	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.candidate_rp = YList()
                        self.candidate_rp.parent = self
                        self.candidate_rp.name = 'candidate_rp'


                    class CandidateRp(object):
                        """
                        PIM BSR candidate RP information
                        
                        .. attribute:: rp_address  <key>
                        
                        	Candidate\-RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: acl_name
                        
                        	Group Access\-List Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: candidate_rp
                        
                        	Cand\-RP Address
                        	**type**\:   :py:class:`CandidateRp_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_>`
                        
                        .. attribute:: candidate_rp_advance_interval
                        
                        	Cand\-RP Adv Interval in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: candidate_rp_mode
                        
                        	Cand\-RP Mode
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: candidate_rp_scope
                        
                        	Cand\-RP Scope
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: candidate_rp_uptime
                        
                        	Cand\-RP uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_access
                        
                        	Group Ranges Using this Cand\-RP
                        	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                        
                        .. attribute:: crp_holdtime
                        
                        	Cand\-RP Holdtime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_priority
                        
                        	Cand\-RP Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rp_address = None
                            self.acl_name = None
                            self.candidate_rp = Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_()
                            self.candidate_rp.parent = self
                            self.candidate_rp_advance_interval = None
                            self.candidate_rp_mode = None
                            self.candidate_rp_scope = None
                            self.candidate_rp_uptime = None
                            self.crp_access = YList()
                            self.crp_access.parent = self
                            self.crp_access.name = 'crp_access'
                            self.crp_holdtime = None
                            self.crp_priority = None


                        class CandidateRp_(object):
                            """
                            Cand\-RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_']['meta_info']


                        class CrpAccess(object):
                            """
                            Group Ranges Using this Cand\-RP
                            
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.acl_name = None
                                self.candidate_rp_mode = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:crp-access'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.acl_name is not None:
                                    return True

                                if self.candidate_rp_mode is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess']['meta_info']

                        @property
                        def _common_path(self):
                            if self.rp_address is None:
                                raise YPYModelError('Key property rp_address is None')

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:candidate-rps/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp[Cisco-IOS-XR-ipv4-pim-oper:rp-address = ' + str(self.rp_address) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rp_address is not None:
                                return True

                            if self.acl_name is not None:
                                return True

                            if self.candidate_rp is not None and self.candidate_rp._has_data():
                                return True

                            if self.candidate_rp_advance_interval is not None:
                                return True

                            if self.candidate_rp_mode is not None:
                                return True

                            if self.candidate_rp_scope is not None:
                                return True

                            if self.candidate_rp_uptime is not None:
                                return True

                            if self.crp_access is not None:
                                for child_ref in self.crp_access:
                                    if child_ref._has_data():
                                        return True

                            if self.crp_holdtime is not None:
                                return True

                            if self.crp_priority is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:candidate-rps'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.candidate_rp is not None:
                            for child_ref in self.candidate_rp:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps']['meta_info']


                class BsrElections(object):
                    """
                    PIM BSR election state
                    
                    .. attribute:: bsr_election
                    
                    	PIM BSR information
                    	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bsr_election = YList()
                        self.bsr_election.parent = self
                        self.bsr_election.name = 'bsr_election'


                    class BsrElection(object):
                        """
                        PIM BSR information
                        
                        .. attribute:: pim_scope  <key>
                        
                        	BSR information
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: bootstrap_timeout
                        
                        	Bootstrap Timeout
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_address
                        
                        	BSR address
                        	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress>`
                        
                        .. attribute:: bsr_election_state
                        
                        	BSR Election State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_mask_length
                        
                        	Hash Function Mask Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_priority
                        
                        	BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_scope
                        
                        	BSR Scope
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_up_time
                        
                        	BSR Uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_bsr_address
                        
                        	C\-BSR address
                        	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                        
                        .. attribute:: candidate_bsr_flag
                        
                        	BSR Candidate Config Flag
                        	**type**\:  bool
                        
                        .. attribute:: candidate_bsr_mask_length
                        
                        	C\-BSR Hash Func. Mask Len
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_priority
                        
                        	C\-BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_state
                        
                        	BSR Candidate State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.pim_scope = None
                            self.bootstrap_timeout = None
                            self.bsr_address = Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress()
                            self.bsr_address.parent = self
                            self.bsr_election_state = None
                            self.bsr_mask_length = None
                            self.bsr_priority = None
                            self.bsr_scope = None
                            self.bsr_up_time = None
                            self.candidate_bsr_address = Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                            self.candidate_bsr_address.parent = self
                            self.candidate_bsr_flag = None
                            self.candidate_bsr_mask_length = None
                            self.candidate_bsr_priority = None
                            self.candidate_bsr_state = None


                        class BsrAddress(object):
                            """
                            BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bsr-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress']['meta_info']


                        class CandidateBsrAddress(object):
                            """
                            C\-BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-bsr-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.pim_scope is None:
                                raise YPYModelError('Key property pim_scope is None')

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:bsr-elections/Cisco-IOS-XR-ipv4-pim-oper:bsr-election[Cisco-IOS-XR-ipv4-pim-oper:pim-scope = ' + str(self.pim_scope) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.pim_scope is not None:
                                return True

                            if self.bootstrap_timeout is not None:
                                return True

                            if self.bsr_address is not None and self.bsr_address._has_data():
                                return True

                            if self.bsr_election_state is not None:
                                return True

                            if self.bsr_mask_length is not None:
                                return True

                            if self.bsr_priority is not None:
                                return True

                            if self.bsr_scope is not None:
                                return True

                            if self.bsr_up_time is not None:
                                return True

                            if self.candidate_bsr_address is not None and self.candidate_bsr_address._has_data():
                                return True

                            if self.candidate_bsr_flag is not None:
                                return True

                            if self.candidate_bsr_mask_length is not None:
                                return True

                            if self.candidate_bsr_priority is not None:
                                return True

                            if self.candidate_bsr_state is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:bsr-elections'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bsr_election is not None:
                            for child_ref in self.bsr_election:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bsr_elections is not None and self.bsr_elections._has_data():
                        return True

                    if self.candidate_rps is not None and self.candidate_rps._has_data():
                        return True

                    if self.rp_caches is not None and self.rp_caches._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Bsr']['meta_info']


            class RoutePolicy(object):
                """
                PIM route policy
                
                .. attribute:: route_policy_statistics
                
                	PIM route policy statistics
                	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics>`
                
                .. attribute:: route_policy_tests
                
                	PIM route policy test run table
                	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.route_policy_statistics = Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics()
                    self.route_policy_statistics.parent = self
                    self.route_policy_tests = Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests()
                    self.route_policy_tests.parent = self


                class RoutePolicyStatistics(object):
                    """
                    PIM route policy statistics
                    
                    .. attribute:: any_table
                    
                    	Number of RPF lookup in any Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table
                    
                    	Number of RPF lookup in default\-only Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop
                    
                    	Number of RPF drops
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pass_
                    
                    	Number of RPF pass
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: policy_name
                    
                    	RPF policy name
                    	**type**\:  str
                    
                    .. attribute:: requests
                    
                    	Number of RPF lookup requests
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.any_table = None
                        self.default_table = None
                        self.drop = None
                        self.pass_ = None
                        self.policy_name = None
                        self.requests = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy/Cisco-IOS-XR-ipv4-pim-oper:route-policy-statistics'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.any_table is not None:
                            return True

                        if self.default_table is not None:
                            return True

                        if self.drop is not None:
                            return True

                        if self.pass_ is not None:
                            return True

                        if self.policy_name is not None:
                            return True

                        if self.requests is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics']['meta_info']


                class RoutePolicyTests(object):
                    """
                    PIM route policy test run table
                    
                    .. attribute:: route_policy_test
                    
                    	PIM route policy test run
                    	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.route_policy_test = YList()
                        self.route_policy_test.parent = self
                        self.route_policy_test.name = 'route_policy_test'


                    class RoutePolicyTest(object):
                        """
                        PIM route policy test run
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Default table selected
                        	**type**\:  bool
                        
                        .. attribute:: ext_comm
                        
                        	Extended Community
                        	**type**\:  str
                        
                        	**length:** 1..8
                        
                        .. attribute:: extended_community_rt
                        
                        	Route Target
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                        
                        .. attribute:: pass_
                        
                        	Pass
                        	**type**\:  bool
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                        
                        .. attribute:: table_active
                        
                        	Table active
                        	**type**\:  bool
                        
                        .. attribute:: table_exists
                        
                        	Table exists
                        	**type**\:  bool
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_name
                        
                        	VRF name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.afi = None
                            self.default_table = None
                            self.ext_comm = None
                            self.extended_community_rt = None
                            self.group_address = None
                            self.group_address_xr = Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self.pass_ = None
                            self.policy_name = None
                            self.safi = None
                            self.source_address = None
                            self.source_address_xr = Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self.table_active = None
                            self.table_exists = None
                            self.table_name = None
                            self.vrf_name = None


                        class SourceAddressXr(object):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy/Cisco-IOS-XR-ipv4-pim-oper:route-policy-tests/Cisco-IOS-XR-ipv4-pim-oper:route-policy-test/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr']['meta_info']


                        class GroupAddressXr(object):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy/Cisco-IOS-XR-ipv4-pim-oper:route-policy-tests/Cisco-IOS-XR-ipv4-pim-oper:route-policy-test/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy/Cisco-IOS-XR-ipv4-pim-oper:route-policy-tests/Cisco-IOS-XR-ipv4-pim-oper:route-policy-test'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.afi is not None:
                                return True

                            if self.default_table is not None:
                                return True

                            if self.ext_comm is not None:
                                return True

                            if self.extended_community_rt is not None:
                                return True

                            if self.group_address is not None:
                                return True

                            if self.group_address_xr is not None and self.group_address_xr._has_data():
                                return True

                            if self.pass_ is not None:
                                return True

                            if self.policy_name is not None:
                                return True

                            if self.safi is not None:
                                return True

                            if self.source_address is not None:
                                return True

                            if self.source_address_xr is not None and self.source_address_xr._has_data():
                                return True

                            if self.table_active is not None:
                                return True

                            if self.table_exists is not None:
                                return True

                            if self.table_name is not None:
                                return True

                            if self.vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy/Cisco-IOS-XR-ipv4-pim-oper:route-policy-tests'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.route_policy_test is not None:
                            for child_ref in self.route_policy_test:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.route_policy_statistics is not None and self.route_policy_statistics._has_data():
                        return True

                    if self.route_policy_tests is not None and self.route_policy_tests._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.RoutePolicy']['meta_info']


            class RpfSummary(object):
                """
                PIM RPF registration summary
                
                .. attribute:: default_safi
                
                	Default RPF Table SAFI
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: default_table_name
                
                	Default RPF Table Name
                	**type**\:  str
                
                .. attribute:: is_isis_mtr_configured
                
                	Is ISIS MTR configured?
                	**type**\:  bool
                
                .. attribute:: is_isis_te_configured
                
                	Is ISIS TE configured?
                	**type**\:  bool
                
                .. attribute:: is_mbgp_configured
                
                	Is MBGP configured?
                	**type**\:  bool
                
                .. attribute:: is_multipath_enabled
                
                	Is Multipath Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_interface_hash_enabled
                
                	Is Multipath Interface Hash Extension Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_hash_enabled
                
                	Is Multipath Source based Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_next_hop_hash_enabled
                
                	Is Multipath Source\-Nexthop Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_ospf_te_configured
                
                	Is OSPF TE configured?
                	**type**\:  bool
                
                .. attribute:: is_rib_convergence
                
                	RIB Convergence status
                	**type**\:  bool
                
                .. attribute:: mo_frr_configured
                
                	Is MoFRR configured?
                	**type**\:  bool
                
                .. attribute:: rib_convergence_time_left
                
                	RIB convergence time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_convergence_timeout
                
                	RIB convergence timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_mo_frr_configured
                
                	Is MoFRR RIB configured?
                	**type**\:  bool
                
                .. attribute:: rpf_registrations
                
                	RPF Registration count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	Is RUMP MuRIB enabled?
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.default_safi = None
                    self.default_table_name = None
                    self.is_isis_mtr_configured = None
                    self.is_isis_te_configured = None
                    self.is_mbgp_configured = None
                    self.is_multipath_enabled = None
                    self.is_multipath_interface_hash_enabled = None
                    self.is_multipath_source_hash_enabled = None
                    self.is_multipath_source_next_hop_hash_enabled = None
                    self.is_ospf_te_configured = None
                    self.is_rib_convergence = None
                    self.mo_frr_configured = None
                    self.rib_convergence_time_left = None
                    self.rib_convergence_timeout = None
                    self.rib_mo_frr_configured = None
                    self.rpf_registrations = None
                    self.rump_enabled = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.default_safi is not None:
                        return True

                    if self.default_table_name is not None:
                        return True

                    if self.is_isis_mtr_configured is not None:
                        return True

                    if self.is_isis_te_configured is not None:
                        return True

                    if self.is_mbgp_configured is not None:
                        return True

                    if self.is_multipath_enabled is not None:
                        return True

                    if self.is_multipath_interface_hash_enabled is not None:
                        return True

                    if self.is_multipath_source_hash_enabled is not None:
                        return True

                    if self.is_multipath_source_next_hop_hash_enabled is not None:
                        return True

                    if self.is_ospf_te_configured is not None:
                        return True

                    if self.is_rib_convergence is not None:
                        return True

                    if self.mo_frr_configured is not None:
                        return True

                    if self.rib_convergence_time_left is not None:
                        return True

                    if self.rib_convergence_timeout is not None:
                        return True

                    if self.rib_mo_frr_configured is not None:
                        return True

                    if self.rpf_registrations is not None:
                        return True

                    if self.rump_enabled is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.RpfSummary']['meta_info']


            class Interfaces(object):
                """
                PIM interfaces
                
                .. attribute:: interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Interfaces.Interface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface = YList()
                    self.interface.parent = self
                    self.interface.name = 'interface'


                class Interface(object):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.configured_override_interval = None
                        self.configured_propagation_delay = None
                        self.dr_address = Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress()
                        self.dr_address.parent = self
                        self.dr_priority = None
                        self.external_neighbor_count = None
                        self.generation_id = None
                        self.hello_expiry = None
                        self.hello_interval = None
                        self.idb_acl_name = None
                        self.idb_acl_provided = None
                        self.idb_current_count = None
                        self.idb_max_count = None
                        self.idb_oor_enabled = None
                        self.idb_threshold_count = None
                        self.interface_address = YList()
                        self.interface_address.parent = self
                        self.interface_address.name = 'interface_address'
                        self.interface_address_mask = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bidirectional_capable = None
                        self.is_enabled = None
                        self.is_proxy_capable = None
                        self.join_prune_interval = None
                        self.neighbor_count = None
                        self.neighbor_filter_name = None
                        self.override_interval = None
                        self.passive_interface = None
                        self.propagation_delay = None
                        self.prune_delay_enabled = None
                        self.virtual_interface = None


                    class DrAddress(object):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress']['meta_info']


                    class InterfaceAddress(object):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interfaces/Cisco-IOS-XR-ipv4-pim-oper:interface[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.are_we_dr is not None:
                            return True

                        if self.bfd_enabled is not None:
                            return True

                        if self.bfd_interval is not None:
                            return True

                        if self.bfd_multiplier is not None:
                            return True

                        if self.configured_override_interval is not None:
                            return True

                        if self.configured_propagation_delay is not None:
                            return True

                        if self.dr_address is not None and self.dr_address._has_data():
                            return True

                        if self.dr_priority is not None:
                            return True

                        if self.external_neighbor_count is not None:
                            return True

                        if self.generation_id is not None:
                            return True

                        if self.hello_expiry is not None:
                            return True

                        if self.hello_interval is not None:
                            return True

                        if self.idb_acl_name is not None:
                            return True

                        if self.idb_acl_provided is not None:
                            return True

                        if self.idb_current_count is not None:
                            return True

                        if self.idb_max_count is not None:
                            return True

                        if self.idb_oor_enabled is not None:
                            return True

                        if self.idb_threshold_count is not None:
                            return True

                        if self.interface_address is not None:
                            for child_ref in self.interface_address:
                                if child_ref._has_data():
                                    return True

                        if self.interface_address_mask is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_enabled is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.join_prune_interval is not None:
                            return True

                        if self.neighbor_count is not None:
                            return True

                        if self.neighbor_filter_name is not None:
                            return True

                        if self.override_interval is not None:
                            return True

                        if self.passive_interface is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.prune_delay_enabled is not None:
                            return True

                        if self.virtual_interface is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Interfaces.Interface']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interfaces'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface is not None:
                        for child_ref in self.interface:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Interfaces']['meta_info']


            class NetIoTunnels(object):
                """
                Tunnel information that NETIO has 
                
                .. attribute:: net_io_tunnel
                
                	PIM netio tunnel information
                	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.net_io_tunnel = YList()
                    self.net_io_tunnel.parent = self
                    self.net_io_tunnel.name = 'net_io_tunnel'


                class NetIoTunnel(object):
                    """
                    PIM netio tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.tunnel_name = None
                        self.group_address_netio = Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self.rp_address = Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress()
                        self.rp_address.parent = self
                        self.source_address = Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress()
                        self.source_address.parent = self
                        self.source_address_netio = Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self.vrf_name = None


                    class SourceAddress(object):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress']['meta_info']


                    class RpAddress(object):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress']['meta_info']


                    class SourceAddressNetio(object):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-netio'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio']['meta_info']


                    class GroupAddressNetio(object):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-netio'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio']['meta_info']

                    @property
                    def _common_path(self):
                        if self.tunnel_name is None:
                            raise YPYModelError('Key property tunnel_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:net-io-tunnels/Cisco-IOS-XR-ipv4-pim-oper:net-io-tunnel[Cisco-IOS-XR-ipv4-pim-oper:tunnel-name = ' + str(self.tunnel_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.tunnel_name is not None:
                            return True

                        if self.group_address_netio is not None and self.group_address_netio._has_data():
                            return True

                        if self.rp_address is not None and self.rp_address._has_data():
                            return True

                        if self.source_address is not None and self.source_address._has_data():
                            return True

                        if self.source_address_netio is not None and self.source_address_netio._has_data():
                            return True

                        if self.vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:net-io-tunnels'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.net_io_tunnel is not None:
                        for child_ref in self.net_io_tunnel:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.NetIoTunnels']['meta_info']


            class BidirDfStates(object):
                """
                Bidirectional PIM DF election state table
                
                .. attribute:: bidir_df_state
                
                	Bidirectional PIM DF Election Table Entry
                	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bidir_df_state = YList()
                    self.bidir_df_state.parent = self
                    self.bidir_df_state.name = 'bidir_df_state'


                class BidirDfState(object):
                    """
                    Bidirectional PIM DF Election Table Entry
                    
                    .. attribute:: election_state
                    
                    	DF Election State
                    	**type**\:  str
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: our_metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: our_metric_preference
                    
                    	MetricPreference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr>`
                    
                    .. attribute:: time_nano_seconds
                    
                    	Timer expires (nseconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: time_seconds
                    
                    	Timer expires (seconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.election_state = None
                        self.interface_name = None
                        self.our_metric = None
                        self.our_metric_preference = None
                        self.pim_interface_name = None
                        self.rp_address = None
                        self.rp_address_xr = Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self.time_nano_seconds = None
                        self.time_seconds = None


                    class RpAddressXr(object):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-states/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-state/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-states/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-state'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.election_state is not None:
                            return True

                        if self.interface_name is not None:
                            return True

                        if self.our_metric is not None:
                            return True

                        if self.our_metric_preference is not None:
                            return True

                        if self.pim_interface_name is not None:
                            return True

                        if self.rp_address is not None:
                            return True

                        if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                            return True

                        if self.time_nano_seconds is not None:
                            return True

                        if self.time_seconds is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-states'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bidir_df_state is not None:
                        for child_ref in self.bidir_df_state:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.BidirDfStates']['meta_info']


            class Topologies(object):
                """
                PIM topology table
                
                .. attribute:: topology
                
                	PIM topology information
                	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.topology = YList()
                    self.topology.parent = self
                    self.topology.name = 'topology'


                class Topology(object):
                    """
                    PIM topology information
                    
                    .. attribute:: alive
                    
                    	Alive time in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: anycast_rp_match
                    
                    	Group matches Anycast\-RP policy
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_route_target
                    
                    	Anycast\-RP RT
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: assume_alive
                    
                    	The Assume Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: bgp_join
                    
                    	BGP C JOIN
                    	**type**\:  bool
                    
                    .. attribute:: bgpjp_time
                    
                    	BGP C JP Time
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: connected
                    
                    	Is Connected ?
                    	**type**\:  bool
                    
                    .. attribute:: customer_routing_type
                    
                    	Type of Customer Routing in the MVPN
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: dont_check_connected
                    
                    	Do we need to make the connected check on this route ?
                    	**type**\:  bool
                    
                    .. attribute:: expiry
                    
                    	When this entry expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: extranet_route
                    
                    	Is a Extranet route ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr>`
                    
                    .. attribute:: inherit_alive
                    
                    	The Inherit Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: inherit_spt
                    
                    	The Inherit SPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: is_via_lsm
                    
                    	Via LSM
                    	**type**\:  bool
                    
                    .. attribute:: jp_status
                    
                    	Join\-Prune Status
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: jp_timer
                    
                    	Join\-Prune Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: last_hop
                    
                    	Are we last hop ?
                    	**type**\:  bool
                    
                    .. attribute:: limit_reached
                    
                    	Have we throttled the creation of routes or interfaces ?
                    	**type**\:  bool
                    
                    .. attribute:: low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_active
                    
                    	Is MoFRR Active?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_backup
                    
                    	Is this Mofrr Backup?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_primary
                    
                    	Is this Mofrr Primary?
                    	**type**\:  bool
                    
                    .. attribute:: orig_src_address
                    
                    	Orig Src Address
                    	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress>`
                    
                    .. attribute:: outgoing_interface
                    
                    	Outgoing interface list
                    	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface>`
                    
                    .. attribute:: probe_alive
                    
                    	The Probe Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                    
                    .. attribute:: proxy
                    
                    	Is the RPF target a proxy?
                    	**type**\:  bool
                    
                    .. attribute:: proxy_address
                    
                    	RPF Proxy address
                    	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress>`
                    
                    .. attribute:: really_alive
                    
                    	The Really Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: register_received
                    
                    	Have registers been received for this source ?
                    	**type**\:  bool
                    
                    .. attribute:: register_received_timer
                    
                    	Register Received Timer in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: remote_source
                    
                    	MSDP told us
                    	**type**\:  bool
                    
                    .. attribute:: rib_mo_frr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rp_address
                    
                    	RP Address (If rpt)
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpAddress>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor>`
                    
                    .. attribute:: rpf_proxy_enabled
                    
                    	Is rpf if proxy enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: rpt
                    
                    	RPT bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpt_xr
                    
                    	Is this on the RPT ?
                    	**type**\:  bool
                    
                    .. attribute:: sa_joined
                    
                    	BGP SA join
                    	**type**\:  bool
                    
                    .. attribute:: sa_received
                    
                    	BGP SA received
                    	**type**\:  bool
                    
                    .. attribute:: sa_sent
                    
                    	BGP SA sent
                    	**type**\:  bool
                    
                    .. attribute:: secondary_rpf_interface_name
                    
                    	Secondary Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: secondary_rpf_neighbor
                    
                    	Secondary RPF Neighbor
                    	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor>`
                    
                    .. attribute:: sending_null_registers
                    
                    	Are we sending null registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: sending_registers
                    
                    	Are we sending registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: signal_sources
                    
                    	Signal Sources on route?
                    	**type**\:  bool
                    
                    .. attribute:: source_address
                    
                    	Source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr>`
                    
                    .. attribute:: spt
                    
                    	Is this on the SPT ?
                    	**type**\:  bool
                    
                    .. attribute:: suppress_registers
                    
                    	When the Null register probe expires
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: vxlan
                    
                    	Is this VXLAN?
                    	**type**\:  bool
                    
                    .. attribute:: wildcard
                    
                    	WC \-Wildcard
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.alive = None
                        self.anycast_rp_match = None
                        self.anycast_rp_route_target = None
                        self.assume_alive = None
                        self.bgp_join = None
                        self.bgpjp_time = None
                        self.connected = None
                        self.customer_routing_type = None
                        self.dont_check_connected = None
                        self.expiry = None
                        self.extranet_route = None
                        self.group_address = None
                        self.group_address_xr = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self.inherit_alive = None
                        self.inherit_spt = None
                        self.is_via_lsm = None
                        self.jp_status = None
                        self.jp_timer = None
                        self.last_hop = None
                        self.limit_reached = None
                        self.low_memory = None
                        self.mofrr_active = None
                        self.mofrr_backup = None
                        self.mofrr_enabled = None
                        self.mofrr_primary = None
                        self.orig_src_address = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress()
                        self.orig_src_address.parent = self
                        self.outgoing_interface = YList()
                        self.outgoing_interface.parent = self
                        self.outgoing_interface.name = 'outgoing_interface'
                        self.probe_alive = None
                        self.protocol = None
                        self.proxy = None
                        self.proxy_address = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress()
                        self.proxy_address.parent = self
                        self.really_alive = None
                        self.register_received = None
                        self.register_received_timer = None
                        self.remote_source = None
                        self.rib_mo_frr_enabled = None
                        self.rp_address = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpAddress()
                        self.rp_address.parent = self
                        self.rpf_drop = None
                        self.rpf_extranet = None
                        self.rpf_interface_name = None
                        self.rpf_neighbor = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self.rpf_proxy_enabled = None
                        self.rpf_root = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot()
                        self.rpf_root.parent = self
                        self.rpf_safi = None
                        self.rpf_table_name = None
                        self.rpf_vrf_name = None
                        self.rpt = None
                        self.rpt_xr = None
                        self.sa_joined = None
                        self.sa_received = None
                        self.sa_sent = None
                        self.secondary_rpf_interface_name = None
                        self.secondary_rpf_neighbor = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor()
                        self.secondary_rpf_neighbor.parent = self
                        self.sending_null_registers = None
                        self.sending_registers = None
                        self.signal_sources = None
                        self.source_address = None
                        self.source_address_xr = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self.spt = None
                        self.suppress_registers = None
                        self.uptime = None
                        self.vxlan = None
                        self.wildcard = None


                    class GroupAddressXr(object):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr']['meta_info']


                    class SourceAddressXr(object):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr']['meta_info']


                    class RpAddress(object):
                        """
                        RP Address (If rpt)
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpAddress']['meta_info']


                    class RpfNeighbor(object):
                        """
                        RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor']['meta_info']


                    class SecondaryRpfNeighbor(object):
                        """
                        Secondary RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:secondary-rpf-neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor']['meta_info']


                    class RpfRoot(object):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:rpf-root'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot']['meta_info']


                    class ProxyAddress(object):
                        """
                        RPF Proxy address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:proxy-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress']['meta_info']


                    class OrigSrcAddress(object):
                        """
                        Orig Src Address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:orig-src-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress']['meta_info']


                    class OutgoingInterface(object):
                        """
                        Outgoing interface list
                        
                        .. attribute:: admin_boundary
                        
                        	Is this an administrative boundary ?
                        	**type**\:  bool
                        
                        .. attribute:: assert_timer
                        
                        	Assert Timer in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: assert_winner
                        
                        	Assert Winner
                        	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner>`
                        
                        .. attribute:: bgp_c_mcast_join
                        
                        	BGP C\-Mcast join
                        	**type**\:  bool
                        
                        .. attribute:: bgp_c_mcast_prune_delay_timer
                        
                        	BGP C\-MCAST Prune Suppression in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: data_mdt_join
                        
                        	Data MDT join
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	Expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: extranet_interface
                        
                        	Is this an Extranet Interface ?
                        	**type**\:  bool
                        
                        .. attribute:: forwarding_state
                        
                        	Forward or Prune
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: igmp_membership
                        
                        	IGMP membership
                        	**type**\:  bool
                        
                        .. attribute:: immediate_state
                        
                        	Immediate fwding state
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_interest_info
                        
                        	Internal Interest
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_state
                        
                        	Join\-Prune State
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer (secs)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: local_mdt_join
                        
                        	Default MDT Join
                        	**type**\:  bool
                        
                        .. attribute:: local_members
                        
                        	Local Information
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: mdt_safi_join
                        
                        	MDT Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mldp_inband_mdt
                        
                        	MLDP Inband MDT interface
                        	**type**\:  bool
                        
                        .. attribute:: mldp_stale
                        
                        	OLE is stale
                        	**type**\:  bool
                        
                        .. attribute:: mvp_nv6_safi_join
                        
                        	MVPN IPv6 Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mvpn_safi_join
                        
                        	MVPN Safi join
                        	**type**\:  bool
                        
                        .. attribute:: sa_prune
                        
                        	BGP SA Prune state
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vrf_name
                        
                        	VRF which physically owns
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.admin_boundary = None
                            self.assert_timer = None
                            self.assert_winner = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner()
                            self.assert_winner.parent = self
                            self.bgp_c_mcast_join = None
                            self.bgp_c_mcast_prune_delay_timer = None
                            self.data_mdt_join = None
                            self.expiry = None
                            self.extranet_interface = None
                            self.forwarding_state = None
                            self.igmp_membership = None
                            self.immediate_state = None
                            self.interface_name = None
                            self.internal_interest_info = None
                            self.jp_state = None
                            self.jp_timer = None
                            self.last_hop = None
                            self.local_mdt_join = None
                            self.local_members = None
                            self.mdt_safi_join = None
                            self.mldp_inband_mdt = None
                            self.mldp_stale = None
                            self.mvp_nv6_safi_join = None
                            self.mvpn_safi_join = None
                            self.sa_prune = None
                            self.uptime = None
                            self.vrf_name = None


                        class AssertWinner(object):
                            """
                            Assert Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:outgoing-interface/Cisco-IOS-XR-ipv4-pim-oper:assert-winner'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:outgoing-interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.admin_boundary is not None:
                                return True

                            if self.assert_timer is not None:
                                return True

                            if self.assert_winner is not None and self.assert_winner._has_data():
                                return True

                            if self.bgp_c_mcast_join is not None:
                                return True

                            if self.bgp_c_mcast_prune_delay_timer is not None:
                                return True

                            if self.data_mdt_join is not None:
                                return True

                            if self.expiry is not None:
                                return True

                            if self.extranet_interface is not None:
                                return True

                            if self.forwarding_state is not None:
                                return True

                            if self.igmp_membership is not None:
                                return True

                            if self.immediate_state is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.internal_interest_info is not None:
                                return True

                            if self.jp_state is not None:
                                return True

                            if self.jp_timer is not None:
                                return True

                            if self.last_hop is not None:
                                return True

                            if self.local_mdt_join is not None:
                                return True

                            if self.local_members is not None:
                                return True

                            if self.mdt_safi_join is not None:
                                return True

                            if self.mldp_inband_mdt is not None:
                                return True

                            if self.mldp_stale is not None:
                                return True

                            if self.mvp_nv6_safi_join is not None:
                                return True

                            if self.mvpn_safi_join is not None:
                                return True

                            if self.sa_prune is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            if self.vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.alive is not None:
                            return True

                        if self.anycast_rp_match is not None:
                            return True

                        if self.anycast_rp_route_target is not None:
                            return True

                        if self.assume_alive is not None:
                            return True

                        if self.bgp_join is not None:
                            return True

                        if self.bgpjp_time is not None:
                            return True

                        if self.connected is not None:
                            return True

                        if self.customer_routing_type is not None:
                            return True

                        if self.dont_check_connected is not None:
                            return True

                        if self.expiry is not None:
                            return True

                        if self.extranet_route is not None:
                            return True

                        if self.group_address is not None:
                            return True

                        if self.group_address_xr is not None and self.group_address_xr._has_data():
                            return True

                        if self.inherit_alive is not None:
                            return True

                        if self.inherit_spt is not None:
                            return True

                        if self.is_via_lsm is not None:
                            return True

                        if self.jp_status is not None:
                            return True

                        if self.jp_timer is not None:
                            return True

                        if self.last_hop is not None:
                            return True

                        if self.limit_reached is not None:
                            return True

                        if self.low_memory is not None:
                            return True

                        if self.mofrr_active is not None:
                            return True

                        if self.mofrr_backup is not None:
                            return True

                        if self.mofrr_enabled is not None:
                            return True

                        if self.mofrr_primary is not None:
                            return True

                        if self.orig_src_address is not None and self.orig_src_address._has_data():
                            return True

                        if self.outgoing_interface is not None:
                            for child_ref in self.outgoing_interface:
                                if child_ref._has_data():
                                    return True

                        if self.probe_alive is not None:
                            return True

                        if self.protocol is not None:
                            return True

                        if self.proxy is not None:
                            return True

                        if self.proxy_address is not None and self.proxy_address._has_data():
                            return True

                        if self.really_alive is not None:
                            return True

                        if self.register_received is not None:
                            return True

                        if self.register_received_timer is not None:
                            return True

                        if self.remote_source is not None:
                            return True

                        if self.rib_mo_frr_enabled is not None:
                            return True

                        if self.rp_address is not None and self.rp_address._has_data():
                            return True

                        if self.rpf_drop is not None:
                            return True

                        if self.rpf_extranet is not None:
                            return True

                        if self.rpf_interface_name is not None:
                            return True

                        if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                            return True

                        if self.rpf_proxy_enabled is not None:
                            return True

                        if self.rpf_root is not None and self.rpf_root._has_data():
                            return True

                        if self.rpf_safi is not None:
                            return True

                        if self.rpf_table_name is not None:
                            return True

                        if self.rpf_vrf_name is not None:
                            return True

                        if self.rpt is not None:
                            return True

                        if self.rpt_xr is not None:
                            return True

                        if self.sa_joined is not None:
                            return True

                        if self.sa_received is not None:
                            return True

                        if self.sa_sent is not None:
                            return True

                        if self.secondary_rpf_interface_name is not None:
                            return True

                        if self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor._has_data():
                            return True

                        if self.sending_null_registers is not None:
                            return True

                        if self.sending_registers is not None:
                            return True

                        if self.signal_sources is not None:
                            return True

                        if self.source_address is not None:
                            return True

                        if self.source_address_xr is not None and self.source_address_xr._has_data():
                            return True

                        if self.spt is not None:
                            return True

                        if self.suppress_registers is not None:
                            return True

                        if self.uptime is not None:
                            return True

                        if self.vxlan is not None:
                            return True

                        if self.wildcard is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Topologies.Topology']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.topology is not None:
                        for child_ref in self.topology:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Topologies']['meta_info']


            class BgpAfs(object):
                """
                PIM BGP SAFI table
                
                .. attribute:: bgp_af
                
                	PIM BGP SAFI information
                	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bgp_af = YList()
                    self.bgp_af.parent = self
                    self.bgp_af.name = 'bgp_af'


                class BgpAf(object):
                    """
                    PIM BGP SAFI information
                    
                    .. attribute:: extranet_path_count
                    
                    	Count of dependent extranet paths
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group
                    
                    	Group address
                    	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group>`
                    
                    .. attribute:: group_address
                    
                    	Group IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: is_bgp_added
                    
                    	SAFI learnt from BGP
                    	**type**\:  bool
                    
                    .. attribute:: next_hop
                    
                    	Next hop address
                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop>`
                    
                    .. attribute:: route_distinguisher
                    
                    	Router ID
                    	**type**\:  str
                    
                    	**length:** 0..256
                    
                    .. attribute:: source
                    
                    	Source address
                    	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source>`
                    
                    .. attribute:: source_address
                    
                    	Source IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.extranet_path_count = None
                        self.group = Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group()
                        self.group.parent = self
                        self.group_address = None
                        self.is_bgp_added = None
                        self.next_hop = Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop()
                        self.next_hop.parent = self
                        self.route_distinguisher = None
                        self.source = Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source()
                        self.source.parent = self
                        self.source_address = None


                    class Source(object):
                        """
                        Source address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs/Cisco-IOS-XR-ipv4-pim-oper:bgp-af/Cisco-IOS-XR-ipv4-pim-oper:source'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source']['meta_info']


                    class Group(object):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs/Cisco-IOS-XR-ipv4-pim-oper:bgp-af/Cisco-IOS-XR-ipv4-pim-oper:group'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group']['meta_info']


                    class NextHop(object):
                        """
                        Next hop address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs/Cisco-IOS-XR-ipv4-pim-oper:bgp-af/Cisco-IOS-XR-ipv4-pim-oper:next-hop'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs/Cisco-IOS-XR-ipv4-pim-oper:bgp-af'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.extranet_path_count is not None:
                            return True

                        if self.group is not None and self.group._has_data():
                            return True

                        if self.group_address is not None:
                            return True

                        if self.is_bgp_added is not None:
                            return True

                        if self.next_hop is not None and self.next_hop._has_data():
                            return True

                        if self.route_distinguisher is not None:
                            return True

                        if self.source is not None and self.source._has_data():
                            return True

                        if self.source_address is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bgp_af is not None:
                        for child_ref in self.bgp_af:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.BgpAfs']['meta_info']


            class AutoRp(object):
                """
                PIM Auto\-RP information
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:auto-rp'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.AutoRp']['meta_info']


            class TopologyInterfaceFlagRouteCounts(object):
                """
                Route count for topology with interface flag set
                
                .. attribute:: topology_interface_flag_route_count
                
                	Route count for topology with interface flag set
                	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.topology_interface_flag_route_count = YList()
                    self.topology_interface_flag_route_count.parent = self
                    self.topology_interface_flag_route_count.name = 'topology_interface_flag_route_count'


                class TopologyInterfaceFlagRouteCount(object):
                    """
                    Route count for topology with interface flag
                    set
                    
                    .. attribute:: interface_flag  <key>
                    
                    	Interface flag
                    	**type**\:   :py:class:`PimTopologyInterfaceFlagEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlagEnum>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_flag = None
                        self.active_group_ranges = None
                        self.group_address = Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self.group_ranges = None
                        self.groute_count = None
                        self.is_node_low_memory = None
                        self.sg_route_count = None
                        self.sgr_route_count = None


                    class GroupAddress(object):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_flag is None:
                            raise YPYModelError('Key property interface_flag is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-interface-flag-route-counts/Cisco-IOS-XR-ipv4-pim-oper:topology-interface-flag-route-count[Cisco-IOS-XR-ipv4-pim-oper:interface-flag = ' + str(self.interface_flag) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_flag is not None:
                            return True

                        if self.active_group_ranges is not None:
                            return True

                        if self.group_address is not None and self.group_address._has_data():
                            return True

                        if self.group_ranges is not None:
                            return True

                        if self.groute_count is not None:
                            return True

                        if self.is_node_low_memory is not None:
                            return True

                        if self.sg_route_count is not None:
                            return True

                        if self.sgr_route_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-interface-flag-route-counts'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.topology_interface_flag_route_count is not None:
                        for child_ref in self.topology_interface_flag_route_count:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts']['meta_info']


            class GroupMapSources(object):
                """
                PIM group\-mapping with source information
                
                .. attribute:: group_map_source
                
                	PIM Group Mapping Entry with source information
                	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.group_map_source = YList()
                    self.group_map_source.parent = self
                    self.group_map_source.name = 'group_map_source'


                class GroupMapSource(object):
                    """
                    PIM Group Mapping Entry with source information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                    
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: priority
                    
                    	RP Priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocolEnum>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation>`
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.client = None
                        self.expires = None
                        self.group_map_information = Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self.holdtime = None
                        self.prefix = None
                        self.prefix_length = None
                        self.priority = None
                        self.protocol = None
                        self.rp_address = None
                        self.source_of_information = Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self.uptime = None


                    class SourceOfInformation(object):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-source/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation']['meta_info']


                    class GroupMapInformation(object):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.group_count = None
                            self.is_override = None
                            self.is_used = None
                            self.mrib_active = None
                            self.prefix = Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.priority = None
                            self.protocol = None
                            self.rp_address = Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self


                        class Prefix(object):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-source/Cisco-IOS-XR-ipv4-pim-oper:group-map-information/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix']['meta_info']


                        class RpAddress(object):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-source/Cisco-IOS-XR-ipv4-pim-oper:group-map-information/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-source/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.group_count is not None:
                                return True

                            if self.is_override is not None:
                                return True

                            if self.is_used is not None:
                                return True

                            if self.mrib_active is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-source'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.client is not None:
                            return True

                        if self.expires is not None:
                            return True

                        if self.group_map_information is not None and self.group_map_information._has_data():
                            return True

                        if self.holdtime is not None:
                            return True

                        if self.prefix is not None:
                            return True

                        if self.prefix_length is not None:
                            return True

                        if self.priority is not None:
                            return True

                        if self.protocol is not None:
                            return True

                        if self.rp_address is not None:
                            return True

                        if self.source_of_information is not None and self.source_of_information._has_data():
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.group_map_source is not None:
                        for child_ref in self.group_map_source:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapSources']['meta_info']


            class TrafficCounters(object):
                """
                PIM message traffic counters
                
                .. attribute:: boundary_acl_rx_drop
                
                	Inc. JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: boundary_acl_tx_drop
                
                	Out JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_error
                
                	Checksum errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: elapsed_time
                
                	Running time for counters in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: format_error
                
                	Malformed packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert
                
                	Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert_batched
                
                	Batched Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_bsr_message
                
                	Input BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_candidate_rp_advertisement
                
                	Input Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_data_register
                
                	Data Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_df_election
                
                	DF Election packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_ecmp_redirect
                
                	Input Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_hello
                
                	Hello packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_jp
                
                	Join Prune packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb_error
                
                	No IDB for intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_pim_error
                
                	PIM Disabled on intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_error
                
                	No VRF for idb error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_null_register
                
                	Null Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim_version_error
                
                	Invalid PIM version error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_register_stop
                
                	Register Stop packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: inputs
                
                	Packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_destination_packets
                
                	Control Packets with Invalid Destination
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_join_prunes
                
                	PIM invalid Join/Prunes received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_registers
                
                	PIM invalid registers received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_local_source_address
                
                	Data MDT Join msgs dropped due to local source addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_idb
                
                	Data MDT Join msgs dropped due to idb missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_vrf
                
                	Data MDT Join msgs dropped due to vrf missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_null_local_address
                
                	Data MDT Join msgs dropped due to null local addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_bad_type
                
                	Data MDT TLV bad type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_received
                
                	Data MDT Join Msgs received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_sent
                
                	Data MDT Join Msgs sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_joins_drop_multiple_encapsulation
                
                	MDT Join msgs dropped due to multiple Encap limitation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_send_queue_full
                
                	Packets dropped since mdt send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_socket_error
                
                	MDT Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_invalid_lsm_identifier
                
                	 Invalid LSM ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_mdt_socket_connection
                
                	Packets dropped since no mdt socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_source_address
                
                	Packets dropped since no source address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: non_supported_packets
                
                	PIM non supported pckets
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert
                
                	Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert_batched
                
                	Batched Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_bsr_message
                
                	Output BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_candidate_rp_advertisement
                
                	Output Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_data_register
                
                	Data Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_df_election
                
                	DF Election packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_ecmp_redirect
                
                	Output Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello
                
                	Hello packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello_bytes
                
                	Output Hello Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_join_group
                
                	Output Join Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_join_prune_bytes
                
                	Output JP Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_jp
                
                	Join Prune packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_loop_error
                
                	Output on loopback error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_null_register
                
                	Null Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_prune_group
                
                	Output Prune Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_register_stop
                
                	Register Stop packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: outputs
                
                	Packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_dequeued
                
                	Packets Dequeued per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_enqueued
                
                	Packets Enqueued per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_packman_error
                
                	Packets Dropped due to Pakman Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue
                
                	Packet queue state and statistics
                	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue>`
                
                .. attribute:: packet_queue_last_clear
                
                	Time in seconds since the last clear of all packet queues stats
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: packet_queue_length
                
                	Packet Queue Length per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue_size
                
                	Packet Queue Size per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_read_socket_error
                
                	Packet Read Socket Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_tail_drop
                
                	Packet Tail Drop per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_standby
                
                	Packets Dropped due to Standby Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pakman_error
                
                	Pakman packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_queue_full
                
                	Packets dropped since send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_error
                
                	Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_packets_error
                
                	Packets received in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: truncated_pim_packets
                
                	Packets dropped due to truncated Joins or Prunes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.boundary_acl_rx_drop = None
                    self.boundary_acl_tx_drop = None
                    self.checksum_error = None
                    self.elapsed_time = None
                    self.format_error = None
                    self.input_assert = None
                    self.input_assert_batched = None
                    self.input_bsr_message = None
                    self.input_candidate_rp_advertisement = None
                    self.input_data_register = None
                    self.input_df_election = None
                    self.input_ecmp_redirect = None
                    self.input_hello = None
                    self.input_jp = None
                    self.input_no_idb_error = None
                    self.input_no_pim_error = None
                    self.input_no_vrf_error = None
                    self.input_null_register = None
                    self.input_pim_version_error = None
                    self.input_register_stop = None
                    self.inputs = None
                    self.invalid_destination_packets = None
                    self.invalid_join_prunes = None
                    self.invalid_registers = None
                    self.mdt_drop_local_source_address = None
                    self.mdt_drop_no_idb = None
                    self.mdt_drop_no_vrf = None
                    self.mdt_drop_null_local_address = None
                    self.mdt_join_bad_type = None
                    self.mdt_join_tlv_received = None
                    self.mdt_join_tlv_sent = None
                    self.mdt_joins_drop_multiple_encapsulation = None
                    self.mdt_send_queue_full = None
                    self.mdt_socket_error = None
                    self.mldp_mdt_invalid_lsm_identifier = None
                    self.no_mdt_socket_connection = None
                    self.no_socket_connection = None
                    self.no_source_address = None
                    self.non_supported_packets = None
                    self.output_assert = None
                    self.output_assert_batched = None
                    self.output_bsr_message = None
                    self.output_candidate_rp_advertisement = None
                    self.output_data_register = None
                    self.output_df_election = None
                    self.output_ecmp_redirect = None
                    self.output_hello = None
                    self.output_hello_bytes = None
                    self.output_join_group = None
                    self.output_join_prune_bytes = None
                    self.output_jp = None
                    self.output_loop_error = None
                    self.output_null_register = None
                    self.output_prune_group = None
                    self.output_register_stop = None
                    self.outputs = None
                    self.packet_dequeued = YLeafList()
                    self.packet_dequeued.parent = self
                    self.packet_dequeued.name = 'packet_dequeued'
                    self.packet_enqueued = YLeafList()
                    self.packet_enqueued.parent = self
                    self.packet_enqueued.name = 'packet_enqueued'
                    self.packet_packman_error = None
                    self.packet_queue = YList()
                    self.packet_queue.parent = self
                    self.packet_queue.name = 'packet_queue'
                    self.packet_queue_last_clear = None
                    self.packet_queue_length = YLeafList()
                    self.packet_queue_length.parent = self
                    self.packet_queue_length.name = 'packet_queue_length'
                    self.packet_queue_size = YLeafList()
                    self.packet_queue_size.parent = self
                    self.packet_queue_size.name = 'packet_queue_size'
                    self.packet_read_socket_error = None
                    self.packet_tail_drop = YLeafList()
                    self.packet_tail_drop.parent = self
                    self.packet_tail_drop.name = 'packet_tail_drop'
                    self.packets_standby = None
                    self.pakman_error = None
                    self.send_queue_full = None
                    self.socket_error = None
                    self.standby_packets_error = None
                    self.truncated_pim_packets = None


                class PacketQueue(object):
                    """
                    Packet queue state and statistics
                    
                    .. attribute:: packet_queue_priority
                    
                    	Priority of this packet queue
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_state
                    
                    	State of the queue
                    	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState>`
                    
                    .. attribute:: packet_queue_stats
                    
                    	Statistics about the queue
                    	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.packet_queue_priority = None
                        self.packet_queue_state = Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState()
                        self.packet_queue_state.parent = self
                        self.packet_queue_stats = Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats()
                        self.packet_queue_stats.parent = self


                    class PacketQueueState(object):
                        """
                        State of the queue
                        
                        .. attribute:: max_queue_size
                        
                        	Maximum size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_bytes
                        
                        	Size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_packets
                        
                        	Size of queue in number of packets
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.max_queue_size = None
                            self.queue_size_bytes = None
                            self.queue_size_packets = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:traffic-counters/Cisco-IOS-XR-ipv4-pim-oper:packet-queue/Cisco-IOS-XR-ipv4-pim-oper:packet-queue-state'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.max_queue_size is not None:
                                return True

                            if self.queue_size_bytes is not None:
                                return True

                            if self.queue_size_packets is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState']['meta_info']


                    class PacketQueueStats(object):
                        """
                        Statistics about the queue
                        
                        .. attribute:: dequeued_packets
                        
                        	Total number of packets dequeued from this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: enqueued_packets
                        
                        	Total number of packets enqueued to this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: high_water_mark_bytes
                        
                        	Highest number of bytes enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: high_water_mark_packets
                        
                        	Highest number of packets enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tail_drops
                        
                        	Number packets dropped from this queue due to max size
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dequeued_packets = None
                            self.enqueued_packets = None
                            self.high_water_mark_bytes = None
                            self.high_water_mark_packets = None
                            self.tail_drops = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:traffic-counters/Cisco-IOS-XR-ipv4-pim-oper:packet-queue/Cisco-IOS-XR-ipv4-pim-oper:packet-queue-stats'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dequeued_packets is not None:
                                return True

                            if self.enqueued_packets is not None:
                                return True

                            if self.high_water_mark_bytes is not None:
                                return True

                            if self.high_water_mark_packets is not None:
                                return True

                            if self.tail_drops is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:traffic-counters/Cisco-IOS-XR-ipv4-pim-oper:packet-queue'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.packet_queue_priority is not None:
                            return True

                        if self.packet_queue_state is not None and self.packet_queue_state._has_data():
                            return True

                        if self.packet_queue_stats is not None and self.packet_queue_stats._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:traffic-counters'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.boundary_acl_rx_drop is not None:
                        return True

                    if self.boundary_acl_tx_drop is not None:
                        return True

                    if self.checksum_error is not None:
                        return True

                    if self.elapsed_time is not None:
                        return True

                    if self.format_error is not None:
                        return True

                    if self.input_assert is not None:
                        return True

                    if self.input_assert_batched is not None:
                        return True

                    if self.input_bsr_message is not None:
                        return True

                    if self.input_candidate_rp_advertisement is not None:
                        return True

                    if self.input_data_register is not None:
                        return True

                    if self.input_df_election is not None:
                        return True

                    if self.input_ecmp_redirect is not None:
                        return True

                    if self.input_hello is not None:
                        return True

                    if self.input_jp is not None:
                        return True

                    if self.input_no_idb_error is not None:
                        return True

                    if self.input_no_pim_error is not None:
                        return True

                    if self.input_no_vrf_error is not None:
                        return True

                    if self.input_null_register is not None:
                        return True

                    if self.input_pim_version_error is not None:
                        return True

                    if self.input_register_stop is not None:
                        return True

                    if self.inputs is not None:
                        return True

                    if self.invalid_destination_packets is not None:
                        return True

                    if self.invalid_join_prunes is not None:
                        return True

                    if self.invalid_registers is not None:
                        return True

                    if self.mdt_drop_local_source_address is not None:
                        return True

                    if self.mdt_drop_no_idb is not None:
                        return True

                    if self.mdt_drop_no_vrf is not None:
                        return True

                    if self.mdt_drop_null_local_address is not None:
                        return True

                    if self.mdt_join_bad_type is not None:
                        return True

                    if self.mdt_join_tlv_received is not None:
                        return True

                    if self.mdt_join_tlv_sent is not None:
                        return True

                    if self.mdt_joins_drop_multiple_encapsulation is not None:
                        return True

                    if self.mdt_send_queue_full is not None:
                        return True

                    if self.mdt_socket_error is not None:
                        return True

                    if self.mldp_mdt_invalid_lsm_identifier is not None:
                        return True

                    if self.no_mdt_socket_connection is not None:
                        return True

                    if self.no_socket_connection is not None:
                        return True

                    if self.no_source_address is not None:
                        return True

                    if self.non_supported_packets is not None:
                        return True

                    if self.output_assert is not None:
                        return True

                    if self.output_assert_batched is not None:
                        return True

                    if self.output_bsr_message is not None:
                        return True

                    if self.output_candidate_rp_advertisement is not None:
                        return True

                    if self.output_data_register is not None:
                        return True

                    if self.output_df_election is not None:
                        return True

                    if self.output_ecmp_redirect is not None:
                        return True

                    if self.output_hello is not None:
                        return True

                    if self.output_hello_bytes is not None:
                        return True

                    if self.output_join_group is not None:
                        return True

                    if self.output_join_prune_bytes is not None:
                        return True

                    if self.output_jp is not None:
                        return True

                    if self.output_loop_error is not None:
                        return True

                    if self.output_null_register is not None:
                        return True

                    if self.output_prune_group is not None:
                        return True

                    if self.output_register_stop is not None:
                        return True

                    if self.outputs is not None:
                        return True

                    if self.packet_dequeued is not None:
                        for child in self.packet_dequeued:
                            if child is not None:
                                return True

                    if self.packet_enqueued is not None:
                        for child in self.packet_enqueued:
                            if child is not None:
                                return True

                    if self.packet_packman_error is not None:
                        return True

                    if self.packet_queue is not None:
                        for child_ref in self.packet_queue:
                            if child_ref._has_data():
                                return True

                    if self.packet_queue_last_clear is not None:
                        return True

                    if self.packet_queue_length is not None:
                        for child in self.packet_queue_length:
                            if child is not None:
                                return True

                    if self.packet_queue_size is not None:
                        for child in self.packet_queue_size:
                            if child is not None:
                                return True

                    if self.packet_read_socket_error is not None:
                        return True

                    if self.packet_tail_drop is not None:
                        for child in self.packet_tail_drop:
                            if child is not None:
                                return True

                    if self.packets_standby is not None:
                        return True

                    if self.pakman_error is not None:
                        return True

                    if self.send_queue_full is not None:
                        return True

                    if self.socket_error is not None:
                        return True

                    if self.standby_packets_error is not None:
                        return True

                    if self.truncated_pim_packets is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.TrafficCounters']['meta_info']


            class GroupMapRpfs(object):
                """
                PIM group mapping information
                
                .. attribute:: group_map_rpf
                
                	PIM group mapping entry
                	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.group_map_rpf = YList()
                    self.group_map_rpf.parent = self
                    self.group_map_rpf.name = 'group_map_rpf'


                class GroupMapRpf(object):
                    """
                    PIM group mapping entry
                    
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\:  bool
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocolEnum>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_priority
                    
                    	RP priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.are_we_rp = None
                        self.client = None
                        self.group_map_information = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self.prefix = None
                        self.prefix_length = None
                        self.protocol = None
                        self.rp_address = None
                        self.rp_priority = None
                        self.rpf_interface_name = None
                        self.rpf_neighbor = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self.rpf_vrf_name = None


                    class RpfNeighbor(object):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor']['meta_info']


                    class GroupMapInformation(object):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.group_count = None
                            self.is_override = None
                            self.is_used = None
                            self.mrib_active = None
                            self.prefix = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.priority = None
                            self.protocol = None
                            self.rp_address = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self


                        class Prefix(object):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf/Cisco-IOS-XR-ipv4-pim-oper:group-map-information/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix']['meta_info']


                        class RpAddress(object):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf/Cisco-IOS-XR-ipv4-pim-oper:group-map-information/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.group_count is not None:
                                return True

                            if self.is_override is not None:
                                return True

                            if self.is_used is not None:
                                return True

                            if self.mrib_active is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.are_we_rp is not None:
                            return True

                        if self.client is not None:
                            return True

                        if self.group_map_information is not None and self.group_map_information._has_data():
                            return True

                        if self.prefix is not None:
                            return True

                        if self.prefix_length is not None:
                            return True

                        if self.protocol is not None:
                            return True

                        if self.rp_address is not None:
                            return True

                        if self.rp_priority is not None:
                            return True

                        if self.rpf_interface_name is not None:
                            return True

                        if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                            return True

                        if self.rpf_vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.group_map_rpf is not None:
                        for child_ref in self.group_map_rpf:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapRpfs']['meta_info']


            class Summary(object):
                """
                PIM summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bsr_candidate_rp_set_count = None
                    self.bsr_candidate_rp_set_limit = None
                    self.bsr_candidate_rp_set_threshold = None
                    self.bsr_range_threshold = None
                    self.bsr_ranges_count = None
                    self.bsr_ranges_limit = None
                    self.global_auto_rp_ranges_limit = None
                    self.global_bsr_candidate_rp_set_count = None
                    self.global_bsr_candidate_rp_set_limit = None
                    self.global_bsr_candidate_rp_set_threshold = None
                    self.global_bsr_ranges_count = None
                    self.global_bsr_ranges_limit = None
                    self.global_bsr_ranges_threshold = None
                    self.global_register_limit = None
                    self.is_bsr_ranges_threshold_reached = None
                    self.is_global_auto_rp_ranges_limit_reached = None
                    self.is_global_bsr_ranges_limit_reached = None
                    self.is_global_register_limit_reached = None
                    self.is_global_route_limit_reached = None
                    self.is_global_rxi_limit_reached = None
                    self.is_maximum_enforcement_disabled = None
                    self.is_node_low_memory = None
                    self.is_ranges_limit_reached = None
                    self.is_route_limit_reached = None
                    self.ranges_count = None
                    self.ranges_limit = None
                    self.ranges_threshold = None
                    self.register_count = None
                    self.register_limit = None
                    self.register_limit_reached = None
                    self.register_threshold = None
                    self.route_count = None
                    self.route_limit = None
                    self.route_low_water_mark = None
                    self.route_threshold = None
                    self.rxi_limit_reached = None
                    self.rxi_low_water_mark = None
                    self.topology_interface_state_count = None
                    self.topology_interface_state_limit = None
                    self.topology_interface_state_threshold = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bsr_candidate_rp_set_count is not None:
                        return True

                    if self.bsr_candidate_rp_set_limit is not None:
                        return True

                    if self.bsr_candidate_rp_set_threshold is not None:
                        return True

                    if self.bsr_range_threshold is not None:
                        return True

                    if self.bsr_ranges_count is not None:
                        return True

                    if self.bsr_ranges_limit is not None:
                        return True

                    if self.global_auto_rp_ranges_limit is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_count is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_limit is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_threshold is not None:
                        return True

                    if self.global_bsr_ranges_count is not None:
                        return True

                    if self.global_bsr_ranges_limit is not None:
                        return True

                    if self.global_bsr_ranges_threshold is not None:
                        return True

                    if self.global_register_limit is not None:
                        return True

                    if self.is_bsr_ranges_threshold_reached is not None:
                        return True

                    if self.is_global_auto_rp_ranges_limit_reached is not None:
                        return True

                    if self.is_global_bsr_ranges_limit_reached is not None:
                        return True

                    if self.is_global_register_limit_reached is not None:
                        return True

                    if self.is_global_route_limit_reached is not None:
                        return True

                    if self.is_global_rxi_limit_reached is not None:
                        return True

                    if self.is_maximum_enforcement_disabled is not None:
                        return True

                    if self.is_node_low_memory is not None:
                        return True

                    if self.is_ranges_limit_reached is not None:
                        return True

                    if self.is_route_limit_reached is not None:
                        return True

                    if self.ranges_count is not None:
                        return True

                    if self.ranges_limit is not None:
                        return True

                    if self.ranges_threshold is not None:
                        return True

                    if self.register_count is not None:
                        return True

                    if self.register_limit is not None:
                        return True

                    if self.register_limit_reached is not None:
                        return True

                    if self.register_threshold is not None:
                        return True

                    if self.route_count is not None:
                        return True

                    if self.route_limit is not None:
                        return True

                    if self.route_low_water_mark is not None:
                        return True

                    if self.route_threshold is not None:
                        return True

                    if self.rxi_limit_reached is not None:
                        return True

                    if self.rxi_low_water_mark is not None:
                        return True

                    if self.topology_interface_state_count is not None:
                        return True

                    if self.topology_interface_state_limit is not None:
                        return True

                    if self.topology_interface_state_threshold is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Summary']['meta_info']


            class Gre(object):
                """
                GRE information
                
                .. attribute:: gre_hashes
                
                	GRE hash
                	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreHashes>`
                
                .. attribute:: gre_next_hops
                
                	GRE destination neighbor table
                	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.gre_hashes = Ipv6Pim.Standby.DefaultContext.Gre.GreHashes()
                    self.gre_hashes.parent = self
                    self.gre_next_hops = Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops()
                    self.gre_next_hops.parent = self


                class GreHashes(object):
                    """
                    GRE hash
                    
                    .. attribute:: gre_hash
                    
                    	PIM GRE Hashed Underlying Interface
                    	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreHashes.GreHash>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.gre_hash = YList()
                        self.gre_hash.parent = self
                        self.gre_hash.name = 'gre_hash'


                    class GreHash(object):
                        """
                        PIM GRE Hashed Underlying Interface
                        
                        .. attribute:: destination_address  <key>
                        
                        	Destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: ifname  <key>
                        
                        	GRE Tunnel Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: source_address  <key>
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: next_hop_interface
                        
                        	Next hop neighbor interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.destination_address = None
                            self.ifname = None
                            self.source_address = None
                            self.next_hop_interface = None

                        @property
                        def _common_path(self):
                            if self.destination_address is None:
                                raise YPYModelError('Key property destination_address is None')
                            if self.ifname is None:
                                raise YPYModelError('Key property ifname is None')
                            if self.source_address is None:
                                raise YPYModelError('Key property source_address is None')

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:gre/Cisco-IOS-XR-ipv4-pim-oper:gre-hashes/Cisco-IOS-XR-ipv4-pim-oper:gre-hash[Cisco-IOS-XR-ipv4-pim-oper:destination-address = ' + str(self.destination_address) + '][Cisco-IOS-XR-ipv4-pim-oper:ifname = ' + str(self.ifname) + '][Cisco-IOS-XR-ipv4-pim-oper:source-address = ' + str(self.source_address) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.destination_address is not None:
                                return True

                            if self.ifname is not None:
                                return True

                            if self.source_address is not None:
                                return True

                            if self.next_hop_interface is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Gre.GreHashes.GreHash']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:gre/Cisco-IOS-XR-ipv4-pim-oper:gre-hashes'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.gre_hash is not None:
                            for child_ref in self.gre_hash:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Gre.GreHashes']['meta_info']


                class GreNextHops(object):
                    """
                    GRE destination neighbor table
                    
                    .. attribute:: gre_next_hop
                    
                    	PIM GRE address next\-hop information
                    	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.gre_next_hop = YList()
                        self.gre_next_hop.parent = self
                        self.gre_next_hop.name = 'gre_next_hop'


                    class GreNextHop(object):
                        """
                        PIM GRE address next\-hop information
                        
                        .. attribute:: destination_address  <key>
                        
                        	GRE destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: gre_path
                        
                        	GRE Paths list
                        	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath>`
                        
                        .. attribute:: is_connected
                        
                        	Are we connected ?
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: registered_address
                        
                        	Address registered
                        	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.destination_address = None
                            self.gre_path = YList()
                            self.gre_path.parent = self
                            self.gre_path.name = 'gre_path'
                            self.is_connected = None
                            self.metric = None
                            self.metric_preference = None
                            self.registered_address = Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                            self.registered_address.parent = self


                        class RegisteredAddress(object):
                            """
                            Address registered
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:registered-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress']['meta_info']


                        class GrePath(object):
                            """
                            GRE Paths list
                            
                            .. attribute:: extranet_vrf_name
                            
                            	Extranet VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: gre_interface_name
                            
                            	GRE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: gre_neighbor
                            
                            	GRE neighbor
                            	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                            
                            .. attribute:: gre_next_hop
                            
                            	GRE nexthop
                            	**type**\:   :py:class:`GreNextHop_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_>`
                            
                            .. attribute:: is_connector_attribute_present
                            
                            	Connector attribute present
                            	**type**\:  bool
                            
                            .. attribute:: is_gre_interface_disabled
                            
                            	Is the gre interface disabled ?
                            	**type**\:  bool
                            
                            .. attribute:: is_via_lsm
                            
                            	Via LSM
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.extranet_vrf_name = None
                                self.gre_interface_name = None
                                self.gre_neighbor = Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                self.gre_neighbor.parent = self
                                self.gre_next_hop = Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_()
                                self.gre_next_hop.parent = self
                                self.is_connector_attribute_present = None
                                self.is_gre_interface_disabled = None
                                self.is_via_lsm = None


                            class GreNeighbor(object):
                                """
                                GRE neighbor
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-neighbor'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor']['meta_info']


                            class GreNextHop_(object):
                                """
                                GRE nexthop
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-path'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.extranet_vrf_name is not None:
                                    return True

                                if self.gre_interface_name is not None:
                                    return True

                                if self.gre_neighbor is not None and self.gre_neighbor._has_data():
                                    return True

                                if self.gre_next_hop is not None and self.gre_next_hop._has_data():
                                    return True

                                if self.is_connector_attribute_present is not None:
                                    return True

                                if self.is_gre_interface_disabled is not None:
                                    return True

                                if self.is_via_lsm is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath']['meta_info']

                        @property
                        def _common_path(self):
                            if self.destination_address is None:
                                raise YPYModelError('Key property destination_address is None')

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:gre/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hops/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hop[Cisco-IOS-XR-ipv4-pim-oper:destination-address = ' + str(self.destination_address) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.destination_address is not None:
                                return True

                            if self.gre_path is not None:
                                for child_ref in self.gre_path:
                                    if child_ref._has_data():
                                        return True

                            if self.is_connected is not None:
                                return True

                            if self.metric is not None:
                                return True

                            if self.metric_preference is not None:
                                return True

                            if self.registered_address is not None and self.registered_address._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:gre/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hops'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.gre_next_hop is not None:
                            for child_ref in self.gre_next_hop:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:gre'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.gre_hashes is not None and self.gre_hashes._has_data():
                        return True

                    if self.gre_next_hops is not None and self.gre_next_hops._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Gre']['meta_info']


            class BidirDfWinners(object):
                """
                Bidirectional PIM DF election winner table
                
                .. attribute:: bidir_df_winner
                
                	Bidirectional PIM DF election table entry
                	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bidir_df_winner = YList()
                    self.bidir_df_winner.parent = self
                    self.bidir_df_winner.name = 'bidir_df_winner'


                class BidirDfWinner(object):
                    """
                    Bidirectional PIM DF election table entry
                    
                    .. attribute:: are_we_df
                    
                    	Are we DF
                    	**type**\:  bool
                    
                    .. attribute:: df_winner
                    
                    	DF Winner
                    	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner>`
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_preference
                    
                    	Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                    
                    .. attribute:: rp_lan
                    
                    	Is this the RP LAN
                    	**type**\:  bool
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.are_we_df = None
                        self.df_winner = Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner()
                        self.df_winner.parent = self
                        self.interface_name = None
                        self.metric = None
                        self.metric_preference = None
                        self.pim_interface_name = None
                        self.rp_address = None
                        self.rp_address_xr = Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self.rp_lan = None
                        self.uptime = None


                    class RpAddressXr(object):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winners/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winner/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr']['meta_info']


                    class DfWinner(object):
                        """
                        DF Winner
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winners/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winner/Cisco-IOS-XR-ipv4-pim-oper:df-winner'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winners/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winner'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.are_we_df is not None:
                            return True

                        if self.df_winner is not None and self.df_winner._has_data():
                            return True

                        if self.interface_name is not None:
                            return True

                        if self.metric is not None:
                            return True

                        if self.metric_preference is not None:
                            return True

                        if self.pim_interface_name is not None:
                            return True

                        if self.rp_address is not None:
                            return True

                        if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                            return True

                        if self.rp_lan is not None:
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winners'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bidir_df_winner is not None:
                        for child_ref in self.bidir_df_winner:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.BidirDfWinners']['meta_info']


            class TableContexts(object):
                """
                PIM table context list
                
                .. attribute:: table_context
                
                	PIM table context information
                	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TableContexts.TableContext>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.table_context = YList()
                    self.table_context.parent = self
                    self.table_context.name = 'table_context'


                class TableContext(object):
                    """
                    PIM table context information
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: saf_name
                    
                    	SAF name
                    	**type**\:   :py:class:`PimSafiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafiEnum>`
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: topology_name
                    
                    	Topology name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.afi = None
                        self.is_active = None
                        self.is_ital_registration_done = None
                        self.is_rib_convergence = None
                        self.is_rib_convergence_received = None
                        self.is_rib_registration_done = None
                        self.rpf_registrations = None
                        self.saf_name = None
                        self.safi = None
                        self.table_id = None
                        self.table_name = None
                        self.topology_name = None
                        self.vrf_id = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:table-contexts/Cisco-IOS-XR-ipv4-pim-oper:table-context'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.afi is not None:
                            return True

                        if self.is_active is not None:
                            return True

                        if self.is_ital_registration_done is not None:
                            return True

                        if self.is_rib_convergence is not None:
                            return True

                        if self.is_rib_convergence_received is not None:
                            return True

                        if self.is_rib_registration_done is not None:
                            return True

                        if self.rpf_registrations is not None:
                            return True

                        if self.saf_name is not None:
                            return True

                        if self.safi is not None:
                            return True

                        if self.table_id is not None:
                            return True

                        if self.table_name is not None:
                            return True

                        if self.topology_name is not None:
                            return True

                        if self.vrf_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.TableContexts.TableContext']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:table-contexts'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.table_context is not None:
                        for child_ref in self.table_context:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.TableContexts']['meta_info']


            class NeighborSummaries(object):
                """
                PIM neighbor summary table
                
                .. attribute:: neighbor_summary
                
                	PIM neighbor summary information
                	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.neighbor_summary = YList()
                    self.neighbor_summary.parent = self
                    self.neighbor_summary.name = 'neighbor_summary'


                class NeighborSummary(object):
                    """
                    PIM neighbor summary information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: number_of_external_neighbors
                    
                    	Number of external neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: number_of_neighbors
                    
                    	Number of neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.number_of_external_neighbors = None
                        self.number_of_neighbors = None

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbor-summaries/Cisco-IOS-XR-ipv4-pim-oper:neighbor-summary[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.number_of_external_neighbors is not None:
                            return True

                        if self.number_of_neighbors is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbor-summaries'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.neighbor_summary is not None:
                        for child_ref in self.neighbor_summary:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.NeighborSummaries']['meta_info']


            class Context(object):
                """
                PIM context information
                
                .. attribute:: active_table_count
                
                	Number of active Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: allow_rp_configured
                
                	Allow RP Configured
                	**type**\:  bool
                
                .. attribute:: allow_rp_group_list
                
                	Allow RP Group\-List ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: allow_rp_rp_list
                
                	Allow RP RP\-list ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: anycast_rp_configured
                
                	Anycast\-RP config
                	**type**\:  bool
                
                .. attribute:: anycast_rp_policy_name
                
                	Anycast\-RP Policy Name
                	**type**\:  str
                
                .. attribute:: anycast_rp_range
                
                	Anycast\-RP Ranges
                	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange>`
                
                .. attribute:: bgp_auto_discovery_configured
                
                	BGP Auto\-Discovery configured
                	**type**\:  bool
                
                .. attribute:: bgp_auto_discovery_type
                
                	BGP Auto Discovery Type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_i_pmsi_added
                
                	BGP I\-PMSI Added
                	**type**\:  bool
                
                .. attribute:: bgp_remote_address
                
                	BGP remote interface address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: bgp_remote_interface
                
                	BGP remote interface handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: bgp_remote_interface_name
                
                	BGP remote interface name
                	**type**\:  str
                
                .. attribute:: bgp_remote_on
                
                	BGP remote interface status
                	**type**\:  bool
                
                .. attribute:: bgp_remote_state
                
                	BGP remote interface state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_source_active_announce
                
                	Send BGP Source\-Active Announcements
                	**type**\:  bool
                
                .. attribute:: export_route_target
                
                	Export Route Targets
                	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.ExportRouteTarget>`
                
                .. attribute:: gin_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: gin_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: gin_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: import_route_target
                
                	Import Route Targets
                	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.ImportRouteTarget>`
                
                .. attribute:: in_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: in_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: in_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_signaling_local_enabled
                
                	Inband signaling Local enabled
                	**type**\:  bool
                
                .. attribute:: in_band_signaling_remote_enabled
                
                	Inband signaling Remote enabled
                	**type**\:  bool
                
                .. attribute:: inter_autonomous_system_enabled
                
                	Inter\-AS Enabled
                	**type**\:  bool
                
                .. attribute:: ir_maximum_mdt_aggregation
                
                	IR MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_announce_interval
                
                	IR Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_switchover_interval
                
                	IR Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_interface
                
                	IRMDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: ir_mdt_mtu
                
                	IRMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_name
                
                	IR MDT Name
                	**type**\:  str
                
                .. attribute:: ir_mdt_rpf_identifier
                
                	IR RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_tail_label
                
                	IR Tail Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_active
                
                	Active
                	**type**\:  bool
                
                .. attribute:: is_active_ital
                
                	Active ITAL
                	**type**\:  bool
                
                .. attribute:: is_all_interface_disable_operation
                
                	PIM all interface disable operation
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_enabled
                
                	Auto RP Listen Enabled
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_sock_add
                
                	Auto RP listen sock add
                	**type**\:  bool
                
                .. attribute:: is_create_gin_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_in_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_ir_mdt_interface
                
                	Create IR MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mdt_interface
                
                	Create MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mldp_mdt_interface
                
                	Create MLDP MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_rsvp_te_mdt_interface
                
                	Create RSVP\-TE MDT interface
                	**type**\:  bool
                
                .. attribute:: is_default_granges
                
                	Default granges
                	**type**\:  bool
                
                .. attribute:: is_gin_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_in_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_ir_mdt_owner
                
                	IR MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_add_required
                
                	VRF LPTS filter required on Socket
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_added
                
                	VRF LPTS filter added on Socket
                	**type**\:  bool
                
                .. attribute:: is_m_host_publish_pending
                
                	Publish pending for MHost Default interface
                	**type**\:  bool
                
                .. attribute:: is_mdt_owner
                
                	MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mldp_mdt_owner
                
                	MLDP MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mrib_register
                
                	MRIB Register
                	**type**\:  bool
                
                .. attribute:: is_multicast_rib_registration
                
                	Mcast RIB Registration
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converge_received
                
                	PIM NSF RIB converge received
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converged
                
                	PIM NSF RIB converged
                	**type**\:  bool
                
                .. attribute:: is_redistribution_reset
                
                	Pending redist reset
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_add_required
                
                	VRF LPTS filter required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_added
                
                	VRF LPTS filter added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_add_required
                
                	VRF required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_added
                
                	VRF added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_enabled
                
                	PIM RIB multiplath enabled
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_interface_hash
                
                	PIM RIB multipath interface hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_hash
                
                	PIM RIB multipath source based hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_next_hop_hash
                
                	PIM RIB multipath source\-nexthop hash
                	**type**\:  bool
                
                .. attribute:: is_routing_enabled
                
                	Routing Enabled
                	**type**\:  bool
                
                .. attribute:: is_rsvp_te_mdt_owner
                
                	RSVP\-TE MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_socket_add_required
                
                	VRF required on Socket
                	**type**\:  bool
                
                .. attribute:: is_socket_added
                
                	VRF added on Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_add_required
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_added
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind
                
                	VRF bound on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind_required
                
                	VRF bind required on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_unicast_rib_registration
                
                	Ucast RIB Registration
                	**type**\:  bool
                
                .. attribute:: maximum_mdt_aggregation
                
                	MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_announce_interval
                
                	Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_switchover_interval
                
                	Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_default_group
                
                	MDT Default group
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_gre_remote_rpf_identifier
                
                	GRE\-MDT Remote RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_gre_rpf_identifier
                
                	GRE\-MDT RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_interface
                
                	MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mdt_mtu
                
                	MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_neighbor_filter_name
                
                	MDT Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: mdt_partitioned_ir_control_identifier
                
                	Partitioned IR MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_partitioned_mdt_control_identifier
                
                	Partitioned MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mhost_default_interface_config
                
                	Configured Mhost Defint
                	**type**\:  str
                
                .. attribute:: mhost_interface
                
                	MHost handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mldp_auto_rp_announce_tree_added
                
                	MLDP Autorp Announce Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_auto_rp_discovery_tree_added
                
                	MLDP Autorp Discovery Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_bsr_control_tree_added
                
                	MLDP BSR Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_control_head_lsm_identifier
                
                	MLDP MVPN Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_local_label
                
                	Partitioned MDT Head local label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_lsm_identifier
                
                	MLDP Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_maximum_mdt_aggregation
                
                	MLDP MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_announce_interval
                
                	MLDP Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_switchover_interval
                
                	MLDP Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_interface
                
                	MLDP MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mldp_mdt_mtu
                
                	MLDP MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_name
                
                	MLDP MDT Name
                	**type**\:  str
                
                .. attribute:: mldp_mdt_remote_rpf_identifier
                
                	MLDP Remote RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_rpf_identifier
                
                	MLDP RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partioned_mp2m_ptree
                
                	MP2MP Partitioned MDT tree
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_head_lsm_identifier
                
                	Partitioned MDT Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partitioned_mdt_configured
                
                	MLDP Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_mdt_identifier
                
                	MLDP Partitioned MDT Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_head_lsm_identifier
                
                	MLDP Remote Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_partitioned_mdt_configured
                
                	MLDP Remote Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_root_address
                
                	MLDP Root addresses
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_root_count
                
                	MLDP Root count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: murib_id
                
                	MURIB ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: neighbor_filter_name
                
                	Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: non_default_vrf_count_on_socket
                
                	Count of non\-default vrfs on raw socket
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: organization_unique_identifier
                
                	OUI for VPN\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: p2mpte_li_drop
                
                	Route LI updates dropped for P2MP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: redistribution_reset_count
                
                	Redist reset count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_default_group
                
                	Remote Default Group
                	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.RemoteDefaultGroup>`
                
                .. attribute:: remote_table_id
                
                	Remote Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_distinguisher
                
                	RD value
                	**type**\:  str
                
                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                
                .. attribute:: rpf_default_table
                
                	RPF Default Table
                	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.RpfDefaultTable>`
                
                .. attribute:: rpf_id
                
                	RPF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rpf_policy_name
                
                	RPF topology selection route\-policy name
                	**type**\:  str
                
                .. attribute:: rsvp_te_maximum_mdt_aggregation
                
                	RSVP\-TE MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_announce_interval
                
                	RSVP\-TE Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_switchover_interval
                
                	RSVP\-TE Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_interface
                
                	RSVP\-TEMDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: rsvp_te_mdt_mtu
                
                	RSVP\-TEMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_name
                
                	RSVP\-TE MDT Name
                	**type**\:  str
                
                .. attribute:: rsvp_te_mdt_rpf_identifier
                
                	RSVP\-TE RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_static_p2mp_count
                
                	Number of Static P2MP\-TE MDT
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	PIM is using MuRIB
                	**type**\:  bool
                
                .. attribute:: sg_expiry_time
                
                	S,G Expiry Time Configured, in seconds
                	**type**\:  int
                
                	**range:** 0..65535
                
                	**units**\: second
                
                .. attribute:: sg_expiry_timer_configured
                
                	S,G Expiry Timer Configured
                	**type**\:  bool
                
                .. attribute:: sg_expiry_timer_sg_list
                
                	S,G expiry timer ACL name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: stale_rd_present
                
                	RD is stale
                	**type**\:  bool
                
                .. attribute:: suppress_pim_data_mdt_tlv
                
                	Suppress PIM Data\-MDT TLV Announcements
                	**type**\:  bool
                
                .. attribute:: suppress_shared_tree_join
                
                	Suppress Shared\-Tree Joins
                	**type**\:  bool
                
                .. attribute:: table_count
                
                	Number of configured Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: table_id
                
                	Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: umh
                
                	Join UMH Core\-Tree
                	**type**\:  bool
                
                .. attribute:: valid_rd_present
                
                	RD is valid
                	**type**\:  bool
                
                .. attribute:: vpn_index
                
                	VPN Index
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vrf_id
                
                	VRF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.active_table_count = None
                    self.allow_rp_configured = None
                    self.allow_rp_group_list = None
                    self.allow_rp_rp_list = None
                    self.anycast_rp_configured = None
                    self.anycast_rp_policy_name = None
                    self.anycast_rp_range = YList()
                    self.anycast_rp_range.parent = self
                    self.anycast_rp_range.name = 'anycast_rp_range'
                    self.bgp_auto_discovery_configured = None
                    self.bgp_auto_discovery_type = None
                    self.bgp_i_pmsi_added = None
                    self.bgp_remote_address = None
                    self.bgp_remote_interface = None
                    self.bgp_remote_interface_name = None
                    self.bgp_remote_on = None
                    self.bgp_remote_state = None
                    self.bgp_source_active_announce = None
                    self.export_route_target = YList()
                    self.export_route_target.parent = self
                    self.export_route_target.name = 'export_route_target'
                    self.gin_b_and_mdt_data_announce_interval = None
                    self.gin_b_and_mdt_data_switchover_interval = None
                    self.gin_b_and_mdt_interface = None
                    self.gin_b_and_mdt_mtu = None
                    self.gin_b_and_mdt_name = None
                    self.gin_b_and_mdt_rpf_identifier = None
                    self.gin_band_maximum_mdt_aggregation = None
                    self.import_route_target = YList()
                    self.import_route_target.parent = self
                    self.import_route_target.name = 'import_route_target'
                    self.in_b_and_mdt_data_announce_interval = None
                    self.in_b_and_mdt_data_switchover_interval = None
                    self.in_b_and_mdt_interface = None
                    self.in_b_and_mdt_mtu = None
                    self.in_b_and_mdt_name = None
                    self.in_b_and_mdt_rpf_identifier = None
                    self.in_band_maximum_mdt_aggregation = None
                    self.in_band_signaling_local_enabled = None
                    self.in_band_signaling_remote_enabled = None
                    self.inter_autonomous_system_enabled = None
                    self.ir_maximum_mdt_aggregation = None
                    self.ir_mdt_data_announce_interval = None
                    self.ir_mdt_data_switchover_interval = None
                    self.ir_mdt_interface = None
                    self.ir_mdt_mtu = None
                    self.ir_mdt_name = None
                    self.ir_mdt_rpf_identifier = None
                    self.ir_mdt_tail_label = None
                    self.is_active = None
                    self.is_active_ital = None
                    self.is_all_interface_disable_operation = None
                    self.is_auto_rp_listen_enabled = None
                    self.is_auto_rp_listen_sock_add = None
                    self.is_create_gin_b_and_mdt_interface = None
                    self.is_create_in_b_and_mdt_interface = None
                    self.is_create_ir_mdt_interface = None
                    self.is_create_mdt_interface = None
                    self.is_create_mldp_mdt_interface = None
                    self.is_create_rsvp_te_mdt_interface = None
                    self.is_default_granges = None
                    self.is_gin_b_and_mdt_owner = None
                    self.is_in_b_and_mdt_owner = None
                    self.is_ir_mdt_owner = None
                    self.is_lpts_socket_add_required = None
                    self.is_lpts_socket_added = None
                    self.is_m_host_publish_pending = None
                    self.is_mdt_owner = None
                    self.is_mldp_mdt_owner = None
                    self.is_mrib_register = None
                    self.is_multicast_rib_registration = None
                    self.is_pim_nsf_rib_converge_received = None
                    self.is_pim_nsf_rib_converged = None
                    self.is_redistribution_reset = None
                    self.is_register_injection_lpts_socket_add_required = None
                    self.is_register_injection_lpts_socket_added = None
                    self.is_register_injection_socket_add_required = None
                    self.is_register_injection_socket_added = None
                    self.is_rib_multipath_enabled = None
                    self.is_rib_multipath_interface_hash = None
                    self.is_rib_multipath_source_hash = None
                    self.is_rib_multipath_source_next_hop_hash = None
                    self.is_routing_enabled = None
                    self.is_rsvp_te_mdt_owner = None
                    self.is_socket_add_required = None
                    self.is_socket_added = None
                    self.is_udp_socket_add_required = None
                    self.is_udp_socket_added = None
                    self.is_udp_socket_bind = None
                    self.is_udp_socket_bind_required = None
                    self.is_unicast_rib_registration = None
                    self.maximum_mdt_aggregation = None
                    self.mdt_data_announce_interval = None
                    self.mdt_data_switchover_interval = None
                    self.mdt_default_group = None
                    self.mdt_gre_remote_rpf_identifier = None
                    self.mdt_gre_rpf_identifier = None
                    self.mdt_interface = None
                    self.mdt_mtu = None
                    self.mdt_neighbor_filter_name = None
                    self.mdt_partitioned_ir_control_identifier = None
                    self.mdt_partitioned_mdt_control_identifier = None
                    self.mhost_default_interface_config = None
                    self.mhost_interface = None
                    self.mldp_auto_rp_announce_tree_added = None
                    self.mldp_auto_rp_discovery_tree_added = None
                    self.mldp_bsr_control_tree_added = None
                    self.mldp_control_head_lsm_identifier = None
                    self.mldp_head_local_label = None
                    self.mldp_head_lsm_identifier = None
                    self.mldp_maximum_mdt_aggregation = None
                    self.mldp_mdt_data_announce_interval = None
                    self.mldp_mdt_data_switchover_interval = None
                    self.mldp_mdt_interface = None
                    self.mldp_mdt_mtu = None
                    self.mldp_mdt_name = None
                    self.mldp_mdt_remote_rpf_identifier = None
                    self.mldp_mdt_rpf_identifier = None
                    self.mldp_partioned_mp2m_ptree = None
                    self.mldp_partitioned_head_lsm_identifier = None
                    self.mldp_partitioned_mdt_configured = None
                    self.mldp_partitioned_mdt_identifier = None
                    self.mldp_remote_head_lsm_identifier = None
                    self.mldp_remote_partitioned_mdt_configured = None
                    self.mldp_root_address = YLeafList()
                    self.mldp_root_address.parent = self
                    self.mldp_root_address.name = 'mldp_root_address'
                    self.mldp_root_count = None
                    self.murib_id = None
                    self.neighbor_filter_name = None
                    self.non_default_vrf_count_on_socket = None
                    self.organization_unique_identifier = None
                    self.p2mpte_li_drop = None
                    self.redistribution_reset_count = None
                    self.remote_default_group = Ipv6Pim.Standby.DefaultContext.Context.RemoteDefaultGroup()
                    self.remote_default_group.parent = self
                    self.remote_table_id = None
                    self.route_distinguisher = None
                    self.rpf_default_table = Ipv6Pim.Standby.DefaultContext.Context.RpfDefaultTable()
                    self.rpf_default_table.parent = self
                    self.rpf_id = None
                    self.rpf_policy_name = None
                    self.rsvp_te_maximum_mdt_aggregation = None
                    self.rsvp_te_mdt_data_announce_interval = None
                    self.rsvp_te_mdt_data_switchover_interval = None
                    self.rsvp_te_mdt_interface = None
                    self.rsvp_te_mdt_mtu = None
                    self.rsvp_te_mdt_name = None
                    self.rsvp_te_mdt_rpf_identifier = None
                    self.rsvp_te_mdt_static_p2mp_count = None
                    self.rump_enabled = None
                    self.sg_expiry_time = None
                    self.sg_expiry_timer_configured = None
                    self.sg_expiry_timer_sg_list = None
                    self.stale_rd_present = None
                    self.suppress_pim_data_mdt_tlv = None
                    self.suppress_shared_tree_join = None
                    self.table_count = None
                    self.table_id = None
                    self.umh = None
                    self.valid_rd_present = None
                    self.vpn_index = None
                    self.vrf_id = None


                class RemoteDefaultGroup(object):
                    """
                    Remote Default Group
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.af_name = None
                        self.ipv4_address = None
                        self.ipv6_address = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:remote-default-group'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.af_name is not None:
                            return True

                        if self.ipv4_address is not None:
                            return True

                        if self.ipv6_address is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Context.RemoteDefaultGroup']['meta_info']


                class RpfDefaultTable(object):
                    """
                    RPF Default Table
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.afi = None
                        self.is_active = None
                        self.is_ital_registration_done = None
                        self.is_rib_convergence = None
                        self.is_rib_convergence_received = None
                        self.is_rib_registration_done = None
                        self.rpf_registrations = None
                        self.safi = None
                        self.table_id = None
                        self.table_name = None
                        self.vrf_id = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:rpf-default-table'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.afi is not None:
                            return True

                        if self.is_active is not None:
                            return True

                        if self.is_ital_registration_done is not None:
                            return True

                        if self.is_rib_convergence is not None:
                            return True

                        if self.is_rib_convergence_received is not None:
                            return True

                        if self.is_rib_registration_done is not None:
                            return True

                        if self.rpf_registrations is not None:
                            return True

                        if self.safi is not None:
                            return True

                        if self.table_id is not None:
                            return True

                        if self.table_name is not None:
                            return True

                        if self.vrf_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Context.RpfDefaultTable']['meta_info']


                class ExportRouteTarget(object):
                    """
                    Export Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.anycast_rp = None
                        self.anycast_rp_marked = None
                        self.bgp_auto_discovery = None
                        self.configured = None
                        self.route_target = None
                        self.segment_border = None
                        self.update_pending = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:export-route-target'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.anycast_rp is not None:
                            return True

                        if self.anycast_rp_marked is not None:
                            return True

                        if self.bgp_auto_discovery is not None:
                            return True

                        if self.configured is not None:
                            return True

                        if self.route_target is not None:
                            return True

                        if self.segment_border is not None:
                            return True

                        if self.update_pending is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Context.ExportRouteTarget']['meta_info']


                class ImportRouteTarget(object):
                    """
                    Import Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.anycast_rp = None
                        self.anycast_rp_marked = None
                        self.bgp_auto_discovery = None
                        self.configured = None
                        self.route_target = None
                        self.segment_border = None
                        self.update_pending = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:import-route-target'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.anycast_rp is not None:
                            return True

                        if self.anycast_rp_marked is not None:
                            return True

                        if self.bgp_auto_discovery is not None:
                            return True

                        if self.configured is not None:
                            return True

                        if self.route_target is not None:
                            return True

                        if self.segment_border is not None:
                            return True

                        if self.update_pending is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Context.ImportRouteTarget']['meta_info']


                class AnycastRpRange(object):
                    """
                    Anycast\-RP Ranges
                    
                    .. attribute:: ancast_rp_marked
                    
                    	Anycast\-RP Range marked
                    	**type**\:  bool
                    
                    .. attribute:: prefix
                    
                    	Anycast\-RP Range Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Anycast\-RP Range Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ancast_rp_marked = None
                        self.prefix = Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix()
                        self.prefix.parent = self
                        self.prefix_length = None


                    class Prefix(object):
                        """
                        Anycast\-RP Range Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:anycast-rp-range/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:anycast-rp-range'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ancast_rp_marked is not None:
                            return True

                        if self.prefix is not None and self.prefix._has_data():
                            return True

                        if self.prefix_length is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.active_table_count is not None:
                        return True

                    if self.allow_rp_configured is not None:
                        return True

                    if self.allow_rp_group_list is not None:
                        return True

                    if self.allow_rp_rp_list is not None:
                        return True

                    if self.anycast_rp_configured is not None:
                        return True

                    if self.anycast_rp_policy_name is not None:
                        return True

                    if self.anycast_rp_range is not None:
                        for child_ref in self.anycast_rp_range:
                            if child_ref._has_data():
                                return True

                    if self.bgp_auto_discovery_configured is not None:
                        return True

                    if self.bgp_auto_discovery_type is not None:
                        return True

                    if self.bgp_i_pmsi_added is not None:
                        return True

                    if self.bgp_remote_address is not None:
                        return True

                    if self.bgp_remote_interface is not None:
                        return True

                    if self.bgp_remote_interface_name is not None:
                        return True

                    if self.bgp_remote_on is not None:
                        return True

                    if self.bgp_remote_state is not None:
                        return True

                    if self.bgp_source_active_announce is not None:
                        return True

                    if self.export_route_target is not None:
                        for child_ref in self.export_route_target:
                            if child_ref._has_data():
                                return True

                    if self.gin_b_and_mdt_data_announce_interval is not None:
                        return True

                    if self.gin_b_and_mdt_data_switchover_interval is not None:
                        return True

                    if self.gin_b_and_mdt_interface is not None:
                        return True

                    if self.gin_b_and_mdt_mtu is not None:
                        return True

                    if self.gin_b_and_mdt_name is not None:
                        return True

                    if self.gin_b_and_mdt_rpf_identifier is not None:
                        return True

                    if self.gin_band_maximum_mdt_aggregation is not None:
                        return True

                    if self.import_route_target is not None:
                        for child_ref in self.import_route_target:
                            if child_ref._has_data():
                                return True

                    if self.in_b_and_mdt_data_announce_interval is not None:
                        return True

                    if self.in_b_and_mdt_data_switchover_interval is not None:
                        return True

                    if self.in_b_and_mdt_interface is not None:
                        return True

                    if self.in_b_and_mdt_mtu is not None:
                        return True

                    if self.in_b_and_mdt_name is not None:
                        return True

                    if self.in_b_and_mdt_rpf_identifier is not None:
                        return True

                    if self.in_band_maximum_mdt_aggregation is not None:
                        return True

                    if self.in_band_signaling_local_enabled is not None:
                        return True

                    if self.in_band_signaling_remote_enabled is not None:
                        return True

                    if self.inter_autonomous_system_enabled is not None:
                        return True

                    if self.ir_maximum_mdt_aggregation is not None:
                        return True

                    if self.ir_mdt_data_announce_interval is not None:
                        return True

                    if self.ir_mdt_data_switchover_interval is not None:
                        return True

                    if self.ir_mdt_interface is not None:
                        return True

                    if self.ir_mdt_mtu is not None:
                        return True

                    if self.ir_mdt_name is not None:
                        return True

                    if self.ir_mdt_rpf_identifier is not None:
                        return True

                    if self.ir_mdt_tail_label is not None:
                        return True

                    if self.is_active is not None:
                        return True

                    if self.is_active_ital is not None:
                        return True

                    if self.is_all_interface_disable_operation is not None:
                        return True

                    if self.is_auto_rp_listen_enabled is not None:
                        return True

                    if self.is_auto_rp_listen_sock_add is not None:
                        return True

                    if self.is_create_gin_b_and_mdt_interface is not None:
                        return True

                    if self.is_create_in_b_and_mdt_interface is not None:
                        return True

                    if self.is_create_ir_mdt_interface is not None:
                        return True

                    if self.is_create_mdt_interface is not None:
                        return True

                    if self.is_create_mldp_mdt_interface is not None:
                        return True

                    if self.is_create_rsvp_te_mdt_interface is not None:
                        return True

                    if self.is_default_granges is not None:
                        return True

                    if self.is_gin_b_and_mdt_owner is not None:
                        return True

                    if self.is_in_b_and_mdt_owner is not None:
                        return True

                    if self.is_ir_mdt_owner is not None:
                        return True

                    if self.is_lpts_socket_add_required is not None:
                        return True

                    if self.is_lpts_socket_added is not None:
                        return True

                    if self.is_m_host_publish_pending is not None:
                        return True

                    if self.is_mdt_owner is not None:
                        return True

                    if self.is_mldp_mdt_owner is not None:
                        return True

                    if self.is_mrib_register is not None:
                        return True

                    if self.is_multicast_rib_registration is not None:
                        return True

                    if self.is_pim_nsf_rib_converge_received is not None:
                        return True

                    if self.is_pim_nsf_rib_converged is not None:
                        return True

                    if self.is_redistribution_reset is not None:
                        return True

                    if self.is_register_injection_lpts_socket_add_required is not None:
                        return True

                    if self.is_register_injection_lpts_socket_added is not None:
                        return True

                    if self.is_register_injection_socket_add_required is not None:
                        return True

                    if self.is_register_injection_socket_added is not None:
                        return True

                    if self.is_rib_multipath_enabled is not None:
                        return True

                    if self.is_rib_multipath_interface_hash is not None:
                        return True

                    if self.is_rib_multipath_source_hash is not None:
                        return True

                    if self.is_rib_multipath_source_next_hop_hash is not None:
                        return True

                    if self.is_routing_enabled is not None:
                        return True

                    if self.is_rsvp_te_mdt_owner is not None:
                        return True

                    if self.is_socket_add_required is not None:
                        return True

                    if self.is_socket_added is not None:
                        return True

                    if self.is_udp_socket_add_required is not None:
                        return True

                    if self.is_udp_socket_added is not None:
                        return True

                    if self.is_udp_socket_bind is not None:
                        return True

                    if self.is_udp_socket_bind_required is not None:
                        return True

                    if self.is_unicast_rib_registration is not None:
                        return True

                    if self.maximum_mdt_aggregation is not None:
                        return True

                    if self.mdt_data_announce_interval is not None:
                        return True

                    if self.mdt_data_switchover_interval is not None:
                        return True

                    if self.mdt_default_group is not None:
                        return True

                    if self.mdt_gre_remote_rpf_identifier is not None:
                        return True

                    if self.mdt_gre_rpf_identifier is not None:
                        return True

                    if self.mdt_interface is not None:
                        return True

                    if self.mdt_mtu is not None:
                        return True

                    if self.mdt_neighbor_filter_name is not None:
                        return True

                    if self.mdt_partitioned_ir_control_identifier is not None:
                        return True

                    if self.mdt_partitioned_mdt_control_identifier is not None:
                        return True

                    if self.mhost_default_interface_config is not None:
                        return True

                    if self.mhost_interface is not None:
                        return True

                    if self.mldp_auto_rp_announce_tree_added is not None:
                        return True

                    if self.mldp_auto_rp_discovery_tree_added is not None:
                        return True

                    if self.mldp_bsr_control_tree_added is not None:
                        return True

                    if self.mldp_control_head_lsm_identifier is not None:
                        return True

                    if self.mldp_head_local_label is not None:
                        return True

                    if self.mldp_head_lsm_identifier is not None:
                        return True

                    if self.mldp_maximum_mdt_aggregation is not None:
                        return True

                    if self.mldp_mdt_data_announce_interval is not None:
                        return True

                    if self.mldp_mdt_data_switchover_interval is not None:
                        return True

                    if self.mldp_mdt_interface is not None:
                        return True

                    if self.mldp_mdt_mtu is not None:
                        return True

                    if self.mldp_mdt_name is not None:
                        return True

                    if self.mldp_mdt_remote_rpf_identifier is not None:
                        return True

                    if self.mldp_mdt_rpf_identifier is not None:
                        return True

                    if self.mldp_partioned_mp2m_ptree is not None:
                        return True

                    if self.mldp_partitioned_head_lsm_identifier is not None:
                        return True

                    if self.mldp_partitioned_mdt_configured is not None:
                        return True

                    if self.mldp_partitioned_mdt_identifier is not None:
                        return True

                    if self.mldp_remote_head_lsm_identifier is not None:
                        return True

                    if self.mldp_remote_partitioned_mdt_configured is not None:
                        return True

                    if self.mldp_root_address is not None:
                        for child in self.mldp_root_address:
                            if child is not None:
                                return True

                    if self.mldp_root_count is not None:
                        return True

                    if self.murib_id is not None:
                        return True

                    if self.neighbor_filter_name is not None:
                        return True

                    if self.non_default_vrf_count_on_socket is not None:
                        return True

                    if self.organization_unique_identifier is not None:
                        return True

                    if self.p2mpte_li_drop is not None:
                        return True

                    if self.redistribution_reset_count is not None:
                        return True

                    if self.remote_default_group is not None and self.remote_default_group._has_data():
                        return True

                    if self.remote_table_id is not None:
                        return True

                    if self.route_distinguisher is not None:
                        return True

                    if self.rpf_default_table is not None and self.rpf_default_table._has_data():
                        return True

                    if self.rpf_id is not None:
                        return True

                    if self.rpf_policy_name is not None:
                        return True

                    if self.rsvp_te_maximum_mdt_aggregation is not None:
                        return True

                    if self.rsvp_te_mdt_data_announce_interval is not None:
                        return True

                    if self.rsvp_te_mdt_data_switchover_interval is not None:
                        return True

                    if self.rsvp_te_mdt_interface is not None:
                        return True

                    if self.rsvp_te_mdt_mtu is not None:
                        return True

                    if self.rsvp_te_mdt_name is not None:
                        return True

                    if self.rsvp_te_mdt_rpf_identifier is not None:
                        return True

                    if self.rsvp_te_mdt_static_p2mp_count is not None:
                        return True

                    if self.rump_enabled is not None:
                        return True

                    if self.sg_expiry_time is not None:
                        return True

                    if self.sg_expiry_timer_configured is not None:
                        return True

                    if self.sg_expiry_timer_sg_list is not None:
                        return True

                    if self.stale_rd_present is not None:
                        return True

                    if self.suppress_pim_data_mdt_tlv is not None:
                        return True

                    if self.suppress_shared_tree_join is not None:
                        return True

                    if self.table_count is not None:
                        return True

                    if self.table_id is not None:
                        return True

                    if self.umh is not None:
                        return True

                    if self.valid_rd_present is not None:
                        return True

                    if self.vpn_index is not None:
                        return True

                    if self.vrf_id is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Context']['meta_info']


            class TopologyEntryFlagRouteCounts(object):
                """
                Route count for topology with entry flag set
                
                .. attribute:: topology_entry_flag_route_count
                
                	Route count for topology with entry flag set
                	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.topology_entry_flag_route_count = YList()
                    self.topology_entry_flag_route_count.parent = self
                    self.topology_entry_flag_route_count.name = 'topology_entry_flag_route_count'


                class TopologyEntryFlagRouteCount(object):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: entry_flag  <key>
                    
                    	entry flag
                    	**type**\:   :py:class:`PimTopologyEntryFlagEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlagEnum>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.entry_flag = None
                        self.active_group_ranges = None
                        self.group_address = Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self.group_ranges = None
                        self.groute_count = None
                        self.is_node_low_memory = None
                        self.sg_route_count = None
                        self.sgr_route_count = None


                    class GroupAddress(object):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.entry_flag is None:
                            raise YPYModelError('Key property entry_flag is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-entry-flag-route-counts/Cisco-IOS-XR-ipv4-pim-oper:topology-entry-flag-route-count[Cisco-IOS-XR-ipv4-pim-oper:entry-flag = ' + str(self.entry_flag) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.entry_flag is not None:
                            return True

                        if self.active_group_ranges is not None:
                            return True

                        if self.group_address is not None and self.group_address._has_data():
                            return True

                        if self.group_ranges is not None:
                            return True

                        if self.groute_count is not None:
                            return True

                        if self.is_node_low_memory is not None:
                            return True

                        if self.sg_route_count is not None:
                            return True

                        if self.sgr_route_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-entry-flag-route-counts'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.topology_entry_flag_route_count is not None:
                        for child_ref in self.topology_entry_flag_route_count:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts']['meta_info']


            class RpfRedirect(object):
                """
                PIM ECMP RPF\-redirect bundle
                
                .. attribute:: bundle_interfaces
                
                	PIM ECMP RPF\-redirect bundle information
                	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces>`
                
                .. attribute:: redirect_route_databases
                
                	PIM ECMP RPF\-redirect route database
                	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bundle_interfaces = Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces()
                    self.bundle_interfaces.parent = self
                    self.redirect_route_databases = Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases()
                    self.redirect_route_databases.parent = self


                class RedirectRouteDatabases(object):
                    """
                    PIM ECMP RPF\-redirect route database
                    
                    .. attribute:: redirect_route_database
                    
                    	PIM ECMP RPF\-redirect route information
                    	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.redirect_route_database = YList()
                        self.redirect_route_database.parent = self
                        self.redirect_route_database.name = 'redirect_route_database'


                    class RedirectRouteDatabase(object):
                        """
                        PIM ECMP RPF\-redirect route information
                        
                        .. attribute:: bandwidth
                        
                        	Bandwidth in Kbps
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group ddress
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                        
                        .. attribute:: interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bandwidth = None
                            self.group_address = None
                            self.group_address_xr = Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self.interface = YList()
                            self.interface.parent = self
                            self.interface.name = 'interface'
                            self.source_address = None
                            self.source_address_xr = Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self.uptime = None


                        class GroupAddressXr(object):
                            """
                            Group ddress
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr']['meta_info']


                        class SourceAddressXr(object):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr']['meta_info']


                        class Interface(object):
                            """
                            Outgoing interface list
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_outgoing_interface
                            
                            	Is outgoing Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_rpf_interface
                            
                            	Is RPF Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_snoop_interface
                            
                            	Is snooping Interface
                            	**type**\:  bool
                            
                            .. attribute:: rpf_address
                            
                            	RPF Address
                            	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.expiry = None
                                self.interface_name = None
                                self.is_outgoing_interface = None
                                self.is_rpf_interface = None
                                self.is_snoop_interface = None
                                self.rpf_address = Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                self.rpf_address.parent = self
                                self.uptime = None


                            class RpfAddress(object):
                                """
                                RPF Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database/Cisco-IOS-XR-ipv4-pim-oper:interface/Cisco-IOS-XR-ipv4-pim-oper:rpf-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database/Cisco-IOS-XR-ipv4-pim-oper:interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.expiry is not None:
                                    return True

                                if self.interface_name is not None:
                                    return True

                                if self.is_outgoing_interface is not None:
                                    return True

                                if self.is_rpf_interface is not None:
                                    return True

                                if self.is_snoop_interface is not None:
                                    return True

                                if self.rpf_address is not None and self.rpf_address._has_data():
                                    return True

                                if self.uptime is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bandwidth is not None:
                                return True

                            if self.group_address is not None:
                                return True

                            if self.group_address_xr is not None and self.group_address_xr._has_data():
                                return True

                            if self.interface is not None:
                                for child_ref in self.interface:
                                    if child_ref._has_data():
                                        return True

                            if self.source_address is not None:
                                return True

                            if self.source_address_xr is not None and self.source_address_xr._has_data():
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.redirect_route_database is not None:
                            for child_ref in self.redirect_route_database:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases']['meta_info']


                class BundleInterfaces(object):
                    """
                    PIM ECMP RPF\-redirect bundle information
                    
                    .. attribute:: bundle_interface
                    
                    	PIM ECMP RPF\-redirect bundle interface information
                    	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bundle_interface = YList()
                        self.bundle_interface.parent = self
                        self.bundle_interface.name = 'bundle_interface'


                    class BundleInterface(object):
                        """
                        PIM ECMP RPF\-redirect bundle interface
                        information
                        
                        .. attribute:: allocated_bandwidth
                        
                        	Bandwidth allocated in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: allocated_threshold_bandwidth
                        
                        	Configured threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_bandwidth
                        
                        	Bandwidth available in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_threshold_bandwidth
                        
                        	Available threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: bundle_name
                        
                        	Bundle name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: interface_name
                        
                        	Bundle interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_redirect_bundle_name
                        
                        	RPF redirect bundle name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpf_redirect_interface_name
                        
                        	RPF redirect interface name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: snooping_bandwidth_used
                        
                        	Bandwidth used by snooped entries in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: topology_bandwidth_used
                        
                        	Bandwidth used by topology in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: total_bandwidth
                        
                        	Total bandwidth used in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.allocated_bandwidth = None
                            self.allocated_threshold_bandwidth = None
                            self.available_bandwidth = None
                            self.available_threshold_bandwidth = None
                            self.bundle_name = None
                            self.interface_name = None
                            self.rpf_redirect_bundle_name = None
                            self.rpf_redirect_interface_name = None
                            self.snooping_bandwidth_used = None
                            self.topology_bandwidth_used = None
                            self.total_bandwidth = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:bundle-interfaces/Cisco-IOS-XR-ipv4-pim-oper:bundle-interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.allocated_bandwidth is not None:
                                return True

                            if self.allocated_threshold_bandwidth is not None:
                                return True

                            if self.available_bandwidth is not None:
                                return True

                            if self.available_threshold_bandwidth is not None:
                                return True

                            if self.bundle_name is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.rpf_redirect_bundle_name is not None:
                                return True

                            if self.rpf_redirect_interface_name is not None:
                                return True

                            if self.snooping_bandwidth_used is not None:
                                return True

                            if self.topology_bandwidth_used is not None:
                                return True

                            if self.total_bandwidth is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:bundle-interfaces'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bundle_interface is not None:
                            for child_ref in self.bundle_interface:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bundle_interfaces is not None and self.bundle_interfaces._has_data():
                        return True

                    if self.redirect_route_databases is not None and self.redirect_route_databases._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.RpfRedirect']['meta_info']


            class Tunnels(object):
                """
                Tunnels information that PIM has
                
                .. attribute:: tunnel
                
                	PIM tunnel information
                	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.tunnel = YList()
                    self.tunnel.parent = self
                    self.tunnel.name = 'tunnel'


                class Tunnel(object):
                    """
                    PIM tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.tunnel_name = None
                        self.group_address_netio = Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self.rp_address = Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress()
                        self.rp_address.parent = self
                        self.source_address = Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress()
                        self.source_address.parent = self
                        self.source_address_netio = Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self.vrf_name = None


                    class SourceAddress(object):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress']['meta_info']


                    class RpAddress(object):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress']['meta_info']


                    class SourceAddressNetio(object):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-netio'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio']['meta_info']


                    class GroupAddressNetio(object):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-netio'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio']['meta_info']

                    @property
                    def _common_path(self):
                        if self.tunnel_name is None:
                            raise YPYModelError('Key property tunnel_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:tunnels/Cisco-IOS-XR-ipv4-pim-oper:tunnel[Cisco-IOS-XR-ipv4-pim-oper:tunnel-name = ' + str(self.tunnel_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.tunnel_name is not None:
                            return True

                        if self.group_address_netio is not None and self.group_address_netio._has_data():
                            return True

                        if self.rp_address is not None and self.rp_address._has_data():
                            return True

                        if self.source_address is not None and self.source_address._has_data():
                            return True

                        if self.source_address_netio is not None and self.source_address_netio._has_data():
                            return True

                        if self.vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:tunnels'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.tunnel is not None:
                        for child_ref in self.tunnel:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Tunnels']['meta_info']


            class MulticastStaticRoutes(object):
                """
                PIM multicast static route table
                
                .. attribute:: multicast_static_route
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.multicast_static_route = YList()
                    self.multicast_static_route.parent = self
                    self.multicast_static_route.name = 'multicast_static_route'


                class MulticastStaticRoute(object):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: address
                    
                    	Network address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: distance
                    
                    	Distance
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_via_lsm
                    
                    	LSM flag
                    	**type**\:  bool
                    
                    .. attribute:: nexthop
                    
                    	Next Hop
                    	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: prefix_length_xr
                    
                    	Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.address = None
                        self.distance = None
                        self.interface_name = None
                        self.is_via_lsm = None
                        self.nexthop = Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                        self.nexthop.parent = self
                        self.prefix = Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                        self.prefix.parent = self
                        self.prefix_length = None
                        self.prefix_length_xr = None


                    class Prefix(object):
                        """
                        Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-routes/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-route/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix']['meta_info']


                    class Nexthop(object):
                        """
                        Next Hop
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-routes/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-route/Cisco-IOS-XR-ipv4-pim-oper:nexthop'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-routes/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-route'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.address is not None:
                            return True

                        if self.distance is not None:
                            return True

                        if self.interface_name is not None:
                            return True

                        if self.is_via_lsm is not None:
                            return True

                        if self.nexthop is not None and self.nexthop._has_data():
                            return True

                        if self.prefix is not None and self.prefix._has_data():
                            return True

                        if self.prefix_length is not None:
                            return True

                        if self.prefix_length_xr is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-routes'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.multicast_static_route is not None:
                        for child_ref in self.multicast_static_route:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes']['meta_info']


            class GroupMapMatchSources(object):
                """
                Find the matching group\-mapping with source
                information on specified group address
                
                .. attribute:: group_map_match_source
                
                	PIM group\-matching mapping entry with source information
                	**type**\: list of    :py:class:`GroupMapMatchSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.group_map_match_source = YList()
                    self.group_map_match_source.parent = self
                    self.group_map_match_source.name = 'group_map_match_source'


                class GroupMapMatchSource(object):
                    """
                    PIM group\-matching mapping entry with source
                    information
                    
                    .. attribute:: group_address  <key>
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation>`
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_address = None
                        self.expires = None
                        self.group_map_information = Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self.holdtime = None
                        self.source_of_information = Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self.uptime = None


                    class SourceOfInformation(object):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation']['meta_info']


                    class GroupMapInformation(object):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.group_count = None
                            self.is_override = None
                            self.is_used = None
                            self.mrib_active = None
                            self.prefix = Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.priority = None
                            self.protocol = None
                            self.rp_address = Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self


                        class Prefix(object):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix']['meta_info']


                        class RpAddress(object):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.group_count is not None:
                                return True

                            if self.is_override is not None:
                                return True

                            if self.is_used is not None:
                                return True

                            if self.mrib_active is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation']['meta_info']

                    @property
                    def _common_path(self):
                        if self.group_address is None:
                            raise YPYModelError('Key property group_address is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-source[Cisco-IOS-XR-ipv4-pim-oper:group-address = ' + str(self.group_address) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_address is not None:
                            return True

                        if self.expires is not None:
                            return True

                        if self.group_map_information is not None and self.group_map_information._has_data():
                            return True

                        if self.holdtime is not None:
                            return True

                        if self.source_of_information is not None and self.source_of_information._has_data():
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-sources'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.group_map_match_source is not None:
                        for child_ref in self.group_map_match_source:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources']['meta_info']


            class Neighbors(object):
                """
                PIM neighbor table
                
                .. attribute:: neighbor
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.neighbor = YList()
                    self.neighbor.parent = self
                    self.neighbor.name = 'neighbor'


                class Neighbor(object):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.dr_priority = None
                        self.expires = None
                        self.expiry_timer = None
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bfd_state = None
                        self.is_bidirectional_capable = None
                        self.is_dr_priority_capable = None
                        self.is_ecmp_redirect_capable = None
                        self.is_proxy_capable = None
                        self.is_this_neighbor_dr = None
                        self.is_this_neighbor_us = None
                        self.neighbor_address = None
                        self.neighbor_address_xr = YList()
                        self.neighbor_address_xr.parent = self
                        self.neighbor_address_xr.name = 'neighbor_address_xr'
                        self.override_interval = None
                        self.propagation_delay = None
                        self.uptime = None


                    class NeighborAddressXr(object):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbors/Cisco-IOS-XR-ipv4-pim-oper:neighbor/Cisco-IOS-XR-ipv4-pim-oper:neighbor-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbors/Cisco-IOS-XR-ipv4-pim-oper:neighbor'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.dr_priority is not None:
                            return True

                        if self.expires is not None:
                            return True

                        if self.expiry_timer is not None:
                            return True

                        if self.interface_name is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bfd_state is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_dr_priority_capable is not None:
                            return True

                        if self.is_ecmp_redirect_capable is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.is_this_neighbor_dr is not None:
                            return True

                        if self.is_this_neighbor_us is not None:
                            return True

                        if self.neighbor_address is not None:
                            return True

                        if self.neighbor_address_xr is not None:
                            for child_ref in self.neighbor_address_xr:
                                if child_ref._has_data():
                                    return True

                        if self.override_interval is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbors'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.neighbor is not None:
                        for child_ref in self.neighbor:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.DefaultContext.Neighbors']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:default-context'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.auto_rp is not None and self.auto_rp._has_data():
                    return True

                if self.bgp_afs is not None and self.bgp_afs._has_data():
                    return True

                if self.bidir_df_states is not None and self.bidir_df_states._has_data():
                    return True

                if self.bidir_df_winners is not None and self.bidir_df_winners._has_data():
                    return True

                if self.bsr is not None and self.bsr._has_data():
                    return True

                if self.context is not None and self.context._has_data():
                    return True

                if self.global_interfaces is not None and self.global_interfaces._has_data():
                    return True

                if self.gre is not None and self.gre._has_data():
                    return True

                if self.group_map_match_rpfs is not None and self.group_map_match_rpfs._has_data():
                    return True

                if self.group_map_match_sources is not None and self.group_map_match_sources._has_data():
                    return True

                if self.group_map_rpfs is not None and self.group_map_rpfs._has_data():
                    return True

                if self.group_map_sources is not None and self.group_map_sources._has_data():
                    return True

                if self.ifrs_interfaces is not None and self.ifrs_interfaces._has_data():
                    return True

                if self.ifrs_summary is not None and self.ifrs_summary._has_data():
                    return True

                if self.interface_old_formats is not None and self.interface_old_formats._has_data():
                    return True

                if self.interface_statistics is not None and self.interface_statistics._has_data():
                    return True

                if self.interfaces is not None and self.interfaces._has_data():
                    return True

                if self.jp_statistics is not None and self.jp_statistics._has_data():
                    return True

                if self.mib_databases is not None and self.mib_databases._has_data():
                    return True

                if self.multicast_static_routes is not None and self.multicast_static_routes._has_data():
                    return True

                if self.neighbor_old_formats is not None and self.neighbor_old_formats._has_data():
                    return True

                if self.neighbor_summaries is not None and self.neighbor_summaries._has_data():
                    return True

                if self.neighbors is not None and self.neighbors._has_data():
                    return True

                if self.net_io_tunnels is not None and self.net_io_tunnels._has_data():
                    return True

                if self.ranges is not None and self.ranges._has_data():
                    return True

                if self.route_policy is not None and self.route_policy._has_data():
                    return True

                if self.rpf_redirect is not None and self.rpf_redirect._has_data():
                    return True

                if self.rpf_summary is not None and self.rpf_summary._has_data():
                    return True

                if self.safs is not None and self.safs._has_data():
                    return True

                if self.summary is not None and self.summary._has_data():
                    return True

                if self.table_contexts is not None and self.table_contexts._has_data():
                    return True

                if self.topologies is not None and self.topologies._has_data():
                    return True

                if self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts._has_data():
                    return True

                if self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts._has_data():
                    return True

                if self.topology_route_count is not None and self.topology_route_count._has_data():
                    return True

                if self.traffic_counters is not None and self.traffic_counters._has_data():
                    return True

                if self.tunnels is not None and self.tunnels._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                return meta._meta_table['Ipv6Pim.Standby.DefaultContext']['meta_info']


        class Process(object):
            """
            Process
            
            .. attribute:: checkpoint_statistics
            
            	Checkpoint Statistics
            	**type**\:   :py:class:`CheckpointStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process.CheckpointStatistics>`
            
            .. attribute:: issu
            
            	ISSU Information
            	**type**\:   :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process.Issu>`
            
            .. attribute:: nsf
            
            	PIM NSF information
            	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process.Nsf>`
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process.Nsr>`
            
            .. attribute:: summary
            
            	PIM Global Summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process.Summary>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.checkpoint_statistics = Ipv6Pim.Standby.Process.CheckpointStatistics()
                self.checkpoint_statistics.parent = self
                self.issu = Ipv6Pim.Standby.Process.Issu()
                self.issu.parent = self
                self.nsf = Ipv6Pim.Standby.Process.Nsf()
                self.nsf.parent = self
                self.nsr = Ipv6Pim.Standby.Process.Nsr()
                self.nsr.parent = self
                self.summary = Ipv6Pim.Standby.Process.Summary()
                self.summary.parent = self


            class CheckpointStatistics(object):
                """
                Checkpoint Statistics
                
                .. attribute:: checkpoint_table
                
                	Array of chkpt table stats
                	**type**\: list of    :py:class:`CheckpointTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process.CheckpointStatistics.CheckpointTable>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.checkpoint_table = YList()
                    self.checkpoint_table.parent = self
                    self.checkpoint_table.name = 'checkpoint_table'


                class CheckpointTable(object):
                    """
                    Array of chkpt table stats
                    
                    .. attribute:: is_mirrored
                    
                    	Table mirrored
                    	**type**\:  bool
                    
                    .. attribute:: statistic
                    
                    	Stats array
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_description
                    
                    	Table description
                    	**type**\:  str
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.is_mirrored = None
                        self.statistic = YLeafList()
                        self.statistic.parent = self
                        self.statistic.name = 'statistic'
                        self.table_description = None
                        self.table_name = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:checkpoint-statistics/Cisco-IOS-XR-ipv4-pim-oper:checkpoint-table'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.is_mirrored is not None:
                            return True

                        if self.statistic is not None:
                            for child in self.statistic:
                                if child is not None:
                                    return True

                        if self.table_description is not None:
                            return True

                        if self.table_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Process.CheckpointStatistics.CheckpointTable']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:checkpoint-statistics'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.checkpoint_table is not None:
                        for child_ref in self.checkpoint_table:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.Process.CheckpointStatistics']['meta_info']


            class Nsr(object):
                """
                NSR Information
                
                .. attribute:: count_connection_dn
                
                	No. of times connection went down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_connection_up
                
                	No. of times connection went up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_connection_dn
                
                	Time when connection went down
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_connection_up
                
                	Time when connection went up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: partner_connected
                
                	Partner process connected
                	**type**\:  bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\:  bool
                
                .. attribute:: rmf_timer_expiry
                
                	Time for RMF timer to expire
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: rmf_timer_valid
                
                	Is RMF timer running ?
                	**type**\:  bool
                
                .. attribute:: state
                
                	NSR state
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.count_connection_dn = None
                    self.count_connection_up = None
                    self.count_rmf_not_ready = None
                    self.count_rmf_ready = None
                    self.last_connection_dn = None
                    self.last_connection_up = None
                    self.last_rmf_not_ready = None
                    self.last_rmf_ready = None
                    self.partner_connected = None
                    self.rmf_notification_done = None
                    self.rmf_timer_expiry = None
                    self.rmf_timer_valid = None
                    self.state = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:nsr'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.count_connection_dn is not None:
                        return True

                    if self.count_connection_up is not None:
                        return True

                    if self.count_rmf_not_ready is not None:
                        return True

                    if self.count_rmf_ready is not None:
                        return True

                    if self.last_connection_dn is not None:
                        return True

                    if self.last_connection_up is not None:
                        return True

                    if self.last_rmf_not_ready is not None:
                        return True

                    if self.last_rmf_ready is not None:
                        return True

                    if self.partner_connected is not None:
                        return True

                    if self.rmf_notification_done is not None:
                        return True

                    if self.rmf_timer_expiry is not None:
                        return True

                    if self.rmf_timer_valid is not None:
                        return True

                    if self.state is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.Process.Nsr']['meta_info']


            class Summary(object):
                """
                PIM Global Summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bsr_candidate_rp_set_count = None
                    self.bsr_candidate_rp_set_limit = None
                    self.bsr_candidate_rp_set_threshold = None
                    self.bsr_range_threshold = None
                    self.bsr_ranges_count = None
                    self.bsr_ranges_limit = None
                    self.global_auto_rp_ranges_limit = None
                    self.global_bsr_candidate_rp_set_count = None
                    self.global_bsr_candidate_rp_set_limit = None
                    self.global_bsr_candidate_rp_set_threshold = None
                    self.global_bsr_ranges_count = None
                    self.global_bsr_ranges_limit = None
                    self.global_bsr_ranges_threshold = None
                    self.global_register_limit = None
                    self.is_bsr_ranges_threshold_reached = None
                    self.is_global_auto_rp_ranges_limit_reached = None
                    self.is_global_bsr_ranges_limit_reached = None
                    self.is_global_register_limit_reached = None
                    self.is_global_route_limit_reached = None
                    self.is_global_rxi_limit_reached = None
                    self.is_maximum_enforcement_disabled = None
                    self.is_node_low_memory = None
                    self.is_ranges_limit_reached = None
                    self.is_route_limit_reached = None
                    self.ranges_count = None
                    self.ranges_limit = None
                    self.ranges_threshold = None
                    self.register_count = None
                    self.register_limit = None
                    self.register_limit_reached = None
                    self.register_threshold = None
                    self.route_count = None
                    self.route_limit = None
                    self.route_low_water_mark = None
                    self.route_threshold = None
                    self.rxi_limit_reached = None
                    self.rxi_low_water_mark = None
                    self.topology_interface_state_count = None
                    self.topology_interface_state_limit = None
                    self.topology_interface_state_threshold = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bsr_candidate_rp_set_count is not None:
                        return True

                    if self.bsr_candidate_rp_set_limit is not None:
                        return True

                    if self.bsr_candidate_rp_set_threshold is not None:
                        return True

                    if self.bsr_range_threshold is not None:
                        return True

                    if self.bsr_ranges_count is not None:
                        return True

                    if self.bsr_ranges_limit is not None:
                        return True

                    if self.global_auto_rp_ranges_limit is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_count is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_limit is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_threshold is not None:
                        return True

                    if self.global_bsr_ranges_count is not None:
                        return True

                    if self.global_bsr_ranges_limit is not None:
                        return True

                    if self.global_bsr_ranges_threshold is not None:
                        return True

                    if self.global_register_limit is not None:
                        return True

                    if self.is_bsr_ranges_threshold_reached is not None:
                        return True

                    if self.is_global_auto_rp_ranges_limit_reached is not None:
                        return True

                    if self.is_global_bsr_ranges_limit_reached is not None:
                        return True

                    if self.is_global_register_limit_reached is not None:
                        return True

                    if self.is_global_route_limit_reached is not None:
                        return True

                    if self.is_global_rxi_limit_reached is not None:
                        return True

                    if self.is_maximum_enforcement_disabled is not None:
                        return True

                    if self.is_node_low_memory is not None:
                        return True

                    if self.is_ranges_limit_reached is not None:
                        return True

                    if self.is_route_limit_reached is not None:
                        return True

                    if self.ranges_count is not None:
                        return True

                    if self.ranges_limit is not None:
                        return True

                    if self.ranges_threshold is not None:
                        return True

                    if self.register_count is not None:
                        return True

                    if self.register_limit is not None:
                        return True

                    if self.register_limit_reached is not None:
                        return True

                    if self.register_threshold is not None:
                        return True

                    if self.route_count is not None:
                        return True

                    if self.route_limit is not None:
                        return True

                    if self.route_low_water_mark is not None:
                        return True

                    if self.route_threshold is not None:
                        return True

                    if self.rxi_limit_reached is not None:
                        return True

                    if self.rxi_low_water_mark is not None:
                        return True

                    if self.topology_interface_state_count is not None:
                        return True

                    if self.topology_interface_state_limit is not None:
                        return True

                    if self.topology_interface_state_threshold is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.Process.Summary']['meta_info']


            class Nsf(object):
                """
                PIM NSF information
                
                .. attribute:: configured_state
                
                	Is Multicast NSF Configured
                	**type**\:  bool
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_sec
                
                	Last ICD Notif Recv in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off_sec
                
                	Last NSF time OFF in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_sec
                
                	Last NSF time ON in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: nsf_state
                
                	Are we currently in NSF
                	**type**\:  bool
                
                .. attribute:: nsf_time_left
                
                	Multicast NSF time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: nsf_timeout
                
                	Multicast NSF timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: waiting_membership
                
                	Waiting for IGMP/MLD
                	**type**\:  bool
                
                .. attribute:: waiting_timer
                
                	Waiting for NSF timer expiry
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.configured_state = None
                    self.last_icd_notif_recv = None
                    self.last_icd_notif_recv_sec = None
                    self.last_nsf_off = None
                    self.last_nsf_off_sec = None
                    self.last_nsf_on = None
                    self.last_nsf_on_sec = None
                    self.nsf_state = None
                    self.nsf_time_left = None
                    self.nsf_timeout = None
                    self.respawn_count = None
                    self.waiting_membership = None
                    self.waiting_timer = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:nsf'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.configured_state is not None:
                        return True

                    if self.last_icd_notif_recv is not None:
                        return True

                    if self.last_icd_notif_recv_sec is not None:
                        return True

                    if self.last_nsf_off is not None:
                        return True

                    if self.last_nsf_off_sec is not None:
                        return True

                    if self.last_nsf_on is not None:
                        return True

                    if self.last_nsf_on_sec is not None:
                        return True

                    if self.nsf_state is not None:
                        return True

                    if self.nsf_time_left is not None:
                        return True

                    if self.nsf_timeout is not None:
                        return True

                    if self.respawn_count is not None:
                        return True

                    if self.waiting_membership is not None:
                        return True

                    if self.waiting_timer is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.Process.Nsf']['meta_info']


            class Issu(object):
                """
                ISSU Information
                
                .. attribute:: checkpoint_idt_timestamp
                
                	Time when Checkpoint IDT done
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: eoc_received_timestamp
                
                	Time when EOC was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: ihms_received_timestamp
                
                	Time when IHMS done was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: informationvalid
                
                	Is Information valid ?
                	**type**\:  bool
                
                .. attribute:: is_checkpoint_idt_done
                
                	Was Checkpoint IDT done ?
                	**type**\:  bool
                
                .. attribute:: is_eoc_received
                
                	Was EOC received ?
                	**type**\:  bool
                
                .. attribute:: is_ihms_done_received
                
                	Was IHMS done received ?
                	**type**\:  bool
                
                .. attribute:: is_nbr_sync_received
                
                	Was NBR Sync achieved ?
                	**type**\:  bool
                
                .. attribute:: is_rib_sync_received
                
                	Was RIB Sync received ?
                	**type**\:  bool
                
                .. attribute:: last_ha_role_notification_received
                
                	Time when last HA role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_phase_notification_received
                
                	Time when last ISSU Phase nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_role_notification_received
                
                	Time when last ISSU role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: nbr_sync_received_timestamp
                
                	Time when NBR Sync was achieved
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: phase_issu
                
                	ISSU Phase
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: rib_sync_received_timestamp
                
                	Time when RIB Sync was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: role_ha
                
                	HA role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: role_issu
                
                	ISSU role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.checkpoint_idt_timestamp = None
                    self.eoc_received_timestamp = None
                    self.ihms_received_timestamp = None
                    self.informationvalid = None
                    self.is_checkpoint_idt_done = None
                    self.is_eoc_received = None
                    self.is_ihms_done_received = None
                    self.is_nbr_sync_received = None
                    self.is_rib_sync_received = None
                    self.last_ha_role_notification_received = None
                    self.last_issu_phase_notification_received = None
                    self.last_issu_role_notification_received = None
                    self.nbr_sync_received_timestamp = None
                    self.phase_issu = None
                    self.rib_sync_received_timestamp = None
                    self.role_ha = None
                    self.role_issu = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:issu'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.checkpoint_idt_timestamp is not None:
                        return True

                    if self.eoc_received_timestamp is not None:
                        return True

                    if self.ihms_received_timestamp is not None:
                        return True

                    if self.informationvalid is not None:
                        return True

                    if self.is_checkpoint_idt_done is not None:
                        return True

                    if self.is_eoc_received is not None:
                        return True

                    if self.is_ihms_done_received is not None:
                        return True

                    if self.is_nbr_sync_received is not None:
                        return True

                    if self.is_rib_sync_received is not None:
                        return True

                    if self.last_ha_role_notification_received is not None:
                        return True

                    if self.last_issu_phase_notification_received is not None:
                        return True

                    if self.last_issu_role_notification_received is not None:
                        return True

                    if self.nbr_sync_received_timestamp is not None:
                        return True

                    if self.phase_issu is not None:
                        return True

                    if self.rib_sync_received_timestamp is not None:
                        return True

                    if self.role_ha is not None:
                        return True

                    if self.role_issu is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.Process.Issu']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:process'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.checkpoint_statistics is not None and self.checkpoint_statistics._has_data():
                    return True

                if self.issu is not None and self.issu._has_data():
                    return True

                if self.nsf is not None and self.nsf._has_data():
                    return True

                if self.nsr is not None and self.nsr._has_data():
                    return True

                if self.summary is not None and self.summary._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                return meta._meta_table['Ipv6Pim.Standby.Process']['meta_info']


        class Vrfs(object):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF name
            	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.vrf = YList()
                self.vrf.parent = self
                self.vrf.name = 'vrf'


            class Vrf(object):
                """
                VRF name
                
                .. attribute:: vrf_name  <key>
                
                	VRF name 
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: auto_rp
                
                	PIM Auto\-RP information
                	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.AutoRp>`
                
                .. attribute:: bgp_afs
                
                	PIM BGP SAFI table
                	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs>`
                
                .. attribute:: bidir_df_states
                
                	Bidirectional PIM DF election state table
                	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates>`
                
                .. attribute:: bidir_df_winners
                
                	Bidirectional PIM DF election winner table
                	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners>`
                
                .. attribute:: bsr
                
                	PIM BSR information
                	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr>`
                
                .. attribute:: context
                
                	PIM context information
                	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context>`
                
                .. attribute:: gre
                
                	GRE information
                	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre>`
                
                .. attribute:: group_map_match_rpfs
                
                	Find matching group\-mapping for the specified group address
                	**type**\:   :py:class:`GroupMapMatchRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs>`
                
                .. attribute:: group_map_match_sources
                
                	Find the matching group\-mapping with source information on specified group address
                	**type**\:   :py:class:`GroupMapMatchSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources>`
                
                .. attribute:: group_map_rpfs
                
                	PIM group mapping information
                	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs>`
                
                .. attribute:: group_map_sources
                
                	PIM group\-mapping with source information
                	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources>`
                
                .. attribute:: ifrs_interfaces
                
                	PIM interfaces in forward reference store table
                	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: ifrs_summary
                
                	PIM interfaces in forward reference store summary
                	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.IfrsSummary>`
                
                .. attribute:: interface_old_formats
                
                	PIM interfaces in old format
                	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats>`
                
                .. attribute:: interface_statistics
                
                	PIM interface statistics
                	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics>`
                
                .. attribute:: interfaces
                
                	PIM interfaces
                	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Interfaces>`
                
                .. attribute:: jp_statistics
                
                	PIM join prune statistics table
                	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics>`
                
                .. attribute:: mib_databases
                
                	PIM group database for mroute mibs table
                	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases>`
                
                .. attribute:: multicast_static_routes
                
                	PIM multicast static route table
                	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes>`
                
                .. attribute:: neighbor_old_formats
                
                	PIM neighbor table old format
                	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats>`
                
                .. attribute:: neighbor_summaries
                
                	PIM neighbor summary table
                	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries>`
                
                .. attribute:: neighbors
                
                	PIM neighbor table
                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Neighbors>`
                
                .. attribute:: net_io_tunnels
                
                	Tunnel information that NETIO has 
                	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels>`
                
                .. attribute:: ranges
                
                	PIM range list information
                	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges>`
                
                .. attribute:: route_policy
                
                	PIM route policy
                	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy>`
                
                .. attribute:: rpf_redirect
                
                	PIM ECMP RPF\-redirect bundle
                	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect>`
                
                .. attribute:: rpf_summary
                
                	PIM RPF registration summary
                	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfSummary>`
                
                .. attribute:: safs
                
                	SAFI table and type
                	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs>`
                
                .. attribute:: summary
                
                	PIM summary
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Summary>`
                
                .. attribute:: table_contexts
                
                	PIM table context list
                	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TableContexts>`
                
                .. attribute:: topologies
                
                	PIM topology table
                	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies>`
                
                .. attribute:: topology_entry_flag_route_counts
                
                	Route count for topology with entry flag set
                	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts>`
                
                .. attribute:: topology_interface_flag_route_counts
                
                	Route count for topology with interface flag set
                	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts>`
                
                .. attribute:: topology_route_count
                
                	Topology route count information from PIM topology table
                	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount>`
                
                .. attribute:: traffic_counters
                
                	PIM message traffic counters
                	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters>`
                
                .. attribute:: tunnels
                
                	Tunnels information that PIM has
                	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.vrf_name = None
                    self.auto_rp = Ipv6Pim.Standby.Vrfs.Vrf.AutoRp()
                    self.auto_rp.parent = self
                    self.bgp_afs = Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs()
                    self.bgp_afs.parent = self
                    self.bidir_df_states = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates()
                    self.bidir_df_states.parent = self
                    self.bidir_df_winners = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners()
                    self.bidir_df_winners.parent = self
                    self.bsr = Ipv6Pim.Standby.Vrfs.Vrf.Bsr()
                    self.bsr.parent = self
                    self.context = Ipv6Pim.Standby.Vrfs.Vrf.Context()
                    self.context.parent = self
                    self.gre = Ipv6Pim.Standby.Vrfs.Vrf.Gre()
                    self.gre.parent = self
                    self.group_map_match_rpfs = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs()
                    self.group_map_match_rpfs.parent = self
                    self.group_map_match_sources = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources()
                    self.group_map_match_sources.parent = self
                    self.group_map_rpfs = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs()
                    self.group_map_rpfs.parent = self
                    self.group_map_sources = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources()
                    self.group_map_sources.parent = self
                    self.ifrs_interfaces = Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self.ifrs_summary = Ipv6Pim.Standby.Vrfs.Vrf.IfrsSummary()
                    self.ifrs_summary.parent = self
                    self.interface_old_formats = Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats()
                    self.interface_old_formats.parent = self
                    self.interface_statistics = Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics()
                    self.interface_statistics.parent = self
                    self.interfaces = Ipv6Pim.Standby.Vrfs.Vrf.Interfaces()
                    self.interfaces.parent = self
                    self.jp_statistics = Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics()
                    self.jp_statistics.parent = self
                    self.mib_databases = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases()
                    self.mib_databases.parent = self
                    self.multicast_static_routes = Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes()
                    self.multicast_static_routes.parent = self
                    self.neighbor_old_formats = Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats()
                    self.neighbor_old_formats.parent = self
                    self.neighbor_summaries = Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries()
                    self.neighbor_summaries.parent = self
                    self.neighbors = Ipv6Pim.Standby.Vrfs.Vrf.Neighbors()
                    self.neighbors.parent = self
                    self.net_io_tunnels = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels()
                    self.net_io_tunnels.parent = self
                    self.ranges = Ipv6Pim.Standby.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self.route_policy = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy()
                    self.route_policy.parent = self
                    self.rpf_redirect = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect()
                    self.rpf_redirect.parent = self
                    self.rpf_summary = Ipv6Pim.Standby.Vrfs.Vrf.RpfSummary()
                    self.rpf_summary.parent = self
                    self.safs = Ipv6Pim.Standby.Vrfs.Vrf.Safs()
                    self.safs.parent = self
                    self.summary = Ipv6Pim.Standby.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self.table_contexts = Ipv6Pim.Standby.Vrfs.Vrf.TableContexts()
                    self.table_contexts.parent = self
                    self.topologies = Ipv6Pim.Standby.Vrfs.Vrf.Topologies()
                    self.topologies.parent = self
                    self.topology_entry_flag_route_counts = Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts()
                    self.topology_entry_flag_route_counts.parent = self
                    self.topology_interface_flag_route_counts = Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts()
                    self.topology_interface_flag_route_counts.parent = self
                    self.topology_route_count = Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount()
                    self.topology_route_count.parent = self
                    self.traffic_counters = Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self.tunnels = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels()
                    self.tunnels.parent = self


                class IfrsInterfaces(object):
                    """
                    PIM interfaces in forward reference store table
                    
                    .. attribute:: ifrs_interface
                    
                    	PIM IFRS interface information
                    	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ifrs_interface = YList()
                        self.ifrs_interface.parent = self
                        self.ifrs_interface.name = 'ifrs_interface'


                    class IfrsInterface(object):
                        """
                        PIM IFRS interface information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.configured_override_interval = None
                            self.configured_propagation_delay = None
                            self.dr_address = Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress()
                            self.dr_address.parent = self
                            self.dr_priority = None
                            self.external_neighbor_count = None
                            self.generation_id = None
                            self.hello_expiry = None
                            self.hello_interval = None
                            self.idb_acl_name = None
                            self.idb_acl_provided = None
                            self.idb_current_count = None
                            self.idb_max_count = None
                            self.idb_oor_enabled = None
                            self.idb_threshold_count = None
                            self.interface_address = YList()
                            self.interface_address.parent = self
                            self.interface_address.name = 'interface_address'
                            self.interface_address_mask = None
                            self.interface_name_xr = None
                            self.is_batch_asserts_capable = None
                            self.is_bidirectional_capable = None
                            self.is_enabled = None
                            self.is_proxy_capable = None
                            self.join_prune_interval = None
                            self.neighbor_count = None
                            self.neighbor_filter_name = None
                            self.override_interval = None
                            self.passive_interface = None
                            self.propagation_delay = None
                            self.prune_delay_enabled = None
                            self.virtual_interface = None


                        class DrAddress(object):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress']['meta_info']


                        class InterfaceAddress(object):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:ifrs-interface[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.are_we_dr is not None:
                                return True

                            if self.bfd_enabled is not None:
                                return True

                            if self.bfd_interval is not None:
                                return True

                            if self.bfd_multiplier is not None:
                                return True

                            if self.configured_override_interval is not None:
                                return True

                            if self.configured_propagation_delay is not None:
                                return True

                            if self.dr_address is not None and self.dr_address._has_data():
                                return True

                            if self.dr_priority is not None:
                                return True

                            if self.external_neighbor_count is not None:
                                return True

                            if self.generation_id is not None:
                                return True

                            if self.hello_expiry is not None:
                                return True

                            if self.hello_interval is not None:
                                return True

                            if self.idb_acl_name is not None:
                                return True

                            if self.idb_acl_provided is not None:
                                return True

                            if self.idb_current_count is not None:
                                return True

                            if self.idb_max_count is not None:
                                return True

                            if self.idb_oor_enabled is not None:
                                return True

                            if self.idb_threshold_count is not None:
                                return True

                            if self.interface_address is not None:
                                for child_ref in self.interface_address:
                                    if child_ref._has_data():
                                        return True

                            if self.interface_address_mask is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.is_batch_asserts_capable is not None:
                                return True

                            if self.is_bidirectional_capable is not None:
                                return True

                            if self.is_enabled is not None:
                                return True

                            if self.is_proxy_capable is not None:
                                return True

                            if self.join_prune_interval is not None:
                                return True

                            if self.neighbor_count is not None:
                                return True

                            if self.neighbor_filter_name is not None:
                                return True

                            if self.override_interval is not None:
                                return True

                            if self.passive_interface is not None:
                                return True

                            if self.propagation_delay is not None:
                                return True

                            if self.prune_delay_enabled is not None:
                                return True

                            if self.virtual_interface is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:ifrs-interfaces'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ifrs_interface is not None:
                            for child_ref in self.ifrs_interface:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces']['meta_info']


                class Safs(object):
                    """
                    SAFI table and type
                    
                    .. attribute:: saf
                    
                    	SAF name 
                    	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.saf = YList()
                        self.saf.parent = self
                        self.saf.name = 'saf'


                    class Saf(object):
                        """
                        SAF name 
                        
                        .. attribute:: rpf_hash_source_groups
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups>`
                        
                        .. attribute:: rpf_hash_sources
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources>`
                        
                        .. attribute:: rpfs
                        
                        	PIM RPF information table
                        	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs>`
                        
                        .. attribute:: saf_name
                        
                        	SAF name 
                        	**type**\:   :py:class:`PimSafiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafiEnum>`
                        
                        .. attribute:: topology_name
                        
                        	Topology name 
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rpf_hash_source_groups = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups()
                            self.rpf_hash_source_groups.parent = self
                            self.rpf_hash_sources = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources()
                            self.rpf_hash_sources.parent = self
                            self.rpfs = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs()
                            self.rpfs.parent = self
                            self.saf_name = None
                            self.topology_name = None


                        class RpfHashSourceGroups(object):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source_group
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.rpf_hash_source_group = YList()
                                self.rpf_hash_source_group.parent = self
                                self.rpf_hash_source_group.name = 'rpf_hash_source_group'


                            class RpfHashSourceGroup(object):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: group_address
                                
                                	Group address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: mask_length
                                
                                	Hash mask length
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.group_address = None
                                    self.mask_length = None
                                    self.mofrr = None
                                    self.next_hop_address = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self.next_hop_interface = None
                                    self.next_hop_multipath_enabled = None
                                    self.secondary_next_hop_address = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self.secondary_next_hop_interface = None
                                    self.source_address = None


                                class NextHopAddress(object):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:next-hop-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress']['meta_info']


                                class SecondaryNextHopAddress(object):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:secondary-next-hop-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-group'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.group_address is not None:
                                        return True

                                    if self.mask_length is not None:
                                        return True

                                    if self.mofrr is not None:
                                        return True

                                    if self.next_hop_address is not None and self.next_hop_address._has_data():
                                        return True

                                    if self.next_hop_interface is not None:
                                        return True

                                    if self.next_hop_multipath_enabled is not None:
                                        return True

                                    if self.secondary_next_hop_address is not None and self.secondary_next_hop_address._has_data():
                                        return True

                                    if self.secondary_next_hop_interface is not None:
                                        return True

                                    if self.source_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-groups'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.rpf_hash_source_group is not None:
                                    for child_ref in self.rpf_hash_source_group:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups']['meta_info']


                        class RpfHashSources(object):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.rpf_hash_source = YList()
                                self.rpf_hash_source.parent = self
                                self.rpf_hash_source.name = 'rpf_hash_source'


                            class RpfHashSource(object):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mofrr = None
                                    self.next_hop_address = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self.next_hop_interface = None
                                    self.next_hop_multipath_enabled = None
                                    self.secondary_next_hop_address = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self.secondary_next_hop_interface = None
                                    self.source_address = None


                                class NextHopAddress(object):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:next-hop-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress']['meta_info']


                                class SecondaryNextHopAddress(object):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:secondary-next-hop-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mofrr is not None:
                                        return True

                                    if self.next_hop_address is not None and self.next_hop_address._has_data():
                                        return True

                                    if self.next_hop_interface is not None:
                                        return True

                                    if self.next_hop_multipath_enabled is not None:
                                        return True

                                    if self.secondary_next_hop_address is not None and self.secondary_next_hop_address._has_data():
                                        return True

                                    if self.secondary_next_hop_interface is not None:
                                        return True

                                    if self.source_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-sources'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.rpf_hash_source is not None:
                                    for child_ref in self.rpf_hash_source:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources']['meta_info']


                        class Rpfs(object):
                            """
                            PIM RPF information table
                            
                            .. attribute:: rpf
                            
                            	PIM RPF information
                            	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.rpf = YList()
                                self.rpf.parent = self
                                self.rpf.name = 'rpf'


                            class Rpf(object):
                                """
                                PIM RPF information
                                
                                .. attribute:: registered_address  <key>
                                
                                	Address for which RPF lookup
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: is_connected
                                
                                	Are we connected ?
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_rpf_bgp_route
                                
                                	Is RPF through BGP route
                                	**type**\:  bool
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_preference
                                
                                	Metric preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: registered_address_xr
                                
                                	Address registered
                                	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                                
                                .. attribute:: rpf_path
                                
                                	RPF Paths list
                                	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.registered_address = None
                                    self.is_connected = None
                                    self.is_rpf_bgp_route = None
                                    self.metric = None
                                    self.metric_preference = None
                                    self.registered_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                    self.registered_address_xr.parent = self
                                    self.rpf_path = YList()
                                    self.rpf_path.parent = self
                                    self.rpf_path.name = 'rpf_path'


                                class RegisteredAddressXr(object):
                                    """
                                    Address registered
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:registered-address-xr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr']['meta_info']


                                class RpfPath(object):
                                    """
                                    RPF Paths list
                                    
                                    .. attribute:: connector
                                    
                                    	Connector Attribute
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: extranet_vrf_name
                                    
                                    	Extranet VRF name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    .. attribute:: is_connector_attribute_present
                                    
                                    	Connector attribute present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rpf_interface_disabled
                                    
                                    	Is the rpf interface disabled ?
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_lsm
                                    
                                    	Via LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_mlsm
                                    
                                    	Via Mstatic LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpf_interface_name
                                    
                                    	RPF Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: rpf_neighbor
                                    
                                    	RPF neighbor
                                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                    
                                    .. attribute:: rpf_nexthop
                                    
                                    	RPF nexthop
                                    	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.connector = None
                                        self.extranet_vrf_name = None
                                        self.is_connector_attribute_present = None
                                        self.is_rpf_interface_disabled = None
                                        self.is_via_lsm = None
                                        self.is_via_mlsm = None
                                        self.rpf_interface_name = None
                                        self.rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                        self.rpf_neighbor.parent = self
                                        self.rpf_nexthop = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                        self.rpf_nexthop.parent = self


                                    class RpfNeighbor(object):
                                        """
                                        RPF neighbor
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor']['meta_info']


                                    class RpfNexthop(object):
                                        """
                                        RPF nexthop
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-nexthop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.connector is not None:
                                            return True

                                        if self.extranet_vrf_name is not None:
                                            return True

                                        if self.is_connector_attribute_present is not None:
                                            return True

                                        if self.is_rpf_interface_disabled is not None:
                                            return True

                                        if self.is_via_lsm is not None:
                                            return True

                                        if self.is_via_mlsm is not None:
                                            return True

                                        if self.rpf_interface_name is not None:
                                            return True

                                        if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                            return True

                                        if self.rpf_nexthop is not None and self.rpf_nexthop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.registered_address is None:
                                        raise YPYModelError('Key property registered_address is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf[Cisco-IOS-XR-ipv4-pim-oper:registered-address = ' + str(self.registered_address) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.registered_address is not None:
                                        return True

                                    if self.is_connected is not None:
                                        return True

                                    if self.is_rpf_bgp_route is not None:
                                        return True

                                    if self.metric is not None:
                                        return True

                                    if self.metric_preference is not None:
                                        return True

                                    if self.registered_address_xr is not None and self.registered_address_xr._has_data():
                                        return True

                                    if self.rpf_path is not None:
                                        for child_ref in self.rpf_path:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpfs'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.rpf is not None:
                                    for child_ref in self.rpf:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:saf'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups._has_data():
                                return True

                            if self.rpf_hash_sources is not None and self.rpf_hash_sources._has_data():
                                return True

                            if self.rpfs is not None and self.rpfs._has_data():
                                return True

                            if self.saf_name is not None:
                                return True

                            if self.topology_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:safs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.saf is not None:
                            for child_ref in self.saf:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Safs']['meta_info']


                class InterfaceStatistics(object):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_statistic
                    
                    	PIM interface statistics
                    	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_statistic = YList()
                        self.interface_statistic.parent = self
                        self.interface_statistic.name = 'interface_statistic'


                    class InterfaceStatistic(object):
                        """
                        PIM interface statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: input_assert
                        
                        	Assert packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_bsr_message
                        
                        	Input BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_candidate_rp_advertisement
                        
                        	Input Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_df_election
                        
                        	DF Election packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_ack_message
                        
                        	Input Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_message
                        
                        	Input Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_hello
                        
                        	Hello packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_jp
                        
                        	Join Prune packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_miscellaneous
                        
                        	Miscellaneous packet in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register
                        
                        	Register packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register_stop
                        
                        	Register Stop packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_assert
                        
                        	Assert packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_bsr_message
                        
                        	Output BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_candidate_rp_advertisement
                        
                        	Output Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_df_election
                        
                        	DF Election packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_ack_message
                        
                        	Output Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_message
                        
                        	Output Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_hello
                        
                        	Hello packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_jp
                        
                        	Join Prune packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register
                        
                        	Register packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register_stop
                        
                        	Register Stop packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.input_assert = None
                            self.input_bsr_message = None
                            self.input_candidate_rp_advertisement = None
                            self.input_df_election = None
                            self.input_graft_ack_message = None
                            self.input_graft_message = None
                            self.input_hello = None
                            self.input_jp = None
                            self.input_miscellaneous = None
                            self.input_register = None
                            self.input_register_stop = None
                            self.output_assert = None
                            self.output_bsr_message = None
                            self.output_candidate_rp_advertisement = None
                            self.output_df_election = None
                            self.output_graft_ack_message = None
                            self.output_graft_message = None
                            self.output_hello = None
                            self.output_jp = None
                            self.output_register = None
                            self.output_register_stop = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-statistic[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.input_assert is not None:
                                return True

                            if self.input_bsr_message is not None:
                                return True

                            if self.input_candidate_rp_advertisement is not None:
                                return True

                            if self.input_df_election is not None:
                                return True

                            if self.input_graft_ack_message is not None:
                                return True

                            if self.input_graft_message is not None:
                                return True

                            if self.input_hello is not None:
                                return True

                            if self.input_jp is not None:
                                return True

                            if self.input_miscellaneous is not None:
                                return True

                            if self.input_register is not None:
                                return True

                            if self.input_register_stop is not None:
                                return True

                            if self.output_assert is not None:
                                return True

                            if self.output_bsr_message is not None:
                                return True

                            if self.output_candidate_rp_advertisement is not None:
                                return True

                            if self.output_df_election is not None:
                                return True

                            if self.output_graft_ack_message is not None:
                                return True

                            if self.output_graft_message is not None:
                                return True

                            if self.output_hello is not None:
                                return True

                            if self.output_jp is not None:
                                return True

                            if self.output_register is not None:
                                return True

                            if self.output_register_stop is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-statistics'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_statistic is not None:
                            for child_ref in self.interface_statistic:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics']['meta_info']


                class TopologyRouteCount(object):
                    """
                    Topology route count information from PIM
                    topology table
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.active_group_ranges = None
                        self.group_address = Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self.group_ranges = None
                        self.groute_count = None
                        self.is_node_low_memory = None
                        self.sg_route_count = None
                        self.sgr_route_count = None


                    class GroupAddress(object):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount.GroupAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology-route-count'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.active_group_ranges is not None:
                            return True

                        if self.group_address is not None and self.group_address._has_data():
                            return True

                        if self.group_ranges is not None:
                            return True

                        if self.groute_count is not None:
                            return True

                        if self.is_node_low_memory is not None:
                            return True

                        if self.sg_route_count is not None:
                            return True

                        if self.sgr_route_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount']['meta_info']


                class JpStatistics(object):
                    """
                    PIM join prune statistics table
                    
                    .. attribute:: jp_statistic
                    
                    	PIM Join Prune Statistics
                    	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.jp_statistic = YList()
                        self.jp_statistic.parent = self
                        self.jp_statistic.name = 'jp_statistic'


                    class JpStatistic(object):
                        """
                        PIM Join Prune Statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received
                        
                        	Received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received100
                        
                        	Received 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_10k
                        
                        	Received 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_1k
                        
                        	Received 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_50k
                        
                        	Deprecated by Received100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted
                        
                        	Transmitted
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transmitted100
                        
                        	Transmitted 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_10k
                        
                        	Transmitted 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_1k
                        
                        	Transmitted 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_50k
                        
                        	Deprecated by Transmitted100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.mtu = None
                            self.received = None
                            self.received100 = None
                            self.received_10k = None
                            self.received_1k = None
                            self.received_50k = None
                            self.transmitted = None
                            self.transmitted100 = None
                            self.transmitted_10k = None
                            self.transmitted_1k = None
                            self.transmitted_50k = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:jp-statistic[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.mtu is not None:
                                return True

                            if self.received is not None:
                                return True

                            if self.received100 is not None:
                                return True

                            if self.received_10k is not None:
                                return True

                            if self.received_1k is not None:
                                return True

                            if self.received_50k is not None:
                                return True

                            if self.transmitted is not None:
                                return True

                            if self.transmitted100 is not None:
                                return True

                            if self.transmitted_10k is not None:
                                return True

                            if self.transmitted_1k is not None:
                                return True

                            if self.transmitted_50k is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:jp-statistics'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.jp_statistic is not None:
                            for child_ref in self.jp_statistic:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics']['meta_info']


                class MibDatabases(object):
                    """
                    PIM group database for mroute mibs table
                    
                    .. attribute:: mib_database
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.mib_database = YList()
                        self.mib_database.parent = self
                        self.mib_database.name = 'mib_database'


                    class MibDatabase(object):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: assert_metric
                        
                        	Assert Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_metric_preference
                        
                        	Assert Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_rpt_bit
                        
                        	Assert RPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: bidirectional_route
                        
                        	Is this Bidir ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Multicast satic route group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr>`
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface name 
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_mask
                        
                        	Mask of the multicast root
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rpf_neighbor
                        
                        	The RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor>`
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: source_address
                        
                        	Multicast static route source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr>`
                        
                        .. attribute:: source_netmask
                        
                        	Source mask
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: spt_bit
                        
                        	Is SPT bit set ?
                        	**type**\:  bool
                        
                        .. attribute:: upstream_assert_timer
                        
                        	Upstream Assert Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime of route
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.assert_metric = None
                            self.assert_metric_preference = None
                            self.assert_rpt_bit = None
                            self.bidirectional_route = None
                            self.group_address = None
                            self.group_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self.protocol = None
                            self.rpf_drop = None
                            self.rpf_extranet = None
                            self.rpf_interface_name = None
                            self.rpf_mask = None
                            self.rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self.rpf_root = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot()
                            self.rpf_root.parent = self
                            self.rpf_safi = None
                            self.rpf_table_name = None
                            self.rpf_vrf_name = None
                            self.source_address = None
                            self.source_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self.source_netmask = None
                            self.spt_bit = None
                            self.upstream_assert_timer = None
                            self.uptime = None


                        class SourceAddressXr(object):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr']['meta_info']


                        class GroupAddressXr(object):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr']['meta_info']


                        class RpfNeighbor(object):
                            """
                            The RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor']['meta_info']


                        class RpfRoot(object):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-root'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:mib-database'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.assert_metric is not None:
                                return True

                            if self.assert_metric_preference is not None:
                                return True

                            if self.assert_rpt_bit is not None:
                                return True

                            if self.bidirectional_route is not None:
                                return True

                            if self.group_address is not None:
                                return True

                            if self.group_address_xr is not None and self.group_address_xr._has_data():
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rpf_drop is not None:
                                return True

                            if self.rpf_extranet is not None:
                                return True

                            if self.rpf_interface_name is not None:
                                return True

                            if self.rpf_mask is not None:
                                return True

                            if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                return True

                            if self.rpf_root is not None and self.rpf_root._has_data():
                                return True

                            if self.rpf_safi is not None:
                                return True

                            if self.rpf_table_name is not None:
                                return True

                            if self.rpf_vrf_name is not None:
                                return True

                            if self.source_address is not None:
                                return True

                            if self.source_address_xr is not None and self.source_address_xr._has_data():
                                return True

                            if self.source_netmask is not None:
                                return True

                            if self.spt_bit is not None:
                                return True

                            if self.upstream_assert_timer is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:mib-databases'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.mib_database is not None:
                            for child_ref in self.mib_database:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases']['meta_info']


                class GroupMapMatchRpfs(object):
                    """
                    Find matching group\-mapping for the specified
                    group address
                    
                    .. attribute:: group_map_match_rpf
                    
                    	PIM group matching mapping entry
                    	**type**\: list of    :py:class:`GroupMapMatchRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_map_match_rpf = YList()
                        self.group_map_match_rpf.parent = self
                        self.group_map_match_rpf.name = 'group_map_match_rpf'


                    class GroupMapMatchRpf(object):
                        """
                        PIM group matching mapping entry
                        
                        .. attribute:: group_address  <key>
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\:  bool
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation>`
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor>`
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.group_address = None
                            self.are_we_rp = None
                            self.group_map_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self.rpf_interface_name = None
                            self.rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self.rpf_vrf_name = None


                        class RpfNeighbor(object):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor']['meta_info']


                        class GroupMapInformation(object):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.client = None
                                self.group_count = None
                                self.is_override = None
                                self.is_used = None
                                self.mrib_active = None
                                self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self.prefix_length = None
                                self.priority = None
                                self.protocol = None
                                self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self


                            class Prefix(object):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix']['meta_info']


                            class RpAddress(object):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.client is not None:
                                    return True

                                if self.group_count is not None:
                                    return True

                                if self.is_override is not None:
                                    return True

                                if self.is_used is not None:
                                    return True

                                if self.mrib_active is not None:
                                    return True

                                if self.prefix is not None and self.prefix._has_data():
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.priority is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.rp_address is not None and self.rp_address._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.group_address is None:
                                raise YPYModelError('Key property group_address is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-rpf[Cisco-IOS-XR-ipv4-pim-oper:group-address = ' + str(self.group_address) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.group_address is not None:
                                return True

                            if self.are_we_rp is not None:
                                return True

                            if self.group_map_information is not None and self.group_map_information._has_data():
                                return True

                            if self.rpf_interface_name is not None:
                                return True

                            if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                return True

                            if self.rpf_vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-rpfs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_map_match_rpf is not None:
                            for child_ref in self.group_map_match_rpf:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs']['meta_info']


                class NeighborOldFormats(object):
                    """
                    PIM neighbor table old format
                    
                    .. attribute:: neighbor_old_format
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.neighbor_old_format = YList()
                        self.neighbor_old_format.parent = self
                        self.neighbor_old_format.name = 'neighbor_old_format'


                    class NeighborOldFormat(object):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dr_priority = None
                            self.expires = None
                            self.expiry_timer = None
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.is_batch_asserts_capable = None
                            self.is_bfd_state = None
                            self.is_bidirectional_capable = None
                            self.is_dr_priority_capable = None
                            self.is_ecmp_redirect_capable = None
                            self.is_proxy_capable = None
                            self.is_this_neighbor_dr = None
                            self.is_this_neighbor_us = None
                            self.neighbor_address = None
                            self.neighbor_address_xr = YList()
                            self.neighbor_address_xr.parent = self
                            self.neighbor_address_xr.name = 'neighbor_address_xr'
                            self.override_interval = None
                            self.propagation_delay = None
                            self.uptime = None


                        class NeighborAddressXr(object):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-format'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dr_priority is not None:
                                return True

                            if self.expires is not None:
                                return True

                            if self.expiry_timer is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.is_batch_asserts_capable is not None:
                                return True

                            if self.is_bfd_state is not None:
                                return True

                            if self.is_bidirectional_capable is not None:
                                return True

                            if self.is_dr_priority_capable is not None:
                                return True

                            if self.is_ecmp_redirect_capable is not None:
                                return True

                            if self.is_proxy_capable is not None:
                                return True

                            if self.is_this_neighbor_dr is not None:
                                return True

                            if self.is_this_neighbor_us is not None:
                                return True

                            if self.neighbor_address is not None:
                                return True

                            if self.neighbor_address_xr is not None:
                                for child_ref in self.neighbor_address_xr:
                                    if child_ref._has_data():
                                        return True

                            if self.override_interval is not None:
                                return True

                            if self.propagation_delay is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-formats'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.neighbor_old_format is not None:
                            for child_ref in self.neighbor_old_format:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats']['meta_info']


                class IfrsSummary(object):
                    """
                    PIM interfaces in forward reference store
                    summary
                    
                    .. attribute:: configuration_count
                    
                    	Configuration counts
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Number of interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.configuration_count = None
                        self.interface_count = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:ifrs-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.configuration_count is not None:
                            return True

                        if self.interface_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.IfrsSummary']['meta_info']


                class Ranges(object):
                    """
                    PIM range list information
                    
                    .. attribute:: range
                    
                    	PIM range list information
                    	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.range = YList()
                        self.range.parent = self
                        self.range.name = 'range'


                    class Range(object):
                        """
                        PIM range list information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                        
                        .. attribute:: client_xr
                        
                        	Client mapping learnt via
                        	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: group_range
                        
                        	List of group ranges
                        	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange>`
                        
                        .. attribute:: protocol
                        
                        	PIM protocol
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	Rendezvous point address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr>`
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.client_xr = None
                            self.expires = None
                            self.group_range = YList()
                            self.group_range.parent = self
                            self.group_range.name = 'group_range'
                            self.protocol = None
                            self.rp_address = None
                            self.rp_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self.source_of_information = Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation()
                            self.source_of_information.parent = self


                        class RpAddressXr(object):
                            """
                            Rendezvous point address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr']['meta_info']


                        class SourceOfInformation(object):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation']['meta_info']


                        class GroupRange(object):
                            """
                            List of group ranges
                            
                            .. attribute:: expires
                            
                            	When mapping expires
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: source_of_information
                            
                            	Source of information
                            	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.expires = None
                                self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix()
                                self.prefix.parent = self
                                self.prefix_length = None
                                self.source_of_information = Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation()
                                self.source_of_information.parent = self
                                self.uptime = None


                            class Prefix(object):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix']['meta_info']


                            class SourceOfInformation(object):
                                """
                                Source of information
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-range'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.expires is not None:
                                    return True

                                if self.prefix is not None and self.prefix._has_data():
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.source_of_information is not None and self.source_of_information._has_data():
                                    return True

                                if self.uptime is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:range'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.client_xr is not None:
                                return True

                            if self.expires is not None:
                                return True

                            if self.group_range is not None:
                                for child_ref in self.group_range:
                                    if child_ref._has_data():
                                        return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None:
                                return True

                            if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                                return True

                            if self.source_of_information is not None and self.source_of_information._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:ranges'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.range is not None:
                            for child_ref in self.range:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Ranges']['meta_info']


                class InterfaceOldFormats(object):
                    """
                    PIM interfaces in old format
                    
                    .. attribute:: interface_old_format
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_old_format = YList()
                        self.interface_old_format.parent = self
                        self.interface_old_format.name = 'interface_old_format'


                    class InterfaceOldFormat(object):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.configured_override_interval = None
                            self.configured_propagation_delay = None
                            self.dr_address = Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                            self.dr_address.parent = self
                            self.dr_priority = None
                            self.external_neighbor_count = None
                            self.generation_id = None
                            self.hello_expiry = None
                            self.hello_interval = None
                            self.idb_acl_name = None
                            self.idb_acl_provided = None
                            self.idb_current_count = None
                            self.idb_max_count = None
                            self.idb_oor_enabled = None
                            self.idb_threshold_count = None
                            self.interface_address = YList()
                            self.interface_address.parent = self
                            self.interface_address.name = 'interface_address'
                            self.interface_address_mask = None
                            self.interface_name_xr = None
                            self.is_batch_asserts_capable = None
                            self.is_bidirectional_capable = None
                            self.is_enabled = None
                            self.is_proxy_capable = None
                            self.join_prune_interval = None
                            self.neighbor_count = None
                            self.neighbor_filter_name = None
                            self.override_interval = None
                            self.passive_interface = None
                            self.propagation_delay = None
                            self.prune_delay_enabled = None
                            self.virtual_interface = None


                        class DrAddress(object):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress']['meta_info']


                        class InterfaceAddress(object):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-old-format[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.are_we_dr is not None:
                                return True

                            if self.bfd_enabled is not None:
                                return True

                            if self.bfd_interval is not None:
                                return True

                            if self.bfd_multiplier is not None:
                                return True

                            if self.configured_override_interval is not None:
                                return True

                            if self.configured_propagation_delay is not None:
                                return True

                            if self.dr_address is not None and self.dr_address._has_data():
                                return True

                            if self.dr_priority is not None:
                                return True

                            if self.external_neighbor_count is not None:
                                return True

                            if self.generation_id is not None:
                                return True

                            if self.hello_expiry is not None:
                                return True

                            if self.hello_interval is not None:
                                return True

                            if self.idb_acl_name is not None:
                                return True

                            if self.idb_acl_provided is not None:
                                return True

                            if self.idb_current_count is not None:
                                return True

                            if self.idb_max_count is not None:
                                return True

                            if self.idb_oor_enabled is not None:
                                return True

                            if self.idb_threshold_count is not None:
                                return True

                            if self.interface_address is not None:
                                for child_ref in self.interface_address:
                                    if child_ref._has_data():
                                        return True

                            if self.interface_address_mask is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.is_batch_asserts_capable is not None:
                                return True

                            if self.is_bidirectional_capable is not None:
                                return True

                            if self.is_enabled is not None:
                                return True

                            if self.is_proxy_capable is not None:
                                return True

                            if self.join_prune_interval is not None:
                                return True

                            if self.neighbor_count is not None:
                                return True

                            if self.neighbor_filter_name is not None:
                                return True

                            if self.override_interval is not None:
                                return True

                            if self.passive_interface is not None:
                                return True

                            if self.propagation_delay is not None:
                                return True

                            if self.prune_delay_enabled is not None:
                                return True

                            if self.virtual_interface is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-old-formats'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_old_format is not None:
                            for child_ref in self.interface_old_format:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats']['meta_info']


                class Bsr(object):
                    """
                    PIM BSR information
                    
                    .. attribute:: bsr_elections
                    
                    	PIM BSR election state
                    	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections>`
                    
                    .. attribute:: candidate_rps
                    
                    	PIM candidate\-RP
                    	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps>`
                    
                    .. attribute:: rp_caches
                    
                    	PIM BSR RP cache table
                    	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bsr_elections = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections()
                        self.bsr_elections.parent = self
                        self.candidate_rps = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps()
                        self.candidate_rps.parent = self
                        self.rp_caches = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches()
                        self.rp_caches.parent = self


                    class RpCaches(object):
                        """
                        PIM BSR RP cache table
                        
                        .. attribute:: rp_cache
                        
                        	PIM BSR RP cache
                        	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rp_cache = YList()
                            self.rp_cache.parent = self
                            self.rp_cache.name = 'rp_cache'


                        class RpCache(object):
                            """
                            PIM BSR RP cache
                            
                            .. attribute:: group_prefix  <key>
                            
                            	Group prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: candidate_rp_group_count
                            
                            	C\-RP count for this Prefix
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: candidate_rp_list
                            
                            	C\-RP list for this prefix
                            	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList>`
                            
                            .. attribute:: group_prefix_length
                            
                            	Group Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_prefix_xr
                            
                            	Group Prefix
                            	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.group_prefix = None
                                self.candidate_rp_group_count = None
                                self.candidate_rp_list = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList()
                                self.candidate_rp_list.parent = self
                                self.group_prefix_length = None
                                self.group_prefix_xr = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                self.group_prefix_xr.parent = self


                            class GroupPrefixXr(object):
                                """
                                Group Prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-prefix-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr']['meta_info']


                            class CandidateRpList(object):
                                """
                                C\-RP list for this prefix
                                
                                .. attribute:: pim_bsr_crp_bag
                                
                                	pim bsr crp bag
                                	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.pim_bsr_crp_bag = YList()
                                    self.pim_bsr_crp_bag.parent = self
                                    self.pim_bsr_crp_bag.name = 'pim_bsr_crp_bag'


                                class PimBsrCrpBag(object):
                                    """
                                    pim bsr crp bag
                                    
                                    .. attribute:: candidate_rp_address
                                    
                                    	C\-RP address
                                    	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                    
                                    .. attribute:: candidate_rp_expires
                                    
                                    	C\-RP Expires
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_holdtime
                                    
                                    	C\-RP Holdtime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_priority
                                    
                                    	C\-RP Priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: candidate_rp_up_time
                                    
                                    	C\-RP Uptime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: protocol
                                    
                                    	PIM Protocol
                                    	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.candidate_rp_address = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                        self.candidate_rp_address.parent = self
                                        self.candidate_rp_expires = None
                                        self.candidate_rp_holdtime = None
                                        self.candidate_rp_priority = None
                                        self.candidate_rp_up_time = None
                                        self.protocol = None


                                    class CandidateRpAddress(object):
                                        """
                                        C\-RP address
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:pim-bsr-crp-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.candidate_rp_address is not None and self.candidate_rp_address._has_data():
                                            return True

                                        if self.candidate_rp_expires is not None:
                                            return True

                                        if self.candidate_rp_holdtime is not None:
                                            return True

                                        if self.candidate_rp_priority is not None:
                                            return True

                                        if self.candidate_rp_up_time is not None:
                                            return True

                                        if self.protocol is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp-list'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.pim_bsr_crp_bag is not None:
                                        for child_ref in self.pim_bsr_crp_bag:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.group_prefix is None:
                                    raise YPYModelError('Key property group_prefix is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-cache[Cisco-IOS-XR-ipv4-pim-oper:group-prefix = ' + str(self.group_prefix) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.group_prefix is not None:
                                    return True

                                if self.candidate_rp_group_count is not None:
                                    return True

                                if self.candidate_rp_list is not None and self.candidate_rp_list._has_data():
                                    return True

                                if self.group_prefix_length is not None:
                                    return True

                                if self.group_prefix_xr is not None and self.group_prefix_xr._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-caches'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rp_cache is not None:
                                for child_ref in self.rp_cache:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches']['meta_info']


                    class CandidateRps(object):
                        """
                        PIM candidate\-RP
                        
                        .. attribute:: candidate_rp
                        
                        	PIM BSR candidate RP information
                        	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.candidate_rp = YList()
                            self.candidate_rp.parent = self
                            self.candidate_rp.name = 'candidate_rp'


                        class CandidateRp(object):
                            """
                            PIM BSR candidate RP information
                            
                            .. attribute:: rp_address  <key>
                            
                            	Candidate\-RP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp
                            
                            	Cand\-RP Address
                            	**type**\:   :py:class:`CandidateRp_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_>`
                            
                            .. attribute:: candidate_rp_advance_interval
                            
                            	Cand\-RP Adv Interval in seconds
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            .. attribute:: candidate_rp_scope
                            
                            	Cand\-RP Scope
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: candidate_rp_uptime
                            
                            	Cand\-RP uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_access
                            
                            	Group Ranges Using this Cand\-RP
                            	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                            
                            .. attribute:: crp_holdtime
                            
                            	Cand\-RP Holdtime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_priority
                            
                            	Cand\-RP Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.rp_address = None
                                self.acl_name = None
                                self.candidate_rp = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_()
                                self.candidate_rp.parent = self
                                self.candidate_rp_advance_interval = None
                                self.candidate_rp_mode = None
                                self.candidate_rp_scope = None
                                self.candidate_rp_uptime = None
                                self.crp_access = YList()
                                self.crp_access.parent = self
                                self.crp_access.name = 'crp_access'
                                self.crp_holdtime = None
                                self.crp_priority = None


                            class CandidateRp_(object):
                                """
                                Cand\-RP Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_']['meta_info']


                            class CrpAccess(object):
                                """
                                Group Ranges Using this Cand\-RP
                                
                                .. attribute:: acl_name
                                
                                	Group Access\-List Name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: candidate_rp_mode
                                
                                	Cand\-RP Mode
                                	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.acl_name = None
                                    self.candidate_rp_mode = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:crp-access'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.acl_name is not None:
                                        return True

                                    if self.candidate_rp_mode is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.rp_address is None:
                                    raise YPYModelError('Key property rp_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp[Cisco-IOS-XR-ipv4-pim-oper:rp-address = ' + str(self.rp_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.rp_address is not None:
                                    return True

                                if self.acl_name is not None:
                                    return True

                                if self.candidate_rp is not None and self.candidate_rp._has_data():
                                    return True

                                if self.candidate_rp_advance_interval is not None:
                                    return True

                                if self.candidate_rp_mode is not None:
                                    return True

                                if self.candidate_rp_scope is not None:
                                    return True

                                if self.candidate_rp_uptime is not None:
                                    return True

                                if self.crp_access is not None:
                                    for child_ref in self.crp_access:
                                        if child_ref._has_data():
                                            return True

                                if self.crp_holdtime is not None:
                                    return True

                                if self.crp_priority is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rps'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.candidate_rp is not None:
                                for child_ref in self.candidate_rp:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps']['meta_info']


                    class BsrElections(object):
                        """
                        PIM BSR election state
                        
                        .. attribute:: bsr_election
                        
                        	PIM BSR information
                        	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bsr_election = YList()
                            self.bsr_election.parent = self
                            self.bsr_election.name = 'bsr_election'


                        class BsrElection(object):
                            """
                            PIM BSR information
                            
                            .. attribute:: pim_scope  <key>
                            
                            	BSR information
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: bootstrap_timeout
                            
                            	Bootstrap Timeout
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_address
                            
                            	BSR address
                            	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress>`
                            
                            .. attribute:: bsr_election_state
                            
                            	BSR Election State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_mask_length
                            
                            	Hash Function Mask Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_priority
                            
                            	BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_scope
                            
                            	BSR Scope
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_up_time
                            
                            	BSR Uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_bsr_address
                            
                            	C\-BSR address
                            	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                            
                            .. attribute:: candidate_bsr_flag
                            
                            	BSR Candidate Config Flag
                            	**type**\:  bool
                            
                            .. attribute:: candidate_bsr_mask_length
                            
                            	C\-BSR Hash Func. Mask Len
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_priority
                            
                            	C\-BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_state
                            
                            	BSR Candidate State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pim_scope = None
                                self.bootstrap_timeout = None
                                self.bsr_address = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress()
                                self.bsr_address.parent = self
                                self.bsr_election_state = None
                                self.bsr_mask_length = None
                                self.bsr_priority = None
                                self.bsr_scope = None
                                self.bsr_up_time = None
                                self.candidate_bsr_address = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                self.candidate_bsr_address.parent = self
                                self.candidate_bsr_flag = None
                                self.candidate_bsr_mask_length = None
                                self.candidate_bsr_priority = None
                                self.candidate_bsr_state = None


                            class BsrAddress(object):
                                """
                                BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bsr-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress']['meta_info']


                            class CandidateBsrAddress(object):
                                """
                                C\-BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-bsr-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.pim_scope is None:
                                    raise YPYModelError('Key property pim_scope is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bsr-election[Cisco-IOS-XR-ipv4-pim-oper:pim-scope = ' + str(self.pim_scope) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pim_scope is not None:
                                    return True

                                if self.bootstrap_timeout is not None:
                                    return True

                                if self.bsr_address is not None and self.bsr_address._has_data():
                                    return True

                                if self.bsr_election_state is not None:
                                    return True

                                if self.bsr_mask_length is not None:
                                    return True

                                if self.bsr_priority is not None:
                                    return True

                                if self.bsr_scope is not None:
                                    return True

                                if self.bsr_up_time is not None:
                                    return True

                                if self.candidate_bsr_address is not None and self.candidate_bsr_address._has_data():
                                    return True

                                if self.candidate_bsr_flag is not None:
                                    return True

                                if self.candidate_bsr_mask_length is not None:
                                    return True

                                if self.candidate_bsr_priority is not None:
                                    return True

                                if self.candidate_bsr_state is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bsr-elections'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bsr_election is not None:
                                for child_ref in self.bsr_election:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bsr'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bsr_elections is not None and self.bsr_elections._has_data():
                            return True

                        if self.candidate_rps is not None and self.candidate_rps._has_data():
                            return True

                        if self.rp_caches is not None and self.rp_caches._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Bsr']['meta_info']


                class RoutePolicy(object):
                    """
                    PIM route policy
                    
                    .. attribute:: route_policy_statistics
                    
                    	PIM route policy statistics
                    	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics>`
                    
                    .. attribute:: route_policy_tests
                    
                    	PIM route policy test run table
                    	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.route_policy_statistics = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics()
                        self.route_policy_statistics.parent = self
                        self.route_policy_tests = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests()
                        self.route_policy_tests.parent = self


                    class RoutePolicyStatistics(object):
                        """
                        PIM route policy statistics
                        
                        .. attribute:: any_table
                        
                        	Number of RPF lookup in any Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Number of RPF lookup in default\-only Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: drop
                        
                        	Number of RPF drops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pass_
                        
                        	Number of RPF pass
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: requests
                        
                        	Number of RPF lookup requests
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.any_table = None
                            self.default_table = None
                            self.drop = None
                            self.pass_ = None
                            self.policy_name = None
                            self.requests = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:route-policy-statistics'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.any_table is not None:
                                return True

                            if self.default_table is not None:
                                return True

                            if self.drop is not None:
                                return True

                            if self.pass_ is not None:
                                return True

                            if self.policy_name is not None:
                                return True

                            if self.requests is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics']['meta_info']


                    class RoutePolicyTests(object):
                        """
                        PIM route policy test run table
                        
                        .. attribute:: route_policy_test
                        
                        	PIM route policy test run
                        	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.route_policy_test = YList()
                            self.route_policy_test.parent = self
                            self.route_policy_test.name = 'route_policy_test'


                        class RoutePolicyTest(object):
                            """
                            PIM route policy test run
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: default_table
                            
                            	Default table selected
                            	**type**\:  bool
                            
                            .. attribute:: ext_comm
                            
                            	Extended Community
                            	**type**\:  str
                            
                            	**length:** 1..8
                            
                            .. attribute:: extended_community_rt
                            
                            	Route Target
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: group_address
                            
                            	Group IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                            
                            .. attribute:: pass_
                            
                            	Pass
                            	**type**\:  bool
                            
                            .. attribute:: policy_name
                            
                            	RPF policy name
                            	**type**\:  str
                            
                            .. attribute:: safi
                            
                            	SAFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_address
                            
                            	Source IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                            
                            .. attribute:: table_active
                            
                            	Table active
                            	**type**\:  bool
                            
                            .. attribute:: table_exists
                            
                            	Table exists
                            	**type**\:  bool
                            
                            .. attribute:: table_name
                            
                            	Table name
                            	**type**\:  str
                            
                            .. attribute:: vrf_name
                            
                            	VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.afi = None
                                self.default_table = None
                                self.ext_comm = None
                                self.extended_community_rt = None
                                self.group_address = None
                                self.group_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self.pass_ = None
                                self.policy_name = None
                                self.safi = None
                                self.source_address = None
                                self.source_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self.table_active = None
                                self.table_exists = None
                                self.table_name = None
                                self.vrf_name = None


                            class SourceAddressXr(object):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr']['meta_info']


                            class GroupAddressXr(object):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:route-policy-test'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.afi is not None:
                                    return True

                                if self.default_table is not None:
                                    return True

                                if self.ext_comm is not None:
                                    return True

                                if self.extended_community_rt is not None:
                                    return True

                                if self.group_address is not None:
                                    return True

                                if self.group_address_xr is not None and self.group_address_xr._has_data():
                                    return True

                                if self.pass_ is not None:
                                    return True

                                if self.policy_name is not None:
                                    return True

                                if self.safi is not None:
                                    return True

                                if self.source_address is not None:
                                    return True

                                if self.source_address_xr is not None and self.source_address_xr._has_data():
                                    return True

                                if self.table_active is not None:
                                    return True

                                if self.table_exists is not None:
                                    return True

                                if self.table_name is not None:
                                    return True

                                if self.vrf_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:route-policy-tests'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.route_policy_test is not None:
                                for child_ref in self.route_policy_test:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:route-policy'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.route_policy_statistics is not None and self.route_policy_statistics._has_data():
                            return True

                        if self.route_policy_tests is not None and self.route_policy_tests._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy']['meta_info']


                class RpfSummary(object):
                    """
                    PIM RPF registration summary
                    
                    .. attribute:: default_safi
                    
                    	Default RPF Table SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table_name
                    
                    	Default RPF Table Name
                    	**type**\:  str
                    
                    .. attribute:: is_isis_mtr_configured
                    
                    	Is ISIS MTR configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_isis_te_configured
                    
                    	Is ISIS TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_mbgp_configured
                    
                    	Is MBGP configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_enabled
                    
                    	Is Multipath Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_interface_hash_enabled
                    
                    	Is Multipath Interface Hash Extension Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_hash_enabled
                    
                    	Is Multipath Source based Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_next_hop_hash_enabled
                    
                    	Is Multipath Source\-Nexthop Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ospf_te_configured
                    
                    	Is OSPF TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: mo_frr_configured
                    
                    	Is MoFRR configured?
                    	**type**\:  bool
                    
                    .. attribute:: rib_convergence_time_left
                    
                    	RIB convergence time left in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_convergence_timeout
                    
                    	RIB convergence timeout in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_mo_frr_configured
                    
                    	Is MoFRR RIB configured?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	Is RUMP MuRIB enabled?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.default_safi = None
                        self.default_table_name = None
                        self.is_isis_mtr_configured = None
                        self.is_isis_te_configured = None
                        self.is_mbgp_configured = None
                        self.is_multipath_enabled = None
                        self.is_multipath_interface_hash_enabled = None
                        self.is_multipath_source_hash_enabled = None
                        self.is_multipath_source_next_hop_hash_enabled = None
                        self.is_ospf_te_configured = None
                        self.is_rib_convergence = None
                        self.mo_frr_configured = None
                        self.rib_convergence_time_left = None
                        self.rib_convergence_timeout = None
                        self.rib_mo_frr_configured = None
                        self.rpf_registrations = None
                        self.rump_enabled = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.default_safi is not None:
                            return True

                        if self.default_table_name is not None:
                            return True

                        if self.is_isis_mtr_configured is not None:
                            return True

                        if self.is_isis_te_configured is not None:
                            return True

                        if self.is_mbgp_configured is not None:
                            return True

                        if self.is_multipath_enabled is not None:
                            return True

                        if self.is_multipath_interface_hash_enabled is not None:
                            return True

                        if self.is_multipath_source_hash_enabled is not None:
                            return True

                        if self.is_multipath_source_next_hop_hash_enabled is not None:
                            return True

                        if self.is_ospf_te_configured is not None:
                            return True

                        if self.is_rib_convergence is not None:
                            return True

                        if self.mo_frr_configured is not None:
                            return True

                        if self.rib_convergence_time_left is not None:
                            return True

                        if self.rib_convergence_timeout is not None:
                            return True

                        if self.rib_mo_frr_configured is not None:
                            return True

                        if self.rpf_registrations is not None:
                            return True

                        if self.rump_enabled is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.RpfSummary']['meta_info']


                class Interfaces(object):
                    """
                    PIM interfaces
                    
                    .. attribute:: interface
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface = YList()
                        self.interface.parent = self
                        self.interface.name = 'interface'


                    class Interface(object):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.configured_override_interval = None
                            self.configured_propagation_delay = None
                            self.dr_address = Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress()
                            self.dr_address.parent = self
                            self.dr_priority = None
                            self.external_neighbor_count = None
                            self.generation_id = None
                            self.hello_expiry = None
                            self.hello_interval = None
                            self.idb_acl_name = None
                            self.idb_acl_provided = None
                            self.idb_current_count = None
                            self.idb_max_count = None
                            self.idb_oor_enabled = None
                            self.idb_threshold_count = None
                            self.interface_address = YList()
                            self.interface_address.parent = self
                            self.interface_address.name = 'interface_address'
                            self.interface_address_mask = None
                            self.interface_name_xr = None
                            self.is_batch_asserts_capable = None
                            self.is_bidirectional_capable = None
                            self.is_enabled = None
                            self.is_proxy_capable = None
                            self.join_prune_interval = None
                            self.neighbor_count = None
                            self.neighbor_filter_name = None
                            self.override_interval = None
                            self.passive_interface = None
                            self.propagation_delay = None
                            self.prune_delay_enabled = None
                            self.virtual_interface = None


                        class DrAddress(object):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress']['meta_info']


                        class InterfaceAddress(object):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.are_we_dr is not None:
                                return True

                            if self.bfd_enabled is not None:
                                return True

                            if self.bfd_interval is not None:
                                return True

                            if self.bfd_multiplier is not None:
                                return True

                            if self.configured_override_interval is not None:
                                return True

                            if self.configured_propagation_delay is not None:
                                return True

                            if self.dr_address is not None and self.dr_address._has_data():
                                return True

                            if self.dr_priority is not None:
                                return True

                            if self.external_neighbor_count is not None:
                                return True

                            if self.generation_id is not None:
                                return True

                            if self.hello_expiry is not None:
                                return True

                            if self.hello_interval is not None:
                                return True

                            if self.idb_acl_name is not None:
                                return True

                            if self.idb_acl_provided is not None:
                                return True

                            if self.idb_current_count is not None:
                                return True

                            if self.idb_max_count is not None:
                                return True

                            if self.idb_oor_enabled is not None:
                                return True

                            if self.idb_threshold_count is not None:
                                return True

                            if self.interface_address is not None:
                                for child_ref in self.interface_address:
                                    if child_ref._has_data():
                                        return True

                            if self.interface_address_mask is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.is_batch_asserts_capable is not None:
                                return True

                            if self.is_bidirectional_capable is not None:
                                return True

                            if self.is_enabled is not None:
                                return True

                            if self.is_proxy_capable is not None:
                                return True

                            if self.join_prune_interval is not None:
                                return True

                            if self.neighbor_count is not None:
                                return True

                            if self.neighbor_filter_name is not None:
                                return True

                            if self.override_interval is not None:
                                return True

                            if self.passive_interface is not None:
                                return True

                            if self.propagation_delay is not None:
                                return True

                            if self.prune_delay_enabled is not None:
                                return True

                            if self.virtual_interface is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interfaces'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface is not None:
                            for child_ref in self.interface:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Interfaces']['meta_info']


                class NetIoTunnels(object):
                    """
                    Tunnel information that NETIO has 
                    
                    .. attribute:: net_io_tunnel
                    
                    	PIM netio tunnel information
                    	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.net_io_tunnel = YList()
                        self.net_io_tunnel.parent = self
                        self.net_io_tunnel.name = 'net_io_tunnel'


                    class NetIoTunnel(object):
                        """
                        PIM netio tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.tunnel_name = None
                            self.group_address_netio = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress()
                            self.rp_address.parent = self
                            self.source_address = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress()
                            self.source_address.parent = self
                            self.source_address_netio = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self.vrf_name = None


                        class SourceAddress(object):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress']['meta_info']


                        class RpAddress(object):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress']['meta_info']


                        class SourceAddressNetio(object):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-netio'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio']['meta_info']


                        class GroupAddressNetio(object):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-netio'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.tunnel_name is None:
                                raise YPYModelError('Key property tunnel_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:net-io-tunnel[Cisco-IOS-XR-ipv4-pim-oper:tunnel-name = ' + str(self.tunnel_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.tunnel_name is not None:
                                return True

                            if self.group_address_netio is not None and self.group_address_netio._has_data():
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            if self.source_address is not None and self.source_address._has_data():
                                return True

                            if self.source_address_netio is not None and self.source_address_netio._has_data():
                                return True

                            if self.vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:net-io-tunnels'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.net_io_tunnel is not None:
                            for child_ref in self.net_io_tunnel:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels']['meta_info']


                class BidirDfStates(object):
                    """
                    Bidirectional PIM DF election state table
                    
                    .. attribute:: bidir_df_state
                    
                    	Bidirectional PIM DF Election Table Entry
                    	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bidir_df_state = YList()
                        self.bidir_df_state.parent = self
                        self.bidir_df_state.name = 'bidir_df_state'


                    class BidirDfState(object):
                        """
                        Bidirectional PIM DF Election Table Entry
                        
                        .. attribute:: election_state
                        
                        	DF Election State
                        	**type**\:  str
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: our_metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: our_metric_preference
                        
                        	MetricPreference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr>`
                        
                        .. attribute:: time_nano_seconds
                        
                        	Timer expires (nseconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: time_seconds
                        
                        	Timer expires (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.election_state = None
                            self.interface_name = None
                            self.our_metric = None
                            self.our_metric_preference = None
                            self.pim_interface_name = None
                            self.rp_address = None
                            self.rp_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self.time_nano_seconds = None
                            self.time_seconds = None


                        class RpAddressXr(object):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-state'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.election_state is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.our_metric is not None:
                                return True

                            if self.our_metric_preference is not None:
                                return True

                            if self.pim_interface_name is not None:
                                return True

                            if self.rp_address is not None:
                                return True

                            if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                                return True

                            if self.time_nano_seconds is not None:
                                return True

                            if self.time_seconds is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-states'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bidir_df_state is not None:
                            for child_ref in self.bidir_df_state:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates']['meta_info']


                class Topologies(object):
                    """
                    PIM topology table
                    
                    .. attribute:: topology
                    
                    	PIM topology information
                    	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.topology = YList()
                        self.topology.parent = self
                        self.topology.name = 'topology'


                    class Topology(object):
                        """
                        PIM topology information
                        
                        .. attribute:: alive
                        
                        	Alive time in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: anycast_rp_match
                        
                        	Group matches Anycast\-RP policy
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_route_target
                        
                        	Anycast\-RP RT
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: assume_alive
                        
                        	The Assume Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: bgp_join
                        
                        	BGP C JOIN
                        	**type**\:  bool
                        
                        .. attribute:: bgpjp_time
                        
                        	BGP C JP Time
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: connected
                        
                        	Is Connected ?
                        	**type**\:  bool
                        
                        .. attribute:: customer_routing_type
                        
                        	Type of Customer Routing in the MVPN
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: dont_check_connected
                        
                        	Do we need to make the connected check on this route ?
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	When this entry expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: extranet_route
                        
                        	Is a Extranet route ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr>`
                        
                        .. attribute:: inherit_alive
                        
                        	The Inherit Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: inherit_spt
                        
                        	The Inherit SPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: is_via_lsm
                        
                        	Via LSM
                        	**type**\:  bool
                        
                        .. attribute:: jp_status
                        
                        	Join\-Prune Status
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: limit_reached
                        
                        	Have we throttled the creation of routes or interfaces ?
                        	**type**\:  bool
                        
                        .. attribute:: low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_active
                        
                        	Is MoFRR Active?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_backup
                        
                        	Is this Mofrr Backup?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_primary
                        
                        	Is this Mofrr Primary?
                        	**type**\:  bool
                        
                        .. attribute:: orig_src_address
                        
                        	Orig Src Address
                        	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress>`
                        
                        .. attribute:: outgoing_interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface>`
                        
                        .. attribute:: probe_alive
                        
                        	The Probe Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: proxy
                        
                        	Is the RPF target a proxy?
                        	**type**\:  bool
                        
                        .. attribute:: proxy_address
                        
                        	RPF Proxy address
                        	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress>`
                        
                        .. attribute:: really_alive
                        
                        	The Really Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: register_received
                        
                        	Have registers been received for this source ?
                        	**type**\:  bool
                        
                        .. attribute:: register_received_timer
                        
                        	Register Received Timer in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: remote_source
                        
                        	MSDP told us
                        	**type**\:  bool
                        
                        .. attribute:: rib_mo_frr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rp_address
                        
                        	RP Address (If rpt)
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor>`
                        
                        .. attribute:: rpf_proxy_enabled
                        
                        	Is rpf if proxy enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpt
                        
                        	RPT bit
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpt_xr
                        
                        	Is this on the RPT ?
                        	**type**\:  bool
                        
                        .. attribute:: sa_joined
                        
                        	BGP SA join
                        	**type**\:  bool
                        
                        .. attribute:: sa_received
                        
                        	BGP SA received
                        	**type**\:  bool
                        
                        .. attribute:: sa_sent
                        
                        	BGP SA sent
                        	**type**\:  bool
                        
                        .. attribute:: secondary_rpf_interface_name
                        
                        	Secondary Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: secondary_rpf_neighbor
                        
                        	Secondary RPF Neighbor
                        	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor>`
                        
                        .. attribute:: sending_null_registers
                        
                        	Are we sending null registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: sending_registers
                        
                        	Are we sending registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: signal_sources
                        
                        	Signal Sources on route?
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr>`
                        
                        .. attribute:: spt
                        
                        	Is this on the SPT ?
                        	**type**\:  bool
                        
                        .. attribute:: suppress_registers
                        
                        	When the Null register probe expires
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vxlan
                        
                        	Is this VXLAN?
                        	**type**\:  bool
                        
                        .. attribute:: wildcard
                        
                        	WC \-Wildcard
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.alive = None
                            self.anycast_rp_match = None
                            self.anycast_rp_route_target = None
                            self.assume_alive = None
                            self.bgp_join = None
                            self.bgpjp_time = None
                            self.connected = None
                            self.customer_routing_type = None
                            self.dont_check_connected = None
                            self.expiry = None
                            self.extranet_route = None
                            self.group_address = None
                            self.group_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self.inherit_alive = None
                            self.inherit_spt = None
                            self.is_via_lsm = None
                            self.jp_status = None
                            self.jp_timer = None
                            self.last_hop = None
                            self.limit_reached = None
                            self.low_memory = None
                            self.mofrr_active = None
                            self.mofrr_backup = None
                            self.mofrr_enabled = None
                            self.mofrr_primary = None
                            self.orig_src_address = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress()
                            self.orig_src_address.parent = self
                            self.outgoing_interface = YList()
                            self.outgoing_interface.parent = self
                            self.outgoing_interface.name = 'outgoing_interface'
                            self.probe_alive = None
                            self.protocol = None
                            self.proxy = None
                            self.proxy_address = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress()
                            self.proxy_address.parent = self
                            self.really_alive = None
                            self.register_received = None
                            self.register_received_timer = None
                            self.remote_source = None
                            self.rib_mo_frr_enabled = None
                            self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress()
                            self.rp_address.parent = self
                            self.rpf_drop = None
                            self.rpf_extranet = None
                            self.rpf_interface_name = None
                            self.rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self.rpf_proxy_enabled = None
                            self.rpf_root = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot()
                            self.rpf_root.parent = self
                            self.rpf_safi = None
                            self.rpf_table_name = None
                            self.rpf_vrf_name = None
                            self.rpt = None
                            self.rpt_xr = None
                            self.sa_joined = None
                            self.sa_received = None
                            self.sa_sent = None
                            self.secondary_rpf_interface_name = None
                            self.secondary_rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor()
                            self.secondary_rpf_neighbor.parent = self
                            self.sending_null_registers = None
                            self.sending_registers = None
                            self.signal_sources = None
                            self.source_address = None
                            self.source_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self.spt = None
                            self.suppress_registers = None
                            self.uptime = None
                            self.vxlan = None
                            self.wildcard = None


                        class GroupAddressXr(object):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr']['meta_info']


                        class SourceAddressXr(object):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr']['meta_info']


                        class RpAddress(object):
                            """
                            RP Address (If rpt)
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress']['meta_info']


                        class RpfNeighbor(object):
                            """
                            RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor']['meta_info']


                        class SecondaryRpfNeighbor(object):
                            """
                            Secondary RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:secondary-rpf-neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor']['meta_info']


                        class RpfRoot(object):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-root'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot']['meta_info']


                        class ProxyAddress(object):
                            """
                            RPF Proxy address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:proxy-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress']['meta_info']


                        class OrigSrcAddress(object):
                            """
                            Orig Src Address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:orig-src-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress']['meta_info']


                        class OutgoingInterface(object):
                            """
                            Outgoing interface list
                            
                            .. attribute:: admin_boundary
                            
                            	Is this an administrative boundary ?
                            	**type**\:  bool
                            
                            .. attribute:: assert_timer
                            
                            	Assert Timer in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: assert_winner
                            
                            	Assert Winner
                            	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner>`
                            
                            .. attribute:: bgp_c_mcast_join
                            
                            	BGP C\-Mcast join
                            	**type**\:  bool
                            
                            .. attribute:: bgp_c_mcast_prune_delay_timer
                            
                            	BGP C\-MCAST Prune Suppression in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: data_mdt_join
                            
                            	Data MDT join
                            	**type**\:  bool
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: extranet_interface
                            
                            	Is this an Extranet Interface ?
                            	**type**\:  bool
                            
                            .. attribute:: forwarding_state
                            
                            	Forward or Prune
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: igmp_membership
                            
                            	IGMP membership
                            	**type**\:  bool
                            
                            .. attribute:: immediate_state
                            
                            	Immediate fwding state
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: interface_name
                            
                            	Interface Identifier
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_interest_info
                            
                            	Internal Interest
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: jp_state
                            
                            	Join\-Prune State
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: jp_timer
                            
                            	Join\-Prune Timer (secs)
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: last_hop
                            
                            	Are we last hop ?
                            	**type**\:  bool
                            
                            .. attribute:: local_mdt_join
                            
                            	Default MDT Join
                            	**type**\:  bool
                            
                            .. attribute:: local_members
                            
                            	Local Information
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: mdt_safi_join
                            
                            	MDT Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mldp_inband_mdt
                            
                            	MLDP Inband MDT interface
                            	**type**\:  bool
                            
                            .. attribute:: mldp_stale
                            
                            	OLE is stale
                            	**type**\:  bool
                            
                            .. attribute:: mvp_nv6_safi_join
                            
                            	MVPN IPv6 Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mvpn_safi_join
                            
                            	MVPN Safi join
                            	**type**\:  bool
                            
                            .. attribute:: sa_prune
                            
                            	BGP SA Prune state
                            	**type**\:  bool
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: vrf_name
                            
                            	VRF which physically owns
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.admin_boundary = None
                                self.assert_timer = None
                                self.assert_winner = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner()
                                self.assert_winner.parent = self
                                self.bgp_c_mcast_join = None
                                self.bgp_c_mcast_prune_delay_timer = None
                                self.data_mdt_join = None
                                self.expiry = None
                                self.extranet_interface = None
                                self.forwarding_state = None
                                self.igmp_membership = None
                                self.immediate_state = None
                                self.interface_name = None
                                self.internal_interest_info = None
                                self.jp_state = None
                                self.jp_timer = None
                                self.last_hop = None
                                self.local_mdt_join = None
                                self.local_members = None
                                self.mdt_safi_join = None
                                self.mldp_inband_mdt = None
                                self.mldp_stale = None
                                self.mvp_nv6_safi_join = None
                                self.mvpn_safi_join = None
                                self.sa_prune = None
                                self.uptime = None
                                self.vrf_name = None


                            class AssertWinner(object):
                                """
                                Assert Winner
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:assert-winner'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:outgoing-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.admin_boundary is not None:
                                    return True

                                if self.assert_timer is not None:
                                    return True

                                if self.assert_winner is not None and self.assert_winner._has_data():
                                    return True

                                if self.bgp_c_mcast_join is not None:
                                    return True

                                if self.bgp_c_mcast_prune_delay_timer is not None:
                                    return True

                                if self.data_mdt_join is not None:
                                    return True

                                if self.expiry is not None:
                                    return True

                                if self.extranet_interface is not None:
                                    return True

                                if self.forwarding_state is not None:
                                    return True

                                if self.igmp_membership is not None:
                                    return True

                                if self.immediate_state is not None:
                                    return True

                                if self.interface_name is not None:
                                    return True

                                if self.internal_interest_info is not None:
                                    return True

                                if self.jp_state is not None:
                                    return True

                                if self.jp_timer is not None:
                                    return True

                                if self.last_hop is not None:
                                    return True

                                if self.local_mdt_join is not None:
                                    return True

                                if self.local_members is not None:
                                    return True

                                if self.mdt_safi_join is not None:
                                    return True

                                if self.mldp_inband_mdt is not None:
                                    return True

                                if self.mldp_stale is not None:
                                    return True

                                if self.mvp_nv6_safi_join is not None:
                                    return True

                                if self.mvpn_safi_join is not None:
                                    return True

                                if self.sa_prune is not None:
                                    return True

                                if self.uptime is not None:
                                    return True

                                if self.vrf_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.alive is not None:
                                return True

                            if self.anycast_rp_match is not None:
                                return True

                            if self.anycast_rp_route_target is not None:
                                return True

                            if self.assume_alive is not None:
                                return True

                            if self.bgp_join is not None:
                                return True

                            if self.bgpjp_time is not None:
                                return True

                            if self.connected is not None:
                                return True

                            if self.customer_routing_type is not None:
                                return True

                            if self.dont_check_connected is not None:
                                return True

                            if self.expiry is not None:
                                return True

                            if self.extranet_route is not None:
                                return True

                            if self.group_address is not None:
                                return True

                            if self.group_address_xr is not None and self.group_address_xr._has_data():
                                return True

                            if self.inherit_alive is not None:
                                return True

                            if self.inherit_spt is not None:
                                return True

                            if self.is_via_lsm is not None:
                                return True

                            if self.jp_status is not None:
                                return True

                            if self.jp_timer is not None:
                                return True

                            if self.last_hop is not None:
                                return True

                            if self.limit_reached is not None:
                                return True

                            if self.low_memory is not None:
                                return True

                            if self.mofrr_active is not None:
                                return True

                            if self.mofrr_backup is not None:
                                return True

                            if self.mofrr_enabled is not None:
                                return True

                            if self.mofrr_primary is not None:
                                return True

                            if self.orig_src_address is not None and self.orig_src_address._has_data():
                                return True

                            if self.outgoing_interface is not None:
                                for child_ref in self.outgoing_interface:
                                    if child_ref._has_data():
                                        return True

                            if self.probe_alive is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.proxy is not None:
                                return True

                            if self.proxy_address is not None and self.proxy_address._has_data():
                                return True

                            if self.really_alive is not None:
                                return True

                            if self.register_received is not None:
                                return True

                            if self.register_received_timer is not None:
                                return True

                            if self.remote_source is not None:
                                return True

                            if self.rib_mo_frr_enabled is not None:
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            if self.rpf_drop is not None:
                                return True

                            if self.rpf_extranet is not None:
                                return True

                            if self.rpf_interface_name is not None:
                                return True

                            if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                return True

                            if self.rpf_proxy_enabled is not None:
                                return True

                            if self.rpf_root is not None and self.rpf_root._has_data():
                                return True

                            if self.rpf_safi is not None:
                                return True

                            if self.rpf_table_name is not None:
                                return True

                            if self.rpf_vrf_name is not None:
                                return True

                            if self.rpt is not None:
                                return True

                            if self.rpt_xr is not None:
                                return True

                            if self.sa_joined is not None:
                                return True

                            if self.sa_received is not None:
                                return True

                            if self.sa_sent is not None:
                                return True

                            if self.secondary_rpf_interface_name is not None:
                                return True

                            if self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor._has_data():
                                return True

                            if self.sending_null_registers is not None:
                                return True

                            if self.sending_registers is not None:
                                return True

                            if self.signal_sources is not None:
                                return True

                            if self.source_address is not None:
                                return True

                            if self.source_address_xr is not None and self.source_address_xr._has_data():
                                return True

                            if self.spt is not None:
                                return True

                            if self.suppress_registers is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            if self.vxlan is not None:
                                return True

                            if self.wildcard is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topologies'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.topology is not None:
                            for child_ref in self.topology:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Topologies']['meta_info']


                class BgpAfs(object):
                    """
                    PIM BGP SAFI table
                    
                    .. attribute:: bgp_af
                    
                    	PIM BGP SAFI information
                    	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bgp_af = YList()
                        self.bgp_af.parent = self
                        self.bgp_af.name = 'bgp_af'


                    class BgpAf(object):
                        """
                        PIM BGP SAFI information
                        
                        .. attribute:: extranet_path_count
                        
                        	Count of dependent extranet paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group
                        
                        	Group address
                        	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group>`
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: is_bgp_added
                        
                        	SAFI learnt from BGP
                        	**type**\:  bool
                        
                        .. attribute:: next_hop
                        
                        	Next hop address
                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop>`
                        
                        .. attribute:: route_distinguisher
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**length:** 0..256
                        
                        .. attribute:: source
                        
                        	Source address
                        	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source>`
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.extranet_path_count = None
                            self.group = Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group()
                            self.group.parent = self
                            self.group_address = None
                            self.is_bgp_added = None
                            self.next_hop = Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop()
                            self.next_hop.parent = self
                            self.route_distinguisher = None
                            self.source = Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source()
                            self.source.parent = self
                            self.source_address = None


                        class Source(object):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source']['meta_info']


                        class Group(object):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group']['meta_info']


                        class NextHop(object):
                            """
                            Next hop address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:next-hop'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bgp-af'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.extranet_path_count is not None:
                                return True

                            if self.group is not None and self.group._has_data():
                                return True

                            if self.group_address is not None:
                                return True

                            if self.is_bgp_added is not None:
                                return True

                            if self.next_hop is not None and self.next_hop._has_data():
                                return True

                            if self.route_distinguisher is not None:
                                return True

                            if self.source is not None and self.source._has_data():
                                return True

                            if self.source_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bgp_af is not None:
                            for child_ref in self.bgp_af:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs']['meta_info']


                class AutoRp(object):
                    """
                    PIM Auto\-RP information
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:auto-rp'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.AutoRp']['meta_info']


                class TopologyInterfaceFlagRouteCounts(object):
                    """
                    Route count for topology with interface flag set
                    
                    .. attribute:: topology_interface_flag_route_count
                    
                    	Route count for topology with interface flag set
                    	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.topology_interface_flag_route_count = YList()
                        self.topology_interface_flag_route_count.parent = self
                        self.topology_interface_flag_route_count.name = 'topology_interface_flag_route_count'


                    class TopologyInterfaceFlagRouteCount(object):
                        """
                        Route count for topology with interface flag
                        set
                        
                        .. attribute:: interface_flag  <key>
                        
                        	Interface flag
                        	**type**\:   :py:class:`PimTopologyInterfaceFlagEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlagEnum>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_flag = None
                            self.active_group_ranges = None
                            self.group_address = Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                            self.group_address.parent = self
                            self.group_ranges = None
                            self.groute_count = None
                            self.is_node_low_memory = None
                            self.sg_route_count = None
                            self.sgr_route_count = None


                        class GroupAddress(object):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_flag is None:
                                raise YPYModelError('Key property interface_flag is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology-interface-flag-route-count[Cisco-IOS-XR-ipv4-pim-oper:interface-flag = ' + str(self.interface_flag) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_flag is not None:
                                return True

                            if self.active_group_ranges is not None:
                                return True

                            if self.group_address is not None and self.group_address._has_data():
                                return True

                            if self.group_ranges is not None:
                                return True

                            if self.groute_count is not None:
                                return True

                            if self.is_node_low_memory is not None:
                                return True

                            if self.sg_route_count is not None:
                                return True

                            if self.sgr_route_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology-interface-flag-route-counts'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.topology_interface_flag_route_count is not None:
                            for child_ref in self.topology_interface_flag_route_count:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts']['meta_info']


                class GroupMapSources(object):
                    """
                    PIM group\-mapping with source information
                    
                    .. attribute:: group_map_source
                    
                    	PIM Group Mapping Entry with source information
                    	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_map_source = YList()
                        self.group_map_source.parent = self
                        self.group_map_source.name = 'group_map_source'


                    class GroupMapSource(object):
                        """
                        PIM Group Mapping Entry with source information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                        
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	RP Priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.expires = None
                            self.group_map_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self.holdtime = None
                            self.prefix = None
                            self.prefix_length = None
                            self.priority = None
                            self.protocol = None
                            self.rp_address = None
                            self.source_of_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self.uptime = None


                        class SourceOfInformation(object):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation']['meta_info']


                        class GroupMapInformation(object):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.client = None
                                self.group_count = None
                                self.is_override = None
                                self.is_used = None
                                self.mrib_active = None
                                self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self.prefix_length = None
                                self.priority = None
                                self.protocol = None
                                self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self


                            class Prefix(object):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix']['meta_info']


                            class RpAddress(object):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.client is not None:
                                    return True

                                if self.group_count is not None:
                                    return True

                                if self.is_override is not None:
                                    return True

                                if self.is_used is not None:
                                    return True

                                if self.mrib_active is not None:
                                    return True

                                if self.prefix is not None and self.prefix._has_data():
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.priority is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.rp_address is not None and self.rp_address._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-source'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.expires is not None:
                                return True

                            if self.group_map_information is not None and self.group_map_information._has_data():
                                return True

                            if self.holdtime is not None:
                                return True

                            if self.prefix is not None:
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None:
                                return True

                            if self.source_of_information is not None and self.source_of_information._has_data():
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_map_source is not None:
                            for child_ref in self.group_map_source:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources']['meta_info']


                class TrafficCounters(object):
                    """
                    PIM message traffic counters
                    
                    .. attribute:: boundary_acl_rx_drop
                    
                    	Inc. JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: boundary_acl_tx_drop
                    
                    	Out JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_error
                    
                    	Checksum errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: format_error
                    
                    	Malformed packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert_batched
                    
                    	Batched Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_data_register
                    
                    	Data Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_ecmp_redirect
                    
                    	Input Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb_error
                    
                    	No IDB for intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_pim_error
                    
                    	PIM Disabled on intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_error
                    
                    	No VRF for idb error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_null_register
                    
                    	Null Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim_version_error
                    
                    	Invalid PIM version error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: inputs
                    
                    	Packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_destination_packets
                    
                    	Control Packets with Invalid Destination
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_join_prunes
                    
                    	PIM invalid Join/Prunes received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_registers
                    
                    	PIM invalid registers received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_local_source_address
                    
                    	Data MDT Join msgs dropped due to local source addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_idb
                    
                    	Data MDT Join msgs dropped due to idb missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_vrf
                    
                    	Data MDT Join msgs dropped due to vrf missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_null_local_address
                    
                    	Data MDT Join msgs dropped due to null local addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_bad_type
                    
                    	Data MDT TLV bad type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_received
                    
                    	Data MDT Join Msgs received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_sent
                    
                    	Data MDT Join Msgs sent
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_joins_drop_multiple_encapsulation
                    
                    	MDT Join msgs dropped due to multiple Encap limitation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_send_queue_full
                    
                    	Packets dropped since mdt send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_socket_error
                    
                    	MDT Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_invalid_lsm_identifier
                    
                    	 Invalid LSM ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_mdt_socket_connection
                    
                    	Packets dropped since no mdt socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_source_address
                    
                    	Packets dropped since no source address
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: non_supported_packets
                    
                    	PIM non supported pckets
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert_batched
                    
                    	Batched Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_data_register
                    
                    	Data Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_ecmp_redirect
                    
                    	Output Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello_bytes
                    
                    	Output Hello Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_join_group
                    
                    	Output Join Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_join_prune_bytes
                    
                    	Output JP Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_loop_error
                    
                    	Output on loopback error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_null_register
                    
                    	Null Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_prune_group
                    
                    	Output Prune Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: outputs
                    
                    	Packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_dequeued
                    
                    	Packets Dequeued per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_enqueued
                    
                    	Packets Enqueued per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_packman_error
                    
                    	Packets Dropped due to Pakman Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue
                    
                    	Packet queue state and statistics
                    	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue>`
                    
                    .. attribute:: packet_queue_last_clear
                    
                    	Time in seconds since the last clear of all packet queues stats
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: packet_queue_length
                    
                    	Packet Queue Length per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_size
                    
                    	Packet Queue Size per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_read_socket_error
                    
                    	Packet Read Socket Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_tail_drop
                    
                    	Packet Tail Drop per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_standby
                    
                    	Packets Dropped due to Standby Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pakman_error
                    
                    	Pakman packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: send_queue_full
                    
                    	Packets dropped since send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_error
                    
                    	Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: standby_packets_error
                    
                    	Packets received in standby state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: truncated_pim_packets
                    
                    	Packets dropped due to truncated Joins or Prunes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.boundary_acl_rx_drop = None
                        self.boundary_acl_tx_drop = None
                        self.checksum_error = None
                        self.elapsed_time = None
                        self.format_error = None
                        self.input_assert = None
                        self.input_assert_batched = None
                        self.input_bsr_message = None
                        self.input_candidate_rp_advertisement = None
                        self.input_data_register = None
                        self.input_df_election = None
                        self.input_ecmp_redirect = None
                        self.input_hello = None
                        self.input_jp = None
                        self.input_no_idb_error = None
                        self.input_no_pim_error = None
                        self.input_no_vrf_error = None
                        self.input_null_register = None
                        self.input_pim_version_error = None
                        self.input_register_stop = None
                        self.inputs = None
                        self.invalid_destination_packets = None
                        self.invalid_join_prunes = None
                        self.invalid_registers = None
                        self.mdt_drop_local_source_address = None
                        self.mdt_drop_no_idb = None
                        self.mdt_drop_no_vrf = None
                        self.mdt_drop_null_local_address = None
                        self.mdt_join_bad_type = None
                        self.mdt_join_tlv_received = None
                        self.mdt_join_tlv_sent = None
                        self.mdt_joins_drop_multiple_encapsulation = None
                        self.mdt_send_queue_full = None
                        self.mdt_socket_error = None
                        self.mldp_mdt_invalid_lsm_identifier = None
                        self.no_mdt_socket_connection = None
                        self.no_socket_connection = None
                        self.no_source_address = None
                        self.non_supported_packets = None
                        self.output_assert = None
                        self.output_assert_batched = None
                        self.output_bsr_message = None
                        self.output_candidate_rp_advertisement = None
                        self.output_data_register = None
                        self.output_df_election = None
                        self.output_ecmp_redirect = None
                        self.output_hello = None
                        self.output_hello_bytes = None
                        self.output_join_group = None
                        self.output_join_prune_bytes = None
                        self.output_jp = None
                        self.output_loop_error = None
                        self.output_null_register = None
                        self.output_prune_group = None
                        self.output_register_stop = None
                        self.outputs = None
                        self.packet_dequeued = YLeafList()
                        self.packet_dequeued.parent = self
                        self.packet_dequeued.name = 'packet_dequeued'
                        self.packet_enqueued = YLeafList()
                        self.packet_enqueued.parent = self
                        self.packet_enqueued.name = 'packet_enqueued'
                        self.packet_packman_error = None
                        self.packet_queue = YList()
                        self.packet_queue.parent = self
                        self.packet_queue.name = 'packet_queue'
                        self.packet_queue_last_clear = None
                        self.packet_queue_length = YLeafList()
                        self.packet_queue_length.parent = self
                        self.packet_queue_length.name = 'packet_queue_length'
                        self.packet_queue_size = YLeafList()
                        self.packet_queue_size.parent = self
                        self.packet_queue_size.name = 'packet_queue_size'
                        self.packet_read_socket_error = None
                        self.packet_tail_drop = YLeafList()
                        self.packet_tail_drop.parent = self
                        self.packet_tail_drop.name = 'packet_tail_drop'
                        self.packets_standby = None
                        self.pakman_error = None
                        self.send_queue_full = None
                        self.socket_error = None
                        self.standby_packets_error = None
                        self.truncated_pim_packets = None


                    class PacketQueue(object):
                        """
                        Packet queue state and statistics
                        
                        .. attribute:: packet_queue_priority
                        
                        	Priority of this packet queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: packet_queue_state
                        
                        	State of the queue
                        	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState>`
                        
                        .. attribute:: packet_queue_stats
                        
                        	Statistics about the queue
                        	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.packet_queue_priority = None
                            self.packet_queue_state = Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState()
                            self.packet_queue_state.parent = self
                            self.packet_queue_stats = Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats()
                            self.packet_queue_stats.parent = self


                        class PacketQueueState(object):
                            """
                            State of the queue
                            
                            .. attribute:: max_queue_size
                            
                            	Maximum size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_bytes
                            
                            	Size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_packets
                            
                            	Size of queue in number of packets
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.max_queue_size = None
                                self.queue_size_bytes = None
                                self.queue_size_packets = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:packet-queue-state'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.max_queue_size is not None:
                                    return True

                                if self.queue_size_bytes is not None:
                                    return True

                                if self.queue_size_packets is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState']['meta_info']


                        class PacketQueueStats(object):
                            """
                            Statistics about the queue
                            
                            .. attribute:: dequeued_packets
                            
                            	Total number of packets dequeued from this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: enqueued_packets
                            
                            	Total number of packets enqueued to this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high_water_mark_bytes
                            
                            	Highest number of bytes enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: high_water_mark_packets
                            
                            	Highest number of packets enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tail_drops
                            
                            	Number packets dropped from this queue due to max size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dequeued_packets = None
                                self.enqueued_packets = None
                                self.high_water_mark_bytes = None
                                self.high_water_mark_packets = None
                                self.tail_drops = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:packet-queue-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dequeued_packets is not None:
                                    return True

                                if self.enqueued_packets is not None:
                                    return True

                                if self.high_water_mark_bytes is not None:
                                    return True

                                if self.high_water_mark_packets is not None:
                                    return True

                                if self.tail_drops is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:packet-queue'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.packet_queue_priority is not None:
                                return True

                            if self.packet_queue_state is not None and self.packet_queue_state._has_data():
                                return True

                            if self.packet_queue_stats is not None and self.packet_queue_stats._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:traffic-counters'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.boundary_acl_rx_drop is not None:
                            return True

                        if self.boundary_acl_tx_drop is not None:
                            return True

                        if self.checksum_error is not None:
                            return True

                        if self.elapsed_time is not None:
                            return True

                        if self.format_error is not None:
                            return True

                        if self.input_assert is not None:
                            return True

                        if self.input_assert_batched is not None:
                            return True

                        if self.input_bsr_message is not None:
                            return True

                        if self.input_candidate_rp_advertisement is not None:
                            return True

                        if self.input_data_register is not None:
                            return True

                        if self.input_df_election is not None:
                            return True

                        if self.input_ecmp_redirect is not None:
                            return True

                        if self.input_hello is not None:
                            return True

                        if self.input_jp is not None:
                            return True

                        if self.input_no_idb_error is not None:
                            return True

                        if self.input_no_pim_error is not None:
                            return True

                        if self.input_no_vrf_error is not None:
                            return True

                        if self.input_null_register is not None:
                            return True

                        if self.input_pim_version_error is not None:
                            return True

                        if self.input_register_stop is not None:
                            return True

                        if self.inputs is not None:
                            return True

                        if self.invalid_destination_packets is not None:
                            return True

                        if self.invalid_join_prunes is not None:
                            return True

                        if self.invalid_registers is not None:
                            return True

                        if self.mdt_drop_local_source_address is not None:
                            return True

                        if self.mdt_drop_no_idb is not None:
                            return True

                        if self.mdt_drop_no_vrf is not None:
                            return True

                        if self.mdt_drop_null_local_address is not None:
                            return True

                        if self.mdt_join_bad_type is not None:
                            return True

                        if self.mdt_join_tlv_received is not None:
                            return True

                        if self.mdt_join_tlv_sent is not None:
                            return True

                        if self.mdt_joins_drop_multiple_encapsulation is not None:
                            return True

                        if self.mdt_send_queue_full is not None:
                            return True

                        if self.mdt_socket_error is not None:
                            return True

                        if self.mldp_mdt_invalid_lsm_identifier is not None:
                            return True

                        if self.no_mdt_socket_connection is not None:
                            return True

                        if self.no_socket_connection is not None:
                            return True

                        if self.no_source_address is not None:
                            return True

                        if self.non_supported_packets is not None:
                            return True

                        if self.output_assert is not None:
                            return True

                        if self.output_assert_batched is not None:
                            return True

                        if self.output_bsr_message is not None:
                            return True

                        if self.output_candidate_rp_advertisement is not None:
                            return True

                        if self.output_data_register is not None:
                            return True

                        if self.output_df_election is not None:
                            return True

                        if self.output_ecmp_redirect is not None:
                            return True

                        if self.output_hello is not None:
                            return True

                        if self.output_hello_bytes is not None:
                            return True

                        if self.output_join_group is not None:
                            return True

                        if self.output_join_prune_bytes is not None:
                            return True

                        if self.output_jp is not None:
                            return True

                        if self.output_loop_error is not None:
                            return True

                        if self.output_null_register is not None:
                            return True

                        if self.output_prune_group is not None:
                            return True

                        if self.output_register_stop is not None:
                            return True

                        if self.outputs is not None:
                            return True

                        if self.packet_dequeued is not None:
                            for child in self.packet_dequeued:
                                if child is not None:
                                    return True

                        if self.packet_enqueued is not None:
                            for child in self.packet_enqueued:
                                if child is not None:
                                    return True

                        if self.packet_packman_error is not None:
                            return True

                        if self.packet_queue is not None:
                            for child_ref in self.packet_queue:
                                if child_ref._has_data():
                                    return True

                        if self.packet_queue_last_clear is not None:
                            return True

                        if self.packet_queue_length is not None:
                            for child in self.packet_queue_length:
                                if child is not None:
                                    return True

                        if self.packet_queue_size is not None:
                            for child in self.packet_queue_size:
                                if child is not None:
                                    return True

                        if self.packet_read_socket_error is not None:
                            return True

                        if self.packet_tail_drop is not None:
                            for child in self.packet_tail_drop:
                                if child is not None:
                                    return True

                        if self.packets_standby is not None:
                            return True

                        if self.pakman_error is not None:
                            return True

                        if self.send_queue_full is not None:
                            return True

                        if self.socket_error is not None:
                            return True

                        if self.standby_packets_error is not None:
                            return True

                        if self.truncated_pim_packets is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters']['meta_info']


                class GroupMapRpfs(object):
                    """
                    PIM group mapping information
                    
                    .. attribute:: group_map_rpf
                    
                    	PIM group mapping entry
                    	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_map_rpf = YList()
                        self.group_map_rpf.parent = self
                        self.group_map_rpf.name = 'group_map_rpf'


                    class GroupMapRpf(object):
                        """
                        PIM group mapping entry
                        
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\:  bool
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_priority
                        
                        	RP priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.are_we_rp = None
                            self.client = None
                            self.group_map_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self.prefix = None
                            self.prefix_length = None
                            self.protocol = None
                            self.rp_address = None
                            self.rp_priority = None
                            self.rpf_interface_name = None
                            self.rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self.rpf_vrf_name = None


                        class RpfNeighbor(object):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor']['meta_info']


                        class GroupMapInformation(object):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.client = None
                                self.group_count = None
                                self.is_override = None
                                self.is_used = None
                                self.mrib_active = None
                                self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self.prefix_length = None
                                self.priority = None
                                self.protocol = None
                                self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self


                            class Prefix(object):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix']['meta_info']


                            class RpAddress(object):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.client is not None:
                                    return True

                                if self.group_count is not None:
                                    return True

                                if self.is_override is not None:
                                    return True

                                if self.is_used is not None:
                                    return True

                                if self.mrib_active is not None:
                                    return True

                                if self.prefix is not None and self.prefix._has_data():
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.priority is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.rp_address is not None and self.rp_address._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.are_we_rp is not None:
                                return True

                            if self.client is not None:
                                return True

                            if self.group_map_information is not None and self.group_map_information._has_data():
                                return True

                            if self.prefix is not None:
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None:
                                return True

                            if self.rp_priority is not None:
                                return True

                            if self.rpf_interface_name is not None:
                                return True

                            if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                return True

                            if self.rpf_vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_map_rpf is not None:
                            for child_ref in self.group_map_rpf:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs']['meta_info']


                class Summary(object):
                    """
                    PIM summary
                    
                    .. attribute:: bsr_candidate_rp_set_count
                    
                    	Current crp\-set count from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_limit
                    
                    	Maximum crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_threshold
                    
                    	Threshold crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_range_threshold
                    
                    	Threshold group range from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_count
                    
                    	Current group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_limit
                    
                    	Maximum group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_auto_rp_ranges_limit
                    
                    	Global Auto\-RP maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_count
                    
                    	Global BSR current crp\-set count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_limit
                    
                    	Global BSR maximum crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_threshold
                    
                    	Global BSR Threshold crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_count
                    
                    	Global BSR current group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_limit
                    
                    	Global BSR maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_threshold
                    
                    	Global BSR Threshold group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_register_limit
                    
                    	Maximum global registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bsr_ranges_threshold_reached
                    
                    	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_auto_rp_ranges_limit_reached
                    
                    	Is global AutoRP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_bsr_ranges_limit_reached
                    
                    	Is global BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_register_limit_reached
                    
                    	Is global PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_route_limit_reached
                    
                    	Is global route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_rxi_limit_reached
                    
                    	Is global interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_maximum_enforcement_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\:  bool
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: is_ranges_limit_reached
                    
                    	Is Auto\-RP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_route_limit_reached
                    
                    	Is route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: ranges_count
                    
                    	Current group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_limit
                    
                    	Maximum group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_threshold
                    
                    	OOR theshold of grange ranges from AutoRP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_count
                    
                    	Current registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit
                    
                    	Maximum registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit_reached
                    
                    	Is PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: register_threshold
                    
                    	Threshold registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_count
                    
                    	Current routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_limit
                    
                    	Maximum routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_low_water_mark
                    
                    	The number of routes below which the throttle on route creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_threshold
                    
                    	Threshold routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rxi_limit_reached
                    
                    	Is interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: rxi_low_water_mark
                    
                    	The rxi below which the throttle on interface creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_count
                    
                    	Current Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_limit
                    
                    	Maximum Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_threshold
                    
                    	Topology Interface State threshold
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bsr_candidate_rp_set_count = None
                        self.bsr_candidate_rp_set_limit = None
                        self.bsr_candidate_rp_set_threshold = None
                        self.bsr_range_threshold = None
                        self.bsr_ranges_count = None
                        self.bsr_ranges_limit = None
                        self.global_auto_rp_ranges_limit = None
                        self.global_bsr_candidate_rp_set_count = None
                        self.global_bsr_candidate_rp_set_limit = None
                        self.global_bsr_candidate_rp_set_threshold = None
                        self.global_bsr_ranges_count = None
                        self.global_bsr_ranges_limit = None
                        self.global_bsr_ranges_threshold = None
                        self.global_register_limit = None
                        self.is_bsr_ranges_threshold_reached = None
                        self.is_global_auto_rp_ranges_limit_reached = None
                        self.is_global_bsr_ranges_limit_reached = None
                        self.is_global_register_limit_reached = None
                        self.is_global_route_limit_reached = None
                        self.is_global_rxi_limit_reached = None
                        self.is_maximum_enforcement_disabled = None
                        self.is_node_low_memory = None
                        self.is_ranges_limit_reached = None
                        self.is_route_limit_reached = None
                        self.ranges_count = None
                        self.ranges_limit = None
                        self.ranges_threshold = None
                        self.register_count = None
                        self.register_limit = None
                        self.register_limit_reached = None
                        self.register_threshold = None
                        self.route_count = None
                        self.route_limit = None
                        self.route_low_water_mark = None
                        self.route_threshold = None
                        self.rxi_limit_reached = None
                        self.rxi_low_water_mark = None
                        self.topology_interface_state_count = None
                        self.topology_interface_state_limit = None
                        self.topology_interface_state_threshold = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bsr_candidate_rp_set_count is not None:
                            return True

                        if self.bsr_candidate_rp_set_limit is not None:
                            return True

                        if self.bsr_candidate_rp_set_threshold is not None:
                            return True

                        if self.bsr_range_threshold is not None:
                            return True

                        if self.bsr_ranges_count is not None:
                            return True

                        if self.bsr_ranges_limit is not None:
                            return True

                        if self.global_auto_rp_ranges_limit is not None:
                            return True

                        if self.global_bsr_candidate_rp_set_count is not None:
                            return True

                        if self.global_bsr_candidate_rp_set_limit is not None:
                            return True

                        if self.global_bsr_candidate_rp_set_threshold is not None:
                            return True

                        if self.global_bsr_ranges_count is not None:
                            return True

                        if self.global_bsr_ranges_limit is not None:
                            return True

                        if self.global_bsr_ranges_threshold is not None:
                            return True

                        if self.global_register_limit is not None:
                            return True

                        if self.is_bsr_ranges_threshold_reached is not None:
                            return True

                        if self.is_global_auto_rp_ranges_limit_reached is not None:
                            return True

                        if self.is_global_bsr_ranges_limit_reached is not None:
                            return True

                        if self.is_global_register_limit_reached is not None:
                            return True

                        if self.is_global_route_limit_reached is not None:
                            return True

                        if self.is_global_rxi_limit_reached is not None:
                            return True

                        if self.is_maximum_enforcement_disabled is not None:
                            return True

                        if self.is_node_low_memory is not None:
                            return True

                        if self.is_ranges_limit_reached is not None:
                            return True

                        if self.is_route_limit_reached is not None:
                            return True

                        if self.ranges_count is not None:
                            return True

                        if self.ranges_limit is not None:
                            return True

                        if self.ranges_threshold is not None:
                            return True

                        if self.register_count is not None:
                            return True

                        if self.register_limit is not None:
                            return True

                        if self.register_limit_reached is not None:
                            return True

                        if self.register_threshold is not None:
                            return True

                        if self.route_count is not None:
                            return True

                        if self.route_limit is not None:
                            return True

                        if self.route_low_water_mark is not None:
                            return True

                        if self.route_threshold is not None:
                            return True

                        if self.rxi_limit_reached is not None:
                            return True

                        if self.rxi_low_water_mark is not None:
                            return True

                        if self.topology_interface_state_count is not None:
                            return True

                        if self.topology_interface_state_limit is not None:
                            return True

                        if self.topology_interface_state_threshold is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Summary']['meta_info']


                class Gre(object):
                    """
                    GRE information
                    
                    .. attribute:: gre_hashes
                    
                    	GRE hash
                    	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes>`
                    
                    .. attribute:: gre_next_hops
                    
                    	GRE destination neighbor table
                    	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.gre_hashes = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes()
                        self.gre_hashes.parent = self
                        self.gre_next_hops = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops()
                        self.gre_next_hops.parent = self


                    class GreHashes(object):
                        """
                        GRE hash
                        
                        .. attribute:: gre_hash
                        
                        	PIM GRE Hashed Underlying Interface
                        	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.gre_hash = YList()
                            self.gre_hash.parent = self
                            self.gre_hash.name = 'gre_hash'


                        class GreHash(object):
                            """
                            PIM GRE Hashed Underlying Interface
                            
                            .. attribute:: destination_address  <key>
                            
                            	Destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: ifname  <key>
                            
                            	GRE Tunnel Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_address  <key>
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.destination_address = None
                                self.ifname = None
                                self.source_address = None
                                self.next_hop_interface = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.destination_address is None:
                                    raise YPYModelError('Key property destination_address is None')
                                if self.ifname is None:
                                    raise YPYModelError('Key property ifname is None')
                                if self.source_address is None:
                                    raise YPYModelError('Key property source_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-hash[Cisco-IOS-XR-ipv4-pim-oper:destination-address = ' + str(self.destination_address) + '][Cisco-IOS-XR-ipv4-pim-oper:ifname = ' + str(self.ifname) + '][Cisco-IOS-XR-ipv4-pim-oper:source-address = ' + str(self.source_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.destination_address is not None:
                                    return True

                                if self.ifname is not None:
                                    return True

                                if self.source_address is not None:
                                    return True

                                if self.next_hop_interface is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-hashes'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.gre_hash is not None:
                                for child_ref in self.gre_hash:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes']['meta_info']


                    class GreNextHops(object):
                        """
                        GRE destination neighbor table
                        
                        .. attribute:: gre_next_hop
                        
                        	PIM GRE address next\-hop information
                        	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.gre_next_hop = YList()
                            self.gre_next_hop.parent = self
                            self.gre_next_hop.name = 'gre_next_hop'


                        class GreNextHop(object):
                            """
                            PIM GRE address next\-hop information
                            
                            .. attribute:: destination_address  <key>
                            
                            	GRE destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: gre_path
                            
                            	GRE Paths list
                            	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath>`
                            
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.destination_address = None
                                self.gre_path = YList()
                                self.gre_path.parent = self
                                self.gre_path.name = 'gre_path'
                                self.is_connected = None
                                self.metric = None
                                self.metric_preference = None
                                self.registered_address = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                self.registered_address.parent = self


                            class RegisteredAddress(object):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:registered-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress']['meta_info']


                            class GrePath(object):
                                """
                                GRE Paths list
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: gre_interface_name
                                
                                	GRE Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: gre_neighbor
                                
                                	GRE neighbor
                                	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                                
                                .. attribute:: gre_next_hop
                                
                                	GRE nexthop
                                	**type**\:   :py:class:`GreNextHop_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_>`
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_gre_interface_disabled
                                
                                	Is the gre interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.extranet_vrf_name = None
                                    self.gre_interface_name = None
                                    self.gre_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                    self.gre_neighbor.parent = self
                                    self.gre_next_hop = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_()
                                    self.gre_next_hop.parent = self
                                    self.is_connector_attribute_present = None
                                    self.is_gre_interface_disabled = None
                                    self.is_via_lsm = None


                                class GreNeighbor(object):
                                    """
                                    GRE neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-neighbor'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor']['meta_info']


                                class GreNextHop_(object):
                                    """
                                    GRE nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.extranet_vrf_name is not None:
                                        return True

                                    if self.gre_interface_name is not None:
                                        return True

                                    if self.gre_neighbor is not None and self.gre_neighbor._has_data():
                                        return True

                                    if self.gre_next_hop is not None and self.gre_next_hop._has_data():
                                        return True

                                    if self.is_connector_attribute_present is not None:
                                        return True

                                    if self.is_gre_interface_disabled is not None:
                                        return True

                                    if self.is_via_lsm is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.destination_address is None:
                                    raise YPYModelError('Key property destination_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hop[Cisco-IOS-XR-ipv4-pim-oper:destination-address = ' + str(self.destination_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.destination_address is not None:
                                    return True

                                if self.gre_path is not None:
                                    for child_ref in self.gre_path:
                                        if child_ref._has_data():
                                            return True

                                if self.is_connected is not None:
                                    return True

                                if self.metric is not None:
                                    return True

                                if self.metric_preference is not None:
                                    return True

                                if self.registered_address is not None and self.registered_address._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hops'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.gre_next_hop is not None:
                                for child_ref in self.gre_next_hop:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.gre_hashes is not None and self.gre_hashes._has_data():
                            return True

                        if self.gre_next_hops is not None and self.gre_next_hops._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Gre']['meta_info']


                class BidirDfWinners(object):
                    """
                    Bidirectional PIM DF election winner table
                    
                    .. attribute:: bidir_df_winner
                    
                    	Bidirectional PIM DF election table entry
                    	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bidir_df_winner = YList()
                        self.bidir_df_winner.parent = self
                        self.bidir_df_winner.name = 'bidir_df_winner'


                    class BidirDfWinner(object):
                        """
                        Bidirectional PIM DF election table entry
                        
                        .. attribute:: are_we_df
                        
                        	Are we DF
                        	**type**\:  bool
                        
                        .. attribute:: df_winner
                        
                        	DF Winner
                        	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner>`
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                        
                        .. attribute:: rp_lan
                        
                        	Is this the RP LAN
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.are_we_df = None
                            self.df_winner = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner()
                            self.df_winner.parent = self
                            self.interface_name = None
                            self.metric = None
                            self.metric_preference = None
                            self.pim_interface_name = None
                            self.rp_address = None
                            self.rp_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self.rp_lan = None
                            self.uptime = None


                        class RpAddressXr(object):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr']['meta_info']


                        class DfWinner(object):
                            """
                            DF Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:df-winner'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winner'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.are_we_df is not None:
                                return True

                            if self.df_winner is not None and self.df_winner._has_data():
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.metric is not None:
                                return True

                            if self.metric_preference is not None:
                                return True

                            if self.pim_interface_name is not None:
                                return True

                            if self.rp_address is not None:
                                return True

                            if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                                return True

                            if self.rp_lan is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winners'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bidir_df_winner is not None:
                            for child_ref in self.bidir_df_winner:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners']['meta_info']


                class TableContexts(object):
                    """
                    PIM table context list
                    
                    .. attribute:: table_context
                    
                    	PIM table context information
                    	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TableContexts.TableContext>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.table_context = YList()
                        self.table_context.parent = self
                        self.table_context.name = 'table_context'


                    class TableContext(object):
                        """
                        PIM table context information
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: saf_name
                        
                        	SAF name
                        	**type**\:   :py:class:`PimSafiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafiEnum>`
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: topology_name
                        
                        	Topology name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.afi = None
                            self.is_active = None
                            self.is_ital_registration_done = None
                            self.is_rib_convergence = None
                            self.is_rib_convergence_received = None
                            self.is_rib_registration_done = None
                            self.rpf_registrations = None
                            self.saf_name = None
                            self.safi = None
                            self.table_id = None
                            self.table_name = None
                            self.topology_name = None
                            self.vrf_id = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:table-context'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.afi is not None:
                                return True

                            if self.is_active is not None:
                                return True

                            if self.is_ital_registration_done is not None:
                                return True

                            if self.is_rib_convergence is not None:
                                return True

                            if self.is_rib_convergence_received is not None:
                                return True

                            if self.is_rib_registration_done is not None:
                                return True

                            if self.rpf_registrations is not None:
                                return True

                            if self.saf_name is not None:
                                return True

                            if self.safi is not None:
                                return True

                            if self.table_id is not None:
                                return True

                            if self.table_name is not None:
                                return True

                            if self.topology_name is not None:
                                return True

                            if self.vrf_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.TableContexts.TableContext']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:table-contexts'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.table_context is not None:
                            for child_ref in self.table_context:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.TableContexts']['meta_info']


                class NeighborSummaries(object):
                    """
                    PIM neighbor summary table
                    
                    .. attribute:: neighbor_summary
                    
                    	PIM neighbor summary information
                    	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.neighbor_summary = YList()
                        self.neighbor_summary.parent = self
                        self.neighbor_summary.name = 'neighbor_summary'


                    class NeighborSummary(object):
                        """
                        PIM neighbor summary information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: number_of_external_neighbors
                        
                        	Number of external neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: number_of_neighbors
                        
                        	Number of neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.number_of_external_neighbors = None
                            self.number_of_neighbors = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-summary[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.number_of_external_neighbors is not None:
                                return True

                            if self.number_of_neighbors is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-summaries'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.neighbor_summary is not None:
                            for child_ref in self.neighbor_summary:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries']['meta_info']


                class Context(object):
                    """
                    PIM context information
                    
                    .. attribute:: active_table_count
                    
                    	Number of active Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: allow_rp_configured
                    
                    	Allow RP Configured
                    	**type**\:  bool
                    
                    .. attribute:: allow_rp_group_list
                    
                    	Allow RP Group\-List ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: allow_rp_rp_list
                    
                    	Allow RP RP\-list ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: anycast_rp_configured
                    
                    	Anycast\-RP config
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_policy_name
                    
                    	Anycast\-RP Policy Name
                    	**type**\:  str
                    
                    .. attribute:: anycast_rp_range
                    
                    	Anycast\-RP Ranges
                    	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange>`
                    
                    .. attribute:: bgp_auto_discovery_configured
                    
                    	BGP Auto\-Discovery configured
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery_type
                    
                    	BGP Auto Discovery Type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_i_pmsi_added
                    
                    	BGP I\-PMSI Added
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_address
                    
                    	BGP remote interface address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: bgp_remote_interface
                    
                    	BGP remote interface handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: bgp_remote_interface_name
                    
                    	BGP remote interface name
                    	**type**\:  str
                    
                    .. attribute:: bgp_remote_on
                    
                    	BGP remote interface status
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_state
                    
                    	BGP remote interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_source_active_announce
                    
                    	Send BGP Source\-Active Announcements
                    	**type**\:  bool
                    
                    .. attribute:: export_route_target
                    
                    	Export Route Targets
                    	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget>`
                    
                    .. attribute:: gin_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: gin_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: gin_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: import_route_target
                    
                    	Import Route Targets
                    	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget>`
                    
                    .. attribute:: in_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: in_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: in_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_signaling_local_enabled
                    
                    	Inband signaling Local enabled
                    	**type**\:  bool
                    
                    .. attribute:: in_band_signaling_remote_enabled
                    
                    	Inband signaling Remote enabled
                    	**type**\:  bool
                    
                    .. attribute:: inter_autonomous_system_enabled
                    
                    	Inter\-AS Enabled
                    	**type**\:  bool
                    
                    .. attribute:: ir_maximum_mdt_aggregation
                    
                    	IR MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_announce_interval
                    
                    	IR Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_switchover_interval
                    
                    	IR Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_interface
                    
                    	IRMDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: ir_mdt_mtu
                    
                    	IRMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_name
                    
                    	IR MDT Name
                    	**type**\:  str
                    
                    .. attribute:: ir_mdt_rpf_identifier
                    
                    	IR RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_tail_label
                    
                    	IR Tail Label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active
                    	**type**\:  bool
                    
                    .. attribute:: is_active_ital
                    
                    	Active ITAL
                    	**type**\:  bool
                    
                    .. attribute:: is_all_interface_disable_operation
                    
                    	PIM all interface disable operation
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_enabled
                    
                    	Auto RP Listen Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_sock_add
                    
                    	Auto RP listen sock add
                    	**type**\:  bool
                    
                    .. attribute:: is_create_gin_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_in_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_ir_mdt_interface
                    
                    	Create IR MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mdt_interface
                    
                    	Create MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mldp_mdt_interface
                    
                    	Create MLDP MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_rsvp_te_mdt_interface
                    
                    	Create RSVP\-TE MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_default_granges
                    
                    	Default granges
                    	**type**\:  bool
                    
                    .. attribute:: is_gin_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_in_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_ir_mdt_owner
                    
                    	IR MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_added
                    
                    	VRF LPTS filter added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_m_host_publish_pending
                    
                    	Publish pending for MHost Default interface
                    	**type**\:  bool
                    
                    .. attribute:: is_mdt_owner
                    
                    	MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mldp_mdt_owner
                    
                    	MLDP MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mrib_register
                    
                    	MRIB Register
                    	**type**\:  bool
                    
                    .. attribute:: is_multicast_rib_registration
                    
                    	Mcast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converge_received
                    
                    	PIM NSF RIB converge received
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converged
                    
                    	PIM NSF RIB converged
                    	**type**\:  bool
                    
                    .. attribute:: is_redistribution_reset
                    
                    	Pending redist reset
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_added
                    
                    	VRF LPTS filter added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_add_required
                    
                    	VRF required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_added
                    
                    	VRF added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_enabled
                    
                    	PIM RIB multiplath enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_interface_hash
                    
                    	PIM RIB multipath interface hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_hash
                    
                    	PIM RIB multipath source based hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_next_hop_hash
                    
                    	PIM RIB multipath source\-nexthop hash
                    	**type**\:  bool
                    
                    .. attribute:: is_routing_enabled
                    
                    	Routing Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rsvp_te_mdt_owner
                    
                    	RSVP\-TE MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_add_required
                    
                    	VRF required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_added
                    
                    	VRF added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_add_required
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_added
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind
                    
                    	VRF bound on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind_required
                    
                    	VRF bind required on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_unicast_rib_registration
                    
                    	Ucast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: maximum_mdt_aggregation
                    
                    	MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_announce_interval
                    
                    	Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_switchover_interval
                    
                    	Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_default_group
                    
                    	MDT Default group
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_gre_remote_rpf_identifier
                    
                    	GRE\-MDT Remote RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_gre_rpf_identifier
                    
                    	GRE\-MDT RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_interface
                    
                    	MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mdt_mtu
                    
                    	MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_neighbor_filter_name
                    
                    	MDT Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: mdt_partitioned_ir_control_identifier
                    
                    	Partitioned IR MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_partitioned_mdt_control_identifier
                    
                    	Partitioned MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mhost_default_interface_config
                    
                    	Configured Mhost Defint
                    	**type**\:  str
                    
                    .. attribute:: mhost_interface
                    
                    	MHost handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mldp_auto_rp_announce_tree_added
                    
                    	MLDP Autorp Announce Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_auto_rp_discovery_tree_added
                    
                    	MLDP Autorp Discovery Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_bsr_control_tree_added
                    
                    	MLDP BSR Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_control_head_lsm_identifier
                    
                    	MLDP MVPN Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_local_label
                    
                    	Partitioned MDT Head local label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_lsm_identifier
                    
                    	MLDP Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_maximum_mdt_aggregation
                    
                    	MLDP MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_announce_interval
                    
                    	MLDP Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_switchover_interval
                    
                    	MLDP Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_interface
                    
                    	MLDP MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mldp_mdt_mtu
                    
                    	MLDP MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_name
                    
                    	MLDP MDT Name
                    	**type**\:  str
                    
                    .. attribute:: mldp_mdt_remote_rpf_identifier
                    
                    	MLDP Remote RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_rpf_identifier
                    
                    	MLDP RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partioned_mp2m_ptree
                    
                    	MP2MP Partitioned MDT tree
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_head_lsm_identifier
                    
                    	Partitioned MDT Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partitioned_mdt_configured
                    
                    	MLDP Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_mdt_identifier
                    
                    	MLDP Partitioned MDT Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_head_lsm_identifier
                    
                    	MLDP Remote Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_partitioned_mdt_configured
                    
                    	MLDP Remote Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_root_address
                    
                    	MLDP Root addresses
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_root_count
                    
                    	MLDP Root count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: murib_id
                    
                    	MURIB ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: non_default_vrf_count_on_socket
                    
                    	Count of non\-default vrfs on raw socket
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: organization_unique_identifier
                    
                    	OUI for VPN\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mpte_li_drop
                    
                    	Route LI updates dropped for P2MP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redistribution_reset_count
                    
                    	Redist reset count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_default_group
                    
                    	Remote Default Group
                    	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup>`
                    
                    .. attribute:: remote_table_id
                    
                    	Remote Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_distinguisher
                    
                    	RD value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: rpf_default_table
                    
                    	RPF Default Table
                    	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable>`
                    
                    .. attribute:: rpf_id
                    
                    	RPF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_policy_name
                    
                    	RPF topology selection route\-policy name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_maximum_mdt_aggregation
                    
                    	RSVP\-TE MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_announce_interval
                    
                    	RSVP\-TE Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_switchover_interval
                    
                    	RSVP\-TE Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_interface
                    
                    	RSVP\-TEMDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rsvp_te_mdt_mtu
                    
                    	RSVP\-TEMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_name
                    
                    	RSVP\-TE MDT Name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_mdt_rpf_identifier
                    
                    	RSVP\-TE RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_static_p2mp_count
                    
                    	Number of Static P2MP\-TE MDT
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	PIM is using MuRIB
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_time
                    
                    	S,G Expiry Time Configured, in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: sg_expiry_timer_configured
                    
                    	S,G Expiry Timer Configured
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_timer_sg_list
                    
                    	S,G expiry timer ACL name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: stale_rd_present
                    
                    	RD is stale
                    	**type**\:  bool
                    
                    .. attribute:: suppress_pim_data_mdt_tlv
                    
                    	Suppress PIM Data\-MDT TLV Announcements
                    	**type**\:  bool
                    
                    .. attribute:: suppress_shared_tree_join
                    
                    	Suppress Shared\-Tree Joins
                    	**type**\:  bool
                    
                    .. attribute:: table_count
                    
                    	Number of configured Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: umh
                    
                    	Join UMH Core\-Tree
                    	**type**\:  bool
                    
                    .. attribute:: valid_rd_present
                    
                    	RD is valid
                    	**type**\:  bool
                    
                    .. attribute:: vpn_index
                    
                    	VPN Index
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.active_table_count = None
                        self.allow_rp_configured = None
                        self.allow_rp_group_list = None
                        self.allow_rp_rp_list = None
                        self.anycast_rp_configured = None
                        self.anycast_rp_policy_name = None
                        self.anycast_rp_range = YList()
                        self.anycast_rp_range.parent = self
                        self.anycast_rp_range.name = 'anycast_rp_range'
                        self.bgp_auto_discovery_configured = None
                        self.bgp_auto_discovery_type = None
                        self.bgp_i_pmsi_added = None
                        self.bgp_remote_address = None
                        self.bgp_remote_interface = None
                        self.bgp_remote_interface_name = None
                        self.bgp_remote_on = None
                        self.bgp_remote_state = None
                        self.bgp_source_active_announce = None
                        self.export_route_target = YList()
                        self.export_route_target.parent = self
                        self.export_route_target.name = 'export_route_target'
                        self.gin_b_and_mdt_data_announce_interval = None
                        self.gin_b_and_mdt_data_switchover_interval = None
                        self.gin_b_and_mdt_interface = None
                        self.gin_b_and_mdt_mtu = None
                        self.gin_b_and_mdt_name = None
                        self.gin_b_and_mdt_rpf_identifier = None
                        self.gin_band_maximum_mdt_aggregation = None
                        self.import_route_target = YList()
                        self.import_route_target.parent = self
                        self.import_route_target.name = 'import_route_target'
                        self.in_b_and_mdt_data_announce_interval = None
                        self.in_b_and_mdt_data_switchover_interval = None
                        self.in_b_and_mdt_interface = None
                        self.in_b_and_mdt_mtu = None
                        self.in_b_and_mdt_name = None
                        self.in_b_and_mdt_rpf_identifier = None
                        self.in_band_maximum_mdt_aggregation = None
                        self.in_band_signaling_local_enabled = None
                        self.in_band_signaling_remote_enabled = None
                        self.inter_autonomous_system_enabled = None
                        self.ir_maximum_mdt_aggregation = None
                        self.ir_mdt_data_announce_interval = None
                        self.ir_mdt_data_switchover_interval = None
                        self.ir_mdt_interface = None
                        self.ir_mdt_mtu = None
                        self.ir_mdt_name = None
                        self.ir_mdt_rpf_identifier = None
                        self.ir_mdt_tail_label = None
                        self.is_active = None
                        self.is_active_ital = None
                        self.is_all_interface_disable_operation = None
                        self.is_auto_rp_listen_enabled = None
                        self.is_auto_rp_listen_sock_add = None
                        self.is_create_gin_b_and_mdt_interface = None
                        self.is_create_in_b_and_mdt_interface = None
                        self.is_create_ir_mdt_interface = None
                        self.is_create_mdt_interface = None
                        self.is_create_mldp_mdt_interface = None
                        self.is_create_rsvp_te_mdt_interface = None
                        self.is_default_granges = None
                        self.is_gin_b_and_mdt_owner = None
                        self.is_in_b_and_mdt_owner = None
                        self.is_ir_mdt_owner = None
                        self.is_lpts_socket_add_required = None
                        self.is_lpts_socket_added = None
                        self.is_m_host_publish_pending = None
                        self.is_mdt_owner = None
                        self.is_mldp_mdt_owner = None
                        self.is_mrib_register = None
                        self.is_multicast_rib_registration = None
                        self.is_pim_nsf_rib_converge_received = None
                        self.is_pim_nsf_rib_converged = None
                        self.is_redistribution_reset = None
                        self.is_register_injection_lpts_socket_add_required = None
                        self.is_register_injection_lpts_socket_added = None
                        self.is_register_injection_socket_add_required = None
                        self.is_register_injection_socket_added = None
                        self.is_rib_multipath_enabled = None
                        self.is_rib_multipath_interface_hash = None
                        self.is_rib_multipath_source_hash = None
                        self.is_rib_multipath_source_next_hop_hash = None
                        self.is_routing_enabled = None
                        self.is_rsvp_te_mdt_owner = None
                        self.is_socket_add_required = None
                        self.is_socket_added = None
                        self.is_udp_socket_add_required = None
                        self.is_udp_socket_added = None
                        self.is_udp_socket_bind = None
                        self.is_udp_socket_bind_required = None
                        self.is_unicast_rib_registration = None
                        self.maximum_mdt_aggregation = None
                        self.mdt_data_announce_interval = None
                        self.mdt_data_switchover_interval = None
                        self.mdt_default_group = None
                        self.mdt_gre_remote_rpf_identifier = None
                        self.mdt_gre_rpf_identifier = None
                        self.mdt_interface = None
                        self.mdt_mtu = None
                        self.mdt_neighbor_filter_name = None
                        self.mdt_partitioned_ir_control_identifier = None
                        self.mdt_partitioned_mdt_control_identifier = None
                        self.mhost_default_interface_config = None
                        self.mhost_interface = None
                        self.mldp_auto_rp_announce_tree_added = None
                        self.mldp_auto_rp_discovery_tree_added = None
                        self.mldp_bsr_control_tree_added = None
                        self.mldp_control_head_lsm_identifier = None
                        self.mldp_head_local_label = None
                        self.mldp_head_lsm_identifier = None
                        self.mldp_maximum_mdt_aggregation = None
                        self.mldp_mdt_data_announce_interval = None
                        self.mldp_mdt_data_switchover_interval = None
                        self.mldp_mdt_interface = None
                        self.mldp_mdt_mtu = None
                        self.mldp_mdt_name = None
                        self.mldp_mdt_remote_rpf_identifier = None
                        self.mldp_mdt_rpf_identifier = None
                        self.mldp_partioned_mp2m_ptree = None
                        self.mldp_partitioned_head_lsm_identifier = None
                        self.mldp_partitioned_mdt_configured = None
                        self.mldp_partitioned_mdt_identifier = None
                        self.mldp_remote_head_lsm_identifier = None
                        self.mldp_remote_partitioned_mdt_configured = None
                        self.mldp_root_address = YLeafList()
                        self.mldp_root_address.parent = self
                        self.mldp_root_address.name = 'mldp_root_address'
                        self.mldp_root_count = None
                        self.murib_id = None
                        self.neighbor_filter_name = None
                        self.non_default_vrf_count_on_socket = None
                        self.organization_unique_identifier = None
                        self.p2mpte_li_drop = None
                        self.redistribution_reset_count = None
                        self.remote_default_group = Ipv6Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup()
                        self.remote_default_group.parent = self
                        self.remote_table_id = None
                        self.route_distinguisher = None
                        self.rpf_default_table = Ipv6Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable()
                        self.rpf_default_table.parent = self
                        self.rpf_id = None
                        self.rpf_policy_name = None
                        self.rsvp_te_maximum_mdt_aggregation = None
                        self.rsvp_te_mdt_data_announce_interval = None
                        self.rsvp_te_mdt_data_switchover_interval = None
                        self.rsvp_te_mdt_interface = None
                        self.rsvp_te_mdt_mtu = None
                        self.rsvp_te_mdt_name = None
                        self.rsvp_te_mdt_rpf_identifier = None
                        self.rsvp_te_mdt_static_p2mp_count = None
                        self.rump_enabled = None
                        self.sg_expiry_time = None
                        self.sg_expiry_timer_configured = None
                        self.sg_expiry_timer_sg_list = None
                        self.stale_rd_present = None
                        self.suppress_pim_data_mdt_tlv = None
                        self.suppress_shared_tree_join = None
                        self.table_count = None
                        self.table_id = None
                        self.umh = None
                        self.valid_rd_present = None
                        self.vpn_index = None
                        self.vrf_id = None


                    class RemoteDefaultGroup(object):
                        """
                        Remote Default Group
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:remote-default-group'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup']['meta_info']


                    class RpfDefaultTable(object):
                        """
                        RPF Default Table
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.afi = None
                            self.is_active = None
                            self.is_ital_registration_done = None
                            self.is_rib_convergence = None
                            self.is_rib_convergence_received = None
                            self.is_rib_registration_done = None
                            self.rpf_registrations = None
                            self.safi = None
                            self.table_id = None
                            self.table_name = None
                            self.vrf_id = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-default-table'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.afi is not None:
                                return True

                            if self.is_active is not None:
                                return True

                            if self.is_ital_registration_done is not None:
                                return True

                            if self.is_rib_convergence is not None:
                                return True

                            if self.is_rib_convergence_received is not None:
                                return True

                            if self.is_rib_registration_done is not None:
                                return True

                            if self.rpf_registrations is not None:
                                return True

                            if self.safi is not None:
                                return True

                            if self.table_id is not None:
                                return True

                            if self.table_name is not None:
                                return True

                            if self.vrf_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable']['meta_info']


                    class ExportRouteTarget(object):
                        """
                        Export Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.anycast_rp = None
                            self.anycast_rp_marked = None
                            self.bgp_auto_discovery = None
                            self.configured = None
                            self.route_target = None
                            self.segment_border = None
                            self.update_pending = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:export-route-target'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.anycast_rp is not None:
                                return True

                            if self.anycast_rp_marked is not None:
                                return True

                            if self.bgp_auto_discovery is not None:
                                return True

                            if self.configured is not None:
                                return True

                            if self.route_target is not None:
                                return True

                            if self.segment_border is not None:
                                return True

                            if self.update_pending is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget']['meta_info']


                    class ImportRouteTarget(object):
                        """
                        Import Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.anycast_rp = None
                            self.anycast_rp_marked = None
                            self.bgp_auto_discovery = None
                            self.configured = None
                            self.route_target = None
                            self.segment_border = None
                            self.update_pending = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:import-route-target'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.anycast_rp is not None:
                                return True

                            if self.anycast_rp_marked is not None:
                                return True

                            if self.bgp_auto_discovery is not None:
                                return True

                            if self.configured is not None:
                                return True

                            if self.route_target is not None:
                                return True

                            if self.segment_border is not None:
                                return True

                            if self.update_pending is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget']['meta_info']


                    class AnycastRpRange(object):
                        """
                        Anycast\-RP Ranges
                        
                        .. attribute:: ancast_rp_marked
                        
                        	Anycast\-RP Range marked
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Anycast\-RP Range Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Anycast\-RP Range Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ancast_rp_marked = None
                            self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None


                        class Prefix(object):
                            """
                            Anycast\-RP Range Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:anycast-rp-range'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ancast_rp_marked is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:context'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.active_table_count is not None:
                            return True

                        if self.allow_rp_configured is not None:
                            return True

                        if self.allow_rp_group_list is not None:
                            return True

                        if self.allow_rp_rp_list is not None:
                            return True

                        if self.anycast_rp_configured is not None:
                            return True

                        if self.anycast_rp_policy_name is not None:
                            return True

                        if self.anycast_rp_range is not None:
                            for child_ref in self.anycast_rp_range:
                                if child_ref._has_data():
                                    return True

                        if self.bgp_auto_discovery_configured is not None:
                            return True

                        if self.bgp_auto_discovery_type is not None:
                            return True

                        if self.bgp_i_pmsi_added is not None:
                            return True

                        if self.bgp_remote_address is not None:
                            return True

                        if self.bgp_remote_interface is not None:
                            return True

                        if self.bgp_remote_interface_name is not None:
                            return True

                        if self.bgp_remote_on is not None:
                            return True

                        if self.bgp_remote_state is not None:
                            return True

                        if self.bgp_source_active_announce is not None:
                            return True

                        if self.export_route_target is not None:
                            for child_ref in self.export_route_target:
                                if child_ref._has_data():
                                    return True

                        if self.gin_b_and_mdt_data_announce_interval is not None:
                            return True

                        if self.gin_b_and_mdt_data_switchover_interval is not None:
                            return True

                        if self.gin_b_and_mdt_interface is not None:
                            return True

                        if self.gin_b_and_mdt_mtu is not None:
                            return True

                        if self.gin_b_and_mdt_name is not None:
                            return True

                        if self.gin_b_and_mdt_rpf_identifier is not None:
                            return True

                        if self.gin_band_maximum_mdt_aggregation is not None:
                            return True

                        if self.import_route_target is not None:
                            for child_ref in self.import_route_target:
                                if child_ref._has_data():
                                    return True

                        if self.in_b_and_mdt_data_announce_interval is not None:
                            return True

                        if self.in_b_and_mdt_data_switchover_interval is not None:
                            return True

                        if self.in_b_and_mdt_interface is not None:
                            return True

                        if self.in_b_and_mdt_mtu is not None:
                            return True

                        if self.in_b_and_mdt_name is not None:
                            return True

                        if self.in_b_and_mdt_rpf_identifier is not None:
                            return True

                        if self.in_band_maximum_mdt_aggregation is not None:
                            return True

                        if self.in_band_signaling_local_enabled is not None:
                            return True

                        if self.in_band_signaling_remote_enabled is not None:
                            return True

                        if self.inter_autonomous_system_enabled is not None:
                            return True

                        if self.ir_maximum_mdt_aggregation is not None:
                            return True

                        if self.ir_mdt_data_announce_interval is not None:
                            return True

                        if self.ir_mdt_data_switchover_interval is not None:
                            return True

                        if self.ir_mdt_interface is not None:
                            return True

                        if self.ir_mdt_mtu is not None:
                            return True

                        if self.ir_mdt_name is not None:
                            return True

                        if self.ir_mdt_rpf_identifier is not None:
                            return True

                        if self.ir_mdt_tail_label is not None:
                            return True

                        if self.is_active is not None:
                            return True

                        if self.is_active_ital is not None:
                            return True

                        if self.is_all_interface_disable_operation is not None:
                            return True

                        if self.is_auto_rp_listen_enabled is not None:
                            return True

                        if self.is_auto_rp_listen_sock_add is not None:
                            return True

                        if self.is_create_gin_b_and_mdt_interface is not None:
                            return True

                        if self.is_create_in_b_and_mdt_interface is not None:
                            return True

                        if self.is_create_ir_mdt_interface is not None:
                            return True

                        if self.is_create_mdt_interface is not None:
                            return True

                        if self.is_create_mldp_mdt_interface is not None:
                            return True

                        if self.is_create_rsvp_te_mdt_interface is not None:
                            return True

                        if self.is_default_granges is not None:
                            return True

                        if self.is_gin_b_and_mdt_owner is not None:
                            return True

                        if self.is_in_b_and_mdt_owner is not None:
                            return True

                        if self.is_ir_mdt_owner is not None:
                            return True

                        if self.is_lpts_socket_add_required is not None:
                            return True

                        if self.is_lpts_socket_added is not None:
                            return True

                        if self.is_m_host_publish_pending is not None:
                            return True

                        if self.is_mdt_owner is not None:
                            return True

                        if self.is_mldp_mdt_owner is not None:
                            return True

                        if self.is_mrib_register is not None:
                            return True

                        if self.is_multicast_rib_registration is not None:
                            return True

                        if self.is_pim_nsf_rib_converge_received is not None:
                            return True

                        if self.is_pim_nsf_rib_converged is not None:
                            return True

                        if self.is_redistribution_reset is not None:
                            return True

                        if self.is_register_injection_lpts_socket_add_required is not None:
                            return True

                        if self.is_register_injection_lpts_socket_added is not None:
                            return True

                        if self.is_register_injection_socket_add_required is not None:
                            return True

                        if self.is_register_injection_socket_added is not None:
                            return True

                        if self.is_rib_multipath_enabled is not None:
                            return True

                        if self.is_rib_multipath_interface_hash is not None:
                            return True

                        if self.is_rib_multipath_source_hash is not None:
                            return True

                        if self.is_rib_multipath_source_next_hop_hash is not None:
                            return True

                        if self.is_routing_enabled is not None:
                            return True

                        if self.is_rsvp_te_mdt_owner is not None:
                            return True

                        if self.is_socket_add_required is not None:
                            return True

                        if self.is_socket_added is not None:
                            return True

                        if self.is_udp_socket_add_required is not None:
                            return True

                        if self.is_udp_socket_added is not None:
                            return True

                        if self.is_udp_socket_bind is not None:
                            return True

                        if self.is_udp_socket_bind_required is not None:
                            return True

                        if self.is_unicast_rib_registration is not None:
                            return True

                        if self.maximum_mdt_aggregation is not None:
                            return True

                        if self.mdt_data_announce_interval is not None:
                            return True

                        if self.mdt_data_switchover_interval is not None:
                            return True

                        if self.mdt_default_group is not None:
                            return True

                        if self.mdt_gre_remote_rpf_identifier is not None:
                            return True

                        if self.mdt_gre_rpf_identifier is not None:
                            return True

                        if self.mdt_interface is not None:
                            return True

                        if self.mdt_mtu is not None:
                            return True

                        if self.mdt_neighbor_filter_name is not None:
                            return True

                        if self.mdt_partitioned_ir_control_identifier is not None:
                            return True

                        if self.mdt_partitioned_mdt_control_identifier is not None:
                            return True

                        if self.mhost_default_interface_config is not None:
                            return True

                        if self.mhost_interface is not None:
                            return True

                        if self.mldp_auto_rp_announce_tree_added is not None:
                            return True

                        if self.mldp_auto_rp_discovery_tree_added is not None:
                            return True

                        if self.mldp_bsr_control_tree_added is not None:
                            return True

                        if self.mldp_control_head_lsm_identifier is not None:
                            return True

                        if self.mldp_head_local_label is not None:
                            return True

                        if self.mldp_head_lsm_identifier is not None:
                            return True

                        if self.mldp_maximum_mdt_aggregation is not None:
                            return True

                        if self.mldp_mdt_data_announce_interval is not None:
                            return True

                        if self.mldp_mdt_data_switchover_interval is not None:
                            return True

                        if self.mldp_mdt_interface is not None:
                            return True

                        if self.mldp_mdt_mtu is not None:
                            return True

                        if self.mldp_mdt_name is not None:
                            return True

                        if self.mldp_mdt_remote_rpf_identifier is not None:
                            return True

                        if self.mldp_mdt_rpf_identifier is not None:
                            return True

                        if self.mldp_partioned_mp2m_ptree is not None:
                            return True

                        if self.mldp_partitioned_head_lsm_identifier is not None:
                            return True

                        if self.mldp_partitioned_mdt_configured is not None:
                            return True

                        if self.mldp_partitioned_mdt_identifier is not None:
                            return True

                        if self.mldp_remote_head_lsm_identifier is not None:
                            return True

                        if self.mldp_remote_partitioned_mdt_configured is not None:
                            return True

                        if self.mldp_root_address is not None:
                            for child in self.mldp_root_address:
                                if child is not None:
                                    return True

                        if self.mldp_root_count is not None:
                            return True

                        if self.murib_id is not None:
                            return True

                        if self.neighbor_filter_name is not None:
                            return True

                        if self.non_default_vrf_count_on_socket is not None:
                            return True

                        if self.organization_unique_identifier is not None:
                            return True

                        if self.p2mpte_li_drop is not None:
                            return True

                        if self.redistribution_reset_count is not None:
                            return True

                        if self.remote_default_group is not None and self.remote_default_group._has_data():
                            return True

                        if self.remote_table_id is not None:
                            return True

                        if self.route_distinguisher is not None:
                            return True

                        if self.rpf_default_table is not None and self.rpf_default_table._has_data():
                            return True

                        if self.rpf_id is not None:
                            return True

                        if self.rpf_policy_name is not None:
                            return True

                        if self.rsvp_te_maximum_mdt_aggregation is not None:
                            return True

                        if self.rsvp_te_mdt_data_announce_interval is not None:
                            return True

                        if self.rsvp_te_mdt_data_switchover_interval is not None:
                            return True

                        if self.rsvp_te_mdt_interface is not None:
                            return True

                        if self.rsvp_te_mdt_mtu is not None:
                            return True

                        if self.rsvp_te_mdt_name is not None:
                            return True

                        if self.rsvp_te_mdt_rpf_identifier is not None:
                            return True

                        if self.rsvp_te_mdt_static_p2mp_count is not None:
                            return True

                        if self.rump_enabled is not None:
                            return True

                        if self.sg_expiry_time is not None:
                            return True

                        if self.sg_expiry_timer_configured is not None:
                            return True

                        if self.sg_expiry_timer_sg_list is not None:
                            return True

                        if self.stale_rd_present is not None:
                            return True

                        if self.suppress_pim_data_mdt_tlv is not None:
                            return True

                        if self.suppress_shared_tree_join is not None:
                            return True

                        if self.table_count is not None:
                            return True

                        if self.table_id is not None:
                            return True

                        if self.umh is not None:
                            return True

                        if self.valid_rd_present is not None:
                            return True

                        if self.vpn_index is not None:
                            return True

                        if self.vrf_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Context']['meta_info']


                class TopologyEntryFlagRouteCounts(object):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: topology_entry_flag_route_count
                    
                    	Route count for topology with entry flag set
                    	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.topology_entry_flag_route_count = YList()
                        self.topology_entry_flag_route_count.parent = self
                        self.topology_entry_flag_route_count.name = 'topology_entry_flag_route_count'


                    class TopologyEntryFlagRouteCount(object):
                        """
                        Route count for topology with entry flag set
                        
                        .. attribute:: entry_flag  <key>
                        
                        	entry flag
                        	**type**\:   :py:class:`PimTopologyEntryFlagEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlagEnum>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.entry_flag = None
                            self.active_group_ranges = None
                            self.group_address = Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                            self.group_address.parent = self
                            self.group_ranges = None
                            self.groute_count = None
                            self.is_node_low_memory = None
                            self.sg_route_count = None
                            self.sgr_route_count = None


                        class GroupAddress(object):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.entry_flag is None:
                                raise YPYModelError('Key property entry_flag is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology-entry-flag-route-count[Cisco-IOS-XR-ipv4-pim-oper:entry-flag = ' + str(self.entry_flag) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.entry_flag is not None:
                                return True

                            if self.active_group_ranges is not None:
                                return True

                            if self.group_address is not None and self.group_address._has_data():
                                return True

                            if self.group_ranges is not None:
                                return True

                            if self.groute_count is not None:
                                return True

                            if self.is_node_low_memory is not None:
                                return True

                            if self.sg_route_count is not None:
                                return True

                            if self.sgr_route_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology-entry-flag-route-counts'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.topology_entry_flag_route_count is not None:
                            for child_ref in self.topology_entry_flag_route_count:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts']['meta_info']


                class RpfRedirect(object):
                    """
                    PIM ECMP RPF\-redirect bundle
                    
                    .. attribute:: bundle_interfaces
                    
                    	PIM ECMP RPF\-redirect bundle information
                    	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces>`
                    
                    .. attribute:: redirect_route_databases
                    
                    	PIM ECMP RPF\-redirect route database
                    	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bundle_interfaces = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces()
                        self.bundle_interfaces.parent = self
                        self.redirect_route_databases = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases()
                        self.redirect_route_databases.parent = self


                    class RedirectRouteDatabases(object):
                        """
                        PIM ECMP RPF\-redirect route database
                        
                        .. attribute:: redirect_route_database
                        
                        	PIM ECMP RPF\-redirect route information
                        	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.redirect_route_database = YList()
                            self.redirect_route_database.parent = self
                            self.redirect_route_database.name = 'redirect_route_database'


                        class RedirectRouteDatabase(object):
                            """
                            PIM ECMP RPF\-redirect route information
                            
                            .. attribute:: bandwidth
                            
                            	Bandwidth in Kbps
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Group ddress
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                            
                            .. attribute:: interface
                            
                            	Outgoing interface list
                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bandwidth = None
                                self.group_address = None
                                self.group_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self.interface = YList()
                                self.interface.parent = self
                                self.interface.name = 'interface'
                                self.source_address = None
                                self.source_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self.uptime = None


                            class GroupAddressXr(object):
                                """
                                Group ddress
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr']['meta_info']


                            class SourceAddressXr(object):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr']['meta_info']


                            class Interface(object):
                                """
                                Outgoing interface list
                                
                                .. attribute:: expiry
                                
                                	Expiry in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: is_outgoing_interface
                                
                                	Is outgoing Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface
                                
                                	Is RPF Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_snoop_interface
                                
                                	Is snooping Interface
                                	**type**\:  bool
                                
                                .. attribute:: rpf_address
                                
                                	RPF Address
                                	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                                
                                .. attribute:: uptime
                                
                                	Uptime in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.expiry = None
                                    self.interface_name = None
                                    self.is_outgoing_interface = None
                                    self.is_rpf_interface = None
                                    self.is_snoop_interface = None
                                    self.rpf_address = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                    self.rpf_address.parent = self
                                    self.uptime = None


                                class RpfAddress(object):
                                    """
                                    RPF Address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.expiry is not None:
                                        return True

                                    if self.interface_name is not None:
                                        return True

                                    if self.is_outgoing_interface is not None:
                                        return True

                                    if self.is_rpf_interface is not None:
                                        return True

                                    if self.is_snoop_interface is not None:
                                        return True

                                    if self.rpf_address is not None and self.rpf_address._has_data():
                                        return True

                                    if self.uptime is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bandwidth is not None:
                                    return True

                                if self.group_address is not None:
                                    return True

                                if self.group_address_xr is not None and self.group_address_xr._has_data():
                                    return True

                                if self.interface is not None:
                                    for child_ref in self.interface:
                                        if child_ref._has_data():
                                            return True

                                if self.source_address is not None:
                                    return True

                                if self.source_address_xr is not None and self.source_address_xr._has_data():
                                    return True

                                if self.uptime is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.redirect_route_database is not None:
                                for child_ref in self.redirect_route_database:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases']['meta_info']


                    class BundleInterfaces(object):
                        """
                        PIM ECMP RPF\-redirect bundle information
                        
                        .. attribute:: bundle_interface
                        
                        	PIM ECMP RPF\-redirect bundle interface information
                        	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bundle_interface = YList()
                            self.bundle_interface.parent = self
                            self.bundle_interface.name = 'bundle_interface'


                        class BundleInterface(object):
                            """
                            PIM ECMP RPF\-redirect bundle interface
                            information
                            
                            .. attribute:: allocated_bandwidth
                            
                            	Bandwidth allocated in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: allocated_threshold_bandwidth
                            
                            	Configured threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_bandwidth
                            
                            	Bandwidth available in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_threshold_bandwidth
                            
                            	Available threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: bundle_name
                            
                            	Bundle name
                            	**type**\:  str
                            
                            	**length:** 1..32
                            
                            .. attribute:: interface_name
                            
                            	Bundle interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: rpf_redirect_bundle_name
                            
                            	RPF redirect bundle name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: rpf_redirect_interface_name
                            
                            	RPF redirect interface name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: snooping_bandwidth_used
                            
                            	Bandwidth used by snooped entries in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: topology_bandwidth_used
                            
                            	Bandwidth used by topology in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: total_bandwidth
                            
                            	Total bandwidth used in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.allocated_bandwidth = None
                                self.allocated_threshold_bandwidth = None
                                self.available_bandwidth = None
                                self.available_threshold_bandwidth = None
                                self.bundle_name = None
                                self.interface_name = None
                                self.rpf_redirect_bundle_name = None
                                self.rpf_redirect_interface_name = None
                                self.snooping_bandwidth_used = None
                                self.topology_bandwidth_used = None
                                self.total_bandwidth = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bundle-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.allocated_bandwidth is not None:
                                    return True

                                if self.allocated_threshold_bandwidth is not None:
                                    return True

                                if self.available_bandwidth is not None:
                                    return True

                                if self.available_threshold_bandwidth is not None:
                                    return True

                                if self.bundle_name is not None:
                                    return True

                                if self.interface_name is not None:
                                    return True

                                if self.rpf_redirect_bundle_name is not None:
                                    return True

                                if self.rpf_redirect_interface_name is not None:
                                    return True

                                if self.snooping_bandwidth_used is not None:
                                    return True

                                if self.topology_bandwidth_used is not None:
                                    return True

                                if self.total_bandwidth is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bundle-interfaces'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bundle_interface is not None:
                                for child_ref in self.bundle_interface:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bundle_interfaces is not None and self.bundle_interfaces._has_data():
                            return True

                        if self.redirect_route_databases is not None and self.redirect_route_databases._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect']['meta_info']


                class Tunnels(object):
                    """
                    Tunnels information that PIM has
                    
                    .. attribute:: tunnel
                    
                    	PIM tunnel information
                    	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.tunnel = YList()
                        self.tunnel.parent = self
                        self.tunnel.name = 'tunnel'


                    class Tunnel(object):
                        """
                        PIM tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.tunnel_name = None
                            self.group_address_netio = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress()
                            self.rp_address.parent = self
                            self.source_address = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress()
                            self.source_address.parent = self
                            self.source_address_netio = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self.vrf_name = None


                        class SourceAddress(object):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress']['meta_info']


                        class RpAddress(object):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress']['meta_info']


                        class SourceAddressNetio(object):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-netio'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio']['meta_info']


                        class GroupAddressNetio(object):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-netio'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.tunnel_name is None:
                                raise YPYModelError('Key property tunnel_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:tunnel[Cisco-IOS-XR-ipv4-pim-oper:tunnel-name = ' + str(self.tunnel_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.tunnel_name is not None:
                                return True

                            if self.group_address_netio is not None and self.group_address_netio._has_data():
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            if self.source_address is not None and self.source_address._has_data():
                                return True

                            if self.source_address_netio is not None and self.source_address_netio._has_data():
                                return True

                            if self.vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:tunnels'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.tunnel is not None:
                            for child_ref in self.tunnel:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Tunnels']['meta_info']


                class MulticastStaticRoutes(object):
                    """
                    PIM multicast static route table
                    
                    .. attribute:: multicast_static_route
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.multicast_static_route = YList()
                        self.multicast_static_route.parent = self
                        self.multicast_static_route.name = 'multicast_static_route'


                    class MulticastStaticRoute(object):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: address
                        
                        	Network address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: distance
                        
                        	Distance
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_via_lsm
                        
                        	LSM flag
                        	**type**\:  bool
                        
                        .. attribute:: nexthop
                        
                        	Next Hop
                        	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: prefix_length_xr
                        
                        	Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.address = None
                            self.distance = None
                            self.interface_name = None
                            self.is_via_lsm = None
                            self.nexthop = Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                            self.nexthop.parent = self
                            self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.prefix_length_xr = None


                        class Prefix(object):
                            """
                            Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix']['meta_info']


                        class Nexthop(object):
                            """
                            Next Hop
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:nexthop'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-route'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.address is not None:
                                return True

                            if self.distance is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.is_via_lsm is not None:
                                return True

                            if self.nexthop is not None and self.nexthop._has_data():
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.prefix_length_xr is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-routes'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.multicast_static_route is not None:
                            for child_ref in self.multicast_static_route:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes']['meta_info']


                class GroupMapMatchSources(object):
                    """
                    Find the matching group\-mapping with source
                    information on specified group address
                    
                    .. attribute:: group_map_match_source
                    
                    	PIM group\-matching mapping entry with source information
                    	**type**\: list of    :py:class:`GroupMapMatchSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_map_match_source = YList()
                        self.group_map_match_source.parent = self
                        self.group_map_match_source.name = 'group_map_match_source'


                    class GroupMapMatchSource(object):
                        """
                        PIM group\-matching mapping entry with source
                        information
                        
                        .. attribute:: group_address  <key>
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.group_address = None
                            self.expires = None
                            self.group_map_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self.holdtime = None
                            self.source_of_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self.uptime = None


                        class SourceOfInformation(object):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation']['meta_info']


                        class GroupMapInformation(object):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.client = None
                                self.group_count = None
                                self.is_override = None
                                self.is_used = None
                                self.mrib_active = None
                                self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self.prefix_length = None
                                self.priority = None
                                self.protocol = None
                                self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self


                            class Prefix(object):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix']['meta_info']


                            class RpAddress(object):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.client is not None:
                                    return True

                                if self.group_count is not None:
                                    return True

                                if self.is_override is not None:
                                    return True

                                if self.is_used is not None:
                                    return True

                                if self.mrib_active is not None:
                                    return True

                                if self.prefix is not None and self.prefix._has_data():
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.priority is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.rp_address is not None and self.rp_address._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.group_address is None:
                                raise YPYModelError('Key property group_address is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-source[Cisco-IOS-XR-ipv4-pim-oper:group-address = ' + str(self.group_address) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.group_address is not None:
                                return True

                            if self.expires is not None:
                                return True

                            if self.group_map_information is not None and self.group_map_information._has_data():
                                return True

                            if self.holdtime is not None:
                                return True

                            if self.source_of_information is not None and self.source_of_information._has_data():
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-sources'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_map_match_source is not None:
                            for child_ref in self.group_map_match_source:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources']['meta_info']


                class Neighbors(object):
                    """
                    PIM neighbor table
                    
                    .. attribute:: neighbor
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.neighbor = YList()
                        self.neighbor.parent = self
                        self.neighbor.name = 'neighbor'


                    class Neighbor(object):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dr_priority = None
                            self.expires = None
                            self.expiry_timer = None
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.is_batch_asserts_capable = None
                            self.is_bfd_state = None
                            self.is_bidirectional_capable = None
                            self.is_dr_priority_capable = None
                            self.is_ecmp_redirect_capable = None
                            self.is_proxy_capable = None
                            self.is_this_neighbor_dr = None
                            self.is_this_neighbor_us = None
                            self.neighbor_address = None
                            self.neighbor_address_xr = YList()
                            self.neighbor_address_xr.parent = self
                            self.neighbor_address_xr.name = 'neighbor_address_xr'
                            self.override_interval = None
                            self.propagation_delay = None
                            self.uptime = None


                        class NeighborAddressXr(object):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dr_priority is not None:
                                return True

                            if self.expires is not None:
                                return True

                            if self.expiry_timer is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.is_batch_asserts_capable is not None:
                                return True

                            if self.is_bfd_state is not None:
                                return True

                            if self.is_bidirectional_capable is not None:
                                return True

                            if self.is_dr_priority_capable is not None:
                                return True

                            if self.is_ecmp_redirect_capable is not None:
                                return True

                            if self.is_proxy_capable is not None:
                                return True

                            if self.is_this_neighbor_dr is not None:
                                return True

                            if self.is_this_neighbor_us is not None:
                                return True

                            if self.neighbor_address is not None:
                                return True

                            if self.neighbor_address_xr is not None:
                                for child_ref in self.neighbor_address_xr:
                                    if child_ref._has_data():
                                        return True

                            if self.override_interval is not None:
                                return True

                            if self.propagation_delay is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbors'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.neighbor is not None:
                            for child_ref in self.neighbor:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf.Neighbors']['meta_info']

                @property
                def _common_path(self):
                    if self.vrf_name is None:
                        raise YPYModelError('Key property vrf_name is None')

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:vrfs/Cisco-IOS-XR-ipv4-pim-oper:vrf[Cisco-IOS-XR-ipv4-pim-oper:vrf-name = ' + str(self.vrf_name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.vrf_name is not None:
                        return True

                    if self.auto_rp is not None and self.auto_rp._has_data():
                        return True

                    if self.bgp_afs is not None and self.bgp_afs._has_data():
                        return True

                    if self.bidir_df_states is not None and self.bidir_df_states._has_data():
                        return True

                    if self.bidir_df_winners is not None and self.bidir_df_winners._has_data():
                        return True

                    if self.bsr is not None and self.bsr._has_data():
                        return True

                    if self.context is not None and self.context._has_data():
                        return True

                    if self.gre is not None and self.gre._has_data():
                        return True

                    if self.group_map_match_rpfs is not None and self.group_map_match_rpfs._has_data():
                        return True

                    if self.group_map_match_sources is not None and self.group_map_match_sources._has_data():
                        return True

                    if self.group_map_rpfs is not None and self.group_map_rpfs._has_data():
                        return True

                    if self.group_map_sources is not None and self.group_map_sources._has_data():
                        return True

                    if self.ifrs_interfaces is not None and self.ifrs_interfaces._has_data():
                        return True

                    if self.ifrs_summary is not None and self.ifrs_summary._has_data():
                        return True

                    if self.interface_old_formats is not None and self.interface_old_formats._has_data():
                        return True

                    if self.interface_statistics is not None and self.interface_statistics._has_data():
                        return True

                    if self.interfaces is not None and self.interfaces._has_data():
                        return True

                    if self.jp_statistics is not None and self.jp_statistics._has_data():
                        return True

                    if self.mib_databases is not None and self.mib_databases._has_data():
                        return True

                    if self.multicast_static_routes is not None and self.multicast_static_routes._has_data():
                        return True

                    if self.neighbor_old_formats is not None and self.neighbor_old_formats._has_data():
                        return True

                    if self.neighbor_summaries is not None and self.neighbor_summaries._has_data():
                        return True

                    if self.neighbors is not None and self.neighbors._has_data():
                        return True

                    if self.net_io_tunnels is not None and self.net_io_tunnels._has_data():
                        return True

                    if self.ranges is not None and self.ranges._has_data():
                        return True

                    if self.route_policy is not None and self.route_policy._has_data():
                        return True

                    if self.rpf_redirect is not None and self.rpf_redirect._has_data():
                        return True

                    if self.rpf_summary is not None and self.rpf_summary._has_data():
                        return True

                    if self.safs is not None and self.safs._has_data():
                        return True

                    if self.summary is not None and self.summary._has_data():
                        return True

                    if self.table_contexts is not None and self.table_contexts._has_data():
                        return True

                    if self.topologies is not None and self.topologies._has_data():
                        return True

                    if self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts._has_data():
                        return True

                    if self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts._has_data():
                        return True

                    if self.topology_route_count is not None and self.topology_route_count._has_data():
                        return True

                    if self.traffic_counters is not None and self.traffic_counters._has_data():
                        return True

                    if self.tunnels is not None and self.tunnels._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Standby.Vrfs.Vrf']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:vrfs'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.vrf is not None:
                    for child_ref in self.vrf:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                return meta._meta_table['Ipv6Pim.Standby.Vrfs']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:standby'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.default_context is not None and self.default_context._has_data():
                return True

            if self.process is not None and self.process._has_data():
                return True

            if self.vrfs is not None and self.vrfs._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
            return meta._meta_table['Ipv6Pim.Standby']['meta_info']


    class Active(object):
        """
        Active Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:   :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:   :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.default_context = Ipv6Pim.Active.DefaultContext()
            self.default_context.parent = self
            self.process = Ipv6Pim.Active.Process()
            self.process.parent = self
            self.vrfs = Ipv6Pim.Active.Vrfs()
            self.vrfs.parent = self


        class DefaultContext(object):
            """
            Default Context
            
            .. attribute:: auto_rp
            
            	PIM Auto\-RP information
            	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.AutoRp>`
            
            .. attribute:: bgp_afs
            
            	PIM BGP SAFI table
            	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BgpAfs>`
            
            .. attribute:: bidir_df_states
            
            	Bidirectional PIM DF election state table
            	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfStates>`
            
            .. attribute:: bidir_df_winners
            
            	Bidirectional PIM DF election winner table
            	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfWinners>`
            
            .. attribute:: bsr
            
            	PIM BSR information
            	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr>`
            
            .. attribute:: context
            
            	PIM context information
            	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context>`
            
            .. attribute:: global_interfaces
            
            	PIM global interface table
            	**type**\:   :py:class:`GlobalInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GlobalInterfaces>`
            
            .. attribute:: gre
            
            	GRE information
            	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre>`
            
            .. attribute:: group_map_match_rpfs
            
            	Find matching group\-mapping for the specified group address
            	**type**\:   :py:class:`GroupMapMatchRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs>`
            
            .. attribute:: group_map_match_sources
            
            	Find the matching group\-mapping with source information on specified group address
            	**type**\:   :py:class:`GroupMapMatchSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchSources>`
            
            .. attribute:: group_map_rpfs
            
            	PIM group mapping information
            	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs>`
            
            .. attribute:: group_map_sources
            
            	PIM group\-mapping with source information
            	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources>`
            
            .. attribute:: ifrs_interfaces
            
            	PIM interfaces in forward reference store table
            	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: ifrs_summary
            
            	PIM interfaces in forward reference store summary
            	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.IfrsSummary>`
            
            .. attribute:: interface_old_formats
            
            	PIM interfaces in old format
            	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceOldFormats>`
            
            .. attribute:: interface_statistics
            
            	PIM interface statistics
            	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceStatistics>`
            
            .. attribute:: interfaces
            
            	PIM interfaces
            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Interfaces>`
            
            .. attribute:: jp_statistics
            
            	PIM join prune statistics table
            	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.JpStatistics>`
            
            .. attribute:: mib_databases
            
            	PIM group database for mroute mibs table
            	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases>`
            
            .. attribute:: multicast_static_routes
            
            	PIM multicast static route table
            	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes>`
            
            .. attribute:: neighbor_old_formats
            
            	PIM neighbor table old format
            	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NeighborOldFormats>`
            
            .. attribute:: neighbor_summaries
            
            	PIM neighbor summary table
            	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NeighborSummaries>`
            
            .. attribute:: neighbors
            
            	PIM neighbor table
            	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Neighbors>`
            
            .. attribute:: net_io_tunnels
            
            	Tunnel information that NETIO has 
            	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels>`
            
            .. attribute:: ranges
            
            	PIM range list information
            	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges>`
            
            .. attribute:: route_policy
            
            	PIM route policy
            	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy>`
            
            .. attribute:: rpf_redirect
            
            	PIM ECMP RPF\-redirect bundle
            	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect>`
            
            .. attribute:: rpf_summary
            
            	PIM RPF registration summary
            	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfSummary>`
            
            .. attribute:: safs
            
            	SAFI table and type
            	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs>`
            
            .. attribute:: summary
            
            	PIM summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Summary>`
            
            .. attribute:: table_contexts
            
            	PIM table context list
            	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TableContexts>`
            
            .. attribute:: topologies
            
            	PIM topology table
            	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies>`
            
            .. attribute:: topology_entry_flag_route_counts
            
            	Route count for topology with entry flag set
            	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts>`
            
            .. attribute:: topology_interface_flag_route_counts
            
            	Route count for topology with interface flag set
            	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts>`
            
            .. attribute:: topology_route_count
            
            	Topology route count information from PIM topology table
            	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyRouteCount>`
            
            .. attribute:: traffic_counters
            
            	PIM message traffic counters
            	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TrafficCounters>`
            
            .. attribute:: tunnels
            
            	Tunnels information that PIM has
            	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.auto_rp = Ipv6Pim.Active.DefaultContext.AutoRp()
                self.auto_rp.parent = self
                self.bgp_afs = Ipv6Pim.Active.DefaultContext.BgpAfs()
                self.bgp_afs.parent = self
                self.bidir_df_states = Ipv6Pim.Active.DefaultContext.BidirDfStates()
                self.bidir_df_states.parent = self
                self.bidir_df_winners = Ipv6Pim.Active.DefaultContext.BidirDfWinners()
                self.bidir_df_winners.parent = self
                self.bsr = Ipv6Pim.Active.DefaultContext.Bsr()
                self.bsr.parent = self
                self.context = Ipv6Pim.Active.DefaultContext.Context()
                self.context.parent = self
                self.global_interfaces = Ipv6Pim.Active.DefaultContext.GlobalInterfaces()
                self.global_interfaces.parent = self
                self.gre = Ipv6Pim.Active.DefaultContext.Gre()
                self.gre.parent = self
                self.group_map_match_rpfs = Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs()
                self.group_map_match_rpfs.parent = self
                self.group_map_match_sources = Ipv6Pim.Active.DefaultContext.GroupMapMatchSources()
                self.group_map_match_sources.parent = self
                self.group_map_rpfs = Ipv6Pim.Active.DefaultContext.GroupMapRpfs()
                self.group_map_rpfs.parent = self
                self.group_map_sources = Ipv6Pim.Active.DefaultContext.GroupMapSources()
                self.group_map_sources.parent = self
                self.ifrs_interfaces = Ipv6Pim.Active.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self.ifrs_summary = Ipv6Pim.Active.DefaultContext.IfrsSummary()
                self.ifrs_summary.parent = self
                self.interface_old_formats = Ipv6Pim.Active.DefaultContext.InterfaceOldFormats()
                self.interface_old_formats.parent = self
                self.interface_statistics = Ipv6Pim.Active.DefaultContext.InterfaceStatistics()
                self.interface_statistics.parent = self
                self.interfaces = Ipv6Pim.Active.DefaultContext.Interfaces()
                self.interfaces.parent = self
                self.jp_statistics = Ipv6Pim.Active.DefaultContext.JpStatistics()
                self.jp_statistics.parent = self
                self.mib_databases = Ipv6Pim.Active.DefaultContext.MibDatabases()
                self.mib_databases.parent = self
                self.multicast_static_routes = Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes()
                self.multicast_static_routes.parent = self
                self.neighbor_old_formats = Ipv6Pim.Active.DefaultContext.NeighborOldFormats()
                self.neighbor_old_formats.parent = self
                self.neighbor_summaries = Ipv6Pim.Active.DefaultContext.NeighborSummaries()
                self.neighbor_summaries.parent = self
                self.neighbors = Ipv6Pim.Active.DefaultContext.Neighbors()
                self.neighbors.parent = self
                self.net_io_tunnels = Ipv6Pim.Active.DefaultContext.NetIoTunnels()
                self.net_io_tunnels.parent = self
                self.ranges = Ipv6Pim.Active.DefaultContext.Ranges()
                self.ranges.parent = self
                self.route_policy = Ipv6Pim.Active.DefaultContext.RoutePolicy()
                self.route_policy.parent = self
                self.rpf_redirect = Ipv6Pim.Active.DefaultContext.RpfRedirect()
                self.rpf_redirect.parent = self
                self.rpf_summary = Ipv6Pim.Active.DefaultContext.RpfSummary()
                self.rpf_summary.parent = self
                self.safs = Ipv6Pim.Active.DefaultContext.Safs()
                self.safs.parent = self
                self.summary = Ipv6Pim.Active.DefaultContext.Summary()
                self.summary.parent = self
                self.table_contexts = Ipv6Pim.Active.DefaultContext.TableContexts()
                self.table_contexts.parent = self
                self.topologies = Ipv6Pim.Active.DefaultContext.Topologies()
                self.topologies.parent = self
                self.topology_entry_flag_route_counts = Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts()
                self.topology_entry_flag_route_counts.parent = self
                self.topology_interface_flag_route_counts = Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts()
                self.topology_interface_flag_route_counts.parent = self
                self.topology_route_count = Ipv6Pim.Active.DefaultContext.TopologyRouteCount()
                self.topology_route_count.parent = self
                self.traffic_counters = Ipv6Pim.Active.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self.tunnels = Ipv6Pim.Active.DefaultContext.Tunnels()
                self.tunnels.parent = self


            class GlobalInterfaces(object):
                """
                PIM global interface table
                
                .. attribute:: global_interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`GlobalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.global_interface = YList()
                    self.global_interface.parent = self
                    self.global_interface.name = 'global_interface'


                class GlobalInterface(object):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.configured_override_interval = None
                        self.configured_propagation_delay = None
                        self.dr_address = Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress()
                        self.dr_address.parent = self
                        self.dr_priority = None
                        self.external_neighbor_count = None
                        self.generation_id = None
                        self.hello_expiry = None
                        self.hello_interval = None
                        self.idb_acl_name = None
                        self.idb_acl_provided = None
                        self.idb_current_count = None
                        self.idb_max_count = None
                        self.idb_oor_enabled = None
                        self.idb_threshold_count = None
                        self.interface_address = YList()
                        self.interface_address.parent = self
                        self.interface_address.name = 'interface_address'
                        self.interface_address_mask = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bidirectional_capable = None
                        self.is_enabled = None
                        self.is_proxy_capable = None
                        self.join_prune_interval = None
                        self.neighbor_count = None
                        self.neighbor_filter_name = None
                        self.override_interval = None
                        self.passive_interface = None
                        self.propagation_delay = None
                        self.prune_delay_enabled = None
                        self.virtual_interface = None


                    class DrAddress(object):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress']['meta_info']


                    class InterfaceAddress(object):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:global-interfaces/Cisco-IOS-XR-ipv4-pim-oper:global-interface[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.are_we_dr is not None:
                            return True

                        if self.bfd_enabled is not None:
                            return True

                        if self.bfd_interval is not None:
                            return True

                        if self.bfd_multiplier is not None:
                            return True

                        if self.configured_override_interval is not None:
                            return True

                        if self.configured_propagation_delay is not None:
                            return True

                        if self.dr_address is not None and self.dr_address._has_data():
                            return True

                        if self.dr_priority is not None:
                            return True

                        if self.external_neighbor_count is not None:
                            return True

                        if self.generation_id is not None:
                            return True

                        if self.hello_expiry is not None:
                            return True

                        if self.hello_interval is not None:
                            return True

                        if self.idb_acl_name is not None:
                            return True

                        if self.idb_acl_provided is not None:
                            return True

                        if self.idb_current_count is not None:
                            return True

                        if self.idb_max_count is not None:
                            return True

                        if self.idb_oor_enabled is not None:
                            return True

                        if self.idb_threshold_count is not None:
                            return True

                        if self.interface_address is not None:
                            for child_ref in self.interface_address:
                                if child_ref._has_data():
                                    return True

                        if self.interface_address_mask is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_enabled is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.join_prune_interval is not None:
                            return True

                        if self.neighbor_count is not None:
                            return True

                        if self.neighbor_filter_name is not None:
                            return True

                        if self.override_interval is not None:
                            return True

                        if self.passive_interface is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.prune_delay_enabled is not None:
                            return True

                        if self.virtual_interface is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:global-interfaces'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.global_interface is not None:
                        for child_ref in self.global_interface:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.GlobalInterfaces']['meta_info']


            class IfrsInterfaces(object):
                """
                PIM interfaces in forward reference store table
                
                .. attribute:: ifrs_interface
                
                	PIM IFRS interface information
                	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.ifrs_interface = YList()
                    self.ifrs_interface.parent = self
                    self.ifrs_interface.name = 'ifrs_interface'


                class IfrsInterface(object):
                    """
                    PIM IFRS interface information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.configured_override_interval = None
                        self.configured_propagation_delay = None
                        self.dr_address = Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress()
                        self.dr_address.parent = self
                        self.dr_priority = None
                        self.external_neighbor_count = None
                        self.generation_id = None
                        self.hello_expiry = None
                        self.hello_interval = None
                        self.idb_acl_name = None
                        self.idb_acl_provided = None
                        self.idb_current_count = None
                        self.idb_max_count = None
                        self.idb_oor_enabled = None
                        self.idb_threshold_count = None
                        self.interface_address = YList()
                        self.interface_address.parent = self
                        self.interface_address.name = 'interface_address'
                        self.interface_address_mask = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bidirectional_capable = None
                        self.is_enabled = None
                        self.is_proxy_capable = None
                        self.join_prune_interval = None
                        self.neighbor_count = None
                        self.neighbor_filter_name = None
                        self.override_interval = None
                        self.passive_interface = None
                        self.propagation_delay = None
                        self.prune_delay_enabled = None
                        self.virtual_interface = None


                    class DrAddress(object):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress']['meta_info']


                    class InterfaceAddress(object):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ifrs-interfaces/Cisco-IOS-XR-ipv4-pim-oper:ifrs-interface[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.are_we_dr is not None:
                            return True

                        if self.bfd_enabled is not None:
                            return True

                        if self.bfd_interval is not None:
                            return True

                        if self.bfd_multiplier is not None:
                            return True

                        if self.configured_override_interval is not None:
                            return True

                        if self.configured_propagation_delay is not None:
                            return True

                        if self.dr_address is not None and self.dr_address._has_data():
                            return True

                        if self.dr_priority is not None:
                            return True

                        if self.external_neighbor_count is not None:
                            return True

                        if self.generation_id is not None:
                            return True

                        if self.hello_expiry is not None:
                            return True

                        if self.hello_interval is not None:
                            return True

                        if self.idb_acl_name is not None:
                            return True

                        if self.idb_acl_provided is not None:
                            return True

                        if self.idb_current_count is not None:
                            return True

                        if self.idb_max_count is not None:
                            return True

                        if self.idb_oor_enabled is not None:
                            return True

                        if self.idb_threshold_count is not None:
                            return True

                        if self.interface_address is not None:
                            for child_ref in self.interface_address:
                                if child_ref._has_data():
                                    return True

                        if self.interface_address_mask is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_enabled is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.join_prune_interval is not None:
                            return True

                        if self.neighbor_count is not None:
                            return True

                        if self.neighbor_filter_name is not None:
                            return True

                        if self.override_interval is not None:
                            return True

                        if self.passive_interface is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.prune_delay_enabled is not None:
                            return True

                        if self.virtual_interface is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ifrs-interfaces'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.ifrs_interface is not None:
                        for child_ref in self.ifrs_interface:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.IfrsInterfaces']['meta_info']


            class Safs(object):
                """
                SAFI table and type
                
                .. attribute:: saf
                
                	SAF name 
                	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.saf = YList()
                    self.saf.parent = self
                    self.saf.name = 'saf'


                class Saf(object):
                    """
                    SAF name 
                    
                    .. attribute:: rpf_hash_source_groups
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups>`
                    
                    .. attribute:: rpf_hash_sources
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources>`
                    
                    .. attribute:: rpfs
                    
                    	PIM RPF information table
                    	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs>`
                    
                    .. attribute:: saf_name
                    
                    	SAF name 
                    	**type**\:   :py:class:`PimSafiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafiEnum>`
                    
                    .. attribute:: topology_name
                    
                    	Topology name 
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.rpf_hash_source_groups = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups()
                        self.rpf_hash_source_groups.parent = self
                        self.rpf_hash_sources = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources()
                        self.rpf_hash_sources.parent = self
                        self.rpfs = Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs()
                        self.rpfs.parent = self
                        self.saf_name = None
                        self.topology_name = None


                    class RpfHashSourceGroups(object):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source_group
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rpf_hash_source_group = YList()
                            self.rpf_hash_source_group.parent = self
                            self.rpf_hash_source_group.name = 'rpf_hash_source_group'


                        class RpfHashSourceGroup(object):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: mask_length
                            
                            	Hash mask length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.group_address = None
                                self.mask_length = None
                                self.mofrr = None
                                self.next_hop_address = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                self.next_hop_address.parent = self
                                self.next_hop_interface = None
                                self.next_hop_multipath_enabled = None
                                self.secondary_next_hop_address = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self.secondary_next_hop_interface = None
                                self.source_address = None


                            class NextHopAddress(object):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-groups/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-group/Cisco-IOS-XR-ipv4-pim-oper:next-hop-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress']['meta_info']


                            class SecondaryNextHopAddress(object):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-groups/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-group/Cisco-IOS-XR-ipv4-pim-oper:secondary-next-hop-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-groups/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-group'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.group_address is not None:
                                    return True

                                if self.mask_length is not None:
                                    return True

                                if self.mofrr is not None:
                                    return True

                                if self.next_hop_address is not None and self.next_hop_address._has_data():
                                    return True

                                if self.next_hop_interface is not None:
                                    return True

                                if self.next_hop_multipath_enabled is not None:
                                    return True

                                if self.secondary_next_hop_address is not None and self.secondary_next_hop_address._has_data():
                                    return True

                                if self.secondary_next_hop_interface is not None:
                                    return True

                                if self.source_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-groups'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rpf_hash_source_group is not None:
                                for child_ref in self.rpf_hash_source_group:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups']['meta_info']


                    class RpfHashSources(object):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rpf_hash_source = YList()
                            self.rpf_hash_source.parent = self
                            self.rpf_hash_source.name = 'rpf_hash_source'


                        class RpfHashSource(object):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mofrr = None
                                self.next_hop_address = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                self.next_hop_address.parent = self
                                self.next_hop_interface = None
                                self.next_hop_multipath_enabled = None
                                self.secondary_next_hop_address = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self.secondary_next_hop_interface = None
                                self.source_address = None


                            class NextHopAddress(object):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-sources/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source/Cisco-IOS-XR-ipv4-pim-oper:next-hop-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress']['meta_info']


                            class SecondaryNextHopAddress(object):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-sources/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source/Cisco-IOS-XR-ipv4-pim-oper:secondary-next-hop-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-sources/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mofrr is not None:
                                    return True

                                if self.next_hop_address is not None and self.next_hop_address._has_data():
                                    return True

                                if self.next_hop_interface is not None:
                                    return True

                                if self.next_hop_multipath_enabled is not None:
                                    return True

                                if self.secondary_next_hop_address is not None and self.secondary_next_hop_address._has_data():
                                    return True

                                if self.secondary_next_hop_interface is not None:
                                    return True

                                if self.source_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-sources'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rpf_hash_source is not None:
                                for child_ref in self.rpf_hash_source:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources']['meta_info']


                    class Rpfs(object):
                        """
                        PIM RPF information table
                        
                        .. attribute:: rpf
                        
                        	PIM RPF information
                        	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rpf = YList()
                            self.rpf.parent = self
                            self.rpf.name = 'rpf'


                        class Rpf(object):
                            """
                            PIM RPF information
                            
                            .. attribute:: registered_address  <key>
                            
                            	Address for which RPF lookup
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: is_rpf_bgp_route
                            
                            	Is RPF through BGP route
                            	**type**\:  bool
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address_xr
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                            
                            .. attribute:: rpf_path
                            
                            	RPF Paths list
                            	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.registered_address = None
                                self.is_connected = None
                                self.is_rpf_bgp_route = None
                                self.metric = None
                                self.metric_preference = None
                                self.registered_address_xr = Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                self.registered_address_xr.parent = self
                                self.rpf_path = YList()
                                self.rpf_path.parent = self
                                self.rpf_path.name = 'rpf_path'


                            class RegisteredAddressXr(object):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:registered-address-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr']['meta_info']


                            class RpfPath(object):
                                """
                                RPF Paths list
                                
                                .. attribute:: connector
                                
                                	Connector Attribute
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface_disabled
                                
                                	Is the rpf interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                .. attribute:: is_via_mlsm
                                
                                	Via Mstatic LSM
                                	**type**\:  bool
                                
                                .. attribute:: rpf_interface_name
                                
                                	RPF Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: rpf_neighbor
                                
                                	RPF neighbor
                                	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                
                                .. attribute:: rpf_nexthop
                                
                                	RPF nexthop
                                	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.connector = None
                                    self.extranet_vrf_name = None
                                    self.is_connector_attribute_present = None
                                    self.is_rpf_interface_disabled = None
                                    self.is_via_lsm = None
                                    self.is_via_mlsm = None
                                    self.rpf_interface_name = None
                                    self.rpf_neighbor = Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self.rpf_nexthop = Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                    self.rpf_nexthop.parent = self


                                class RpfNeighbor(object):
                                    """
                                    RPF neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor']['meta_info']


                                class RpfNexthop(object):
                                    """
                                    RPF nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-nexthop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.connector is not None:
                                        return True

                                    if self.extranet_vrf_name is not None:
                                        return True

                                    if self.is_connector_attribute_present is not None:
                                        return True

                                    if self.is_rpf_interface_disabled is not None:
                                        return True

                                    if self.is_via_lsm is not None:
                                        return True

                                    if self.is_via_mlsm is not None:
                                        return True

                                    if self.rpf_interface_name is not None:
                                        return True

                                    if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                        return True

                                    if self.rpf_nexthop is not None and self.rpf_nexthop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath']['meta_info']

                            @property
                            def _common_path(self):
                                if self.registered_address is None:
                                    raise YPYModelError('Key property registered_address is None')

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpfs/Cisco-IOS-XR-ipv4-pim-oper:rpf[Cisco-IOS-XR-ipv4-pim-oper:registered-address = ' + str(self.registered_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.registered_address is not None:
                                    return True

                                if self.is_connected is not None:
                                    return True

                                if self.is_rpf_bgp_route is not None:
                                    return True

                                if self.metric is not None:
                                    return True

                                if self.metric_preference is not None:
                                    return True

                                if self.registered_address_xr is not None and self.registered_address_xr._has_data():
                                    return True

                                if self.rpf_path is not None:
                                    for child_ref in self.rpf_path:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf/Cisco-IOS-XR-ipv4-pim-oper:rpfs'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rpf is not None:
                                for child_ref in self.rpf:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs/Cisco-IOS-XR-ipv4-pim-oper:saf'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups._has_data():
                            return True

                        if self.rpf_hash_sources is not None and self.rpf_hash_sources._has_data():
                            return True

                        if self.rpfs is not None and self.rpfs._has_data():
                            return True

                        if self.saf_name is not None:
                            return True

                        if self.topology_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.Safs.Saf']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:safs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.saf is not None:
                        for child_ref in self.saf:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.Safs']['meta_info']


            class InterfaceStatistics(object):
                """
                PIM interface statistics
                
                .. attribute:: interface_statistic
                
                	PIM interface statistics
                	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_statistic = YList()
                    self.interface_statistic.parent = self
                    self.interface_statistic.name = 'interface_statistic'


                class InterfaceStatistic(object):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_ack_message
                    
                    	Input Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_message
                    
                    	Input Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_miscellaneous
                    
                    	Miscellaneous packet in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register
                    
                    	Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_ack_message
                    
                    	Output Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_message
                    
                    	Output Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register
                    
                    	Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.input_assert = None
                        self.input_bsr_message = None
                        self.input_candidate_rp_advertisement = None
                        self.input_df_election = None
                        self.input_graft_ack_message = None
                        self.input_graft_message = None
                        self.input_hello = None
                        self.input_jp = None
                        self.input_miscellaneous = None
                        self.input_register = None
                        self.input_register_stop = None
                        self.output_assert = None
                        self.output_bsr_message = None
                        self.output_candidate_rp_advertisement = None
                        self.output_df_election = None
                        self.output_graft_ack_message = None
                        self.output_graft_message = None
                        self.output_hello = None
                        self.output_jp = None
                        self.output_register = None
                        self.output_register_stop = None

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interface-statistics/Cisco-IOS-XR-ipv4-pim-oper:interface-statistic[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.input_assert is not None:
                            return True

                        if self.input_bsr_message is not None:
                            return True

                        if self.input_candidate_rp_advertisement is not None:
                            return True

                        if self.input_df_election is not None:
                            return True

                        if self.input_graft_ack_message is not None:
                            return True

                        if self.input_graft_message is not None:
                            return True

                        if self.input_hello is not None:
                            return True

                        if self.input_jp is not None:
                            return True

                        if self.input_miscellaneous is not None:
                            return True

                        if self.input_register is not None:
                            return True

                        if self.input_register_stop is not None:
                            return True

                        if self.output_assert is not None:
                            return True

                        if self.output_bsr_message is not None:
                            return True

                        if self.output_candidate_rp_advertisement is not None:
                            return True

                        if self.output_df_election is not None:
                            return True

                        if self.output_graft_ack_message is not None:
                            return True

                        if self.output_graft_message is not None:
                            return True

                        if self.output_hello is not None:
                            return True

                        if self.output_jp is not None:
                            return True

                        if self.output_register is not None:
                            return True

                        if self.output_register_stop is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interface-statistics'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_statistic is not None:
                        for child_ref in self.interface_statistic:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.InterfaceStatistics']['meta_info']


            class TopologyRouteCount(object):
                """
                Topology route count information from PIM
                topology table
                
                .. attribute:: active_group_ranges
                
                	No. of (\*,G/M) routes active in mrib
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_address
                
                	Group Address
                	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyRouteCount.GroupAddress>`
                
                .. attribute:: group_ranges
                
                	No. of (\*,G/M) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groute_count
                
                	No. of (\*,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: sg_route_count
                
                	No. of (S,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sgr_route_count
                
                	No. of (S,G)RPT routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.active_group_ranges = None
                    self.group_address = Ipv6Pim.Active.DefaultContext.TopologyRouteCount.GroupAddress()
                    self.group_address.parent = self
                    self.group_ranges = None
                    self.groute_count = None
                    self.is_node_low_memory = None
                    self.sg_route_count = None
                    self.sgr_route_count = None


                class GroupAddress(object):
                    """
                    Group Address
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.af_name = None
                        self.ipv4_address = None
                        self.ipv6_address = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-route-count/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.af_name is not None:
                            return True

                        if self.ipv4_address is not None:
                            return True

                        if self.ipv6_address is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.TopologyRouteCount.GroupAddress']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-route-count'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.active_group_ranges is not None:
                        return True

                    if self.group_address is not None and self.group_address._has_data():
                        return True

                    if self.group_ranges is not None:
                        return True

                    if self.groute_count is not None:
                        return True

                    if self.is_node_low_memory is not None:
                        return True

                    if self.sg_route_count is not None:
                        return True

                    if self.sgr_route_count is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.TopologyRouteCount']['meta_info']


            class JpStatistics(object):
                """
                PIM join prune statistics table
                
                .. attribute:: jp_statistic
                
                	PIM Join Prune Statistics
                	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.JpStatistics.JpStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.jp_statistic = YList()
                    self.jp_statistic.parent = self
                    self.jp_statistic.name = 'jp_statistic'


                class JpStatistic(object):
                    """
                    PIM Join Prune Statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mtu
                    
                    	Interface MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received
                    
                    	Received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received100
                    
                    	Received 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_10k
                    
                    	Received 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_1k
                    
                    	Received 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_50k
                    
                    	Deprecated by Received100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted
                    
                    	Transmitted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: transmitted100
                    
                    	Transmitted 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_10k
                    
                    	Transmitted 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_1k
                    
                    	Transmitted 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_50k
                    
                    	Deprecated by Transmitted100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.mtu = None
                        self.received = None
                        self.received100 = None
                        self.received_10k = None
                        self.received_1k = None
                        self.received_50k = None
                        self.transmitted = None
                        self.transmitted100 = None
                        self.transmitted_10k = None
                        self.transmitted_1k = None
                        self.transmitted_50k = None

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:jp-statistics/Cisco-IOS-XR-ipv4-pim-oper:jp-statistic[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.mtu is not None:
                            return True

                        if self.received is not None:
                            return True

                        if self.received100 is not None:
                            return True

                        if self.received_10k is not None:
                            return True

                        if self.received_1k is not None:
                            return True

                        if self.received_50k is not None:
                            return True

                        if self.transmitted is not None:
                            return True

                        if self.transmitted100 is not None:
                            return True

                        if self.transmitted_10k is not None:
                            return True

                        if self.transmitted_1k is not None:
                            return True

                        if self.transmitted_50k is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.JpStatistics.JpStatistic']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:jp-statistics'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.jp_statistic is not None:
                        for child_ref in self.jp_statistic:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.JpStatistics']['meta_info']


            class MibDatabases(object):
                """
                PIM group database for mroute mibs table
                
                .. attribute:: mib_database
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.mib_database = YList()
                    self.mib_database.parent = self
                    self.mib_database.name = 'mib_database'


                class MibDatabase(object):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: assert_metric
                    
                    	Assert Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_metric_preference
                    
                    	Assert Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_rpt_bit
                    
                    	Assert RPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: bidirectional_route
                    
                    	Is this Bidir ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Multicast satic route group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr>`
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface name 
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_mask
                    
                    	Mask of the multicast root
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_neighbor
                    
                    	The RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor>`
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: source_address
                    
                    	Multicast static route source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr>`
                    
                    .. attribute:: source_netmask
                    
                    	Source mask
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: spt_bit
                    
                    	Is SPT bit set ?
                    	**type**\:  bool
                    
                    .. attribute:: upstream_assert_timer
                    
                    	Upstream Assert Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime of route
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.assert_metric = None
                        self.assert_metric_preference = None
                        self.assert_rpt_bit = None
                        self.bidirectional_route = None
                        self.group_address = None
                        self.group_address_xr = Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self.protocol = None
                        self.rpf_drop = None
                        self.rpf_extranet = None
                        self.rpf_interface_name = None
                        self.rpf_mask = None
                        self.rpf_neighbor = Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self.rpf_root = Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot()
                        self.rpf_root.parent = self
                        self.rpf_safi = None
                        self.rpf_table_name = None
                        self.rpf_vrf_name = None
                        self.source_address = None
                        self.source_address_xr = Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self.source_netmask = None
                        self.spt_bit = None
                        self.upstream_assert_timer = None
                        self.uptime = None


                    class SourceAddressXr(object):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases/Cisco-IOS-XR-ipv4-pim-oper:mib-database/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr']['meta_info']


                    class GroupAddressXr(object):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases/Cisco-IOS-XR-ipv4-pim-oper:mib-database/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr']['meta_info']


                    class RpfNeighbor(object):
                        """
                        The RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases/Cisco-IOS-XR-ipv4-pim-oper:mib-database/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor']['meta_info']


                    class RpfRoot(object):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases/Cisco-IOS-XR-ipv4-pim-oper:mib-database/Cisco-IOS-XR-ipv4-pim-oper:rpf-root'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases/Cisco-IOS-XR-ipv4-pim-oper:mib-database'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.assert_metric is not None:
                            return True

                        if self.assert_metric_preference is not None:
                            return True

                        if self.assert_rpt_bit is not None:
                            return True

                        if self.bidirectional_route is not None:
                            return True

                        if self.group_address is not None:
                            return True

                        if self.group_address_xr is not None and self.group_address_xr._has_data():
                            return True

                        if self.protocol is not None:
                            return True

                        if self.rpf_drop is not None:
                            return True

                        if self.rpf_extranet is not None:
                            return True

                        if self.rpf_interface_name is not None:
                            return True

                        if self.rpf_mask is not None:
                            return True

                        if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                            return True

                        if self.rpf_root is not None and self.rpf_root._has_data():
                            return True

                        if self.rpf_safi is not None:
                            return True

                        if self.rpf_table_name is not None:
                            return True

                        if self.rpf_vrf_name is not None:
                            return True

                        if self.source_address is not None:
                            return True

                        if self.source_address_xr is not None and self.source_address_xr._has_data():
                            return True

                        if self.source_netmask is not None:
                            return True

                        if self.spt_bit is not None:
                            return True

                        if self.upstream_assert_timer is not None:
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:mib-databases'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.mib_database is not None:
                        for child_ref in self.mib_database:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.MibDatabases']['meta_info']


            class GroupMapMatchRpfs(object):
                """
                Find matching group\-mapping for the specified
                group address
                
                .. attribute:: group_map_match_rpf
                
                	PIM group matching mapping entry
                	**type**\: list of    :py:class:`GroupMapMatchRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.group_map_match_rpf = YList()
                    self.group_map_match_rpf.parent = self
                    self.group_map_match_rpf.name = 'group_map_match_rpf'


                class GroupMapMatchRpf(object):
                    """
                    PIM group matching mapping entry
                    
                    .. attribute:: group_address  <key>
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\:  bool
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation>`
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor>`
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_address = None
                        self.are_we_rp = None
                        self.group_map_information = Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self.rpf_interface_name = None
                        self.rpf_neighbor = Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self.rpf_vrf_name = None


                    class RpfNeighbor(object):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor']['meta_info']


                    class GroupMapInformation(object):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.group_count = None
                            self.is_override = None
                            self.is_used = None
                            self.mrib_active = None
                            self.prefix = Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.priority = None
                            self.protocol = None
                            self.rp_address = Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self


                        class Prefix(object):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix']['meta_info']


                        class RpAddress(object):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.group_count is not None:
                                return True

                            if self.is_override is not None:
                                return True

                            if self.is_used is not None:
                                return True

                            if self.mrib_active is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation']['meta_info']

                    @property
                    def _common_path(self):
                        if self.group_address is None:
                            raise YPYModelError('Key property group_address is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-rpf[Cisco-IOS-XR-ipv4-pim-oper:group-address = ' + str(self.group_address) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_address is not None:
                            return True

                        if self.are_we_rp is not None:
                            return True

                        if self.group_map_information is not None and self.group_map_information._has_data():
                            return True

                        if self.rpf_interface_name is not None:
                            return True

                        if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                            return True

                        if self.rpf_vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-rpfs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.group_map_match_rpf is not None:
                        for child_ref in self.group_map_match_rpf:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs']['meta_info']


            class NeighborOldFormats(object):
                """
                PIM neighbor table old format
                
                .. attribute:: neighbor_old_format
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.neighbor_old_format = YList()
                    self.neighbor_old_format.parent = self
                    self.neighbor_old_format.name = 'neighbor_old_format'


                class NeighborOldFormat(object):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.dr_priority = None
                        self.expires = None
                        self.expiry_timer = None
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bfd_state = None
                        self.is_bidirectional_capable = None
                        self.is_dr_priority_capable = None
                        self.is_ecmp_redirect_capable = None
                        self.is_proxy_capable = None
                        self.is_this_neighbor_dr = None
                        self.is_this_neighbor_us = None
                        self.neighbor_address = None
                        self.neighbor_address_xr = YList()
                        self.neighbor_address_xr.parent = self
                        self.neighbor_address_xr.name = 'neighbor_address_xr'
                        self.override_interval = None
                        self.propagation_delay = None
                        self.uptime = None


                    class NeighborAddressXr(object):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-formats/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-format/Cisco-IOS-XR-ipv4-pim-oper:neighbor-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-formats/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-format'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.dr_priority is not None:
                            return True

                        if self.expires is not None:
                            return True

                        if self.expiry_timer is not None:
                            return True

                        if self.interface_name is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bfd_state is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_dr_priority_capable is not None:
                            return True

                        if self.is_ecmp_redirect_capable is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.is_this_neighbor_dr is not None:
                            return True

                        if self.is_this_neighbor_us is not None:
                            return True

                        if self.neighbor_address is not None:
                            return True

                        if self.neighbor_address_xr is not None:
                            for child_ref in self.neighbor_address_xr:
                                if child_ref._has_data():
                                    return True

                        if self.override_interval is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-formats'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.neighbor_old_format is not None:
                        for child_ref in self.neighbor_old_format:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.NeighborOldFormats']['meta_info']


            class IfrsSummary(object):
                """
                PIM interfaces in forward reference store
                summary
                
                .. attribute:: configuration_count
                
                	Configuration counts
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_count
                
                	Number of interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.configuration_count = None
                    self.interface_count = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ifrs-summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.configuration_count is not None:
                        return True

                    if self.interface_count is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.IfrsSummary']['meta_info']


            class Ranges(object):
                """
                PIM range list information
                
                .. attribute:: range
                
                	PIM range list information
                	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.range = YList()
                    self.range.parent = self
                    self.range.name = 'range'


                class Range(object):
                    """
                    PIM range list information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                    
                    .. attribute:: client_xr
                    
                    	Client mapping learnt via
                    	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                    
                    .. attribute:: expires
                    
                    	When mapping expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: group_range
                    
                    	List of group ranges
                    	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange>`
                    
                    .. attribute:: protocol
                    
                    	PIM protocol
                    	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	Rendezvous point address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range.RpAddressXr>`
                    
                    .. attribute:: source_of_information
                    
                    	Source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.client = None
                        self.client_xr = None
                        self.expires = None
                        self.group_range = YList()
                        self.group_range.parent = self
                        self.group_range.name = 'group_range'
                        self.protocol = None
                        self.rp_address = None
                        self.rp_address_xr = Ipv6Pim.Active.DefaultContext.Ranges.Range.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self.source_of_information = Ipv6Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation()
                        self.source_of_information.parent = self


                    class RpAddressXr(object):
                        """
                        Rendezvous point address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Ranges.Range.RpAddressXr']['meta_info']


                    class SourceOfInformation(object):
                        """
                        Source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation']['meta_info']


                    class GroupRange(object):
                        """
                        List of group ranges
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.expires = None
                            self.prefix = Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.source_of_information = Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation()
                            self.source_of_information.parent = self
                            self.uptime = None


                        class Prefix(object):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range/Cisco-IOS-XR-ipv4-pim-oper:group-range/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix']['meta_info']


                        class SourceOfInformation(object):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range/Cisco-IOS-XR-ipv4-pim-oper:group-range/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range/Cisco-IOS-XR-ipv4-pim-oper:group-range'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.expires is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.source_of_information is not None and self.source_of_information._has_data():
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges/Cisco-IOS-XR-ipv4-pim-oper:range'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.client is not None:
                            return True

                        if self.client_xr is not None:
                            return True

                        if self.expires is not None:
                            return True

                        if self.group_range is not None:
                            for child_ref in self.group_range:
                                if child_ref._has_data():
                                    return True

                        if self.protocol is not None:
                            return True

                        if self.rp_address is not None:
                            return True

                        if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                            return True

                        if self.source_of_information is not None and self.source_of_information._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.Ranges.Range']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:ranges'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.range is not None:
                        for child_ref in self.range:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.Ranges']['meta_info']


            class InterfaceOldFormats(object):
                """
                PIM interfaces in old format
                
                .. attribute:: interface_old_format
                
                	PIM interface name
                	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_old_format = YList()
                    self.interface_old_format.parent = self
                    self.interface_old_format.name = 'interface_old_format'


                class InterfaceOldFormat(object):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.configured_override_interval = None
                        self.configured_propagation_delay = None
                        self.dr_address = Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                        self.dr_address.parent = self
                        self.dr_priority = None
                        self.external_neighbor_count = None
                        self.generation_id = None
                        self.hello_expiry = None
                        self.hello_interval = None
                        self.idb_acl_name = None
                        self.idb_acl_provided = None
                        self.idb_current_count = None
                        self.idb_max_count = None
                        self.idb_oor_enabled = None
                        self.idb_threshold_count = None
                        self.interface_address = YList()
                        self.interface_address.parent = self
                        self.interface_address.name = 'interface_address'
                        self.interface_address_mask = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bidirectional_capable = None
                        self.is_enabled = None
                        self.is_proxy_capable = None
                        self.join_prune_interval = None
                        self.neighbor_count = None
                        self.neighbor_filter_name = None
                        self.override_interval = None
                        self.passive_interface = None
                        self.propagation_delay = None
                        self.prune_delay_enabled = None
                        self.virtual_interface = None


                    class DrAddress(object):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress']['meta_info']


                    class InterfaceAddress(object):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interface-old-formats/Cisco-IOS-XR-ipv4-pim-oper:interface-old-format[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.are_we_dr is not None:
                            return True

                        if self.bfd_enabled is not None:
                            return True

                        if self.bfd_interval is not None:
                            return True

                        if self.bfd_multiplier is not None:
                            return True

                        if self.configured_override_interval is not None:
                            return True

                        if self.configured_propagation_delay is not None:
                            return True

                        if self.dr_address is not None and self.dr_address._has_data():
                            return True

                        if self.dr_priority is not None:
                            return True

                        if self.external_neighbor_count is not None:
                            return True

                        if self.generation_id is not None:
                            return True

                        if self.hello_expiry is not None:
                            return True

                        if self.hello_interval is not None:
                            return True

                        if self.idb_acl_name is not None:
                            return True

                        if self.idb_acl_provided is not None:
                            return True

                        if self.idb_current_count is not None:
                            return True

                        if self.idb_max_count is not None:
                            return True

                        if self.idb_oor_enabled is not None:
                            return True

                        if self.idb_threshold_count is not None:
                            return True

                        if self.interface_address is not None:
                            for child_ref in self.interface_address:
                                if child_ref._has_data():
                                    return True

                        if self.interface_address_mask is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_enabled is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.join_prune_interval is not None:
                            return True

                        if self.neighbor_count is not None:
                            return True

                        if self.neighbor_filter_name is not None:
                            return True

                        if self.override_interval is not None:
                            return True

                        if self.passive_interface is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.prune_delay_enabled is not None:
                            return True

                        if self.virtual_interface is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interface-old-formats'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_old_format is not None:
                        for child_ref in self.interface_old_format:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.InterfaceOldFormats']['meta_info']


            class Bsr(object):
                """
                PIM BSR information
                
                .. attribute:: bsr_elections
                
                	PIM BSR election state
                	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.BsrElections>`
                
                .. attribute:: candidate_rps
                
                	PIM candidate\-RP
                	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps>`
                
                .. attribute:: rp_caches
                
                	PIM BSR RP cache table
                	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bsr_elections = Ipv6Pim.Active.DefaultContext.Bsr.BsrElections()
                    self.bsr_elections.parent = self
                    self.candidate_rps = Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps()
                    self.candidate_rps.parent = self
                    self.rp_caches = Ipv6Pim.Active.DefaultContext.Bsr.RpCaches()
                    self.rp_caches.parent = self


                class RpCaches(object):
                    """
                    PIM BSR RP cache table
                    
                    .. attribute:: rp_cache
                    
                    	PIM BSR RP cache
                    	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.rp_cache = YList()
                        self.rp_cache.parent = self
                        self.rp_cache.name = 'rp_cache'


                    class RpCache(object):
                        """
                        PIM BSR RP cache
                        
                        .. attribute:: group_prefix  <key>
                        
                        	Group prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: candidate_rp_group_count
                        
                        	C\-RP count for this Prefix
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: candidate_rp_list
                        
                        	C\-RP list for this prefix
                        	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList>`
                        
                        .. attribute:: group_prefix_length
                        
                        	Group Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_prefix_xr
                        
                        	Group Prefix
                        	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.group_prefix = None
                            self.candidate_rp_group_count = None
                            self.candidate_rp_list = Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList()
                            self.candidate_rp_list.parent = self
                            self.group_prefix_length = None
                            self.group_prefix_xr = Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr()
                            self.group_prefix_xr.parent = self


                        class GroupPrefixXr(object):
                            """
                            Group Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-prefix-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr']['meta_info']


                        class CandidateRpList(object):
                            """
                            C\-RP list for this prefix
                            
                            .. attribute:: pim_bsr_crp_bag
                            
                            	pim bsr crp bag
                            	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pim_bsr_crp_bag = YList()
                                self.pim_bsr_crp_bag.parent = self
                                self.pim_bsr_crp_bag.name = 'pim_bsr_crp_bag'


                            class PimBsrCrpBag(object):
                                """
                                pim bsr crp bag
                                
                                .. attribute:: candidate_rp_address
                                
                                	C\-RP address
                                	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                
                                .. attribute:: candidate_rp_expires
                                
                                	C\-RP Expires
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_holdtime
                                
                                	C\-RP Holdtime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_priority
                                
                                	C\-RP Priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: candidate_rp_up_time
                                
                                	C\-RP Uptime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: protocol
                                
                                	PIM Protocol
                                	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.candidate_rp_address = Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                    self.candidate_rp_address.parent = self
                                    self.candidate_rp_expires = None
                                    self.candidate_rp_holdtime = None
                                    self.candidate_rp_priority = None
                                    self.candidate_rp_up_time = None
                                    self.protocol = None


                                class CandidateRpAddress(object):
                                    """
                                    C\-RP address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:pim-bsr-crp-bag'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.candidate_rp_address is not None and self.candidate_rp_address._has_data():
                                        return True

                                    if self.candidate_rp_expires is not None:
                                        return True

                                    if self.candidate_rp_holdtime is not None:
                                        return True

                                    if self.candidate_rp_priority is not None:
                                        return True

                                    if self.candidate_rp_up_time is not None:
                                        return True

                                    if self.protocol is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp-list'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pim_bsr_crp_bag is not None:
                                    for child_ref in self.pim_bsr_crp_bag:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList']['meta_info']

                        @property
                        def _common_path(self):
                            if self.group_prefix is None:
                                raise YPYModelError('Key property group_prefix is None')

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:rp-caches/Cisco-IOS-XR-ipv4-pim-oper:rp-cache[Cisco-IOS-XR-ipv4-pim-oper:group-prefix = ' + str(self.group_prefix) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.group_prefix is not None:
                                return True

                            if self.candidate_rp_group_count is not None:
                                return True

                            if self.candidate_rp_list is not None and self.candidate_rp_list._has_data():
                                return True

                            if self.group_prefix_length is not None:
                                return True

                            if self.group_prefix_xr is not None and self.group_prefix_xr._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:rp-caches'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.rp_cache is not None:
                            for child_ref in self.rp_cache:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.Bsr.RpCaches']['meta_info']


                class CandidateRps(object):
                    """
                    PIM candidate\-RP
                    
                    .. attribute:: candidate_rp
                    
                    	PIM BSR candidate RP information
                    	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.candidate_rp = YList()
                        self.candidate_rp.parent = self
                        self.candidate_rp.name = 'candidate_rp'


                    class CandidateRp(object):
                        """
                        PIM BSR candidate RP information
                        
                        .. attribute:: rp_address  <key>
                        
                        	Candidate\-RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: acl_name
                        
                        	Group Access\-List Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: candidate_rp
                        
                        	Cand\-RP Address
                        	**type**\:   :py:class:`CandidateRp_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_>`
                        
                        .. attribute:: candidate_rp_advance_interval
                        
                        	Cand\-RP Adv Interval in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: candidate_rp_mode
                        
                        	Cand\-RP Mode
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: candidate_rp_scope
                        
                        	Cand\-RP Scope
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: candidate_rp_uptime
                        
                        	Cand\-RP uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_access
                        
                        	Group Ranges Using this Cand\-RP
                        	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                        
                        .. attribute:: crp_holdtime
                        
                        	Cand\-RP Holdtime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_priority
                        
                        	Cand\-RP Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rp_address = None
                            self.acl_name = None
                            self.candidate_rp = Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_()
                            self.candidate_rp.parent = self
                            self.candidate_rp_advance_interval = None
                            self.candidate_rp_mode = None
                            self.candidate_rp_scope = None
                            self.candidate_rp_uptime = None
                            self.crp_access = YList()
                            self.crp_access.parent = self
                            self.crp_access.name = 'crp_access'
                            self.crp_holdtime = None
                            self.crp_priority = None


                        class CandidateRp_(object):
                            """
                            Cand\-RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_']['meta_info']


                        class CrpAccess(object):
                            """
                            Group Ranges Using this Cand\-RP
                            
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.acl_name = None
                                self.candidate_rp_mode = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:crp-access'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.acl_name is not None:
                                    return True

                                if self.candidate_rp_mode is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess']['meta_info']

                        @property
                        def _common_path(self):
                            if self.rp_address is None:
                                raise YPYModelError('Key property rp_address is None')

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:candidate-rps/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp[Cisco-IOS-XR-ipv4-pim-oper:rp-address = ' + str(self.rp_address) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rp_address is not None:
                                return True

                            if self.acl_name is not None:
                                return True

                            if self.candidate_rp is not None and self.candidate_rp._has_data():
                                return True

                            if self.candidate_rp_advance_interval is not None:
                                return True

                            if self.candidate_rp_mode is not None:
                                return True

                            if self.candidate_rp_scope is not None:
                                return True

                            if self.candidate_rp_uptime is not None:
                                return True

                            if self.crp_access is not None:
                                for child_ref in self.crp_access:
                                    if child_ref._has_data():
                                        return True

                            if self.crp_holdtime is not None:
                                return True

                            if self.crp_priority is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:candidate-rps'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.candidate_rp is not None:
                            for child_ref in self.candidate_rp:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps']['meta_info']


                class BsrElections(object):
                    """
                    PIM BSR election state
                    
                    .. attribute:: bsr_election
                    
                    	PIM BSR information
                    	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bsr_election = YList()
                        self.bsr_election.parent = self
                        self.bsr_election.name = 'bsr_election'


                    class BsrElection(object):
                        """
                        PIM BSR information
                        
                        .. attribute:: pim_scope  <key>
                        
                        	BSR information
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: bootstrap_timeout
                        
                        	Bootstrap Timeout
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_address
                        
                        	BSR address
                        	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress>`
                        
                        .. attribute:: bsr_election_state
                        
                        	BSR Election State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_mask_length
                        
                        	Hash Function Mask Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_priority
                        
                        	BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_scope
                        
                        	BSR Scope
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_up_time
                        
                        	BSR Uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_bsr_address
                        
                        	C\-BSR address
                        	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                        
                        .. attribute:: candidate_bsr_flag
                        
                        	BSR Candidate Config Flag
                        	**type**\:  bool
                        
                        .. attribute:: candidate_bsr_mask_length
                        
                        	C\-BSR Hash Func. Mask Len
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_priority
                        
                        	C\-BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_state
                        
                        	BSR Candidate State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.pim_scope = None
                            self.bootstrap_timeout = None
                            self.bsr_address = Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress()
                            self.bsr_address.parent = self
                            self.bsr_election_state = None
                            self.bsr_mask_length = None
                            self.bsr_priority = None
                            self.bsr_scope = None
                            self.bsr_up_time = None
                            self.candidate_bsr_address = Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                            self.candidate_bsr_address.parent = self
                            self.candidate_bsr_flag = None
                            self.candidate_bsr_mask_length = None
                            self.candidate_bsr_priority = None
                            self.candidate_bsr_state = None


                        class BsrAddress(object):
                            """
                            BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bsr-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress']['meta_info']


                        class CandidateBsrAddress(object):
                            """
                            C\-BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-bsr-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.pim_scope is None:
                                raise YPYModelError('Key property pim_scope is None')

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:bsr-elections/Cisco-IOS-XR-ipv4-pim-oper:bsr-election[Cisco-IOS-XR-ipv4-pim-oper:pim-scope = ' + str(self.pim_scope) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.pim_scope is not None:
                                return True

                            if self.bootstrap_timeout is not None:
                                return True

                            if self.bsr_address is not None and self.bsr_address._has_data():
                                return True

                            if self.bsr_election_state is not None:
                                return True

                            if self.bsr_mask_length is not None:
                                return True

                            if self.bsr_priority is not None:
                                return True

                            if self.bsr_scope is not None:
                                return True

                            if self.bsr_up_time is not None:
                                return True

                            if self.candidate_bsr_address is not None and self.candidate_bsr_address._has_data():
                                return True

                            if self.candidate_bsr_flag is not None:
                                return True

                            if self.candidate_bsr_mask_length is not None:
                                return True

                            if self.candidate_bsr_priority is not None:
                                return True

                            if self.candidate_bsr_state is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr/Cisco-IOS-XR-ipv4-pim-oper:bsr-elections'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bsr_election is not None:
                            for child_ref in self.bsr_election:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.Bsr.BsrElections']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bsr'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bsr_elections is not None and self.bsr_elections._has_data():
                        return True

                    if self.candidate_rps is not None and self.candidate_rps._has_data():
                        return True

                    if self.rp_caches is not None and self.rp_caches._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.Bsr']['meta_info']


            class RoutePolicy(object):
                """
                PIM route policy
                
                .. attribute:: route_policy_statistics
                
                	PIM route policy statistics
                	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics>`
                
                .. attribute:: route_policy_tests
                
                	PIM route policy test run table
                	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.route_policy_statistics = Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics()
                    self.route_policy_statistics.parent = self
                    self.route_policy_tests = Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests()
                    self.route_policy_tests.parent = self


                class RoutePolicyStatistics(object):
                    """
                    PIM route policy statistics
                    
                    .. attribute:: any_table
                    
                    	Number of RPF lookup in any Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table
                    
                    	Number of RPF lookup in default\-only Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop
                    
                    	Number of RPF drops
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pass_
                    
                    	Number of RPF pass
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: policy_name
                    
                    	RPF policy name
                    	**type**\:  str
                    
                    .. attribute:: requests
                    
                    	Number of RPF lookup requests
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.any_table = None
                        self.default_table = None
                        self.drop = None
                        self.pass_ = None
                        self.policy_name = None
                        self.requests = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy/Cisco-IOS-XR-ipv4-pim-oper:route-policy-statistics'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.any_table is not None:
                            return True

                        if self.default_table is not None:
                            return True

                        if self.drop is not None:
                            return True

                        if self.pass_ is not None:
                            return True

                        if self.policy_name is not None:
                            return True

                        if self.requests is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics']['meta_info']


                class RoutePolicyTests(object):
                    """
                    PIM route policy test run table
                    
                    .. attribute:: route_policy_test
                    
                    	PIM route policy test run
                    	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.route_policy_test = YList()
                        self.route_policy_test.parent = self
                        self.route_policy_test.name = 'route_policy_test'


                    class RoutePolicyTest(object):
                        """
                        PIM route policy test run
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Default table selected
                        	**type**\:  bool
                        
                        .. attribute:: ext_comm
                        
                        	Extended Community
                        	**type**\:  str
                        
                        	**length:** 1..8
                        
                        .. attribute:: extended_community_rt
                        
                        	Route Target
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                        
                        .. attribute:: pass_
                        
                        	Pass
                        	**type**\:  bool
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                        
                        .. attribute:: table_active
                        
                        	Table active
                        	**type**\:  bool
                        
                        .. attribute:: table_exists
                        
                        	Table exists
                        	**type**\:  bool
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_name
                        
                        	VRF name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.afi = None
                            self.default_table = None
                            self.ext_comm = None
                            self.extended_community_rt = None
                            self.group_address = None
                            self.group_address_xr = Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self.pass_ = None
                            self.policy_name = None
                            self.safi = None
                            self.source_address = None
                            self.source_address_xr = Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self.table_active = None
                            self.table_exists = None
                            self.table_name = None
                            self.vrf_name = None


                        class SourceAddressXr(object):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy/Cisco-IOS-XR-ipv4-pim-oper:route-policy-tests/Cisco-IOS-XR-ipv4-pim-oper:route-policy-test/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr']['meta_info']


                        class GroupAddressXr(object):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy/Cisco-IOS-XR-ipv4-pim-oper:route-policy-tests/Cisco-IOS-XR-ipv4-pim-oper:route-policy-test/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy/Cisco-IOS-XR-ipv4-pim-oper:route-policy-tests/Cisco-IOS-XR-ipv4-pim-oper:route-policy-test'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.afi is not None:
                                return True

                            if self.default_table is not None:
                                return True

                            if self.ext_comm is not None:
                                return True

                            if self.extended_community_rt is not None:
                                return True

                            if self.group_address is not None:
                                return True

                            if self.group_address_xr is not None and self.group_address_xr._has_data():
                                return True

                            if self.pass_ is not None:
                                return True

                            if self.policy_name is not None:
                                return True

                            if self.safi is not None:
                                return True

                            if self.source_address is not None:
                                return True

                            if self.source_address_xr is not None and self.source_address_xr._has_data():
                                return True

                            if self.table_active is not None:
                                return True

                            if self.table_exists is not None:
                                return True

                            if self.table_name is not None:
                                return True

                            if self.vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy/Cisco-IOS-XR-ipv4-pim-oper:route-policy-tests'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.route_policy_test is not None:
                            for child_ref in self.route_policy_test:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:route-policy'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.route_policy_statistics is not None and self.route_policy_statistics._has_data():
                        return True

                    if self.route_policy_tests is not None and self.route_policy_tests._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.RoutePolicy']['meta_info']


            class RpfSummary(object):
                """
                PIM RPF registration summary
                
                .. attribute:: default_safi
                
                	Default RPF Table SAFI
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: default_table_name
                
                	Default RPF Table Name
                	**type**\:  str
                
                .. attribute:: is_isis_mtr_configured
                
                	Is ISIS MTR configured?
                	**type**\:  bool
                
                .. attribute:: is_isis_te_configured
                
                	Is ISIS TE configured?
                	**type**\:  bool
                
                .. attribute:: is_mbgp_configured
                
                	Is MBGP configured?
                	**type**\:  bool
                
                .. attribute:: is_multipath_enabled
                
                	Is Multipath Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_interface_hash_enabled
                
                	Is Multipath Interface Hash Extension Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_hash_enabled
                
                	Is Multipath Source based Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_next_hop_hash_enabled
                
                	Is Multipath Source\-Nexthop Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_ospf_te_configured
                
                	Is OSPF TE configured?
                	**type**\:  bool
                
                .. attribute:: is_rib_convergence
                
                	RIB Convergence status
                	**type**\:  bool
                
                .. attribute:: mo_frr_configured
                
                	Is MoFRR configured?
                	**type**\:  bool
                
                .. attribute:: rib_convergence_time_left
                
                	RIB convergence time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_convergence_timeout
                
                	RIB convergence timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_mo_frr_configured
                
                	Is MoFRR RIB configured?
                	**type**\:  bool
                
                .. attribute:: rpf_registrations
                
                	RPF Registration count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	Is RUMP MuRIB enabled?
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.default_safi = None
                    self.default_table_name = None
                    self.is_isis_mtr_configured = None
                    self.is_isis_te_configured = None
                    self.is_mbgp_configured = None
                    self.is_multipath_enabled = None
                    self.is_multipath_interface_hash_enabled = None
                    self.is_multipath_source_hash_enabled = None
                    self.is_multipath_source_next_hop_hash_enabled = None
                    self.is_ospf_te_configured = None
                    self.is_rib_convergence = None
                    self.mo_frr_configured = None
                    self.rib_convergence_time_left = None
                    self.rib_convergence_timeout = None
                    self.rib_mo_frr_configured = None
                    self.rpf_registrations = None
                    self.rump_enabled = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.default_safi is not None:
                        return True

                    if self.default_table_name is not None:
                        return True

                    if self.is_isis_mtr_configured is not None:
                        return True

                    if self.is_isis_te_configured is not None:
                        return True

                    if self.is_mbgp_configured is not None:
                        return True

                    if self.is_multipath_enabled is not None:
                        return True

                    if self.is_multipath_interface_hash_enabled is not None:
                        return True

                    if self.is_multipath_source_hash_enabled is not None:
                        return True

                    if self.is_multipath_source_next_hop_hash_enabled is not None:
                        return True

                    if self.is_ospf_te_configured is not None:
                        return True

                    if self.is_rib_convergence is not None:
                        return True

                    if self.mo_frr_configured is not None:
                        return True

                    if self.rib_convergence_time_left is not None:
                        return True

                    if self.rib_convergence_timeout is not None:
                        return True

                    if self.rib_mo_frr_configured is not None:
                        return True

                    if self.rpf_registrations is not None:
                        return True

                    if self.rump_enabled is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.RpfSummary']['meta_info']


            class Interfaces(object):
                """
                PIM interfaces
                
                .. attribute:: interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Interfaces.Interface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface = YList()
                    self.interface.parent = self
                    self.interface.name = 'interface'


                class Interface(object):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Interfaces.Interface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.configured_override_interval = None
                        self.configured_propagation_delay = None
                        self.dr_address = Ipv6Pim.Active.DefaultContext.Interfaces.Interface.DrAddress()
                        self.dr_address.parent = self
                        self.dr_priority = None
                        self.external_neighbor_count = None
                        self.generation_id = None
                        self.hello_expiry = None
                        self.hello_interval = None
                        self.idb_acl_name = None
                        self.idb_acl_provided = None
                        self.idb_current_count = None
                        self.idb_max_count = None
                        self.idb_oor_enabled = None
                        self.idb_threshold_count = None
                        self.interface_address = YList()
                        self.interface_address.parent = self
                        self.interface_address.name = 'interface_address'
                        self.interface_address_mask = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bidirectional_capable = None
                        self.is_enabled = None
                        self.is_proxy_capable = None
                        self.join_prune_interval = None
                        self.neighbor_count = None
                        self.neighbor_filter_name = None
                        self.override_interval = None
                        self.passive_interface = None
                        self.propagation_delay = None
                        self.prune_delay_enabled = None
                        self.virtual_interface = None


                    class DrAddress(object):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Interfaces.Interface.DrAddress']['meta_info']


                    class InterfaceAddress(object):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interfaces/Cisco-IOS-XR-ipv4-pim-oper:interface[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.are_we_dr is not None:
                            return True

                        if self.bfd_enabled is not None:
                            return True

                        if self.bfd_interval is not None:
                            return True

                        if self.bfd_multiplier is not None:
                            return True

                        if self.configured_override_interval is not None:
                            return True

                        if self.configured_propagation_delay is not None:
                            return True

                        if self.dr_address is not None and self.dr_address._has_data():
                            return True

                        if self.dr_priority is not None:
                            return True

                        if self.external_neighbor_count is not None:
                            return True

                        if self.generation_id is not None:
                            return True

                        if self.hello_expiry is not None:
                            return True

                        if self.hello_interval is not None:
                            return True

                        if self.idb_acl_name is not None:
                            return True

                        if self.idb_acl_provided is not None:
                            return True

                        if self.idb_current_count is not None:
                            return True

                        if self.idb_max_count is not None:
                            return True

                        if self.idb_oor_enabled is not None:
                            return True

                        if self.idb_threshold_count is not None:
                            return True

                        if self.interface_address is not None:
                            for child_ref in self.interface_address:
                                if child_ref._has_data():
                                    return True

                        if self.interface_address_mask is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_enabled is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.join_prune_interval is not None:
                            return True

                        if self.neighbor_count is not None:
                            return True

                        if self.neighbor_filter_name is not None:
                            return True

                        if self.override_interval is not None:
                            return True

                        if self.passive_interface is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.prune_delay_enabled is not None:
                            return True

                        if self.virtual_interface is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.Interfaces.Interface']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:interfaces'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface is not None:
                        for child_ref in self.interface:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.Interfaces']['meta_info']


            class NetIoTunnels(object):
                """
                Tunnel information that NETIO has 
                
                .. attribute:: net_io_tunnel
                
                	PIM netio tunnel information
                	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.net_io_tunnel = YList()
                    self.net_io_tunnel.parent = self
                    self.net_io_tunnel.name = 'net_io_tunnel'


                class NetIoTunnel(object):
                    """
                    PIM netio tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.tunnel_name = None
                        self.group_address_netio = Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self.rp_address = Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress()
                        self.rp_address.parent = self
                        self.source_address = Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress()
                        self.source_address.parent = self
                        self.source_address_netio = Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self.vrf_name = None


                    class SourceAddress(object):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress']['meta_info']


                    class RpAddress(object):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress']['meta_info']


                    class SourceAddressNetio(object):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-netio'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio']['meta_info']


                    class GroupAddressNetio(object):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-netio'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio']['meta_info']

                    @property
                    def _common_path(self):
                        if self.tunnel_name is None:
                            raise YPYModelError('Key property tunnel_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:net-io-tunnels/Cisco-IOS-XR-ipv4-pim-oper:net-io-tunnel[Cisco-IOS-XR-ipv4-pim-oper:tunnel-name = ' + str(self.tunnel_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.tunnel_name is not None:
                            return True

                        if self.group_address_netio is not None and self.group_address_netio._has_data():
                            return True

                        if self.rp_address is not None and self.rp_address._has_data():
                            return True

                        if self.source_address is not None and self.source_address._has_data():
                            return True

                        if self.source_address_netio is not None and self.source_address_netio._has_data():
                            return True

                        if self.vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:net-io-tunnels'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.net_io_tunnel is not None:
                        for child_ref in self.net_io_tunnel:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.NetIoTunnels']['meta_info']


            class BidirDfStates(object):
                """
                Bidirectional PIM DF election state table
                
                .. attribute:: bidir_df_state
                
                	Bidirectional PIM DF Election Table Entry
                	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bidir_df_state = YList()
                    self.bidir_df_state.parent = self
                    self.bidir_df_state.name = 'bidir_df_state'


                class BidirDfState(object):
                    """
                    Bidirectional PIM DF Election Table Entry
                    
                    .. attribute:: election_state
                    
                    	DF Election State
                    	**type**\:  str
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: our_metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: our_metric_preference
                    
                    	MetricPreference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr>`
                    
                    .. attribute:: time_nano_seconds
                    
                    	Timer expires (nseconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: time_seconds
                    
                    	Timer expires (seconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.election_state = None
                        self.interface_name = None
                        self.our_metric = None
                        self.our_metric_preference = None
                        self.pim_interface_name = None
                        self.rp_address = None
                        self.rp_address_xr = Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self.time_nano_seconds = None
                        self.time_seconds = None


                    class RpAddressXr(object):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-states/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-state/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-states/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-state'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.election_state is not None:
                            return True

                        if self.interface_name is not None:
                            return True

                        if self.our_metric is not None:
                            return True

                        if self.our_metric_preference is not None:
                            return True

                        if self.pim_interface_name is not None:
                            return True

                        if self.rp_address is not None:
                            return True

                        if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                            return True

                        if self.time_nano_seconds is not None:
                            return True

                        if self.time_seconds is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-states'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bidir_df_state is not None:
                        for child_ref in self.bidir_df_state:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.BidirDfStates']['meta_info']


            class Topologies(object):
                """
                PIM topology table
                
                .. attribute:: topology
                
                	PIM topology information
                	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.topology = YList()
                    self.topology.parent = self
                    self.topology.name = 'topology'


                class Topology(object):
                    """
                    PIM topology information
                    
                    .. attribute:: alive
                    
                    	Alive time in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: anycast_rp_match
                    
                    	Group matches Anycast\-RP policy
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_route_target
                    
                    	Anycast\-RP RT
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: assume_alive
                    
                    	The Assume Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: bgp_join
                    
                    	BGP C JOIN
                    	**type**\:  bool
                    
                    .. attribute:: bgpjp_time
                    
                    	BGP C JP Time
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: connected
                    
                    	Is Connected ?
                    	**type**\:  bool
                    
                    .. attribute:: customer_routing_type
                    
                    	Type of Customer Routing in the MVPN
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: dont_check_connected
                    
                    	Do we need to make the connected check on this route ?
                    	**type**\:  bool
                    
                    .. attribute:: expiry
                    
                    	When this entry expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: extranet_route
                    
                    	Is a Extranet route ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr>`
                    
                    .. attribute:: inherit_alive
                    
                    	The Inherit Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: inherit_spt
                    
                    	The Inherit SPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: is_via_lsm
                    
                    	Via LSM
                    	**type**\:  bool
                    
                    .. attribute:: jp_status
                    
                    	Join\-Prune Status
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: jp_timer
                    
                    	Join\-Prune Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: last_hop
                    
                    	Are we last hop ?
                    	**type**\:  bool
                    
                    .. attribute:: limit_reached
                    
                    	Have we throttled the creation of routes or interfaces ?
                    	**type**\:  bool
                    
                    .. attribute:: low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_active
                    
                    	Is MoFRR Active?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_backup
                    
                    	Is this Mofrr Backup?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_primary
                    
                    	Is this Mofrr Primary?
                    	**type**\:  bool
                    
                    .. attribute:: orig_src_address
                    
                    	Orig Src Address
                    	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress>`
                    
                    .. attribute:: outgoing_interface
                    
                    	Outgoing interface list
                    	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface>`
                    
                    .. attribute:: probe_alive
                    
                    	The Probe Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                    
                    .. attribute:: proxy
                    
                    	Is the RPF target a proxy?
                    	**type**\:  bool
                    
                    .. attribute:: proxy_address
                    
                    	RPF Proxy address
                    	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress>`
                    
                    .. attribute:: really_alive
                    
                    	The Really Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: register_received
                    
                    	Have registers been received for this source ?
                    	**type**\:  bool
                    
                    .. attribute:: register_received_timer
                    
                    	Register Received Timer in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: remote_source
                    
                    	MSDP told us
                    	**type**\:  bool
                    
                    .. attribute:: rib_mo_frr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rp_address
                    
                    	RP Address (If rpt)
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpAddress>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor>`
                    
                    .. attribute:: rpf_proxy_enabled
                    
                    	Is rpf if proxy enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: rpt
                    
                    	RPT bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpt_xr
                    
                    	Is this on the RPT ?
                    	**type**\:  bool
                    
                    .. attribute:: sa_joined
                    
                    	BGP SA join
                    	**type**\:  bool
                    
                    .. attribute:: sa_received
                    
                    	BGP SA received
                    	**type**\:  bool
                    
                    .. attribute:: sa_sent
                    
                    	BGP SA sent
                    	**type**\:  bool
                    
                    .. attribute:: secondary_rpf_interface_name
                    
                    	Secondary Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: secondary_rpf_neighbor
                    
                    	Secondary RPF Neighbor
                    	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor>`
                    
                    .. attribute:: sending_null_registers
                    
                    	Are we sending null registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: sending_registers
                    
                    	Are we sending registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: signal_sources
                    
                    	Signal Sources on route?
                    	**type**\:  bool
                    
                    .. attribute:: source_address
                    
                    	Source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr>`
                    
                    .. attribute:: spt
                    
                    	Is this on the SPT ?
                    	**type**\:  bool
                    
                    .. attribute:: suppress_registers
                    
                    	When the Null register probe expires
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: vxlan
                    
                    	Is this VXLAN?
                    	**type**\:  bool
                    
                    .. attribute:: wildcard
                    
                    	WC \-Wildcard
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.alive = None
                        self.anycast_rp_match = None
                        self.anycast_rp_route_target = None
                        self.assume_alive = None
                        self.bgp_join = None
                        self.bgpjp_time = None
                        self.connected = None
                        self.customer_routing_type = None
                        self.dont_check_connected = None
                        self.expiry = None
                        self.extranet_route = None
                        self.group_address = None
                        self.group_address_xr = Ipv6Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self.inherit_alive = None
                        self.inherit_spt = None
                        self.is_via_lsm = None
                        self.jp_status = None
                        self.jp_timer = None
                        self.last_hop = None
                        self.limit_reached = None
                        self.low_memory = None
                        self.mofrr_active = None
                        self.mofrr_backup = None
                        self.mofrr_enabled = None
                        self.mofrr_primary = None
                        self.orig_src_address = Ipv6Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress()
                        self.orig_src_address.parent = self
                        self.outgoing_interface = YList()
                        self.outgoing_interface.parent = self
                        self.outgoing_interface.name = 'outgoing_interface'
                        self.probe_alive = None
                        self.protocol = None
                        self.proxy = None
                        self.proxy_address = Ipv6Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress()
                        self.proxy_address.parent = self
                        self.really_alive = None
                        self.register_received = None
                        self.register_received_timer = None
                        self.remote_source = None
                        self.rib_mo_frr_enabled = None
                        self.rp_address = Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpAddress()
                        self.rp_address.parent = self
                        self.rpf_drop = None
                        self.rpf_extranet = None
                        self.rpf_interface_name = None
                        self.rpf_neighbor = Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self.rpf_proxy_enabled = None
                        self.rpf_root = Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfRoot()
                        self.rpf_root.parent = self
                        self.rpf_safi = None
                        self.rpf_table_name = None
                        self.rpf_vrf_name = None
                        self.rpt = None
                        self.rpt_xr = None
                        self.sa_joined = None
                        self.sa_received = None
                        self.sa_sent = None
                        self.secondary_rpf_interface_name = None
                        self.secondary_rpf_neighbor = Ipv6Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor()
                        self.secondary_rpf_neighbor.parent = self
                        self.sending_null_registers = None
                        self.sending_registers = None
                        self.signal_sources = None
                        self.source_address = None
                        self.source_address_xr = Ipv6Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self.spt = None
                        self.suppress_registers = None
                        self.uptime = None
                        self.vxlan = None
                        self.wildcard = None


                    class GroupAddressXr(object):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr']['meta_info']


                    class SourceAddressXr(object):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr']['meta_info']


                    class RpAddress(object):
                        """
                        RP Address (If rpt)
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpAddress']['meta_info']


                    class RpfNeighbor(object):
                        """
                        RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor']['meta_info']


                    class SecondaryRpfNeighbor(object):
                        """
                        Secondary RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:secondary-rpf-neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor']['meta_info']


                    class RpfRoot(object):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:rpf-root'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfRoot']['meta_info']


                    class ProxyAddress(object):
                        """
                        RPF Proxy address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:proxy-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress']['meta_info']


                    class OrigSrcAddress(object):
                        """
                        Orig Src Address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:orig-src-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress']['meta_info']


                    class OutgoingInterface(object):
                        """
                        Outgoing interface list
                        
                        .. attribute:: admin_boundary
                        
                        	Is this an administrative boundary ?
                        	**type**\:  bool
                        
                        .. attribute:: assert_timer
                        
                        	Assert Timer in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: assert_winner
                        
                        	Assert Winner
                        	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner>`
                        
                        .. attribute:: bgp_c_mcast_join
                        
                        	BGP C\-Mcast join
                        	**type**\:  bool
                        
                        .. attribute:: bgp_c_mcast_prune_delay_timer
                        
                        	BGP C\-MCAST Prune Suppression in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: data_mdt_join
                        
                        	Data MDT join
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	Expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: extranet_interface
                        
                        	Is this an Extranet Interface ?
                        	**type**\:  bool
                        
                        .. attribute:: forwarding_state
                        
                        	Forward or Prune
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: igmp_membership
                        
                        	IGMP membership
                        	**type**\:  bool
                        
                        .. attribute:: immediate_state
                        
                        	Immediate fwding state
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_interest_info
                        
                        	Internal Interest
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_state
                        
                        	Join\-Prune State
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer (secs)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: local_mdt_join
                        
                        	Default MDT Join
                        	**type**\:  bool
                        
                        .. attribute:: local_members
                        
                        	Local Information
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: mdt_safi_join
                        
                        	MDT Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mldp_inband_mdt
                        
                        	MLDP Inband MDT interface
                        	**type**\:  bool
                        
                        .. attribute:: mldp_stale
                        
                        	OLE is stale
                        	**type**\:  bool
                        
                        .. attribute:: mvp_nv6_safi_join
                        
                        	MVPN IPv6 Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mvpn_safi_join
                        
                        	MVPN Safi join
                        	**type**\:  bool
                        
                        .. attribute:: sa_prune
                        
                        	BGP SA Prune state
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vrf_name
                        
                        	VRF which physically owns
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.admin_boundary = None
                            self.assert_timer = None
                            self.assert_winner = Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner()
                            self.assert_winner.parent = self
                            self.bgp_c_mcast_join = None
                            self.bgp_c_mcast_prune_delay_timer = None
                            self.data_mdt_join = None
                            self.expiry = None
                            self.extranet_interface = None
                            self.forwarding_state = None
                            self.igmp_membership = None
                            self.immediate_state = None
                            self.interface_name = None
                            self.internal_interest_info = None
                            self.jp_state = None
                            self.jp_timer = None
                            self.last_hop = None
                            self.local_mdt_join = None
                            self.local_members = None
                            self.mdt_safi_join = None
                            self.mldp_inband_mdt = None
                            self.mldp_stale = None
                            self.mvp_nv6_safi_join = None
                            self.mvpn_safi_join = None
                            self.sa_prune = None
                            self.uptime = None
                            self.vrf_name = None


                        class AssertWinner(object):
                            """
                            Assert Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:outgoing-interface/Cisco-IOS-XR-ipv4-pim-oper:assert-winner'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology/Cisco-IOS-XR-ipv4-pim-oper:outgoing-interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.admin_boundary is not None:
                                return True

                            if self.assert_timer is not None:
                                return True

                            if self.assert_winner is not None and self.assert_winner._has_data():
                                return True

                            if self.bgp_c_mcast_join is not None:
                                return True

                            if self.bgp_c_mcast_prune_delay_timer is not None:
                                return True

                            if self.data_mdt_join is not None:
                                return True

                            if self.expiry is not None:
                                return True

                            if self.extranet_interface is not None:
                                return True

                            if self.forwarding_state is not None:
                                return True

                            if self.igmp_membership is not None:
                                return True

                            if self.immediate_state is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.internal_interest_info is not None:
                                return True

                            if self.jp_state is not None:
                                return True

                            if self.jp_timer is not None:
                                return True

                            if self.last_hop is not None:
                                return True

                            if self.local_mdt_join is not None:
                                return True

                            if self.local_members is not None:
                                return True

                            if self.mdt_safi_join is not None:
                                return True

                            if self.mldp_inband_mdt is not None:
                                return True

                            if self.mldp_stale is not None:
                                return True

                            if self.mvp_nv6_safi_join is not None:
                                return True

                            if self.mvpn_safi_join is not None:
                                return True

                            if self.sa_prune is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            if self.vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies/Cisco-IOS-XR-ipv4-pim-oper:topology'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.alive is not None:
                            return True

                        if self.anycast_rp_match is not None:
                            return True

                        if self.anycast_rp_route_target is not None:
                            return True

                        if self.assume_alive is not None:
                            return True

                        if self.bgp_join is not None:
                            return True

                        if self.bgpjp_time is not None:
                            return True

                        if self.connected is not None:
                            return True

                        if self.customer_routing_type is not None:
                            return True

                        if self.dont_check_connected is not None:
                            return True

                        if self.expiry is not None:
                            return True

                        if self.extranet_route is not None:
                            return True

                        if self.group_address is not None:
                            return True

                        if self.group_address_xr is not None and self.group_address_xr._has_data():
                            return True

                        if self.inherit_alive is not None:
                            return True

                        if self.inherit_spt is not None:
                            return True

                        if self.is_via_lsm is not None:
                            return True

                        if self.jp_status is not None:
                            return True

                        if self.jp_timer is not None:
                            return True

                        if self.last_hop is not None:
                            return True

                        if self.limit_reached is not None:
                            return True

                        if self.low_memory is not None:
                            return True

                        if self.mofrr_active is not None:
                            return True

                        if self.mofrr_backup is not None:
                            return True

                        if self.mofrr_enabled is not None:
                            return True

                        if self.mofrr_primary is not None:
                            return True

                        if self.orig_src_address is not None and self.orig_src_address._has_data():
                            return True

                        if self.outgoing_interface is not None:
                            for child_ref in self.outgoing_interface:
                                if child_ref._has_data():
                                    return True

                        if self.probe_alive is not None:
                            return True

                        if self.protocol is not None:
                            return True

                        if self.proxy is not None:
                            return True

                        if self.proxy_address is not None and self.proxy_address._has_data():
                            return True

                        if self.really_alive is not None:
                            return True

                        if self.register_received is not None:
                            return True

                        if self.register_received_timer is not None:
                            return True

                        if self.remote_source is not None:
                            return True

                        if self.rib_mo_frr_enabled is not None:
                            return True

                        if self.rp_address is not None and self.rp_address._has_data():
                            return True

                        if self.rpf_drop is not None:
                            return True

                        if self.rpf_extranet is not None:
                            return True

                        if self.rpf_interface_name is not None:
                            return True

                        if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                            return True

                        if self.rpf_proxy_enabled is not None:
                            return True

                        if self.rpf_root is not None and self.rpf_root._has_data():
                            return True

                        if self.rpf_safi is not None:
                            return True

                        if self.rpf_table_name is not None:
                            return True

                        if self.rpf_vrf_name is not None:
                            return True

                        if self.rpt is not None:
                            return True

                        if self.rpt_xr is not None:
                            return True

                        if self.sa_joined is not None:
                            return True

                        if self.sa_received is not None:
                            return True

                        if self.sa_sent is not None:
                            return True

                        if self.secondary_rpf_interface_name is not None:
                            return True

                        if self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor._has_data():
                            return True

                        if self.sending_null_registers is not None:
                            return True

                        if self.sending_registers is not None:
                            return True

                        if self.signal_sources is not None:
                            return True

                        if self.source_address is not None:
                            return True

                        if self.source_address_xr is not None and self.source_address_xr._has_data():
                            return True

                        if self.spt is not None:
                            return True

                        if self.suppress_registers is not None:
                            return True

                        if self.uptime is not None:
                            return True

                        if self.vxlan is not None:
                            return True

                        if self.wildcard is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.Topologies.Topology']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topologies'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.topology is not None:
                        for child_ref in self.topology:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.Topologies']['meta_info']


            class BgpAfs(object):
                """
                PIM BGP SAFI table
                
                .. attribute:: bgp_af
                
                	PIM BGP SAFI information
                	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bgp_af = YList()
                    self.bgp_af.parent = self
                    self.bgp_af.name = 'bgp_af'


                class BgpAf(object):
                    """
                    PIM BGP SAFI information
                    
                    .. attribute:: extranet_path_count
                    
                    	Count of dependent extranet paths
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group
                    
                    	Group address
                    	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Group>`
                    
                    .. attribute:: group_address
                    
                    	Group IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: is_bgp_added
                    
                    	SAFI learnt from BGP
                    	**type**\:  bool
                    
                    .. attribute:: next_hop
                    
                    	Next hop address
                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop>`
                    
                    .. attribute:: route_distinguisher
                    
                    	Router ID
                    	**type**\:  str
                    
                    	**length:** 0..256
                    
                    .. attribute:: source
                    
                    	Source address
                    	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Source>`
                    
                    .. attribute:: source_address
                    
                    	Source IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.extranet_path_count = None
                        self.group = Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Group()
                        self.group.parent = self
                        self.group_address = None
                        self.is_bgp_added = None
                        self.next_hop = Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop()
                        self.next_hop.parent = self
                        self.route_distinguisher = None
                        self.source = Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Source()
                        self.source.parent = self
                        self.source_address = None


                    class Source(object):
                        """
                        Source address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs/Cisco-IOS-XR-ipv4-pim-oper:bgp-af/Cisco-IOS-XR-ipv4-pim-oper:source'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Source']['meta_info']


                    class Group(object):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs/Cisco-IOS-XR-ipv4-pim-oper:bgp-af/Cisco-IOS-XR-ipv4-pim-oper:group'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Group']['meta_info']


                    class NextHop(object):
                        """
                        Next hop address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs/Cisco-IOS-XR-ipv4-pim-oper:bgp-af/Cisco-IOS-XR-ipv4-pim-oper:next-hop'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs/Cisco-IOS-XR-ipv4-pim-oper:bgp-af'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.extranet_path_count is not None:
                            return True

                        if self.group is not None and self.group._has_data():
                            return True

                        if self.group_address is not None:
                            return True

                        if self.is_bgp_added is not None:
                            return True

                        if self.next_hop is not None and self.next_hop._has_data():
                            return True

                        if self.route_distinguisher is not None:
                            return True

                        if self.source is not None and self.source._has_data():
                            return True

                        if self.source_address is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bgp_af is not None:
                        for child_ref in self.bgp_af:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.BgpAfs']['meta_info']


            class AutoRp(object):
                """
                PIM Auto\-RP information
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:auto-rp'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.AutoRp']['meta_info']


            class TopologyInterfaceFlagRouteCounts(object):
                """
                Route count for topology with interface flag set
                
                .. attribute:: topology_interface_flag_route_count
                
                	Route count for topology with interface flag set
                	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.topology_interface_flag_route_count = YList()
                    self.topology_interface_flag_route_count.parent = self
                    self.topology_interface_flag_route_count.name = 'topology_interface_flag_route_count'


                class TopologyInterfaceFlagRouteCount(object):
                    """
                    Route count for topology with interface flag
                    set
                    
                    .. attribute:: interface_flag  <key>
                    
                    	Interface flag
                    	**type**\:   :py:class:`PimTopologyInterfaceFlagEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlagEnum>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_flag = None
                        self.active_group_ranges = None
                        self.group_address = Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self.group_ranges = None
                        self.groute_count = None
                        self.is_node_low_memory = None
                        self.sg_route_count = None
                        self.sgr_route_count = None


                    class GroupAddress(object):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_flag is None:
                            raise YPYModelError('Key property interface_flag is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-interface-flag-route-counts/Cisco-IOS-XR-ipv4-pim-oper:topology-interface-flag-route-count[Cisco-IOS-XR-ipv4-pim-oper:interface-flag = ' + str(self.interface_flag) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_flag is not None:
                            return True

                        if self.active_group_ranges is not None:
                            return True

                        if self.group_address is not None and self.group_address._has_data():
                            return True

                        if self.group_ranges is not None:
                            return True

                        if self.groute_count is not None:
                            return True

                        if self.is_node_low_memory is not None:
                            return True

                        if self.sg_route_count is not None:
                            return True

                        if self.sgr_route_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-interface-flag-route-counts'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.topology_interface_flag_route_count is not None:
                        for child_ref in self.topology_interface_flag_route_count:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts']['meta_info']


            class GroupMapSources(object):
                """
                PIM group\-mapping with source information
                
                .. attribute:: group_map_source
                
                	PIM Group Mapping Entry with source information
                	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.group_map_source = YList()
                    self.group_map_source.parent = self
                    self.group_map_source.name = 'group_map_source'


                class GroupMapSource(object):
                    """
                    PIM Group Mapping Entry with source information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                    
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: priority
                    
                    	RP Priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocolEnum>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation>`
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.client = None
                        self.expires = None
                        self.group_map_information = Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self.holdtime = None
                        self.prefix = None
                        self.prefix_length = None
                        self.priority = None
                        self.protocol = None
                        self.rp_address = None
                        self.source_of_information = Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self.uptime = None


                    class SourceOfInformation(object):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-source/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation']['meta_info']


                    class GroupMapInformation(object):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.group_count = None
                            self.is_override = None
                            self.is_used = None
                            self.mrib_active = None
                            self.prefix = Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.priority = None
                            self.protocol = None
                            self.rp_address = Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self


                        class Prefix(object):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-source/Cisco-IOS-XR-ipv4-pim-oper:group-map-information/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix']['meta_info']


                        class RpAddress(object):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-source/Cisco-IOS-XR-ipv4-pim-oper:group-map-information/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-source/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.group_count is not None:
                                return True

                            if self.is_override is not None:
                                return True

                            if self.is_used is not None:
                                return True

                            if self.mrib_active is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-source'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.client is not None:
                            return True

                        if self.expires is not None:
                            return True

                        if self.group_map_information is not None and self.group_map_information._has_data():
                            return True

                        if self.holdtime is not None:
                            return True

                        if self.prefix is not None:
                            return True

                        if self.prefix_length is not None:
                            return True

                        if self.priority is not None:
                            return True

                        if self.protocol is not None:
                            return True

                        if self.rp_address is not None:
                            return True

                        if self.source_of_information is not None and self.source_of_information._has_data():
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.group_map_source is not None:
                        for child_ref in self.group_map_source:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapSources']['meta_info']


            class TrafficCounters(object):
                """
                PIM message traffic counters
                
                .. attribute:: boundary_acl_rx_drop
                
                	Inc. JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: boundary_acl_tx_drop
                
                	Out JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_error
                
                	Checksum errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: elapsed_time
                
                	Running time for counters in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: format_error
                
                	Malformed packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert
                
                	Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert_batched
                
                	Batched Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_bsr_message
                
                	Input BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_candidate_rp_advertisement
                
                	Input Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_data_register
                
                	Data Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_df_election
                
                	DF Election packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_ecmp_redirect
                
                	Input Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_hello
                
                	Hello packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_jp
                
                	Join Prune packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb_error
                
                	No IDB for intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_pim_error
                
                	PIM Disabled on intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_error
                
                	No VRF for idb error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_null_register
                
                	Null Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim_version_error
                
                	Invalid PIM version error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_register_stop
                
                	Register Stop packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: inputs
                
                	Packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_destination_packets
                
                	Control Packets with Invalid Destination
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_join_prunes
                
                	PIM invalid Join/Prunes received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_registers
                
                	PIM invalid registers received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_local_source_address
                
                	Data MDT Join msgs dropped due to local source addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_idb
                
                	Data MDT Join msgs dropped due to idb missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_vrf
                
                	Data MDT Join msgs dropped due to vrf missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_null_local_address
                
                	Data MDT Join msgs dropped due to null local addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_bad_type
                
                	Data MDT TLV bad type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_received
                
                	Data MDT Join Msgs received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_sent
                
                	Data MDT Join Msgs sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_joins_drop_multiple_encapsulation
                
                	MDT Join msgs dropped due to multiple Encap limitation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_send_queue_full
                
                	Packets dropped since mdt send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_socket_error
                
                	MDT Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_invalid_lsm_identifier
                
                	 Invalid LSM ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_mdt_socket_connection
                
                	Packets dropped since no mdt socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_source_address
                
                	Packets dropped since no source address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: non_supported_packets
                
                	PIM non supported pckets
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert
                
                	Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert_batched
                
                	Batched Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_bsr_message
                
                	Output BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_candidate_rp_advertisement
                
                	Output Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_data_register
                
                	Data Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_df_election
                
                	DF Election packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_ecmp_redirect
                
                	Output Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello
                
                	Hello packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello_bytes
                
                	Output Hello Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_join_group
                
                	Output Join Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_join_prune_bytes
                
                	Output JP Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_jp
                
                	Join Prune packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_loop_error
                
                	Output on loopback error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_null_register
                
                	Null Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_prune_group
                
                	Output Prune Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_register_stop
                
                	Register Stop packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: outputs
                
                	Packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_dequeued
                
                	Packets Dequeued per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_enqueued
                
                	Packets Enqueued per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_packman_error
                
                	Packets Dropped due to Pakman Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue
                
                	Packet queue state and statistics
                	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue>`
                
                .. attribute:: packet_queue_last_clear
                
                	Time in seconds since the last clear of all packet queues stats
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: packet_queue_length
                
                	Packet Queue Length per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue_size
                
                	Packet Queue Size per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_read_socket_error
                
                	Packet Read Socket Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_tail_drop
                
                	Packet Tail Drop per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_standby
                
                	Packets Dropped due to Standby Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pakman_error
                
                	Pakman packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_queue_full
                
                	Packets dropped since send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_error
                
                	Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_packets_error
                
                	Packets received in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: truncated_pim_packets
                
                	Packets dropped due to truncated Joins or Prunes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.boundary_acl_rx_drop = None
                    self.boundary_acl_tx_drop = None
                    self.checksum_error = None
                    self.elapsed_time = None
                    self.format_error = None
                    self.input_assert = None
                    self.input_assert_batched = None
                    self.input_bsr_message = None
                    self.input_candidate_rp_advertisement = None
                    self.input_data_register = None
                    self.input_df_election = None
                    self.input_ecmp_redirect = None
                    self.input_hello = None
                    self.input_jp = None
                    self.input_no_idb_error = None
                    self.input_no_pim_error = None
                    self.input_no_vrf_error = None
                    self.input_null_register = None
                    self.input_pim_version_error = None
                    self.input_register_stop = None
                    self.inputs = None
                    self.invalid_destination_packets = None
                    self.invalid_join_prunes = None
                    self.invalid_registers = None
                    self.mdt_drop_local_source_address = None
                    self.mdt_drop_no_idb = None
                    self.mdt_drop_no_vrf = None
                    self.mdt_drop_null_local_address = None
                    self.mdt_join_bad_type = None
                    self.mdt_join_tlv_received = None
                    self.mdt_join_tlv_sent = None
                    self.mdt_joins_drop_multiple_encapsulation = None
                    self.mdt_send_queue_full = None
                    self.mdt_socket_error = None
                    self.mldp_mdt_invalid_lsm_identifier = None
                    self.no_mdt_socket_connection = None
                    self.no_socket_connection = None
                    self.no_source_address = None
                    self.non_supported_packets = None
                    self.output_assert = None
                    self.output_assert_batched = None
                    self.output_bsr_message = None
                    self.output_candidate_rp_advertisement = None
                    self.output_data_register = None
                    self.output_df_election = None
                    self.output_ecmp_redirect = None
                    self.output_hello = None
                    self.output_hello_bytes = None
                    self.output_join_group = None
                    self.output_join_prune_bytes = None
                    self.output_jp = None
                    self.output_loop_error = None
                    self.output_null_register = None
                    self.output_prune_group = None
                    self.output_register_stop = None
                    self.outputs = None
                    self.packet_dequeued = YLeafList()
                    self.packet_dequeued.parent = self
                    self.packet_dequeued.name = 'packet_dequeued'
                    self.packet_enqueued = YLeafList()
                    self.packet_enqueued.parent = self
                    self.packet_enqueued.name = 'packet_enqueued'
                    self.packet_packman_error = None
                    self.packet_queue = YList()
                    self.packet_queue.parent = self
                    self.packet_queue.name = 'packet_queue'
                    self.packet_queue_last_clear = None
                    self.packet_queue_length = YLeafList()
                    self.packet_queue_length.parent = self
                    self.packet_queue_length.name = 'packet_queue_length'
                    self.packet_queue_size = YLeafList()
                    self.packet_queue_size.parent = self
                    self.packet_queue_size.name = 'packet_queue_size'
                    self.packet_read_socket_error = None
                    self.packet_tail_drop = YLeafList()
                    self.packet_tail_drop.parent = self
                    self.packet_tail_drop.name = 'packet_tail_drop'
                    self.packets_standby = None
                    self.pakman_error = None
                    self.send_queue_full = None
                    self.socket_error = None
                    self.standby_packets_error = None
                    self.truncated_pim_packets = None


                class PacketQueue(object):
                    """
                    Packet queue state and statistics
                    
                    .. attribute:: packet_queue_priority
                    
                    	Priority of this packet queue
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_state
                    
                    	State of the queue
                    	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState>`
                    
                    .. attribute:: packet_queue_stats
                    
                    	Statistics about the queue
                    	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.packet_queue_priority = None
                        self.packet_queue_state = Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState()
                        self.packet_queue_state.parent = self
                        self.packet_queue_stats = Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats()
                        self.packet_queue_stats.parent = self


                    class PacketQueueState(object):
                        """
                        State of the queue
                        
                        .. attribute:: max_queue_size
                        
                        	Maximum size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_bytes
                        
                        	Size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_packets
                        
                        	Size of queue in number of packets
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.max_queue_size = None
                            self.queue_size_bytes = None
                            self.queue_size_packets = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:traffic-counters/Cisco-IOS-XR-ipv4-pim-oper:packet-queue/Cisco-IOS-XR-ipv4-pim-oper:packet-queue-state'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.max_queue_size is not None:
                                return True

                            if self.queue_size_bytes is not None:
                                return True

                            if self.queue_size_packets is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState']['meta_info']


                    class PacketQueueStats(object):
                        """
                        Statistics about the queue
                        
                        .. attribute:: dequeued_packets
                        
                        	Total number of packets dequeued from this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: enqueued_packets
                        
                        	Total number of packets enqueued to this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: high_water_mark_bytes
                        
                        	Highest number of bytes enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: high_water_mark_packets
                        
                        	Highest number of packets enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tail_drops
                        
                        	Number packets dropped from this queue due to max size
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dequeued_packets = None
                            self.enqueued_packets = None
                            self.high_water_mark_bytes = None
                            self.high_water_mark_packets = None
                            self.tail_drops = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:traffic-counters/Cisco-IOS-XR-ipv4-pim-oper:packet-queue/Cisco-IOS-XR-ipv4-pim-oper:packet-queue-stats'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dequeued_packets is not None:
                                return True

                            if self.enqueued_packets is not None:
                                return True

                            if self.high_water_mark_bytes is not None:
                                return True

                            if self.high_water_mark_packets is not None:
                                return True

                            if self.tail_drops is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:traffic-counters/Cisco-IOS-XR-ipv4-pim-oper:packet-queue'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.packet_queue_priority is not None:
                            return True

                        if self.packet_queue_state is not None and self.packet_queue_state._has_data():
                            return True

                        if self.packet_queue_stats is not None and self.packet_queue_stats._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:traffic-counters'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.boundary_acl_rx_drop is not None:
                        return True

                    if self.boundary_acl_tx_drop is not None:
                        return True

                    if self.checksum_error is not None:
                        return True

                    if self.elapsed_time is not None:
                        return True

                    if self.format_error is not None:
                        return True

                    if self.input_assert is not None:
                        return True

                    if self.input_assert_batched is not None:
                        return True

                    if self.input_bsr_message is not None:
                        return True

                    if self.input_candidate_rp_advertisement is not None:
                        return True

                    if self.input_data_register is not None:
                        return True

                    if self.input_df_election is not None:
                        return True

                    if self.input_ecmp_redirect is not None:
                        return True

                    if self.input_hello is not None:
                        return True

                    if self.input_jp is not None:
                        return True

                    if self.input_no_idb_error is not None:
                        return True

                    if self.input_no_pim_error is not None:
                        return True

                    if self.input_no_vrf_error is not None:
                        return True

                    if self.input_null_register is not None:
                        return True

                    if self.input_pim_version_error is not None:
                        return True

                    if self.input_register_stop is not None:
                        return True

                    if self.inputs is not None:
                        return True

                    if self.invalid_destination_packets is not None:
                        return True

                    if self.invalid_join_prunes is not None:
                        return True

                    if self.invalid_registers is not None:
                        return True

                    if self.mdt_drop_local_source_address is not None:
                        return True

                    if self.mdt_drop_no_idb is not None:
                        return True

                    if self.mdt_drop_no_vrf is not None:
                        return True

                    if self.mdt_drop_null_local_address is not None:
                        return True

                    if self.mdt_join_bad_type is not None:
                        return True

                    if self.mdt_join_tlv_received is not None:
                        return True

                    if self.mdt_join_tlv_sent is not None:
                        return True

                    if self.mdt_joins_drop_multiple_encapsulation is not None:
                        return True

                    if self.mdt_send_queue_full is not None:
                        return True

                    if self.mdt_socket_error is not None:
                        return True

                    if self.mldp_mdt_invalid_lsm_identifier is not None:
                        return True

                    if self.no_mdt_socket_connection is not None:
                        return True

                    if self.no_socket_connection is not None:
                        return True

                    if self.no_source_address is not None:
                        return True

                    if self.non_supported_packets is not None:
                        return True

                    if self.output_assert is not None:
                        return True

                    if self.output_assert_batched is not None:
                        return True

                    if self.output_bsr_message is not None:
                        return True

                    if self.output_candidate_rp_advertisement is not None:
                        return True

                    if self.output_data_register is not None:
                        return True

                    if self.output_df_election is not None:
                        return True

                    if self.output_ecmp_redirect is not None:
                        return True

                    if self.output_hello is not None:
                        return True

                    if self.output_hello_bytes is not None:
                        return True

                    if self.output_join_group is not None:
                        return True

                    if self.output_join_prune_bytes is not None:
                        return True

                    if self.output_jp is not None:
                        return True

                    if self.output_loop_error is not None:
                        return True

                    if self.output_null_register is not None:
                        return True

                    if self.output_prune_group is not None:
                        return True

                    if self.output_register_stop is not None:
                        return True

                    if self.outputs is not None:
                        return True

                    if self.packet_dequeued is not None:
                        for child in self.packet_dequeued:
                            if child is not None:
                                return True

                    if self.packet_enqueued is not None:
                        for child in self.packet_enqueued:
                            if child is not None:
                                return True

                    if self.packet_packman_error is not None:
                        return True

                    if self.packet_queue is not None:
                        for child_ref in self.packet_queue:
                            if child_ref._has_data():
                                return True

                    if self.packet_queue_last_clear is not None:
                        return True

                    if self.packet_queue_length is not None:
                        for child in self.packet_queue_length:
                            if child is not None:
                                return True

                    if self.packet_queue_size is not None:
                        for child in self.packet_queue_size:
                            if child is not None:
                                return True

                    if self.packet_read_socket_error is not None:
                        return True

                    if self.packet_tail_drop is not None:
                        for child in self.packet_tail_drop:
                            if child is not None:
                                return True

                    if self.packets_standby is not None:
                        return True

                    if self.pakman_error is not None:
                        return True

                    if self.send_queue_full is not None:
                        return True

                    if self.socket_error is not None:
                        return True

                    if self.standby_packets_error is not None:
                        return True

                    if self.truncated_pim_packets is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.TrafficCounters']['meta_info']


            class GroupMapRpfs(object):
                """
                PIM group mapping information
                
                .. attribute:: group_map_rpf
                
                	PIM group mapping entry
                	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.group_map_rpf = YList()
                    self.group_map_rpf.parent = self
                    self.group_map_rpf.name = 'group_map_rpf'


                class GroupMapRpf(object):
                    """
                    PIM group mapping entry
                    
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\:  bool
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocolEnum>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_priority
                    
                    	RP priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.are_we_rp = None
                        self.client = None
                        self.group_map_information = Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self.prefix = None
                        self.prefix_length = None
                        self.protocol = None
                        self.rp_address = None
                        self.rp_priority = None
                        self.rpf_interface_name = None
                        self.rpf_neighbor = Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self.rpf_vrf_name = None


                    class RpfNeighbor(object):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor']['meta_info']


                    class GroupMapInformation(object):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.group_count = None
                            self.is_override = None
                            self.is_used = None
                            self.mrib_active = None
                            self.prefix = Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.priority = None
                            self.protocol = None
                            self.rp_address = Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self


                        class Prefix(object):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf/Cisco-IOS-XR-ipv4-pim-oper:group-map-information/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix']['meta_info']


                        class RpAddress(object):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf/Cisco-IOS-XR-ipv4-pim-oper:group-map-information/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.group_count is not None:
                                return True

                            if self.is_override is not None:
                                return True

                            if self.is_used is not None:
                                return True

                            if self.mrib_active is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.are_we_rp is not None:
                            return True

                        if self.client is not None:
                            return True

                        if self.group_map_information is not None and self.group_map_information._has_data():
                            return True

                        if self.prefix is not None:
                            return True

                        if self.prefix_length is not None:
                            return True

                        if self.protocol is not None:
                            return True

                        if self.rp_address is not None:
                            return True

                        if self.rp_priority is not None:
                            return True

                        if self.rpf_interface_name is not None:
                            return True

                        if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                            return True

                        if self.rpf_vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.group_map_rpf is not None:
                        for child_ref in self.group_map_rpf:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapRpfs']['meta_info']


            class Summary(object):
                """
                PIM summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bsr_candidate_rp_set_count = None
                    self.bsr_candidate_rp_set_limit = None
                    self.bsr_candidate_rp_set_threshold = None
                    self.bsr_range_threshold = None
                    self.bsr_ranges_count = None
                    self.bsr_ranges_limit = None
                    self.global_auto_rp_ranges_limit = None
                    self.global_bsr_candidate_rp_set_count = None
                    self.global_bsr_candidate_rp_set_limit = None
                    self.global_bsr_candidate_rp_set_threshold = None
                    self.global_bsr_ranges_count = None
                    self.global_bsr_ranges_limit = None
                    self.global_bsr_ranges_threshold = None
                    self.global_register_limit = None
                    self.is_bsr_ranges_threshold_reached = None
                    self.is_global_auto_rp_ranges_limit_reached = None
                    self.is_global_bsr_ranges_limit_reached = None
                    self.is_global_register_limit_reached = None
                    self.is_global_route_limit_reached = None
                    self.is_global_rxi_limit_reached = None
                    self.is_maximum_enforcement_disabled = None
                    self.is_node_low_memory = None
                    self.is_ranges_limit_reached = None
                    self.is_route_limit_reached = None
                    self.ranges_count = None
                    self.ranges_limit = None
                    self.ranges_threshold = None
                    self.register_count = None
                    self.register_limit = None
                    self.register_limit_reached = None
                    self.register_threshold = None
                    self.route_count = None
                    self.route_limit = None
                    self.route_low_water_mark = None
                    self.route_threshold = None
                    self.rxi_limit_reached = None
                    self.rxi_low_water_mark = None
                    self.topology_interface_state_count = None
                    self.topology_interface_state_limit = None
                    self.topology_interface_state_threshold = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bsr_candidate_rp_set_count is not None:
                        return True

                    if self.bsr_candidate_rp_set_limit is not None:
                        return True

                    if self.bsr_candidate_rp_set_threshold is not None:
                        return True

                    if self.bsr_range_threshold is not None:
                        return True

                    if self.bsr_ranges_count is not None:
                        return True

                    if self.bsr_ranges_limit is not None:
                        return True

                    if self.global_auto_rp_ranges_limit is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_count is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_limit is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_threshold is not None:
                        return True

                    if self.global_bsr_ranges_count is not None:
                        return True

                    if self.global_bsr_ranges_limit is not None:
                        return True

                    if self.global_bsr_ranges_threshold is not None:
                        return True

                    if self.global_register_limit is not None:
                        return True

                    if self.is_bsr_ranges_threshold_reached is not None:
                        return True

                    if self.is_global_auto_rp_ranges_limit_reached is not None:
                        return True

                    if self.is_global_bsr_ranges_limit_reached is not None:
                        return True

                    if self.is_global_register_limit_reached is not None:
                        return True

                    if self.is_global_route_limit_reached is not None:
                        return True

                    if self.is_global_rxi_limit_reached is not None:
                        return True

                    if self.is_maximum_enforcement_disabled is not None:
                        return True

                    if self.is_node_low_memory is not None:
                        return True

                    if self.is_ranges_limit_reached is not None:
                        return True

                    if self.is_route_limit_reached is not None:
                        return True

                    if self.ranges_count is not None:
                        return True

                    if self.ranges_limit is not None:
                        return True

                    if self.ranges_threshold is not None:
                        return True

                    if self.register_count is not None:
                        return True

                    if self.register_limit is not None:
                        return True

                    if self.register_limit_reached is not None:
                        return True

                    if self.register_threshold is not None:
                        return True

                    if self.route_count is not None:
                        return True

                    if self.route_limit is not None:
                        return True

                    if self.route_low_water_mark is not None:
                        return True

                    if self.route_threshold is not None:
                        return True

                    if self.rxi_limit_reached is not None:
                        return True

                    if self.rxi_low_water_mark is not None:
                        return True

                    if self.topology_interface_state_count is not None:
                        return True

                    if self.topology_interface_state_limit is not None:
                        return True

                    if self.topology_interface_state_threshold is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.Summary']['meta_info']


            class Gre(object):
                """
                GRE information
                
                .. attribute:: gre_hashes
                
                	GRE hash
                	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreHashes>`
                
                .. attribute:: gre_next_hops
                
                	GRE destination neighbor table
                	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.gre_hashes = Ipv6Pim.Active.DefaultContext.Gre.GreHashes()
                    self.gre_hashes.parent = self
                    self.gre_next_hops = Ipv6Pim.Active.DefaultContext.Gre.GreNextHops()
                    self.gre_next_hops.parent = self


                class GreHashes(object):
                    """
                    GRE hash
                    
                    .. attribute:: gre_hash
                    
                    	PIM GRE Hashed Underlying Interface
                    	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreHashes.GreHash>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.gre_hash = YList()
                        self.gre_hash.parent = self
                        self.gre_hash.name = 'gre_hash'


                    class GreHash(object):
                        """
                        PIM GRE Hashed Underlying Interface
                        
                        .. attribute:: destination_address  <key>
                        
                        	Destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: ifname  <key>
                        
                        	GRE Tunnel Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: source_address  <key>
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: next_hop_interface
                        
                        	Next hop neighbor interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.destination_address = None
                            self.ifname = None
                            self.source_address = None
                            self.next_hop_interface = None

                        @property
                        def _common_path(self):
                            if self.destination_address is None:
                                raise YPYModelError('Key property destination_address is None')
                            if self.ifname is None:
                                raise YPYModelError('Key property ifname is None')
                            if self.source_address is None:
                                raise YPYModelError('Key property source_address is None')

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:gre/Cisco-IOS-XR-ipv4-pim-oper:gre-hashes/Cisco-IOS-XR-ipv4-pim-oper:gre-hash[Cisco-IOS-XR-ipv4-pim-oper:destination-address = ' + str(self.destination_address) + '][Cisco-IOS-XR-ipv4-pim-oper:ifname = ' + str(self.ifname) + '][Cisco-IOS-XR-ipv4-pim-oper:source-address = ' + str(self.source_address) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.destination_address is not None:
                                return True

                            if self.ifname is not None:
                                return True

                            if self.source_address is not None:
                                return True

                            if self.next_hop_interface is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Gre.GreHashes.GreHash']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:gre/Cisco-IOS-XR-ipv4-pim-oper:gre-hashes'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.gre_hash is not None:
                            for child_ref in self.gre_hash:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.Gre.GreHashes']['meta_info']


                class GreNextHops(object):
                    """
                    GRE destination neighbor table
                    
                    .. attribute:: gre_next_hop
                    
                    	PIM GRE address next\-hop information
                    	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.gre_next_hop = YList()
                        self.gre_next_hop.parent = self
                        self.gre_next_hop.name = 'gre_next_hop'


                    class GreNextHop(object):
                        """
                        PIM GRE address next\-hop information
                        
                        .. attribute:: destination_address  <key>
                        
                        	GRE destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: gre_path
                        
                        	GRE Paths list
                        	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath>`
                        
                        .. attribute:: is_connected
                        
                        	Are we connected ?
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: registered_address
                        
                        	Address registered
                        	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.destination_address = None
                            self.gre_path = YList()
                            self.gre_path.parent = self
                            self.gre_path.name = 'gre_path'
                            self.is_connected = None
                            self.metric = None
                            self.metric_preference = None
                            self.registered_address = Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                            self.registered_address.parent = self


                        class RegisteredAddress(object):
                            """
                            Address registered
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:registered-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress']['meta_info']


                        class GrePath(object):
                            """
                            GRE Paths list
                            
                            .. attribute:: extranet_vrf_name
                            
                            	Extranet VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: gre_interface_name
                            
                            	GRE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: gre_neighbor
                            
                            	GRE neighbor
                            	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                            
                            .. attribute:: gre_next_hop
                            
                            	GRE nexthop
                            	**type**\:   :py:class:`GreNextHop_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_>`
                            
                            .. attribute:: is_connector_attribute_present
                            
                            	Connector attribute present
                            	**type**\:  bool
                            
                            .. attribute:: is_gre_interface_disabled
                            
                            	Is the gre interface disabled ?
                            	**type**\:  bool
                            
                            .. attribute:: is_via_lsm
                            
                            	Via LSM
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.extranet_vrf_name = None
                                self.gre_interface_name = None
                                self.gre_neighbor = Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                self.gre_neighbor.parent = self
                                self.gre_next_hop = Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_()
                                self.gre_next_hop.parent = self
                                self.is_connector_attribute_present = None
                                self.is_gre_interface_disabled = None
                                self.is_via_lsm = None


                            class GreNeighbor(object):
                                """
                                GRE neighbor
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-neighbor'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor']['meta_info']


                            class GreNextHop_(object):
                                """
                                GRE nexthop
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-path'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.extranet_vrf_name is not None:
                                    return True

                                if self.gre_interface_name is not None:
                                    return True

                                if self.gre_neighbor is not None and self.gre_neighbor._has_data():
                                    return True

                                if self.gre_next_hop is not None and self.gre_next_hop._has_data():
                                    return True

                                if self.is_connector_attribute_present is not None:
                                    return True

                                if self.is_gre_interface_disabled is not None:
                                    return True

                                if self.is_via_lsm is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath']['meta_info']

                        @property
                        def _common_path(self):
                            if self.destination_address is None:
                                raise YPYModelError('Key property destination_address is None')

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:gre/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hops/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hop[Cisco-IOS-XR-ipv4-pim-oper:destination-address = ' + str(self.destination_address) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.destination_address is not None:
                                return True

                            if self.gre_path is not None:
                                for child_ref in self.gre_path:
                                    if child_ref._has_data():
                                        return True

                            if self.is_connected is not None:
                                return True

                            if self.metric is not None:
                                return True

                            if self.metric_preference is not None:
                                return True

                            if self.registered_address is not None and self.registered_address._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:gre/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hops'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.gre_next_hop is not None:
                            for child_ref in self.gre_next_hop:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.Gre.GreNextHops']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:gre'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.gre_hashes is not None and self.gre_hashes._has_data():
                        return True

                    if self.gre_next_hops is not None and self.gre_next_hops._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.Gre']['meta_info']


            class BidirDfWinners(object):
                """
                Bidirectional PIM DF election winner table
                
                .. attribute:: bidir_df_winner
                
                	Bidirectional PIM DF election table entry
                	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bidir_df_winner = YList()
                    self.bidir_df_winner.parent = self
                    self.bidir_df_winner.name = 'bidir_df_winner'


                class BidirDfWinner(object):
                    """
                    Bidirectional PIM DF election table entry
                    
                    .. attribute:: are_we_df
                    
                    	Are we DF
                    	**type**\:  bool
                    
                    .. attribute:: df_winner
                    
                    	DF Winner
                    	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner>`
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_preference
                    
                    	Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                    
                    .. attribute:: rp_lan
                    
                    	Is this the RP LAN
                    	**type**\:  bool
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.are_we_df = None
                        self.df_winner = Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner()
                        self.df_winner.parent = self
                        self.interface_name = None
                        self.metric = None
                        self.metric_preference = None
                        self.pim_interface_name = None
                        self.rp_address = None
                        self.rp_address_xr = Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self.rp_lan = None
                        self.uptime = None


                    class RpAddressXr(object):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winners/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winner/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr']['meta_info']


                    class DfWinner(object):
                        """
                        DF Winner
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winners/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winner/Cisco-IOS-XR-ipv4-pim-oper:df-winner'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winners/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winner'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.are_we_df is not None:
                            return True

                        if self.df_winner is not None and self.df_winner._has_data():
                            return True

                        if self.interface_name is not None:
                            return True

                        if self.metric is not None:
                            return True

                        if self.metric_preference is not None:
                            return True

                        if self.pim_interface_name is not None:
                            return True

                        if self.rp_address is not None:
                            return True

                        if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                            return True

                        if self.rp_lan is not None:
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winners'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bidir_df_winner is not None:
                        for child_ref in self.bidir_df_winner:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.BidirDfWinners']['meta_info']


            class TableContexts(object):
                """
                PIM table context list
                
                .. attribute:: table_context
                
                	PIM table context information
                	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TableContexts.TableContext>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.table_context = YList()
                    self.table_context.parent = self
                    self.table_context.name = 'table_context'


                class TableContext(object):
                    """
                    PIM table context information
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: saf_name
                    
                    	SAF name
                    	**type**\:   :py:class:`PimSafiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafiEnum>`
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: topology_name
                    
                    	Topology name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.afi = None
                        self.is_active = None
                        self.is_ital_registration_done = None
                        self.is_rib_convergence = None
                        self.is_rib_convergence_received = None
                        self.is_rib_registration_done = None
                        self.rpf_registrations = None
                        self.saf_name = None
                        self.safi = None
                        self.table_id = None
                        self.table_name = None
                        self.topology_name = None
                        self.vrf_id = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:table-contexts/Cisco-IOS-XR-ipv4-pim-oper:table-context'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.afi is not None:
                            return True

                        if self.is_active is not None:
                            return True

                        if self.is_ital_registration_done is not None:
                            return True

                        if self.is_rib_convergence is not None:
                            return True

                        if self.is_rib_convergence_received is not None:
                            return True

                        if self.is_rib_registration_done is not None:
                            return True

                        if self.rpf_registrations is not None:
                            return True

                        if self.saf_name is not None:
                            return True

                        if self.safi is not None:
                            return True

                        if self.table_id is not None:
                            return True

                        if self.table_name is not None:
                            return True

                        if self.topology_name is not None:
                            return True

                        if self.vrf_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.TableContexts.TableContext']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:table-contexts'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.table_context is not None:
                        for child_ref in self.table_context:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.TableContexts']['meta_info']


            class NeighborSummaries(object):
                """
                PIM neighbor summary table
                
                .. attribute:: neighbor_summary
                
                	PIM neighbor summary information
                	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.neighbor_summary = YList()
                    self.neighbor_summary.parent = self
                    self.neighbor_summary.name = 'neighbor_summary'


                class NeighborSummary(object):
                    """
                    PIM neighbor summary information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: number_of_external_neighbors
                    
                    	Number of external neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: number_of_neighbors
                    
                    	Number of neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.number_of_external_neighbors = None
                        self.number_of_neighbors = None

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbor-summaries/Cisco-IOS-XR-ipv4-pim-oper:neighbor-summary[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.number_of_external_neighbors is not None:
                            return True

                        if self.number_of_neighbors is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbor-summaries'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.neighbor_summary is not None:
                        for child_ref in self.neighbor_summary:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.NeighborSummaries']['meta_info']


            class Context(object):
                """
                PIM context information
                
                .. attribute:: active_table_count
                
                	Number of active Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: allow_rp_configured
                
                	Allow RP Configured
                	**type**\:  bool
                
                .. attribute:: allow_rp_group_list
                
                	Allow RP Group\-List ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: allow_rp_rp_list
                
                	Allow RP RP\-list ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: anycast_rp_configured
                
                	Anycast\-RP config
                	**type**\:  bool
                
                .. attribute:: anycast_rp_policy_name
                
                	Anycast\-RP Policy Name
                	**type**\:  str
                
                .. attribute:: anycast_rp_range
                
                	Anycast\-RP Ranges
                	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange>`
                
                .. attribute:: bgp_auto_discovery_configured
                
                	BGP Auto\-Discovery configured
                	**type**\:  bool
                
                .. attribute:: bgp_auto_discovery_type
                
                	BGP Auto Discovery Type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_i_pmsi_added
                
                	BGP I\-PMSI Added
                	**type**\:  bool
                
                .. attribute:: bgp_remote_address
                
                	BGP remote interface address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: bgp_remote_interface
                
                	BGP remote interface handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: bgp_remote_interface_name
                
                	BGP remote interface name
                	**type**\:  str
                
                .. attribute:: bgp_remote_on
                
                	BGP remote interface status
                	**type**\:  bool
                
                .. attribute:: bgp_remote_state
                
                	BGP remote interface state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_source_active_announce
                
                	Send BGP Source\-Active Announcements
                	**type**\:  bool
                
                .. attribute:: export_route_target
                
                	Export Route Targets
                	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.ExportRouteTarget>`
                
                .. attribute:: gin_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: gin_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: gin_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: import_route_target
                
                	Import Route Targets
                	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.ImportRouteTarget>`
                
                .. attribute:: in_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: in_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: in_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_signaling_local_enabled
                
                	Inband signaling Local enabled
                	**type**\:  bool
                
                .. attribute:: in_band_signaling_remote_enabled
                
                	Inband signaling Remote enabled
                	**type**\:  bool
                
                .. attribute:: inter_autonomous_system_enabled
                
                	Inter\-AS Enabled
                	**type**\:  bool
                
                .. attribute:: ir_maximum_mdt_aggregation
                
                	IR MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_announce_interval
                
                	IR Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_switchover_interval
                
                	IR Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_interface
                
                	IRMDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: ir_mdt_mtu
                
                	IRMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_name
                
                	IR MDT Name
                	**type**\:  str
                
                .. attribute:: ir_mdt_rpf_identifier
                
                	IR RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_tail_label
                
                	IR Tail Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_active
                
                	Active
                	**type**\:  bool
                
                .. attribute:: is_active_ital
                
                	Active ITAL
                	**type**\:  bool
                
                .. attribute:: is_all_interface_disable_operation
                
                	PIM all interface disable operation
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_enabled
                
                	Auto RP Listen Enabled
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_sock_add
                
                	Auto RP listen sock add
                	**type**\:  bool
                
                .. attribute:: is_create_gin_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_in_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_ir_mdt_interface
                
                	Create IR MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mdt_interface
                
                	Create MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mldp_mdt_interface
                
                	Create MLDP MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_rsvp_te_mdt_interface
                
                	Create RSVP\-TE MDT interface
                	**type**\:  bool
                
                .. attribute:: is_default_granges
                
                	Default granges
                	**type**\:  bool
                
                .. attribute:: is_gin_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_in_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_ir_mdt_owner
                
                	IR MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_add_required
                
                	VRF LPTS filter required on Socket
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_added
                
                	VRF LPTS filter added on Socket
                	**type**\:  bool
                
                .. attribute:: is_m_host_publish_pending
                
                	Publish pending for MHost Default interface
                	**type**\:  bool
                
                .. attribute:: is_mdt_owner
                
                	MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mldp_mdt_owner
                
                	MLDP MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mrib_register
                
                	MRIB Register
                	**type**\:  bool
                
                .. attribute:: is_multicast_rib_registration
                
                	Mcast RIB Registration
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converge_received
                
                	PIM NSF RIB converge received
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converged
                
                	PIM NSF RIB converged
                	**type**\:  bool
                
                .. attribute:: is_redistribution_reset
                
                	Pending redist reset
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_add_required
                
                	VRF LPTS filter required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_added
                
                	VRF LPTS filter added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_add_required
                
                	VRF required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_added
                
                	VRF added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_enabled
                
                	PIM RIB multiplath enabled
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_interface_hash
                
                	PIM RIB multipath interface hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_hash
                
                	PIM RIB multipath source based hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_next_hop_hash
                
                	PIM RIB multipath source\-nexthop hash
                	**type**\:  bool
                
                .. attribute:: is_routing_enabled
                
                	Routing Enabled
                	**type**\:  bool
                
                .. attribute:: is_rsvp_te_mdt_owner
                
                	RSVP\-TE MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_socket_add_required
                
                	VRF required on Socket
                	**type**\:  bool
                
                .. attribute:: is_socket_added
                
                	VRF added on Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_add_required
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_added
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind
                
                	VRF bound on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind_required
                
                	VRF bind required on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_unicast_rib_registration
                
                	Ucast RIB Registration
                	**type**\:  bool
                
                .. attribute:: maximum_mdt_aggregation
                
                	MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_announce_interval
                
                	Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_switchover_interval
                
                	Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_default_group
                
                	MDT Default group
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_gre_remote_rpf_identifier
                
                	GRE\-MDT Remote RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_gre_rpf_identifier
                
                	GRE\-MDT RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_interface
                
                	MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mdt_mtu
                
                	MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_neighbor_filter_name
                
                	MDT Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: mdt_partitioned_ir_control_identifier
                
                	Partitioned IR MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_partitioned_mdt_control_identifier
                
                	Partitioned MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mhost_default_interface_config
                
                	Configured Mhost Defint
                	**type**\:  str
                
                .. attribute:: mhost_interface
                
                	MHost handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mldp_auto_rp_announce_tree_added
                
                	MLDP Autorp Announce Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_auto_rp_discovery_tree_added
                
                	MLDP Autorp Discovery Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_bsr_control_tree_added
                
                	MLDP BSR Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_control_head_lsm_identifier
                
                	MLDP MVPN Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_local_label
                
                	Partitioned MDT Head local label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_lsm_identifier
                
                	MLDP Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_maximum_mdt_aggregation
                
                	MLDP MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_announce_interval
                
                	MLDP Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_switchover_interval
                
                	MLDP Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_interface
                
                	MLDP MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mldp_mdt_mtu
                
                	MLDP MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_name
                
                	MLDP MDT Name
                	**type**\:  str
                
                .. attribute:: mldp_mdt_remote_rpf_identifier
                
                	MLDP Remote RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_rpf_identifier
                
                	MLDP RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partioned_mp2m_ptree
                
                	MP2MP Partitioned MDT tree
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_head_lsm_identifier
                
                	Partitioned MDT Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partitioned_mdt_configured
                
                	MLDP Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_mdt_identifier
                
                	MLDP Partitioned MDT Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_head_lsm_identifier
                
                	MLDP Remote Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_partitioned_mdt_configured
                
                	MLDP Remote Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_root_address
                
                	MLDP Root addresses
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_root_count
                
                	MLDP Root count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: murib_id
                
                	MURIB ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: neighbor_filter_name
                
                	Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: non_default_vrf_count_on_socket
                
                	Count of non\-default vrfs on raw socket
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: organization_unique_identifier
                
                	OUI for VPN\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: p2mpte_li_drop
                
                	Route LI updates dropped for P2MP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: redistribution_reset_count
                
                	Redist reset count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_default_group
                
                	Remote Default Group
                	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.RemoteDefaultGroup>`
                
                .. attribute:: remote_table_id
                
                	Remote Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_distinguisher
                
                	RD value
                	**type**\:  str
                
                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                
                .. attribute:: rpf_default_table
                
                	RPF Default Table
                	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.RpfDefaultTable>`
                
                .. attribute:: rpf_id
                
                	RPF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rpf_policy_name
                
                	RPF topology selection route\-policy name
                	**type**\:  str
                
                .. attribute:: rsvp_te_maximum_mdt_aggregation
                
                	RSVP\-TE MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_announce_interval
                
                	RSVP\-TE Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_switchover_interval
                
                	RSVP\-TE Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_interface
                
                	RSVP\-TEMDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: rsvp_te_mdt_mtu
                
                	RSVP\-TEMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_name
                
                	RSVP\-TE MDT Name
                	**type**\:  str
                
                .. attribute:: rsvp_te_mdt_rpf_identifier
                
                	RSVP\-TE RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_static_p2mp_count
                
                	Number of Static P2MP\-TE MDT
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	PIM is using MuRIB
                	**type**\:  bool
                
                .. attribute:: sg_expiry_time
                
                	S,G Expiry Time Configured, in seconds
                	**type**\:  int
                
                	**range:** 0..65535
                
                	**units**\: second
                
                .. attribute:: sg_expiry_timer_configured
                
                	S,G Expiry Timer Configured
                	**type**\:  bool
                
                .. attribute:: sg_expiry_timer_sg_list
                
                	S,G expiry timer ACL name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: stale_rd_present
                
                	RD is stale
                	**type**\:  bool
                
                .. attribute:: suppress_pim_data_mdt_tlv
                
                	Suppress PIM Data\-MDT TLV Announcements
                	**type**\:  bool
                
                .. attribute:: suppress_shared_tree_join
                
                	Suppress Shared\-Tree Joins
                	**type**\:  bool
                
                .. attribute:: table_count
                
                	Number of configured Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: table_id
                
                	Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: umh
                
                	Join UMH Core\-Tree
                	**type**\:  bool
                
                .. attribute:: valid_rd_present
                
                	RD is valid
                	**type**\:  bool
                
                .. attribute:: vpn_index
                
                	VPN Index
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vrf_id
                
                	VRF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.active_table_count = None
                    self.allow_rp_configured = None
                    self.allow_rp_group_list = None
                    self.allow_rp_rp_list = None
                    self.anycast_rp_configured = None
                    self.anycast_rp_policy_name = None
                    self.anycast_rp_range = YList()
                    self.anycast_rp_range.parent = self
                    self.anycast_rp_range.name = 'anycast_rp_range'
                    self.bgp_auto_discovery_configured = None
                    self.bgp_auto_discovery_type = None
                    self.bgp_i_pmsi_added = None
                    self.bgp_remote_address = None
                    self.bgp_remote_interface = None
                    self.bgp_remote_interface_name = None
                    self.bgp_remote_on = None
                    self.bgp_remote_state = None
                    self.bgp_source_active_announce = None
                    self.export_route_target = YList()
                    self.export_route_target.parent = self
                    self.export_route_target.name = 'export_route_target'
                    self.gin_b_and_mdt_data_announce_interval = None
                    self.gin_b_and_mdt_data_switchover_interval = None
                    self.gin_b_and_mdt_interface = None
                    self.gin_b_and_mdt_mtu = None
                    self.gin_b_and_mdt_name = None
                    self.gin_b_and_mdt_rpf_identifier = None
                    self.gin_band_maximum_mdt_aggregation = None
                    self.import_route_target = YList()
                    self.import_route_target.parent = self
                    self.import_route_target.name = 'import_route_target'
                    self.in_b_and_mdt_data_announce_interval = None
                    self.in_b_and_mdt_data_switchover_interval = None
                    self.in_b_and_mdt_interface = None
                    self.in_b_and_mdt_mtu = None
                    self.in_b_and_mdt_name = None
                    self.in_b_and_mdt_rpf_identifier = None
                    self.in_band_maximum_mdt_aggregation = None
                    self.in_band_signaling_local_enabled = None
                    self.in_band_signaling_remote_enabled = None
                    self.inter_autonomous_system_enabled = None
                    self.ir_maximum_mdt_aggregation = None
                    self.ir_mdt_data_announce_interval = None
                    self.ir_mdt_data_switchover_interval = None
                    self.ir_mdt_interface = None
                    self.ir_mdt_mtu = None
                    self.ir_mdt_name = None
                    self.ir_mdt_rpf_identifier = None
                    self.ir_mdt_tail_label = None
                    self.is_active = None
                    self.is_active_ital = None
                    self.is_all_interface_disable_operation = None
                    self.is_auto_rp_listen_enabled = None
                    self.is_auto_rp_listen_sock_add = None
                    self.is_create_gin_b_and_mdt_interface = None
                    self.is_create_in_b_and_mdt_interface = None
                    self.is_create_ir_mdt_interface = None
                    self.is_create_mdt_interface = None
                    self.is_create_mldp_mdt_interface = None
                    self.is_create_rsvp_te_mdt_interface = None
                    self.is_default_granges = None
                    self.is_gin_b_and_mdt_owner = None
                    self.is_in_b_and_mdt_owner = None
                    self.is_ir_mdt_owner = None
                    self.is_lpts_socket_add_required = None
                    self.is_lpts_socket_added = None
                    self.is_m_host_publish_pending = None
                    self.is_mdt_owner = None
                    self.is_mldp_mdt_owner = None
                    self.is_mrib_register = None
                    self.is_multicast_rib_registration = None
                    self.is_pim_nsf_rib_converge_received = None
                    self.is_pim_nsf_rib_converged = None
                    self.is_redistribution_reset = None
                    self.is_register_injection_lpts_socket_add_required = None
                    self.is_register_injection_lpts_socket_added = None
                    self.is_register_injection_socket_add_required = None
                    self.is_register_injection_socket_added = None
                    self.is_rib_multipath_enabled = None
                    self.is_rib_multipath_interface_hash = None
                    self.is_rib_multipath_source_hash = None
                    self.is_rib_multipath_source_next_hop_hash = None
                    self.is_routing_enabled = None
                    self.is_rsvp_te_mdt_owner = None
                    self.is_socket_add_required = None
                    self.is_socket_added = None
                    self.is_udp_socket_add_required = None
                    self.is_udp_socket_added = None
                    self.is_udp_socket_bind = None
                    self.is_udp_socket_bind_required = None
                    self.is_unicast_rib_registration = None
                    self.maximum_mdt_aggregation = None
                    self.mdt_data_announce_interval = None
                    self.mdt_data_switchover_interval = None
                    self.mdt_default_group = None
                    self.mdt_gre_remote_rpf_identifier = None
                    self.mdt_gre_rpf_identifier = None
                    self.mdt_interface = None
                    self.mdt_mtu = None
                    self.mdt_neighbor_filter_name = None
                    self.mdt_partitioned_ir_control_identifier = None
                    self.mdt_partitioned_mdt_control_identifier = None
                    self.mhost_default_interface_config = None
                    self.mhost_interface = None
                    self.mldp_auto_rp_announce_tree_added = None
                    self.mldp_auto_rp_discovery_tree_added = None
                    self.mldp_bsr_control_tree_added = None
                    self.mldp_control_head_lsm_identifier = None
                    self.mldp_head_local_label = None
                    self.mldp_head_lsm_identifier = None
                    self.mldp_maximum_mdt_aggregation = None
                    self.mldp_mdt_data_announce_interval = None
                    self.mldp_mdt_data_switchover_interval = None
                    self.mldp_mdt_interface = None
                    self.mldp_mdt_mtu = None
                    self.mldp_mdt_name = None
                    self.mldp_mdt_remote_rpf_identifier = None
                    self.mldp_mdt_rpf_identifier = None
                    self.mldp_partioned_mp2m_ptree = None
                    self.mldp_partitioned_head_lsm_identifier = None
                    self.mldp_partitioned_mdt_configured = None
                    self.mldp_partitioned_mdt_identifier = None
                    self.mldp_remote_head_lsm_identifier = None
                    self.mldp_remote_partitioned_mdt_configured = None
                    self.mldp_root_address = YLeafList()
                    self.mldp_root_address.parent = self
                    self.mldp_root_address.name = 'mldp_root_address'
                    self.mldp_root_count = None
                    self.murib_id = None
                    self.neighbor_filter_name = None
                    self.non_default_vrf_count_on_socket = None
                    self.organization_unique_identifier = None
                    self.p2mpte_li_drop = None
                    self.redistribution_reset_count = None
                    self.remote_default_group = Ipv6Pim.Active.DefaultContext.Context.RemoteDefaultGroup()
                    self.remote_default_group.parent = self
                    self.remote_table_id = None
                    self.route_distinguisher = None
                    self.rpf_default_table = Ipv6Pim.Active.DefaultContext.Context.RpfDefaultTable()
                    self.rpf_default_table.parent = self
                    self.rpf_id = None
                    self.rpf_policy_name = None
                    self.rsvp_te_maximum_mdt_aggregation = None
                    self.rsvp_te_mdt_data_announce_interval = None
                    self.rsvp_te_mdt_data_switchover_interval = None
                    self.rsvp_te_mdt_interface = None
                    self.rsvp_te_mdt_mtu = None
                    self.rsvp_te_mdt_name = None
                    self.rsvp_te_mdt_rpf_identifier = None
                    self.rsvp_te_mdt_static_p2mp_count = None
                    self.rump_enabled = None
                    self.sg_expiry_time = None
                    self.sg_expiry_timer_configured = None
                    self.sg_expiry_timer_sg_list = None
                    self.stale_rd_present = None
                    self.suppress_pim_data_mdt_tlv = None
                    self.suppress_shared_tree_join = None
                    self.table_count = None
                    self.table_id = None
                    self.umh = None
                    self.valid_rd_present = None
                    self.vpn_index = None
                    self.vrf_id = None


                class RemoteDefaultGroup(object):
                    """
                    Remote Default Group
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.af_name = None
                        self.ipv4_address = None
                        self.ipv6_address = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:remote-default-group'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.af_name is not None:
                            return True

                        if self.ipv4_address is not None:
                            return True

                        if self.ipv6_address is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.Context.RemoteDefaultGroup']['meta_info']


                class RpfDefaultTable(object):
                    """
                    RPF Default Table
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.afi = None
                        self.is_active = None
                        self.is_ital_registration_done = None
                        self.is_rib_convergence = None
                        self.is_rib_convergence_received = None
                        self.is_rib_registration_done = None
                        self.rpf_registrations = None
                        self.safi = None
                        self.table_id = None
                        self.table_name = None
                        self.vrf_id = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:rpf-default-table'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.afi is not None:
                            return True

                        if self.is_active is not None:
                            return True

                        if self.is_ital_registration_done is not None:
                            return True

                        if self.is_rib_convergence is not None:
                            return True

                        if self.is_rib_convergence_received is not None:
                            return True

                        if self.is_rib_registration_done is not None:
                            return True

                        if self.rpf_registrations is not None:
                            return True

                        if self.safi is not None:
                            return True

                        if self.table_id is not None:
                            return True

                        if self.table_name is not None:
                            return True

                        if self.vrf_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.Context.RpfDefaultTable']['meta_info']


                class ExportRouteTarget(object):
                    """
                    Export Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.anycast_rp = None
                        self.anycast_rp_marked = None
                        self.bgp_auto_discovery = None
                        self.configured = None
                        self.route_target = None
                        self.segment_border = None
                        self.update_pending = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:export-route-target'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.anycast_rp is not None:
                            return True

                        if self.anycast_rp_marked is not None:
                            return True

                        if self.bgp_auto_discovery is not None:
                            return True

                        if self.configured is not None:
                            return True

                        if self.route_target is not None:
                            return True

                        if self.segment_border is not None:
                            return True

                        if self.update_pending is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.Context.ExportRouteTarget']['meta_info']


                class ImportRouteTarget(object):
                    """
                    Import Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.anycast_rp = None
                        self.anycast_rp_marked = None
                        self.bgp_auto_discovery = None
                        self.configured = None
                        self.route_target = None
                        self.segment_border = None
                        self.update_pending = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:import-route-target'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.anycast_rp is not None:
                            return True

                        if self.anycast_rp_marked is not None:
                            return True

                        if self.bgp_auto_discovery is not None:
                            return True

                        if self.configured is not None:
                            return True

                        if self.route_target is not None:
                            return True

                        if self.segment_border is not None:
                            return True

                        if self.update_pending is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.Context.ImportRouteTarget']['meta_info']


                class AnycastRpRange(object):
                    """
                    Anycast\-RP Ranges
                    
                    .. attribute:: ancast_rp_marked
                    
                    	Anycast\-RP Range marked
                    	**type**\:  bool
                    
                    .. attribute:: prefix
                    
                    	Anycast\-RP Range Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Anycast\-RP Range Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ancast_rp_marked = None
                        self.prefix = Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix()
                        self.prefix.parent = self
                        self.prefix_length = None


                    class Prefix(object):
                        """
                        Anycast\-RP Range Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:anycast-rp-range/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context/Cisco-IOS-XR-ipv4-pim-oper:anycast-rp-range'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ancast_rp_marked is not None:
                            return True

                        if self.prefix is not None and self.prefix._has_data():
                            return True

                        if self.prefix_length is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:context'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.active_table_count is not None:
                        return True

                    if self.allow_rp_configured is not None:
                        return True

                    if self.allow_rp_group_list is not None:
                        return True

                    if self.allow_rp_rp_list is not None:
                        return True

                    if self.anycast_rp_configured is not None:
                        return True

                    if self.anycast_rp_policy_name is not None:
                        return True

                    if self.anycast_rp_range is not None:
                        for child_ref in self.anycast_rp_range:
                            if child_ref._has_data():
                                return True

                    if self.bgp_auto_discovery_configured is not None:
                        return True

                    if self.bgp_auto_discovery_type is not None:
                        return True

                    if self.bgp_i_pmsi_added is not None:
                        return True

                    if self.bgp_remote_address is not None:
                        return True

                    if self.bgp_remote_interface is not None:
                        return True

                    if self.bgp_remote_interface_name is not None:
                        return True

                    if self.bgp_remote_on is not None:
                        return True

                    if self.bgp_remote_state is not None:
                        return True

                    if self.bgp_source_active_announce is not None:
                        return True

                    if self.export_route_target is not None:
                        for child_ref in self.export_route_target:
                            if child_ref._has_data():
                                return True

                    if self.gin_b_and_mdt_data_announce_interval is not None:
                        return True

                    if self.gin_b_and_mdt_data_switchover_interval is not None:
                        return True

                    if self.gin_b_and_mdt_interface is not None:
                        return True

                    if self.gin_b_and_mdt_mtu is not None:
                        return True

                    if self.gin_b_and_mdt_name is not None:
                        return True

                    if self.gin_b_and_mdt_rpf_identifier is not None:
                        return True

                    if self.gin_band_maximum_mdt_aggregation is not None:
                        return True

                    if self.import_route_target is not None:
                        for child_ref in self.import_route_target:
                            if child_ref._has_data():
                                return True

                    if self.in_b_and_mdt_data_announce_interval is not None:
                        return True

                    if self.in_b_and_mdt_data_switchover_interval is not None:
                        return True

                    if self.in_b_and_mdt_interface is not None:
                        return True

                    if self.in_b_and_mdt_mtu is not None:
                        return True

                    if self.in_b_and_mdt_name is not None:
                        return True

                    if self.in_b_and_mdt_rpf_identifier is not None:
                        return True

                    if self.in_band_maximum_mdt_aggregation is not None:
                        return True

                    if self.in_band_signaling_local_enabled is not None:
                        return True

                    if self.in_band_signaling_remote_enabled is not None:
                        return True

                    if self.inter_autonomous_system_enabled is not None:
                        return True

                    if self.ir_maximum_mdt_aggregation is not None:
                        return True

                    if self.ir_mdt_data_announce_interval is not None:
                        return True

                    if self.ir_mdt_data_switchover_interval is not None:
                        return True

                    if self.ir_mdt_interface is not None:
                        return True

                    if self.ir_mdt_mtu is not None:
                        return True

                    if self.ir_mdt_name is not None:
                        return True

                    if self.ir_mdt_rpf_identifier is not None:
                        return True

                    if self.ir_mdt_tail_label is not None:
                        return True

                    if self.is_active is not None:
                        return True

                    if self.is_active_ital is not None:
                        return True

                    if self.is_all_interface_disable_operation is not None:
                        return True

                    if self.is_auto_rp_listen_enabled is not None:
                        return True

                    if self.is_auto_rp_listen_sock_add is not None:
                        return True

                    if self.is_create_gin_b_and_mdt_interface is not None:
                        return True

                    if self.is_create_in_b_and_mdt_interface is not None:
                        return True

                    if self.is_create_ir_mdt_interface is not None:
                        return True

                    if self.is_create_mdt_interface is not None:
                        return True

                    if self.is_create_mldp_mdt_interface is not None:
                        return True

                    if self.is_create_rsvp_te_mdt_interface is not None:
                        return True

                    if self.is_default_granges is not None:
                        return True

                    if self.is_gin_b_and_mdt_owner is not None:
                        return True

                    if self.is_in_b_and_mdt_owner is not None:
                        return True

                    if self.is_ir_mdt_owner is not None:
                        return True

                    if self.is_lpts_socket_add_required is not None:
                        return True

                    if self.is_lpts_socket_added is not None:
                        return True

                    if self.is_m_host_publish_pending is not None:
                        return True

                    if self.is_mdt_owner is not None:
                        return True

                    if self.is_mldp_mdt_owner is not None:
                        return True

                    if self.is_mrib_register is not None:
                        return True

                    if self.is_multicast_rib_registration is not None:
                        return True

                    if self.is_pim_nsf_rib_converge_received is not None:
                        return True

                    if self.is_pim_nsf_rib_converged is not None:
                        return True

                    if self.is_redistribution_reset is not None:
                        return True

                    if self.is_register_injection_lpts_socket_add_required is not None:
                        return True

                    if self.is_register_injection_lpts_socket_added is not None:
                        return True

                    if self.is_register_injection_socket_add_required is not None:
                        return True

                    if self.is_register_injection_socket_added is not None:
                        return True

                    if self.is_rib_multipath_enabled is not None:
                        return True

                    if self.is_rib_multipath_interface_hash is not None:
                        return True

                    if self.is_rib_multipath_source_hash is not None:
                        return True

                    if self.is_rib_multipath_source_next_hop_hash is not None:
                        return True

                    if self.is_routing_enabled is not None:
                        return True

                    if self.is_rsvp_te_mdt_owner is not None:
                        return True

                    if self.is_socket_add_required is not None:
                        return True

                    if self.is_socket_added is not None:
                        return True

                    if self.is_udp_socket_add_required is not None:
                        return True

                    if self.is_udp_socket_added is not None:
                        return True

                    if self.is_udp_socket_bind is not None:
                        return True

                    if self.is_udp_socket_bind_required is not None:
                        return True

                    if self.is_unicast_rib_registration is not None:
                        return True

                    if self.maximum_mdt_aggregation is not None:
                        return True

                    if self.mdt_data_announce_interval is not None:
                        return True

                    if self.mdt_data_switchover_interval is not None:
                        return True

                    if self.mdt_default_group is not None:
                        return True

                    if self.mdt_gre_remote_rpf_identifier is not None:
                        return True

                    if self.mdt_gre_rpf_identifier is not None:
                        return True

                    if self.mdt_interface is not None:
                        return True

                    if self.mdt_mtu is not None:
                        return True

                    if self.mdt_neighbor_filter_name is not None:
                        return True

                    if self.mdt_partitioned_ir_control_identifier is not None:
                        return True

                    if self.mdt_partitioned_mdt_control_identifier is not None:
                        return True

                    if self.mhost_default_interface_config is not None:
                        return True

                    if self.mhost_interface is not None:
                        return True

                    if self.mldp_auto_rp_announce_tree_added is not None:
                        return True

                    if self.mldp_auto_rp_discovery_tree_added is not None:
                        return True

                    if self.mldp_bsr_control_tree_added is not None:
                        return True

                    if self.mldp_control_head_lsm_identifier is not None:
                        return True

                    if self.mldp_head_local_label is not None:
                        return True

                    if self.mldp_head_lsm_identifier is not None:
                        return True

                    if self.mldp_maximum_mdt_aggregation is not None:
                        return True

                    if self.mldp_mdt_data_announce_interval is not None:
                        return True

                    if self.mldp_mdt_data_switchover_interval is not None:
                        return True

                    if self.mldp_mdt_interface is not None:
                        return True

                    if self.mldp_mdt_mtu is not None:
                        return True

                    if self.mldp_mdt_name is not None:
                        return True

                    if self.mldp_mdt_remote_rpf_identifier is not None:
                        return True

                    if self.mldp_mdt_rpf_identifier is not None:
                        return True

                    if self.mldp_partioned_mp2m_ptree is not None:
                        return True

                    if self.mldp_partitioned_head_lsm_identifier is not None:
                        return True

                    if self.mldp_partitioned_mdt_configured is not None:
                        return True

                    if self.mldp_partitioned_mdt_identifier is not None:
                        return True

                    if self.mldp_remote_head_lsm_identifier is not None:
                        return True

                    if self.mldp_remote_partitioned_mdt_configured is not None:
                        return True

                    if self.mldp_root_address is not None:
                        for child in self.mldp_root_address:
                            if child is not None:
                                return True

                    if self.mldp_root_count is not None:
                        return True

                    if self.murib_id is not None:
                        return True

                    if self.neighbor_filter_name is not None:
                        return True

                    if self.non_default_vrf_count_on_socket is not None:
                        return True

                    if self.organization_unique_identifier is not None:
                        return True

                    if self.p2mpte_li_drop is not None:
                        return True

                    if self.redistribution_reset_count is not None:
                        return True

                    if self.remote_default_group is not None and self.remote_default_group._has_data():
                        return True

                    if self.remote_table_id is not None:
                        return True

                    if self.route_distinguisher is not None:
                        return True

                    if self.rpf_default_table is not None and self.rpf_default_table._has_data():
                        return True

                    if self.rpf_id is not None:
                        return True

                    if self.rpf_policy_name is not None:
                        return True

                    if self.rsvp_te_maximum_mdt_aggregation is not None:
                        return True

                    if self.rsvp_te_mdt_data_announce_interval is not None:
                        return True

                    if self.rsvp_te_mdt_data_switchover_interval is not None:
                        return True

                    if self.rsvp_te_mdt_interface is not None:
                        return True

                    if self.rsvp_te_mdt_mtu is not None:
                        return True

                    if self.rsvp_te_mdt_name is not None:
                        return True

                    if self.rsvp_te_mdt_rpf_identifier is not None:
                        return True

                    if self.rsvp_te_mdt_static_p2mp_count is not None:
                        return True

                    if self.rump_enabled is not None:
                        return True

                    if self.sg_expiry_time is not None:
                        return True

                    if self.sg_expiry_timer_configured is not None:
                        return True

                    if self.sg_expiry_timer_sg_list is not None:
                        return True

                    if self.stale_rd_present is not None:
                        return True

                    if self.suppress_pim_data_mdt_tlv is not None:
                        return True

                    if self.suppress_shared_tree_join is not None:
                        return True

                    if self.table_count is not None:
                        return True

                    if self.table_id is not None:
                        return True

                    if self.umh is not None:
                        return True

                    if self.valid_rd_present is not None:
                        return True

                    if self.vpn_index is not None:
                        return True

                    if self.vrf_id is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.Context']['meta_info']


            class TopologyEntryFlagRouteCounts(object):
                """
                Route count for topology with entry flag set
                
                .. attribute:: topology_entry_flag_route_count
                
                	Route count for topology with entry flag set
                	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.topology_entry_flag_route_count = YList()
                    self.topology_entry_flag_route_count.parent = self
                    self.topology_entry_flag_route_count.name = 'topology_entry_flag_route_count'


                class TopologyEntryFlagRouteCount(object):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: entry_flag  <key>
                    
                    	entry flag
                    	**type**\:   :py:class:`PimTopologyEntryFlagEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlagEnum>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.entry_flag = None
                        self.active_group_ranges = None
                        self.group_address = Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self.group_ranges = None
                        self.groute_count = None
                        self.is_node_low_memory = None
                        self.sg_route_count = None
                        self.sgr_route_count = None


                    class GroupAddress(object):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.entry_flag is None:
                            raise YPYModelError('Key property entry_flag is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-entry-flag-route-counts/Cisco-IOS-XR-ipv4-pim-oper:topology-entry-flag-route-count[Cisco-IOS-XR-ipv4-pim-oper:entry-flag = ' + str(self.entry_flag) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.entry_flag is not None:
                            return True

                        if self.active_group_ranges is not None:
                            return True

                        if self.group_address is not None and self.group_address._has_data():
                            return True

                        if self.group_ranges is not None:
                            return True

                        if self.groute_count is not None:
                            return True

                        if self.is_node_low_memory is not None:
                            return True

                        if self.sg_route_count is not None:
                            return True

                        if self.sgr_route_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:topology-entry-flag-route-counts'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.topology_entry_flag_route_count is not None:
                        for child_ref in self.topology_entry_flag_route_count:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts']['meta_info']


            class RpfRedirect(object):
                """
                PIM ECMP RPF\-redirect bundle
                
                .. attribute:: bundle_interfaces
                
                	PIM ECMP RPF\-redirect bundle information
                	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces>`
                
                .. attribute:: redirect_route_databases
                
                	PIM ECMP RPF\-redirect route database
                	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bundle_interfaces = Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces()
                    self.bundle_interfaces.parent = self
                    self.redirect_route_databases = Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases()
                    self.redirect_route_databases.parent = self


                class RedirectRouteDatabases(object):
                    """
                    PIM ECMP RPF\-redirect route database
                    
                    .. attribute:: redirect_route_database
                    
                    	PIM ECMP RPF\-redirect route information
                    	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.redirect_route_database = YList()
                        self.redirect_route_database.parent = self
                        self.redirect_route_database.name = 'redirect_route_database'


                    class RedirectRouteDatabase(object):
                        """
                        PIM ECMP RPF\-redirect route information
                        
                        .. attribute:: bandwidth
                        
                        	Bandwidth in Kbps
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group ddress
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                        
                        .. attribute:: interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bandwidth = None
                            self.group_address = None
                            self.group_address_xr = Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self.interface = YList()
                            self.interface.parent = self
                            self.interface.name = 'interface'
                            self.source_address = None
                            self.source_address_xr = Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self.uptime = None


                        class GroupAddressXr(object):
                            """
                            Group ddress
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr']['meta_info']


                        class SourceAddressXr(object):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr']['meta_info']


                        class Interface(object):
                            """
                            Outgoing interface list
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_outgoing_interface
                            
                            	Is outgoing Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_rpf_interface
                            
                            	Is RPF Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_snoop_interface
                            
                            	Is snooping Interface
                            	**type**\:  bool
                            
                            .. attribute:: rpf_address
                            
                            	RPF Address
                            	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.expiry = None
                                self.interface_name = None
                                self.is_outgoing_interface = None
                                self.is_rpf_interface = None
                                self.is_snoop_interface = None
                                self.rpf_address = Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                self.rpf_address.parent = self
                                self.uptime = None


                            class RpfAddress(object):
                                """
                                RPF Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database/Cisco-IOS-XR-ipv4-pim-oper:interface/Cisco-IOS-XR-ipv4-pim-oper:rpf-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database/Cisco-IOS-XR-ipv4-pim-oper:interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.expiry is not None:
                                    return True

                                if self.interface_name is not None:
                                    return True

                                if self.is_outgoing_interface is not None:
                                    return True

                                if self.is_rpf_interface is not None:
                                    return True

                                if self.is_snoop_interface is not None:
                                    return True

                                if self.rpf_address is not None and self.rpf_address._has_data():
                                    return True

                                if self.uptime is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bandwidth is not None:
                                return True

                            if self.group_address is not None:
                                return True

                            if self.group_address_xr is not None and self.group_address_xr._has_data():
                                return True

                            if self.interface is not None:
                                for child_ref in self.interface:
                                    if child_ref._has_data():
                                        return True

                            if self.source_address is not None:
                                return True

                            if self.source_address_xr is not None and self.source_address_xr._has_data():
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.redirect_route_database is not None:
                            for child_ref in self.redirect_route_database:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases']['meta_info']


                class BundleInterfaces(object):
                    """
                    PIM ECMP RPF\-redirect bundle information
                    
                    .. attribute:: bundle_interface
                    
                    	PIM ECMP RPF\-redirect bundle interface information
                    	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bundle_interface = YList()
                        self.bundle_interface.parent = self
                        self.bundle_interface.name = 'bundle_interface'


                    class BundleInterface(object):
                        """
                        PIM ECMP RPF\-redirect bundle interface
                        information
                        
                        .. attribute:: allocated_bandwidth
                        
                        	Bandwidth allocated in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: allocated_threshold_bandwidth
                        
                        	Configured threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_bandwidth
                        
                        	Bandwidth available in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_threshold_bandwidth
                        
                        	Available threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: bundle_name
                        
                        	Bundle name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: interface_name
                        
                        	Bundle interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_redirect_bundle_name
                        
                        	RPF redirect bundle name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpf_redirect_interface_name
                        
                        	RPF redirect interface name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: snooping_bandwidth_used
                        
                        	Bandwidth used by snooped entries in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: topology_bandwidth_used
                        
                        	Bandwidth used by topology in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: total_bandwidth
                        
                        	Total bandwidth used in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.allocated_bandwidth = None
                            self.allocated_threshold_bandwidth = None
                            self.available_bandwidth = None
                            self.available_threshold_bandwidth = None
                            self.bundle_name = None
                            self.interface_name = None
                            self.rpf_redirect_bundle_name = None
                            self.rpf_redirect_interface_name = None
                            self.snooping_bandwidth_used = None
                            self.topology_bandwidth_used = None
                            self.total_bandwidth = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:bundle-interfaces/Cisco-IOS-XR-ipv4-pim-oper:bundle-interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.allocated_bandwidth is not None:
                                return True

                            if self.allocated_threshold_bandwidth is not None:
                                return True

                            if self.available_bandwidth is not None:
                                return True

                            if self.available_threshold_bandwidth is not None:
                                return True

                            if self.bundle_name is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.rpf_redirect_bundle_name is not None:
                                return True

                            if self.rpf_redirect_interface_name is not None:
                                return True

                            if self.snooping_bandwidth_used is not None:
                                return True

                            if self.topology_bandwidth_used is not None:
                                return True

                            if self.total_bandwidth is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect/Cisco-IOS-XR-ipv4-pim-oper:bundle-interfaces'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bundle_interface is not None:
                            for child_ref in self.bundle_interface:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bundle_interfaces is not None and self.bundle_interfaces._has_data():
                        return True

                    if self.redirect_route_databases is not None and self.redirect_route_databases._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.RpfRedirect']['meta_info']


            class Tunnels(object):
                """
                Tunnels information that PIM has
                
                .. attribute:: tunnel
                
                	PIM tunnel information
                	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.tunnel = YList()
                    self.tunnel.parent = self
                    self.tunnel.name = 'tunnel'


                class Tunnel(object):
                    """
                    PIM tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.tunnel_name = None
                        self.group_address_netio = Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self.rp_address = Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress()
                        self.rp_address.parent = self
                        self.source_address = Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress()
                        self.source_address.parent = self
                        self.source_address_netio = Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self.vrf_name = None


                    class SourceAddress(object):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress']['meta_info']


                    class RpAddress(object):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress']['meta_info']


                    class SourceAddressNetio(object):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-netio'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio']['meta_info']


                    class GroupAddressNetio(object):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-netio'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio']['meta_info']

                    @property
                    def _common_path(self):
                        if self.tunnel_name is None:
                            raise YPYModelError('Key property tunnel_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:tunnels/Cisco-IOS-XR-ipv4-pim-oper:tunnel[Cisco-IOS-XR-ipv4-pim-oper:tunnel-name = ' + str(self.tunnel_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.tunnel_name is not None:
                            return True

                        if self.group_address_netio is not None and self.group_address_netio._has_data():
                            return True

                        if self.rp_address is not None and self.rp_address._has_data():
                            return True

                        if self.source_address is not None and self.source_address._has_data():
                            return True

                        if self.source_address_netio is not None and self.source_address_netio._has_data():
                            return True

                        if self.vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:tunnels'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.tunnel is not None:
                        for child_ref in self.tunnel:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.Tunnels']['meta_info']


            class MulticastStaticRoutes(object):
                """
                PIM multicast static route table
                
                .. attribute:: multicast_static_route
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.multicast_static_route = YList()
                    self.multicast_static_route.parent = self
                    self.multicast_static_route.name = 'multicast_static_route'


                class MulticastStaticRoute(object):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: address
                    
                    	Network address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: distance
                    
                    	Distance
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_via_lsm
                    
                    	LSM flag
                    	**type**\:  bool
                    
                    .. attribute:: nexthop
                    
                    	Next Hop
                    	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: prefix_length_xr
                    
                    	Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.address = None
                        self.distance = None
                        self.interface_name = None
                        self.is_via_lsm = None
                        self.nexthop = Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                        self.nexthop.parent = self
                        self.prefix = Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                        self.prefix.parent = self
                        self.prefix_length = None
                        self.prefix_length_xr = None


                    class Prefix(object):
                        """
                        Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-routes/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-route/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix']['meta_info']


                    class Nexthop(object):
                        """
                        Next Hop
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-routes/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-route/Cisco-IOS-XR-ipv4-pim-oper:nexthop'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-routes/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-route'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.address is not None:
                            return True

                        if self.distance is not None:
                            return True

                        if self.interface_name is not None:
                            return True

                        if self.is_via_lsm is not None:
                            return True

                        if self.nexthop is not None and self.nexthop._has_data():
                            return True

                        if self.prefix is not None and self.prefix._has_data():
                            return True

                        if self.prefix_length is not None:
                            return True

                        if self.prefix_length_xr is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-routes'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.multicast_static_route is not None:
                        for child_ref in self.multicast_static_route:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes']['meta_info']


            class GroupMapMatchSources(object):
                """
                Find the matching group\-mapping with source
                information on specified group address
                
                .. attribute:: group_map_match_source
                
                	PIM group\-matching mapping entry with source information
                	**type**\: list of    :py:class:`GroupMapMatchSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.group_map_match_source = YList()
                    self.group_map_match_source.parent = self
                    self.group_map_match_source.name = 'group_map_match_source'


                class GroupMapMatchSource(object):
                    """
                    PIM group\-matching mapping entry with source
                    information
                    
                    .. attribute:: group_address  <key>
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation>`
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_address = None
                        self.expires = None
                        self.group_map_information = Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self.holdtime = None
                        self.source_of_information = Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self.uptime = None


                    class SourceOfInformation(object):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation']['meta_info']


                    class GroupMapInformation(object):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.group_count = None
                            self.is_override = None
                            self.is_used = None
                            self.mrib_active = None
                            self.prefix = Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.priority = None
                            self.protocol = None
                            self.rp_address = Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self


                        class Prefix(object):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix']['meta_info']


                        class RpAddress(object):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.group_count is not None:
                                return True

                            if self.is_override is not None:
                                return True

                            if self.is_used is not None:
                                return True

                            if self.mrib_active is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation']['meta_info']

                    @property
                    def _common_path(self):
                        if self.group_address is None:
                            raise YPYModelError('Key property group_address is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-sources/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-source[Cisco-IOS-XR-ipv4-pim-oper:group-address = ' + str(self.group_address) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_address is not None:
                            return True

                        if self.expires is not None:
                            return True

                        if self.group_map_information is not None and self.group_map_information._has_data():
                            return True

                        if self.holdtime is not None:
                            return True

                        if self.source_of_information is not None and self.source_of_information._has_data():
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-sources'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.group_map_match_source is not None:
                        for child_ref in self.group_map_match_source:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.GroupMapMatchSources']['meta_info']


            class Neighbors(object):
                """
                PIM neighbor table
                
                .. attribute:: neighbor
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.neighbor = YList()
                    self.neighbor.parent = self
                    self.neighbor.name = 'neighbor'


                class Neighbor(object):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.dr_priority = None
                        self.expires = None
                        self.expiry_timer = None
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.is_batch_asserts_capable = None
                        self.is_bfd_state = None
                        self.is_bidirectional_capable = None
                        self.is_dr_priority_capable = None
                        self.is_ecmp_redirect_capable = None
                        self.is_proxy_capable = None
                        self.is_this_neighbor_dr = None
                        self.is_this_neighbor_us = None
                        self.neighbor_address = None
                        self.neighbor_address_xr = YList()
                        self.neighbor_address_xr.parent = self
                        self.neighbor_address_xr.name = 'neighbor_address_xr'
                        self.override_interval = None
                        self.propagation_delay = None
                        self.uptime = None


                    class NeighborAddressXr(object):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbors/Cisco-IOS-XR-ipv4-pim-oper:neighbor/Cisco-IOS-XR-ipv4-pim-oper:neighbor-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbors/Cisco-IOS-XR-ipv4-pim-oper:neighbor'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.dr_priority is not None:
                            return True

                        if self.expires is not None:
                            return True

                        if self.expiry_timer is not None:
                            return True

                        if self.interface_name is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.is_batch_asserts_capable is not None:
                            return True

                        if self.is_bfd_state is not None:
                            return True

                        if self.is_bidirectional_capable is not None:
                            return True

                        if self.is_dr_priority_capable is not None:
                            return True

                        if self.is_ecmp_redirect_capable is not None:
                            return True

                        if self.is_proxy_capable is not None:
                            return True

                        if self.is_this_neighbor_dr is not None:
                            return True

                        if self.is_this_neighbor_us is not None:
                            return True

                        if self.neighbor_address is not None:
                            return True

                        if self.neighbor_address_xr is not None:
                            for child_ref in self.neighbor_address_xr:
                                if child_ref._has_data():
                                    return True

                        if self.override_interval is not None:
                            return True

                        if self.propagation_delay is not None:
                            return True

                        if self.uptime is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context/Cisco-IOS-XR-ipv4-pim-oper:neighbors'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.neighbor is not None:
                        for child_ref in self.neighbor:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.DefaultContext.Neighbors']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:default-context'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.auto_rp is not None and self.auto_rp._has_data():
                    return True

                if self.bgp_afs is not None and self.bgp_afs._has_data():
                    return True

                if self.bidir_df_states is not None and self.bidir_df_states._has_data():
                    return True

                if self.bidir_df_winners is not None and self.bidir_df_winners._has_data():
                    return True

                if self.bsr is not None and self.bsr._has_data():
                    return True

                if self.context is not None and self.context._has_data():
                    return True

                if self.global_interfaces is not None and self.global_interfaces._has_data():
                    return True

                if self.gre is not None and self.gre._has_data():
                    return True

                if self.group_map_match_rpfs is not None and self.group_map_match_rpfs._has_data():
                    return True

                if self.group_map_match_sources is not None and self.group_map_match_sources._has_data():
                    return True

                if self.group_map_rpfs is not None and self.group_map_rpfs._has_data():
                    return True

                if self.group_map_sources is not None and self.group_map_sources._has_data():
                    return True

                if self.ifrs_interfaces is not None and self.ifrs_interfaces._has_data():
                    return True

                if self.ifrs_summary is not None and self.ifrs_summary._has_data():
                    return True

                if self.interface_old_formats is not None and self.interface_old_formats._has_data():
                    return True

                if self.interface_statistics is not None and self.interface_statistics._has_data():
                    return True

                if self.interfaces is not None and self.interfaces._has_data():
                    return True

                if self.jp_statistics is not None and self.jp_statistics._has_data():
                    return True

                if self.mib_databases is not None and self.mib_databases._has_data():
                    return True

                if self.multicast_static_routes is not None and self.multicast_static_routes._has_data():
                    return True

                if self.neighbor_old_formats is not None and self.neighbor_old_formats._has_data():
                    return True

                if self.neighbor_summaries is not None and self.neighbor_summaries._has_data():
                    return True

                if self.neighbors is not None and self.neighbors._has_data():
                    return True

                if self.net_io_tunnels is not None and self.net_io_tunnels._has_data():
                    return True

                if self.ranges is not None and self.ranges._has_data():
                    return True

                if self.route_policy is not None and self.route_policy._has_data():
                    return True

                if self.rpf_redirect is not None and self.rpf_redirect._has_data():
                    return True

                if self.rpf_summary is not None and self.rpf_summary._has_data():
                    return True

                if self.safs is not None and self.safs._has_data():
                    return True

                if self.summary is not None and self.summary._has_data():
                    return True

                if self.table_contexts is not None and self.table_contexts._has_data():
                    return True

                if self.topologies is not None and self.topologies._has_data():
                    return True

                if self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts._has_data():
                    return True

                if self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts._has_data():
                    return True

                if self.topology_route_count is not None and self.topology_route_count._has_data():
                    return True

                if self.traffic_counters is not None and self.traffic_counters._has_data():
                    return True

                if self.tunnels is not None and self.tunnels._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                return meta._meta_table['Ipv6Pim.Active.DefaultContext']['meta_info']


        class Process(object):
            """
            Process
            
            .. attribute:: checkpoint_statistics
            
            	Checkpoint Statistics
            	**type**\:   :py:class:`CheckpointStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process.CheckpointStatistics>`
            
            .. attribute:: issu
            
            	ISSU Information
            	**type**\:   :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process.Issu>`
            
            .. attribute:: nsf
            
            	PIM NSF information
            	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process.Nsf>`
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process.Nsr>`
            
            .. attribute:: summary
            
            	PIM Global Summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process.Summary>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.checkpoint_statistics = Ipv6Pim.Active.Process.CheckpointStatistics()
                self.checkpoint_statistics.parent = self
                self.issu = Ipv6Pim.Active.Process.Issu()
                self.issu.parent = self
                self.nsf = Ipv6Pim.Active.Process.Nsf()
                self.nsf.parent = self
                self.nsr = Ipv6Pim.Active.Process.Nsr()
                self.nsr.parent = self
                self.summary = Ipv6Pim.Active.Process.Summary()
                self.summary.parent = self


            class CheckpointStatistics(object):
                """
                Checkpoint Statistics
                
                .. attribute:: checkpoint_table
                
                	Array of chkpt table stats
                	**type**\: list of    :py:class:`CheckpointTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process.CheckpointStatistics.CheckpointTable>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.checkpoint_table = YList()
                    self.checkpoint_table.parent = self
                    self.checkpoint_table.name = 'checkpoint_table'


                class CheckpointTable(object):
                    """
                    Array of chkpt table stats
                    
                    .. attribute:: is_mirrored
                    
                    	Table mirrored
                    	**type**\:  bool
                    
                    .. attribute:: statistic
                    
                    	Stats array
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_description
                    
                    	Table description
                    	**type**\:  str
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.is_mirrored = None
                        self.statistic = YLeafList()
                        self.statistic.parent = self
                        self.statistic.name = 'statistic'
                        self.table_description = None
                        self.table_name = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:checkpoint-statistics/Cisco-IOS-XR-ipv4-pim-oper:checkpoint-table'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.is_mirrored is not None:
                            return True

                        if self.statistic is not None:
                            for child in self.statistic:
                                if child is not None:
                                    return True

                        if self.table_description is not None:
                            return True

                        if self.table_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Process.CheckpointStatistics.CheckpointTable']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:checkpoint-statistics'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.checkpoint_table is not None:
                        for child_ref in self.checkpoint_table:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.Process.CheckpointStatistics']['meta_info']


            class Nsr(object):
                """
                NSR Information
                
                .. attribute:: count_connection_dn
                
                	No. of times connection went down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_connection_up
                
                	No. of times connection went up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_connection_dn
                
                	Time when connection went down
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_connection_up
                
                	Time when connection went up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: partner_connected
                
                	Partner process connected
                	**type**\:  bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\:  bool
                
                .. attribute:: rmf_timer_expiry
                
                	Time for RMF timer to expire
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: rmf_timer_valid
                
                	Is RMF timer running ?
                	**type**\:  bool
                
                .. attribute:: state
                
                	NSR state
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.count_connection_dn = None
                    self.count_connection_up = None
                    self.count_rmf_not_ready = None
                    self.count_rmf_ready = None
                    self.last_connection_dn = None
                    self.last_connection_up = None
                    self.last_rmf_not_ready = None
                    self.last_rmf_ready = None
                    self.partner_connected = None
                    self.rmf_notification_done = None
                    self.rmf_timer_expiry = None
                    self.rmf_timer_valid = None
                    self.state = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:nsr'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.count_connection_dn is not None:
                        return True

                    if self.count_connection_up is not None:
                        return True

                    if self.count_rmf_not_ready is not None:
                        return True

                    if self.count_rmf_ready is not None:
                        return True

                    if self.last_connection_dn is not None:
                        return True

                    if self.last_connection_up is not None:
                        return True

                    if self.last_rmf_not_ready is not None:
                        return True

                    if self.last_rmf_ready is not None:
                        return True

                    if self.partner_connected is not None:
                        return True

                    if self.rmf_notification_done is not None:
                        return True

                    if self.rmf_timer_expiry is not None:
                        return True

                    if self.rmf_timer_valid is not None:
                        return True

                    if self.state is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.Process.Nsr']['meta_info']


            class Summary(object):
                """
                PIM Global Summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bsr_candidate_rp_set_count = None
                    self.bsr_candidate_rp_set_limit = None
                    self.bsr_candidate_rp_set_threshold = None
                    self.bsr_range_threshold = None
                    self.bsr_ranges_count = None
                    self.bsr_ranges_limit = None
                    self.global_auto_rp_ranges_limit = None
                    self.global_bsr_candidate_rp_set_count = None
                    self.global_bsr_candidate_rp_set_limit = None
                    self.global_bsr_candidate_rp_set_threshold = None
                    self.global_bsr_ranges_count = None
                    self.global_bsr_ranges_limit = None
                    self.global_bsr_ranges_threshold = None
                    self.global_register_limit = None
                    self.is_bsr_ranges_threshold_reached = None
                    self.is_global_auto_rp_ranges_limit_reached = None
                    self.is_global_bsr_ranges_limit_reached = None
                    self.is_global_register_limit_reached = None
                    self.is_global_route_limit_reached = None
                    self.is_global_rxi_limit_reached = None
                    self.is_maximum_enforcement_disabled = None
                    self.is_node_low_memory = None
                    self.is_ranges_limit_reached = None
                    self.is_route_limit_reached = None
                    self.ranges_count = None
                    self.ranges_limit = None
                    self.ranges_threshold = None
                    self.register_count = None
                    self.register_limit = None
                    self.register_limit_reached = None
                    self.register_threshold = None
                    self.route_count = None
                    self.route_limit = None
                    self.route_low_water_mark = None
                    self.route_threshold = None
                    self.rxi_limit_reached = None
                    self.rxi_low_water_mark = None
                    self.topology_interface_state_count = None
                    self.topology_interface_state_limit = None
                    self.topology_interface_state_threshold = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bsr_candidate_rp_set_count is not None:
                        return True

                    if self.bsr_candidate_rp_set_limit is not None:
                        return True

                    if self.bsr_candidate_rp_set_threshold is not None:
                        return True

                    if self.bsr_range_threshold is not None:
                        return True

                    if self.bsr_ranges_count is not None:
                        return True

                    if self.bsr_ranges_limit is not None:
                        return True

                    if self.global_auto_rp_ranges_limit is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_count is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_limit is not None:
                        return True

                    if self.global_bsr_candidate_rp_set_threshold is not None:
                        return True

                    if self.global_bsr_ranges_count is not None:
                        return True

                    if self.global_bsr_ranges_limit is not None:
                        return True

                    if self.global_bsr_ranges_threshold is not None:
                        return True

                    if self.global_register_limit is not None:
                        return True

                    if self.is_bsr_ranges_threshold_reached is not None:
                        return True

                    if self.is_global_auto_rp_ranges_limit_reached is not None:
                        return True

                    if self.is_global_bsr_ranges_limit_reached is not None:
                        return True

                    if self.is_global_register_limit_reached is not None:
                        return True

                    if self.is_global_route_limit_reached is not None:
                        return True

                    if self.is_global_rxi_limit_reached is not None:
                        return True

                    if self.is_maximum_enforcement_disabled is not None:
                        return True

                    if self.is_node_low_memory is not None:
                        return True

                    if self.is_ranges_limit_reached is not None:
                        return True

                    if self.is_route_limit_reached is not None:
                        return True

                    if self.ranges_count is not None:
                        return True

                    if self.ranges_limit is not None:
                        return True

                    if self.ranges_threshold is not None:
                        return True

                    if self.register_count is not None:
                        return True

                    if self.register_limit is not None:
                        return True

                    if self.register_limit_reached is not None:
                        return True

                    if self.register_threshold is not None:
                        return True

                    if self.route_count is not None:
                        return True

                    if self.route_limit is not None:
                        return True

                    if self.route_low_water_mark is not None:
                        return True

                    if self.route_threshold is not None:
                        return True

                    if self.rxi_limit_reached is not None:
                        return True

                    if self.rxi_low_water_mark is not None:
                        return True

                    if self.topology_interface_state_count is not None:
                        return True

                    if self.topology_interface_state_limit is not None:
                        return True

                    if self.topology_interface_state_threshold is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.Process.Summary']['meta_info']


            class Nsf(object):
                """
                PIM NSF information
                
                .. attribute:: configured_state
                
                	Is Multicast NSF Configured
                	**type**\:  bool
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_sec
                
                	Last ICD Notif Recv in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off_sec
                
                	Last NSF time OFF in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_sec
                
                	Last NSF time ON in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: nsf_state
                
                	Are we currently in NSF
                	**type**\:  bool
                
                .. attribute:: nsf_time_left
                
                	Multicast NSF time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: nsf_timeout
                
                	Multicast NSF timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: waiting_membership
                
                	Waiting for IGMP/MLD
                	**type**\:  bool
                
                .. attribute:: waiting_timer
                
                	Waiting for NSF timer expiry
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.configured_state = None
                    self.last_icd_notif_recv = None
                    self.last_icd_notif_recv_sec = None
                    self.last_nsf_off = None
                    self.last_nsf_off_sec = None
                    self.last_nsf_on = None
                    self.last_nsf_on_sec = None
                    self.nsf_state = None
                    self.nsf_time_left = None
                    self.nsf_timeout = None
                    self.respawn_count = None
                    self.waiting_membership = None
                    self.waiting_timer = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:nsf'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.configured_state is not None:
                        return True

                    if self.last_icd_notif_recv is not None:
                        return True

                    if self.last_icd_notif_recv_sec is not None:
                        return True

                    if self.last_nsf_off is not None:
                        return True

                    if self.last_nsf_off_sec is not None:
                        return True

                    if self.last_nsf_on is not None:
                        return True

                    if self.last_nsf_on_sec is not None:
                        return True

                    if self.nsf_state is not None:
                        return True

                    if self.nsf_time_left is not None:
                        return True

                    if self.nsf_timeout is not None:
                        return True

                    if self.respawn_count is not None:
                        return True

                    if self.waiting_membership is not None:
                        return True

                    if self.waiting_timer is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.Process.Nsf']['meta_info']


            class Issu(object):
                """
                ISSU Information
                
                .. attribute:: checkpoint_idt_timestamp
                
                	Time when Checkpoint IDT done
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: eoc_received_timestamp
                
                	Time when EOC was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: ihms_received_timestamp
                
                	Time when IHMS done was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: informationvalid
                
                	Is Information valid ?
                	**type**\:  bool
                
                .. attribute:: is_checkpoint_idt_done
                
                	Was Checkpoint IDT done ?
                	**type**\:  bool
                
                .. attribute:: is_eoc_received
                
                	Was EOC received ?
                	**type**\:  bool
                
                .. attribute:: is_ihms_done_received
                
                	Was IHMS done received ?
                	**type**\:  bool
                
                .. attribute:: is_nbr_sync_received
                
                	Was NBR Sync achieved ?
                	**type**\:  bool
                
                .. attribute:: is_rib_sync_received
                
                	Was RIB Sync received ?
                	**type**\:  bool
                
                .. attribute:: last_ha_role_notification_received
                
                	Time when last HA role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_phase_notification_received
                
                	Time when last ISSU Phase nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_role_notification_received
                
                	Time when last ISSU role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: nbr_sync_received_timestamp
                
                	Time when NBR Sync was achieved
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: phase_issu
                
                	ISSU Phase
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: rib_sync_received_timestamp
                
                	Time when RIB Sync was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: role_ha
                
                	HA role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: role_issu
                
                	ISSU role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.checkpoint_idt_timestamp = None
                    self.eoc_received_timestamp = None
                    self.ihms_received_timestamp = None
                    self.informationvalid = None
                    self.is_checkpoint_idt_done = None
                    self.is_eoc_received = None
                    self.is_ihms_done_received = None
                    self.is_nbr_sync_received = None
                    self.is_rib_sync_received = None
                    self.last_ha_role_notification_received = None
                    self.last_issu_phase_notification_received = None
                    self.last_issu_role_notification_received = None
                    self.nbr_sync_received_timestamp = None
                    self.phase_issu = None
                    self.rib_sync_received_timestamp = None
                    self.role_ha = None
                    self.role_issu = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:process/Cisco-IOS-XR-ipv4-pim-oper:issu'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.checkpoint_idt_timestamp is not None:
                        return True

                    if self.eoc_received_timestamp is not None:
                        return True

                    if self.ihms_received_timestamp is not None:
                        return True

                    if self.informationvalid is not None:
                        return True

                    if self.is_checkpoint_idt_done is not None:
                        return True

                    if self.is_eoc_received is not None:
                        return True

                    if self.is_ihms_done_received is not None:
                        return True

                    if self.is_nbr_sync_received is not None:
                        return True

                    if self.is_rib_sync_received is not None:
                        return True

                    if self.last_ha_role_notification_received is not None:
                        return True

                    if self.last_issu_phase_notification_received is not None:
                        return True

                    if self.last_issu_role_notification_received is not None:
                        return True

                    if self.nbr_sync_received_timestamp is not None:
                        return True

                    if self.phase_issu is not None:
                        return True

                    if self.rib_sync_received_timestamp is not None:
                        return True

                    if self.role_ha is not None:
                        return True

                    if self.role_issu is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.Process.Issu']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:process'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.checkpoint_statistics is not None and self.checkpoint_statistics._has_data():
                    return True

                if self.issu is not None and self.issu._has_data():
                    return True

                if self.nsf is not None and self.nsf._has_data():
                    return True

                if self.nsr is not None and self.nsr._has_data():
                    return True

                if self.summary is not None and self.summary._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                return meta._meta_table['Ipv6Pim.Active.Process']['meta_info']


        class Vrfs(object):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF name
            	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.vrf = YList()
                self.vrf.parent = self
                self.vrf.name = 'vrf'


            class Vrf(object):
                """
                VRF name
                
                .. attribute:: vrf_name  <key>
                
                	VRF name 
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: auto_rp
                
                	PIM Auto\-RP information
                	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.AutoRp>`
                
                .. attribute:: bgp_afs
                
                	PIM BGP SAFI table
                	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BgpAfs>`
                
                .. attribute:: bidir_df_states
                
                	Bidirectional PIM DF election state table
                	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates>`
                
                .. attribute:: bidir_df_winners
                
                	Bidirectional PIM DF election winner table
                	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners>`
                
                .. attribute:: bsr
                
                	PIM BSR information
                	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr>`
                
                .. attribute:: context
                
                	PIM context information
                	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context>`
                
                .. attribute:: gre
                
                	GRE information
                	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre>`
                
                .. attribute:: group_map_match_rpfs
                
                	Find matching group\-mapping for the specified group address
                	**type**\:   :py:class:`GroupMapMatchRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs>`
                
                .. attribute:: group_map_match_sources
                
                	Find the matching group\-mapping with source information on specified group address
                	**type**\:   :py:class:`GroupMapMatchSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources>`
                
                .. attribute:: group_map_rpfs
                
                	PIM group mapping information
                	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs>`
                
                .. attribute:: group_map_sources
                
                	PIM group\-mapping with source information
                	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources>`
                
                .. attribute:: ifrs_interfaces
                
                	PIM interfaces in forward reference store table
                	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: ifrs_summary
                
                	PIM interfaces in forward reference store summary
                	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.IfrsSummary>`
                
                .. attribute:: interface_old_formats
                
                	PIM interfaces in old format
                	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats>`
                
                .. attribute:: interface_statistics
                
                	PIM interface statistics
                	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics>`
                
                .. attribute:: interfaces
                
                	PIM interfaces
                	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Interfaces>`
                
                .. attribute:: jp_statistics
                
                	PIM join prune statistics table
                	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.JpStatistics>`
                
                .. attribute:: mib_databases
                
                	PIM group database for mroute mibs table
                	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases>`
                
                .. attribute:: multicast_static_routes
                
                	PIM multicast static route table
                	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes>`
                
                .. attribute:: neighbor_old_formats
                
                	PIM neighbor table old format
                	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats>`
                
                .. attribute:: neighbor_summaries
                
                	PIM neighbor summary table
                	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries>`
                
                .. attribute:: neighbors
                
                	PIM neighbor table
                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Neighbors>`
                
                .. attribute:: net_io_tunnels
                
                	Tunnel information that NETIO has 
                	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels>`
                
                .. attribute:: ranges
                
                	PIM range list information
                	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges>`
                
                .. attribute:: route_policy
                
                	PIM route policy
                	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy>`
                
                .. attribute:: rpf_redirect
                
                	PIM ECMP RPF\-redirect bundle
                	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect>`
                
                .. attribute:: rpf_summary
                
                	PIM RPF registration summary
                	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfSummary>`
                
                .. attribute:: safs
                
                	SAFI table and type
                	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs>`
                
                .. attribute:: summary
                
                	PIM summary
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Summary>`
                
                .. attribute:: table_contexts
                
                	PIM table context list
                	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TableContexts>`
                
                .. attribute:: topologies
                
                	PIM topology table
                	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies>`
                
                .. attribute:: topology_entry_flag_route_counts
                
                	Route count for topology with entry flag set
                	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts>`
                
                .. attribute:: topology_interface_flag_route_counts
                
                	Route count for topology with interface flag set
                	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts>`
                
                .. attribute:: topology_route_count
                
                	Topology route count information from PIM topology table
                	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount>`
                
                .. attribute:: traffic_counters
                
                	PIM message traffic counters
                	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters>`
                
                .. attribute:: tunnels
                
                	Tunnels information that PIM has
                	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.vrf_name = None
                    self.auto_rp = Ipv6Pim.Active.Vrfs.Vrf.AutoRp()
                    self.auto_rp.parent = self
                    self.bgp_afs = Ipv6Pim.Active.Vrfs.Vrf.BgpAfs()
                    self.bgp_afs.parent = self
                    self.bidir_df_states = Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates()
                    self.bidir_df_states.parent = self
                    self.bidir_df_winners = Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners()
                    self.bidir_df_winners.parent = self
                    self.bsr = Ipv6Pim.Active.Vrfs.Vrf.Bsr()
                    self.bsr.parent = self
                    self.context = Ipv6Pim.Active.Vrfs.Vrf.Context()
                    self.context.parent = self
                    self.gre = Ipv6Pim.Active.Vrfs.Vrf.Gre()
                    self.gre.parent = self
                    self.group_map_match_rpfs = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs()
                    self.group_map_match_rpfs.parent = self
                    self.group_map_match_sources = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources()
                    self.group_map_match_sources.parent = self
                    self.group_map_rpfs = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs()
                    self.group_map_rpfs.parent = self
                    self.group_map_sources = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources()
                    self.group_map_sources.parent = self
                    self.ifrs_interfaces = Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self.ifrs_summary = Ipv6Pim.Active.Vrfs.Vrf.IfrsSummary()
                    self.ifrs_summary.parent = self
                    self.interface_old_formats = Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats()
                    self.interface_old_formats.parent = self
                    self.interface_statistics = Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics()
                    self.interface_statistics.parent = self
                    self.interfaces = Ipv6Pim.Active.Vrfs.Vrf.Interfaces()
                    self.interfaces.parent = self
                    self.jp_statistics = Ipv6Pim.Active.Vrfs.Vrf.JpStatistics()
                    self.jp_statistics.parent = self
                    self.mib_databases = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases()
                    self.mib_databases.parent = self
                    self.multicast_static_routes = Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes()
                    self.multicast_static_routes.parent = self
                    self.neighbor_old_formats = Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats()
                    self.neighbor_old_formats.parent = self
                    self.neighbor_summaries = Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries()
                    self.neighbor_summaries.parent = self
                    self.neighbors = Ipv6Pim.Active.Vrfs.Vrf.Neighbors()
                    self.neighbors.parent = self
                    self.net_io_tunnels = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels()
                    self.net_io_tunnels.parent = self
                    self.ranges = Ipv6Pim.Active.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self.route_policy = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy()
                    self.route_policy.parent = self
                    self.rpf_redirect = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect()
                    self.rpf_redirect.parent = self
                    self.rpf_summary = Ipv6Pim.Active.Vrfs.Vrf.RpfSummary()
                    self.rpf_summary.parent = self
                    self.safs = Ipv6Pim.Active.Vrfs.Vrf.Safs()
                    self.safs.parent = self
                    self.summary = Ipv6Pim.Active.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self.table_contexts = Ipv6Pim.Active.Vrfs.Vrf.TableContexts()
                    self.table_contexts.parent = self
                    self.topologies = Ipv6Pim.Active.Vrfs.Vrf.Topologies()
                    self.topologies.parent = self
                    self.topology_entry_flag_route_counts = Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts()
                    self.topology_entry_flag_route_counts.parent = self
                    self.topology_interface_flag_route_counts = Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts()
                    self.topology_interface_flag_route_counts.parent = self
                    self.topology_route_count = Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount()
                    self.topology_route_count.parent = self
                    self.traffic_counters = Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self.tunnels = Ipv6Pim.Active.Vrfs.Vrf.Tunnels()
                    self.tunnels.parent = self


                class IfrsInterfaces(object):
                    """
                    PIM interfaces in forward reference store table
                    
                    .. attribute:: ifrs_interface
                    
                    	PIM IFRS interface information
                    	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ifrs_interface = YList()
                        self.ifrs_interface.parent = self
                        self.ifrs_interface.name = 'ifrs_interface'


                    class IfrsInterface(object):
                        """
                        PIM IFRS interface information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.configured_override_interval = None
                            self.configured_propagation_delay = None
                            self.dr_address = Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress()
                            self.dr_address.parent = self
                            self.dr_priority = None
                            self.external_neighbor_count = None
                            self.generation_id = None
                            self.hello_expiry = None
                            self.hello_interval = None
                            self.idb_acl_name = None
                            self.idb_acl_provided = None
                            self.idb_current_count = None
                            self.idb_max_count = None
                            self.idb_oor_enabled = None
                            self.idb_threshold_count = None
                            self.interface_address = YList()
                            self.interface_address.parent = self
                            self.interface_address.name = 'interface_address'
                            self.interface_address_mask = None
                            self.interface_name_xr = None
                            self.is_batch_asserts_capable = None
                            self.is_bidirectional_capable = None
                            self.is_enabled = None
                            self.is_proxy_capable = None
                            self.join_prune_interval = None
                            self.neighbor_count = None
                            self.neighbor_filter_name = None
                            self.override_interval = None
                            self.passive_interface = None
                            self.propagation_delay = None
                            self.prune_delay_enabled = None
                            self.virtual_interface = None


                        class DrAddress(object):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress']['meta_info']


                        class InterfaceAddress(object):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:ifrs-interface[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.are_we_dr is not None:
                                return True

                            if self.bfd_enabled is not None:
                                return True

                            if self.bfd_interval is not None:
                                return True

                            if self.bfd_multiplier is not None:
                                return True

                            if self.configured_override_interval is not None:
                                return True

                            if self.configured_propagation_delay is not None:
                                return True

                            if self.dr_address is not None and self.dr_address._has_data():
                                return True

                            if self.dr_priority is not None:
                                return True

                            if self.external_neighbor_count is not None:
                                return True

                            if self.generation_id is not None:
                                return True

                            if self.hello_expiry is not None:
                                return True

                            if self.hello_interval is not None:
                                return True

                            if self.idb_acl_name is not None:
                                return True

                            if self.idb_acl_provided is not None:
                                return True

                            if self.idb_current_count is not None:
                                return True

                            if self.idb_max_count is not None:
                                return True

                            if self.idb_oor_enabled is not None:
                                return True

                            if self.idb_threshold_count is not None:
                                return True

                            if self.interface_address is not None:
                                for child_ref in self.interface_address:
                                    if child_ref._has_data():
                                        return True

                            if self.interface_address_mask is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.is_batch_asserts_capable is not None:
                                return True

                            if self.is_bidirectional_capable is not None:
                                return True

                            if self.is_enabled is not None:
                                return True

                            if self.is_proxy_capable is not None:
                                return True

                            if self.join_prune_interval is not None:
                                return True

                            if self.neighbor_count is not None:
                                return True

                            if self.neighbor_filter_name is not None:
                                return True

                            if self.override_interval is not None:
                                return True

                            if self.passive_interface is not None:
                                return True

                            if self.propagation_delay is not None:
                                return True

                            if self.prune_delay_enabled is not None:
                                return True

                            if self.virtual_interface is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:ifrs-interfaces'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ifrs_interface is not None:
                            for child_ref in self.ifrs_interface:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces']['meta_info']


                class Safs(object):
                    """
                    SAFI table and type
                    
                    .. attribute:: saf
                    
                    	SAF name 
                    	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.saf = YList()
                        self.saf.parent = self
                        self.saf.name = 'saf'


                    class Saf(object):
                        """
                        SAF name 
                        
                        .. attribute:: rpf_hash_source_groups
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups>`
                        
                        .. attribute:: rpf_hash_sources
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources>`
                        
                        .. attribute:: rpfs
                        
                        	PIM RPF information table
                        	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs>`
                        
                        .. attribute:: saf_name
                        
                        	SAF name 
                        	**type**\:   :py:class:`PimSafiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafiEnum>`
                        
                        .. attribute:: topology_name
                        
                        	Topology name 
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rpf_hash_source_groups = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups()
                            self.rpf_hash_source_groups.parent = self
                            self.rpf_hash_sources = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources()
                            self.rpf_hash_sources.parent = self
                            self.rpfs = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs()
                            self.rpfs.parent = self
                            self.saf_name = None
                            self.topology_name = None


                        class RpfHashSourceGroups(object):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source_group
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.rpf_hash_source_group = YList()
                                self.rpf_hash_source_group.parent = self
                                self.rpf_hash_source_group.name = 'rpf_hash_source_group'


                            class RpfHashSourceGroup(object):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: group_address
                                
                                	Group address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: mask_length
                                
                                	Hash mask length
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.group_address = None
                                    self.mask_length = None
                                    self.mofrr = None
                                    self.next_hop_address = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self.next_hop_interface = None
                                    self.next_hop_multipath_enabled = None
                                    self.secondary_next_hop_address = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self.secondary_next_hop_interface = None
                                    self.source_address = None


                                class NextHopAddress(object):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:next-hop-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress']['meta_info']


                                class SecondaryNextHopAddress(object):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:secondary-next-hop-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-group'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.group_address is not None:
                                        return True

                                    if self.mask_length is not None:
                                        return True

                                    if self.mofrr is not None:
                                        return True

                                    if self.next_hop_address is not None and self.next_hop_address._has_data():
                                        return True

                                    if self.next_hop_interface is not None:
                                        return True

                                    if self.next_hop_multipath_enabled is not None:
                                        return True

                                    if self.secondary_next_hop_address is not None and self.secondary_next_hop_address._has_data():
                                        return True

                                    if self.secondary_next_hop_interface is not None:
                                        return True

                                    if self.source_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source-groups'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.rpf_hash_source_group is not None:
                                    for child_ref in self.rpf_hash_source_group:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups']['meta_info']


                        class RpfHashSources(object):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.rpf_hash_source = YList()
                                self.rpf_hash_source.parent = self
                                self.rpf_hash_source.name = 'rpf_hash_source'


                            class RpfHashSource(object):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mofrr = None
                                    self.next_hop_address = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self.next_hop_interface = None
                                    self.next_hop_multipath_enabled = None
                                    self.secondary_next_hop_address = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self.secondary_next_hop_interface = None
                                    self.source_address = None


                                class NextHopAddress(object):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:next-hop-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress']['meta_info']


                                class SecondaryNextHopAddress(object):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:secondary-next-hop-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-source'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mofrr is not None:
                                        return True

                                    if self.next_hop_address is not None and self.next_hop_address._has_data():
                                        return True

                                    if self.next_hop_interface is not None:
                                        return True

                                    if self.next_hop_multipath_enabled is not None:
                                        return True

                                    if self.secondary_next_hop_address is not None and self.secondary_next_hop_address._has_data():
                                        return True

                                    if self.secondary_next_hop_interface is not None:
                                        return True

                                    if self.source_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-hash-sources'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.rpf_hash_source is not None:
                                    for child_ref in self.rpf_hash_source:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources']['meta_info']


                        class Rpfs(object):
                            """
                            PIM RPF information table
                            
                            .. attribute:: rpf
                            
                            	PIM RPF information
                            	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.rpf = YList()
                                self.rpf.parent = self
                                self.rpf.name = 'rpf'


                            class Rpf(object):
                                """
                                PIM RPF information
                                
                                .. attribute:: registered_address  <key>
                                
                                	Address for which RPF lookup
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: is_connected
                                
                                	Are we connected ?
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_rpf_bgp_route
                                
                                	Is RPF through BGP route
                                	**type**\:  bool
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_preference
                                
                                	Metric preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: registered_address_xr
                                
                                	Address registered
                                	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                                
                                .. attribute:: rpf_path
                                
                                	RPF Paths list
                                	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.registered_address = None
                                    self.is_connected = None
                                    self.is_rpf_bgp_route = None
                                    self.metric = None
                                    self.metric_preference = None
                                    self.registered_address_xr = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                    self.registered_address_xr.parent = self
                                    self.rpf_path = YList()
                                    self.rpf_path.parent = self
                                    self.rpf_path.name = 'rpf_path'


                                class RegisteredAddressXr(object):
                                    """
                                    Address registered
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:registered-address-xr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr']['meta_info']


                                class RpfPath(object):
                                    """
                                    RPF Paths list
                                    
                                    .. attribute:: connector
                                    
                                    	Connector Attribute
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: extranet_vrf_name
                                    
                                    	Extranet VRF name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    .. attribute:: is_connector_attribute_present
                                    
                                    	Connector attribute present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rpf_interface_disabled
                                    
                                    	Is the rpf interface disabled ?
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_lsm
                                    
                                    	Via LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_mlsm
                                    
                                    	Via Mstatic LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpf_interface_name
                                    
                                    	RPF Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: rpf_neighbor
                                    
                                    	RPF neighbor
                                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                    
                                    .. attribute:: rpf_nexthop
                                    
                                    	RPF nexthop
                                    	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.connector = None
                                        self.extranet_vrf_name = None
                                        self.is_connector_attribute_present = None
                                        self.is_rpf_interface_disabled = None
                                        self.is_via_lsm = None
                                        self.is_via_mlsm = None
                                        self.rpf_interface_name = None
                                        self.rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                        self.rpf_neighbor.parent = self
                                        self.rpf_nexthop = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                        self.rpf_nexthop.parent = self


                                    class RpfNeighbor(object):
                                        """
                                        RPF neighbor
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor']['meta_info']


                                    class RpfNexthop(object):
                                        """
                                        RPF nexthop
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-nexthop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.connector is not None:
                                            return True

                                        if self.extranet_vrf_name is not None:
                                            return True

                                        if self.is_connector_attribute_present is not None:
                                            return True

                                        if self.is_rpf_interface_disabled is not None:
                                            return True

                                        if self.is_via_lsm is not None:
                                            return True

                                        if self.is_via_mlsm is not None:
                                            return True

                                        if self.rpf_interface_name is not None:
                                            return True

                                        if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                            return True

                                        if self.rpf_nexthop is not None and self.rpf_nexthop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.registered_address is None:
                                        raise YPYModelError('Key property registered_address is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf[Cisco-IOS-XR-ipv4-pim-oper:registered-address = ' + str(self.registered_address) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.registered_address is not None:
                                        return True

                                    if self.is_connected is not None:
                                        return True

                                    if self.is_rpf_bgp_route is not None:
                                        return True

                                    if self.metric is not None:
                                        return True

                                    if self.metric_preference is not None:
                                        return True

                                    if self.registered_address_xr is not None and self.registered_address_xr._has_data():
                                        return True

                                    if self.rpf_path is not None:
                                        for child_ref in self.rpf_path:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpfs'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.rpf is not None:
                                    for child_ref in self.rpf:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:saf'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups._has_data():
                                return True

                            if self.rpf_hash_sources is not None and self.rpf_hash_sources._has_data():
                                return True

                            if self.rpfs is not None and self.rpfs._has_data():
                                return True

                            if self.saf_name is not None:
                                return True

                            if self.topology_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:safs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.saf is not None:
                            for child_ref in self.saf:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Safs']['meta_info']


                class InterfaceStatistics(object):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_statistic
                    
                    	PIM interface statistics
                    	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_statistic = YList()
                        self.interface_statistic.parent = self
                        self.interface_statistic.name = 'interface_statistic'


                    class InterfaceStatistic(object):
                        """
                        PIM interface statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: input_assert
                        
                        	Assert packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_bsr_message
                        
                        	Input BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_candidate_rp_advertisement
                        
                        	Input Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_df_election
                        
                        	DF Election packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_ack_message
                        
                        	Input Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_message
                        
                        	Input Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_hello
                        
                        	Hello packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_jp
                        
                        	Join Prune packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_miscellaneous
                        
                        	Miscellaneous packet in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register
                        
                        	Register packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register_stop
                        
                        	Register Stop packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_assert
                        
                        	Assert packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_bsr_message
                        
                        	Output BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_candidate_rp_advertisement
                        
                        	Output Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_df_election
                        
                        	DF Election packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_ack_message
                        
                        	Output Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_message
                        
                        	Output Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_hello
                        
                        	Hello packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_jp
                        
                        	Join Prune packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register
                        
                        	Register packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register_stop
                        
                        	Register Stop packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.input_assert = None
                            self.input_bsr_message = None
                            self.input_candidate_rp_advertisement = None
                            self.input_df_election = None
                            self.input_graft_ack_message = None
                            self.input_graft_message = None
                            self.input_hello = None
                            self.input_jp = None
                            self.input_miscellaneous = None
                            self.input_register = None
                            self.input_register_stop = None
                            self.output_assert = None
                            self.output_bsr_message = None
                            self.output_candidate_rp_advertisement = None
                            self.output_df_election = None
                            self.output_graft_ack_message = None
                            self.output_graft_message = None
                            self.output_hello = None
                            self.output_jp = None
                            self.output_register = None
                            self.output_register_stop = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-statistic[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.input_assert is not None:
                                return True

                            if self.input_bsr_message is not None:
                                return True

                            if self.input_candidate_rp_advertisement is not None:
                                return True

                            if self.input_df_election is not None:
                                return True

                            if self.input_graft_ack_message is not None:
                                return True

                            if self.input_graft_message is not None:
                                return True

                            if self.input_hello is not None:
                                return True

                            if self.input_jp is not None:
                                return True

                            if self.input_miscellaneous is not None:
                                return True

                            if self.input_register is not None:
                                return True

                            if self.input_register_stop is not None:
                                return True

                            if self.output_assert is not None:
                                return True

                            if self.output_bsr_message is not None:
                                return True

                            if self.output_candidate_rp_advertisement is not None:
                                return True

                            if self.output_df_election is not None:
                                return True

                            if self.output_graft_ack_message is not None:
                                return True

                            if self.output_graft_message is not None:
                                return True

                            if self.output_hello is not None:
                                return True

                            if self.output_jp is not None:
                                return True

                            if self.output_register is not None:
                                return True

                            if self.output_register_stop is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-statistics'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_statistic is not None:
                            for child_ref in self.interface_statistic:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics']['meta_info']


                class TopologyRouteCount(object):
                    """
                    Topology route count information from PIM
                    topology table
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.active_group_ranges = None
                        self.group_address = Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self.group_ranges = None
                        self.groute_count = None
                        self.is_node_low_memory = None
                        self.sg_route_count = None
                        self.sgr_route_count = None


                    class GroupAddress(object):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount.GroupAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology-route-count'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.active_group_ranges is not None:
                            return True

                        if self.group_address is not None and self.group_address._has_data():
                            return True

                        if self.group_ranges is not None:
                            return True

                        if self.groute_count is not None:
                            return True

                        if self.is_node_low_memory is not None:
                            return True

                        if self.sg_route_count is not None:
                            return True

                        if self.sgr_route_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount']['meta_info']


                class JpStatistics(object):
                    """
                    PIM join prune statistics table
                    
                    .. attribute:: jp_statistic
                    
                    	PIM Join Prune Statistics
                    	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.jp_statistic = YList()
                        self.jp_statistic.parent = self
                        self.jp_statistic.name = 'jp_statistic'


                    class JpStatistic(object):
                        """
                        PIM Join Prune Statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received
                        
                        	Received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received100
                        
                        	Received 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_10k
                        
                        	Received 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_1k
                        
                        	Received 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_50k
                        
                        	Deprecated by Received100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted
                        
                        	Transmitted
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transmitted100
                        
                        	Transmitted 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_10k
                        
                        	Transmitted 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_1k
                        
                        	Transmitted 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_50k
                        
                        	Deprecated by Transmitted100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.mtu = None
                            self.received = None
                            self.received100 = None
                            self.received_10k = None
                            self.received_1k = None
                            self.received_50k = None
                            self.transmitted = None
                            self.transmitted100 = None
                            self.transmitted_10k = None
                            self.transmitted_1k = None
                            self.transmitted_50k = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:jp-statistic[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.mtu is not None:
                                return True

                            if self.received is not None:
                                return True

                            if self.received100 is not None:
                                return True

                            if self.received_10k is not None:
                                return True

                            if self.received_1k is not None:
                                return True

                            if self.received_50k is not None:
                                return True

                            if self.transmitted is not None:
                                return True

                            if self.transmitted100 is not None:
                                return True

                            if self.transmitted_10k is not None:
                                return True

                            if self.transmitted_1k is not None:
                                return True

                            if self.transmitted_50k is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:jp-statistics'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.jp_statistic is not None:
                            for child_ref in self.jp_statistic:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.JpStatistics']['meta_info']


                class MibDatabases(object):
                    """
                    PIM group database for mroute mibs table
                    
                    .. attribute:: mib_database
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.mib_database = YList()
                        self.mib_database.parent = self
                        self.mib_database.name = 'mib_database'


                    class MibDatabase(object):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: assert_metric
                        
                        	Assert Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_metric_preference
                        
                        	Assert Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_rpt_bit
                        
                        	Assert RPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: bidirectional_route
                        
                        	Is this Bidir ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Multicast satic route group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr>`
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface name 
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_mask
                        
                        	Mask of the multicast root
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rpf_neighbor
                        
                        	The RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor>`
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: source_address
                        
                        	Multicast static route source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr>`
                        
                        .. attribute:: source_netmask
                        
                        	Source mask
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: spt_bit
                        
                        	Is SPT bit set ?
                        	**type**\:  bool
                        
                        .. attribute:: upstream_assert_timer
                        
                        	Upstream Assert Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime of route
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.assert_metric = None
                            self.assert_metric_preference = None
                            self.assert_rpt_bit = None
                            self.bidirectional_route = None
                            self.group_address = None
                            self.group_address_xr = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self.protocol = None
                            self.rpf_drop = None
                            self.rpf_extranet = None
                            self.rpf_interface_name = None
                            self.rpf_mask = None
                            self.rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self.rpf_root = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot()
                            self.rpf_root.parent = self
                            self.rpf_safi = None
                            self.rpf_table_name = None
                            self.rpf_vrf_name = None
                            self.source_address = None
                            self.source_address_xr = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self.source_netmask = None
                            self.spt_bit = None
                            self.upstream_assert_timer = None
                            self.uptime = None


                        class SourceAddressXr(object):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr']['meta_info']


                        class GroupAddressXr(object):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr']['meta_info']


                        class RpfNeighbor(object):
                            """
                            The RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor']['meta_info']


                        class RpfRoot(object):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-root'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:mib-database'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.assert_metric is not None:
                                return True

                            if self.assert_metric_preference is not None:
                                return True

                            if self.assert_rpt_bit is not None:
                                return True

                            if self.bidirectional_route is not None:
                                return True

                            if self.group_address is not None:
                                return True

                            if self.group_address_xr is not None and self.group_address_xr._has_data():
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rpf_drop is not None:
                                return True

                            if self.rpf_extranet is not None:
                                return True

                            if self.rpf_interface_name is not None:
                                return True

                            if self.rpf_mask is not None:
                                return True

                            if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                return True

                            if self.rpf_root is not None and self.rpf_root._has_data():
                                return True

                            if self.rpf_safi is not None:
                                return True

                            if self.rpf_table_name is not None:
                                return True

                            if self.rpf_vrf_name is not None:
                                return True

                            if self.source_address is not None:
                                return True

                            if self.source_address_xr is not None and self.source_address_xr._has_data():
                                return True

                            if self.source_netmask is not None:
                                return True

                            if self.spt_bit is not None:
                                return True

                            if self.upstream_assert_timer is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:mib-databases'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.mib_database is not None:
                            for child_ref in self.mib_database:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.MibDatabases']['meta_info']


                class GroupMapMatchRpfs(object):
                    """
                    Find matching group\-mapping for the specified
                    group address
                    
                    .. attribute:: group_map_match_rpf
                    
                    	PIM group matching mapping entry
                    	**type**\: list of    :py:class:`GroupMapMatchRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_map_match_rpf = YList()
                        self.group_map_match_rpf.parent = self
                        self.group_map_match_rpf.name = 'group_map_match_rpf'


                    class GroupMapMatchRpf(object):
                        """
                        PIM group matching mapping entry
                        
                        .. attribute:: group_address  <key>
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\:  bool
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation>`
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor>`
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.group_address = None
                            self.are_we_rp = None
                            self.group_map_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self.rpf_interface_name = None
                            self.rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self.rpf_vrf_name = None


                        class RpfNeighbor(object):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor']['meta_info']


                        class GroupMapInformation(object):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.client = None
                                self.group_count = None
                                self.is_override = None
                                self.is_used = None
                                self.mrib_active = None
                                self.prefix = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self.prefix_length = None
                                self.priority = None
                                self.protocol = None
                                self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self


                            class Prefix(object):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix']['meta_info']


                            class RpAddress(object):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.client is not None:
                                    return True

                                if self.group_count is not None:
                                    return True

                                if self.is_override is not None:
                                    return True

                                if self.is_used is not None:
                                    return True

                                if self.mrib_active is not None:
                                    return True

                                if self.prefix is not None and self.prefix._has_data():
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.priority is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.rp_address is not None and self.rp_address._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.group_address is None:
                                raise YPYModelError('Key property group_address is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-rpf[Cisco-IOS-XR-ipv4-pim-oper:group-address = ' + str(self.group_address) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.group_address is not None:
                                return True

                            if self.are_we_rp is not None:
                                return True

                            if self.group_map_information is not None and self.group_map_information._has_data():
                                return True

                            if self.rpf_interface_name is not None:
                                return True

                            if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                return True

                            if self.rpf_vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-rpfs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_map_match_rpf is not None:
                            for child_ref in self.group_map_match_rpf:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs']['meta_info']


                class NeighborOldFormats(object):
                    """
                    PIM neighbor table old format
                    
                    .. attribute:: neighbor_old_format
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.neighbor_old_format = YList()
                        self.neighbor_old_format.parent = self
                        self.neighbor_old_format.name = 'neighbor_old_format'


                    class NeighborOldFormat(object):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dr_priority = None
                            self.expires = None
                            self.expiry_timer = None
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.is_batch_asserts_capable = None
                            self.is_bfd_state = None
                            self.is_bidirectional_capable = None
                            self.is_dr_priority_capable = None
                            self.is_ecmp_redirect_capable = None
                            self.is_proxy_capable = None
                            self.is_this_neighbor_dr = None
                            self.is_this_neighbor_us = None
                            self.neighbor_address = None
                            self.neighbor_address_xr = YList()
                            self.neighbor_address_xr.parent = self
                            self.neighbor_address_xr.name = 'neighbor_address_xr'
                            self.override_interval = None
                            self.propagation_delay = None
                            self.uptime = None


                        class NeighborAddressXr(object):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-format'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dr_priority is not None:
                                return True

                            if self.expires is not None:
                                return True

                            if self.expiry_timer is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.is_batch_asserts_capable is not None:
                                return True

                            if self.is_bfd_state is not None:
                                return True

                            if self.is_bidirectional_capable is not None:
                                return True

                            if self.is_dr_priority_capable is not None:
                                return True

                            if self.is_ecmp_redirect_capable is not None:
                                return True

                            if self.is_proxy_capable is not None:
                                return True

                            if self.is_this_neighbor_dr is not None:
                                return True

                            if self.is_this_neighbor_us is not None:
                                return True

                            if self.neighbor_address is not None:
                                return True

                            if self.neighbor_address_xr is not None:
                                for child_ref in self.neighbor_address_xr:
                                    if child_ref._has_data():
                                        return True

                            if self.override_interval is not None:
                                return True

                            if self.propagation_delay is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-old-formats'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.neighbor_old_format is not None:
                            for child_ref in self.neighbor_old_format:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats']['meta_info']


                class IfrsSummary(object):
                    """
                    PIM interfaces in forward reference store
                    summary
                    
                    .. attribute:: configuration_count
                    
                    	Configuration counts
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Number of interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.configuration_count = None
                        self.interface_count = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:ifrs-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.configuration_count is not None:
                            return True

                        if self.interface_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.IfrsSummary']['meta_info']


                class Ranges(object):
                    """
                    PIM range list information
                    
                    .. attribute:: range
                    
                    	PIM range list information
                    	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.range = YList()
                        self.range.parent = self
                        self.range.name = 'range'


                    class Range(object):
                        """
                        PIM range list information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                        
                        .. attribute:: client_xr
                        
                        	Client mapping learnt via
                        	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: group_range
                        
                        	List of group ranges
                        	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange>`
                        
                        .. attribute:: protocol
                        
                        	PIM protocol
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	Rendezvous point address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr>`
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.client_xr = None
                            self.expires = None
                            self.group_range = YList()
                            self.group_range.parent = self
                            self.group_range.name = 'group_range'
                            self.protocol = None
                            self.rp_address = None
                            self.rp_address_xr = Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self.source_of_information = Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation()
                            self.source_of_information.parent = self


                        class RpAddressXr(object):
                            """
                            Rendezvous point address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr']['meta_info']


                        class SourceOfInformation(object):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation']['meta_info']


                        class GroupRange(object):
                            """
                            List of group ranges
                            
                            .. attribute:: expires
                            
                            	When mapping expires
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: source_of_information
                            
                            	Source of information
                            	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.expires = None
                                self.prefix = Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix()
                                self.prefix.parent = self
                                self.prefix_length = None
                                self.source_of_information = Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation()
                                self.source_of_information.parent = self
                                self.uptime = None


                            class Prefix(object):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix']['meta_info']


                            class SourceOfInformation(object):
                                """
                                Source of information
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-range'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.expires is not None:
                                    return True

                                if self.prefix is not None and self.prefix._has_data():
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.source_of_information is not None and self.source_of_information._has_data():
                                    return True

                                if self.uptime is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:range'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.client_xr is not None:
                                return True

                            if self.expires is not None:
                                return True

                            if self.group_range is not None:
                                for child_ref in self.group_range:
                                    if child_ref._has_data():
                                        return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None:
                                return True

                            if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                                return True

                            if self.source_of_information is not None and self.source_of_information._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:ranges'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.range is not None:
                            for child_ref in self.range:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Ranges']['meta_info']


                class InterfaceOldFormats(object):
                    """
                    PIM interfaces in old format
                    
                    .. attribute:: interface_old_format
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_old_format = YList()
                        self.interface_old_format.parent = self
                        self.interface_old_format.name = 'interface_old_format'


                    class InterfaceOldFormat(object):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.configured_override_interval = None
                            self.configured_propagation_delay = None
                            self.dr_address = Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                            self.dr_address.parent = self
                            self.dr_priority = None
                            self.external_neighbor_count = None
                            self.generation_id = None
                            self.hello_expiry = None
                            self.hello_interval = None
                            self.idb_acl_name = None
                            self.idb_acl_provided = None
                            self.idb_current_count = None
                            self.idb_max_count = None
                            self.idb_oor_enabled = None
                            self.idb_threshold_count = None
                            self.interface_address = YList()
                            self.interface_address.parent = self
                            self.interface_address.name = 'interface_address'
                            self.interface_address_mask = None
                            self.interface_name_xr = None
                            self.is_batch_asserts_capable = None
                            self.is_bidirectional_capable = None
                            self.is_enabled = None
                            self.is_proxy_capable = None
                            self.join_prune_interval = None
                            self.neighbor_count = None
                            self.neighbor_filter_name = None
                            self.override_interval = None
                            self.passive_interface = None
                            self.propagation_delay = None
                            self.prune_delay_enabled = None
                            self.virtual_interface = None


                        class DrAddress(object):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress']['meta_info']


                        class InterfaceAddress(object):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-old-format[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.are_we_dr is not None:
                                return True

                            if self.bfd_enabled is not None:
                                return True

                            if self.bfd_interval is not None:
                                return True

                            if self.bfd_multiplier is not None:
                                return True

                            if self.configured_override_interval is not None:
                                return True

                            if self.configured_propagation_delay is not None:
                                return True

                            if self.dr_address is not None and self.dr_address._has_data():
                                return True

                            if self.dr_priority is not None:
                                return True

                            if self.external_neighbor_count is not None:
                                return True

                            if self.generation_id is not None:
                                return True

                            if self.hello_expiry is not None:
                                return True

                            if self.hello_interval is not None:
                                return True

                            if self.idb_acl_name is not None:
                                return True

                            if self.idb_acl_provided is not None:
                                return True

                            if self.idb_current_count is not None:
                                return True

                            if self.idb_max_count is not None:
                                return True

                            if self.idb_oor_enabled is not None:
                                return True

                            if self.idb_threshold_count is not None:
                                return True

                            if self.interface_address is not None:
                                for child_ref in self.interface_address:
                                    if child_ref._has_data():
                                        return True

                            if self.interface_address_mask is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.is_batch_asserts_capable is not None:
                                return True

                            if self.is_bidirectional_capable is not None:
                                return True

                            if self.is_enabled is not None:
                                return True

                            if self.is_proxy_capable is not None:
                                return True

                            if self.join_prune_interval is not None:
                                return True

                            if self.neighbor_count is not None:
                                return True

                            if self.neighbor_filter_name is not None:
                                return True

                            if self.override_interval is not None:
                                return True

                            if self.passive_interface is not None:
                                return True

                            if self.propagation_delay is not None:
                                return True

                            if self.prune_delay_enabled is not None:
                                return True

                            if self.virtual_interface is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-old-formats'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_old_format is not None:
                            for child_ref in self.interface_old_format:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats']['meta_info']


                class Bsr(object):
                    """
                    PIM BSR information
                    
                    .. attribute:: bsr_elections
                    
                    	PIM BSR election state
                    	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections>`
                    
                    .. attribute:: candidate_rps
                    
                    	PIM candidate\-RP
                    	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps>`
                    
                    .. attribute:: rp_caches
                    
                    	PIM BSR RP cache table
                    	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bsr_elections = Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections()
                        self.bsr_elections.parent = self
                        self.candidate_rps = Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps()
                        self.candidate_rps.parent = self
                        self.rp_caches = Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches()
                        self.rp_caches.parent = self


                    class RpCaches(object):
                        """
                        PIM BSR RP cache table
                        
                        .. attribute:: rp_cache
                        
                        	PIM BSR RP cache
                        	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.rp_cache = YList()
                            self.rp_cache.parent = self
                            self.rp_cache.name = 'rp_cache'


                        class RpCache(object):
                            """
                            PIM BSR RP cache
                            
                            .. attribute:: group_prefix  <key>
                            
                            	Group prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: candidate_rp_group_count
                            
                            	C\-RP count for this Prefix
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: candidate_rp_list
                            
                            	C\-RP list for this prefix
                            	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList>`
                            
                            .. attribute:: group_prefix_length
                            
                            	Group Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_prefix_xr
                            
                            	Group Prefix
                            	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.group_prefix = None
                                self.candidate_rp_group_count = None
                                self.candidate_rp_list = Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList()
                                self.candidate_rp_list.parent = self
                                self.group_prefix_length = None
                                self.group_prefix_xr = Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                self.group_prefix_xr.parent = self


                            class GroupPrefixXr(object):
                                """
                                Group Prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-prefix-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr']['meta_info']


                            class CandidateRpList(object):
                                """
                                C\-RP list for this prefix
                                
                                .. attribute:: pim_bsr_crp_bag
                                
                                	pim bsr crp bag
                                	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.pim_bsr_crp_bag = YList()
                                    self.pim_bsr_crp_bag.parent = self
                                    self.pim_bsr_crp_bag.name = 'pim_bsr_crp_bag'


                                class PimBsrCrpBag(object):
                                    """
                                    pim bsr crp bag
                                    
                                    .. attribute:: candidate_rp_address
                                    
                                    	C\-RP address
                                    	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                    
                                    .. attribute:: candidate_rp_expires
                                    
                                    	C\-RP Expires
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_holdtime
                                    
                                    	C\-RP Holdtime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_priority
                                    
                                    	C\-RP Priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: candidate_rp_up_time
                                    
                                    	C\-RP Uptime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: protocol
                                    
                                    	PIM Protocol
                                    	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.candidate_rp_address = Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                        self.candidate_rp_address.parent = self
                                        self.candidate_rp_expires = None
                                        self.candidate_rp_holdtime = None
                                        self.candidate_rp_priority = None
                                        self.candidate_rp_up_time = None
                                        self.protocol = None


                                    class CandidateRpAddress(object):
                                        """
                                        C\-RP address
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:pim-bsr-crp-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.candidate_rp_address is not None and self.candidate_rp_address._has_data():
                                            return True

                                        if self.candidate_rp_expires is not None:
                                            return True

                                        if self.candidate_rp_holdtime is not None:
                                            return True

                                        if self.candidate_rp_priority is not None:
                                            return True

                                        if self.candidate_rp_up_time is not None:
                                            return True

                                        if self.protocol is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp-list'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.pim_bsr_crp_bag is not None:
                                        for child_ref in self.pim_bsr_crp_bag:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.group_prefix is None:
                                    raise YPYModelError('Key property group_prefix is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-cache[Cisco-IOS-XR-ipv4-pim-oper:group-prefix = ' + str(self.group_prefix) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.group_prefix is not None:
                                    return True

                                if self.candidate_rp_group_count is not None:
                                    return True

                                if self.candidate_rp_list is not None and self.candidate_rp_list._has_data():
                                    return True

                                if self.group_prefix_length is not None:
                                    return True

                                if self.group_prefix_xr is not None and self.group_prefix_xr._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-caches'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.rp_cache is not None:
                                for child_ref in self.rp_cache:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches']['meta_info']


                    class CandidateRps(object):
                        """
                        PIM candidate\-RP
                        
                        .. attribute:: candidate_rp
                        
                        	PIM BSR candidate RP information
                        	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.candidate_rp = YList()
                            self.candidate_rp.parent = self
                            self.candidate_rp.name = 'candidate_rp'


                        class CandidateRp(object):
                            """
                            PIM BSR candidate RP information
                            
                            .. attribute:: rp_address  <key>
                            
                            	Candidate\-RP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp
                            
                            	Cand\-RP Address
                            	**type**\:   :py:class:`CandidateRp_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_>`
                            
                            .. attribute:: candidate_rp_advance_interval
                            
                            	Cand\-RP Adv Interval in seconds
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            .. attribute:: candidate_rp_scope
                            
                            	Cand\-RP Scope
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: candidate_rp_uptime
                            
                            	Cand\-RP uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_access
                            
                            	Group Ranges Using this Cand\-RP
                            	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                            
                            .. attribute:: crp_holdtime
                            
                            	Cand\-RP Holdtime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_priority
                            
                            	Cand\-RP Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.rp_address = None
                                self.acl_name = None
                                self.candidate_rp = Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_()
                                self.candidate_rp.parent = self
                                self.candidate_rp_advance_interval = None
                                self.candidate_rp_mode = None
                                self.candidate_rp_scope = None
                                self.candidate_rp_uptime = None
                                self.crp_access = YList()
                                self.crp_access.parent = self
                                self.crp_access.name = 'crp_access'
                                self.crp_holdtime = None
                                self.crp_priority = None


                            class CandidateRp_(object):
                                """
                                Cand\-RP Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_']['meta_info']


                            class CrpAccess(object):
                                """
                                Group Ranges Using this Cand\-RP
                                
                                .. attribute:: acl_name
                                
                                	Group Access\-List Name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: candidate_rp_mode
                                
                                	Cand\-RP Mode
                                	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.acl_name = None
                                    self.candidate_rp_mode = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:crp-access'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.acl_name is not None:
                                        return True

                                    if self.candidate_rp_mode is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.rp_address is None:
                                    raise YPYModelError('Key property rp_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rp[Cisco-IOS-XR-ipv4-pim-oper:rp-address = ' + str(self.rp_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.rp_address is not None:
                                    return True

                                if self.acl_name is not None:
                                    return True

                                if self.candidate_rp is not None and self.candidate_rp._has_data():
                                    return True

                                if self.candidate_rp_advance_interval is not None:
                                    return True

                                if self.candidate_rp_mode is not None:
                                    return True

                                if self.candidate_rp_scope is not None:
                                    return True

                                if self.candidate_rp_uptime is not None:
                                    return True

                                if self.crp_access is not None:
                                    for child_ref in self.crp_access:
                                        if child_ref._has_data():
                                            return True

                                if self.crp_holdtime is not None:
                                    return True

                                if self.crp_priority is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-rps'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.candidate_rp is not None:
                                for child_ref in self.candidate_rp:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps']['meta_info']


                    class BsrElections(object):
                        """
                        PIM BSR election state
                        
                        .. attribute:: bsr_election
                        
                        	PIM BSR information
                        	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bsr_election = YList()
                            self.bsr_election.parent = self
                            self.bsr_election.name = 'bsr_election'


                        class BsrElection(object):
                            """
                            PIM BSR information
                            
                            .. attribute:: pim_scope  <key>
                            
                            	BSR information
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: bootstrap_timeout
                            
                            	Bootstrap Timeout
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_address
                            
                            	BSR address
                            	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress>`
                            
                            .. attribute:: bsr_election_state
                            
                            	BSR Election State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_mask_length
                            
                            	Hash Function Mask Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_priority
                            
                            	BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_scope
                            
                            	BSR Scope
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_up_time
                            
                            	BSR Uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_bsr_address
                            
                            	C\-BSR address
                            	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                            
                            .. attribute:: candidate_bsr_flag
                            
                            	BSR Candidate Config Flag
                            	**type**\:  bool
                            
                            .. attribute:: candidate_bsr_mask_length
                            
                            	C\-BSR Hash Func. Mask Len
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_priority
                            
                            	C\-BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_state
                            
                            	BSR Candidate State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pim_scope = None
                                self.bootstrap_timeout = None
                                self.bsr_address = Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress()
                                self.bsr_address.parent = self
                                self.bsr_election_state = None
                                self.bsr_mask_length = None
                                self.bsr_priority = None
                                self.bsr_scope = None
                                self.bsr_up_time = None
                                self.candidate_bsr_address = Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                self.candidate_bsr_address.parent = self
                                self.candidate_bsr_flag = None
                                self.candidate_bsr_mask_length = None
                                self.candidate_bsr_priority = None
                                self.candidate_bsr_state = None


                            class BsrAddress(object):
                                """
                                BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bsr-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress']['meta_info']


                            class CandidateBsrAddress(object):
                                """
                                C\-BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:candidate-bsr-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.pim_scope is None:
                                    raise YPYModelError('Key property pim_scope is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bsr-election[Cisco-IOS-XR-ipv4-pim-oper:pim-scope = ' + str(self.pim_scope) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pim_scope is not None:
                                    return True

                                if self.bootstrap_timeout is not None:
                                    return True

                                if self.bsr_address is not None and self.bsr_address._has_data():
                                    return True

                                if self.bsr_election_state is not None:
                                    return True

                                if self.bsr_mask_length is not None:
                                    return True

                                if self.bsr_priority is not None:
                                    return True

                                if self.bsr_scope is not None:
                                    return True

                                if self.bsr_up_time is not None:
                                    return True

                                if self.candidate_bsr_address is not None and self.candidate_bsr_address._has_data():
                                    return True

                                if self.candidate_bsr_flag is not None:
                                    return True

                                if self.candidate_bsr_mask_length is not None:
                                    return True

                                if self.candidate_bsr_priority is not None:
                                    return True

                                if self.candidate_bsr_state is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bsr-elections'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bsr_election is not None:
                                for child_ref in self.bsr_election:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bsr'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bsr_elections is not None and self.bsr_elections._has_data():
                            return True

                        if self.candidate_rps is not None and self.candidate_rps._has_data():
                            return True

                        if self.rp_caches is not None and self.rp_caches._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Bsr']['meta_info']


                class RoutePolicy(object):
                    """
                    PIM route policy
                    
                    .. attribute:: route_policy_statistics
                    
                    	PIM route policy statistics
                    	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics>`
                    
                    .. attribute:: route_policy_tests
                    
                    	PIM route policy test run table
                    	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.route_policy_statistics = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics()
                        self.route_policy_statistics.parent = self
                        self.route_policy_tests = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests()
                        self.route_policy_tests.parent = self


                    class RoutePolicyStatistics(object):
                        """
                        PIM route policy statistics
                        
                        .. attribute:: any_table
                        
                        	Number of RPF lookup in any Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Number of RPF lookup in default\-only Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: drop
                        
                        	Number of RPF drops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pass_
                        
                        	Number of RPF pass
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: requests
                        
                        	Number of RPF lookup requests
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.any_table = None
                            self.default_table = None
                            self.drop = None
                            self.pass_ = None
                            self.policy_name = None
                            self.requests = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:route-policy-statistics'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.any_table is not None:
                                return True

                            if self.default_table is not None:
                                return True

                            if self.drop is not None:
                                return True

                            if self.pass_ is not None:
                                return True

                            if self.policy_name is not None:
                                return True

                            if self.requests is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics']['meta_info']


                    class RoutePolicyTests(object):
                        """
                        PIM route policy test run table
                        
                        .. attribute:: route_policy_test
                        
                        	PIM route policy test run
                        	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.route_policy_test = YList()
                            self.route_policy_test.parent = self
                            self.route_policy_test.name = 'route_policy_test'


                        class RoutePolicyTest(object):
                            """
                            PIM route policy test run
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: default_table
                            
                            	Default table selected
                            	**type**\:  bool
                            
                            .. attribute:: ext_comm
                            
                            	Extended Community
                            	**type**\:  str
                            
                            	**length:** 1..8
                            
                            .. attribute:: extended_community_rt
                            
                            	Route Target
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: group_address
                            
                            	Group IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                            
                            .. attribute:: pass_
                            
                            	Pass
                            	**type**\:  bool
                            
                            .. attribute:: policy_name
                            
                            	RPF policy name
                            	**type**\:  str
                            
                            .. attribute:: safi
                            
                            	SAFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_address
                            
                            	Source IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                            
                            .. attribute:: table_active
                            
                            	Table active
                            	**type**\:  bool
                            
                            .. attribute:: table_exists
                            
                            	Table exists
                            	**type**\:  bool
                            
                            .. attribute:: table_name
                            
                            	Table name
                            	**type**\:  str
                            
                            .. attribute:: vrf_name
                            
                            	VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.afi = None
                                self.default_table = None
                                self.ext_comm = None
                                self.extended_community_rt = None
                                self.group_address = None
                                self.group_address_xr = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self.pass_ = None
                                self.policy_name = None
                                self.safi = None
                                self.source_address = None
                                self.source_address_xr = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self.table_active = None
                                self.table_exists = None
                                self.table_name = None
                                self.vrf_name = None


                            class SourceAddressXr(object):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr']['meta_info']


                            class GroupAddressXr(object):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:route-policy-test'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.afi is not None:
                                    return True

                                if self.default_table is not None:
                                    return True

                                if self.ext_comm is not None:
                                    return True

                                if self.extended_community_rt is not None:
                                    return True

                                if self.group_address is not None:
                                    return True

                                if self.group_address_xr is not None and self.group_address_xr._has_data():
                                    return True

                                if self.pass_ is not None:
                                    return True

                                if self.policy_name is not None:
                                    return True

                                if self.safi is not None:
                                    return True

                                if self.source_address is not None:
                                    return True

                                if self.source_address_xr is not None and self.source_address_xr._has_data():
                                    return True

                                if self.table_active is not None:
                                    return True

                                if self.table_exists is not None:
                                    return True

                                if self.table_name is not None:
                                    return True

                                if self.vrf_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:route-policy-tests'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.route_policy_test is not None:
                                for child_ref in self.route_policy_test:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:route-policy'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.route_policy_statistics is not None and self.route_policy_statistics._has_data():
                            return True

                        if self.route_policy_tests is not None and self.route_policy_tests._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy']['meta_info']


                class RpfSummary(object):
                    """
                    PIM RPF registration summary
                    
                    .. attribute:: default_safi
                    
                    	Default RPF Table SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table_name
                    
                    	Default RPF Table Name
                    	**type**\:  str
                    
                    .. attribute:: is_isis_mtr_configured
                    
                    	Is ISIS MTR configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_isis_te_configured
                    
                    	Is ISIS TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_mbgp_configured
                    
                    	Is MBGP configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_enabled
                    
                    	Is Multipath Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_interface_hash_enabled
                    
                    	Is Multipath Interface Hash Extension Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_hash_enabled
                    
                    	Is Multipath Source based Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_next_hop_hash_enabled
                    
                    	Is Multipath Source\-Nexthop Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ospf_te_configured
                    
                    	Is OSPF TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: mo_frr_configured
                    
                    	Is MoFRR configured?
                    	**type**\:  bool
                    
                    .. attribute:: rib_convergence_time_left
                    
                    	RIB convergence time left in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_convergence_timeout
                    
                    	RIB convergence timeout in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_mo_frr_configured
                    
                    	Is MoFRR RIB configured?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	Is RUMP MuRIB enabled?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.default_safi = None
                        self.default_table_name = None
                        self.is_isis_mtr_configured = None
                        self.is_isis_te_configured = None
                        self.is_mbgp_configured = None
                        self.is_multipath_enabled = None
                        self.is_multipath_interface_hash_enabled = None
                        self.is_multipath_source_hash_enabled = None
                        self.is_multipath_source_next_hop_hash_enabled = None
                        self.is_ospf_te_configured = None
                        self.is_rib_convergence = None
                        self.mo_frr_configured = None
                        self.rib_convergence_time_left = None
                        self.rib_convergence_timeout = None
                        self.rib_mo_frr_configured = None
                        self.rpf_registrations = None
                        self.rump_enabled = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.default_safi is not None:
                            return True

                        if self.default_table_name is not None:
                            return True

                        if self.is_isis_mtr_configured is not None:
                            return True

                        if self.is_isis_te_configured is not None:
                            return True

                        if self.is_mbgp_configured is not None:
                            return True

                        if self.is_multipath_enabled is not None:
                            return True

                        if self.is_multipath_interface_hash_enabled is not None:
                            return True

                        if self.is_multipath_source_hash_enabled is not None:
                            return True

                        if self.is_multipath_source_next_hop_hash_enabled is not None:
                            return True

                        if self.is_ospf_te_configured is not None:
                            return True

                        if self.is_rib_convergence is not None:
                            return True

                        if self.mo_frr_configured is not None:
                            return True

                        if self.rib_convergence_time_left is not None:
                            return True

                        if self.rib_convergence_timeout is not None:
                            return True

                        if self.rib_mo_frr_configured is not None:
                            return True

                        if self.rpf_registrations is not None:
                            return True

                        if self.rump_enabled is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.RpfSummary']['meta_info']


                class Interfaces(object):
                    """
                    PIM interfaces
                    
                    .. attribute:: interface
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface = YList()
                        self.interface.parent = self
                        self.interface.name = 'interface'


                    class Interface(object):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.configured_override_interval = None
                            self.configured_propagation_delay = None
                            self.dr_address = Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress()
                            self.dr_address.parent = self
                            self.dr_priority = None
                            self.external_neighbor_count = None
                            self.generation_id = None
                            self.hello_expiry = None
                            self.hello_interval = None
                            self.idb_acl_name = None
                            self.idb_acl_provided = None
                            self.idb_current_count = None
                            self.idb_max_count = None
                            self.idb_oor_enabled = None
                            self.idb_threshold_count = None
                            self.interface_address = YList()
                            self.interface_address.parent = self
                            self.interface_address.name = 'interface_address'
                            self.interface_address_mask = None
                            self.interface_name_xr = None
                            self.is_batch_asserts_capable = None
                            self.is_bidirectional_capable = None
                            self.is_enabled = None
                            self.is_proxy_capable = None
                            self.join_prune_interval = None
                            self.neighbor_count = None
                            self.neighbor_filter_name = None
                            self.override_interval = None
                            self.passive_interface = None
                            self.propagation_delay = None
                            self.prune_delay_enabled = None
                            self.virtual_interface = None


                        class DrAddress(object):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:dr-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress']['meta_info']


                        class InterfaceAddress(object):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.are_we_dr is not None:
                                return True

                            if self.bfd_enabled is not None:
                                return True

                            if self.bfd_interval is not None:
                                return True

                            if self.bfd_multiplier is not None:
                                return True

                            if self.configured_override_interval is not None:
                                return True

                            if self.configured_propagation_delay is not None:
                                return True

                            if self.dr_address is not None and self.dr_address._has_data():
                                return True

                            if self.dr_priority is not None:
                                return True

                            if self.external_neighbor_count is not None:
                                return True

                            if self.generation_id is not None:
                                return True

                            if self.hello_expiry is not None:
                                return True

                            if self.hello_interval is not None:
                                return True

                            if self.idb_acl_name is not None:
                                return True

                            if self.idb_acl_provided is not None:
                                return True

                            if self.idb_current_count is not None:
                                return True

                            if self.idb_max_count is not None:
                                return True

                            if self.idb_oor_enabled is not None:
                                return True

                            if self.idb_threshold_count is not None:
                                return True

                            if self.interface_address is not None:
                                for child_ref in self.interface_address:
                                    if child_ref._has_data():
                                        return True

                            if self.interface_address_mask is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.is_batch_asserts_capable is not None:
                                return True

                            if self.is_bidirectional_capable is not None:
                                return True

                            if self.is_enabled is not None:
                                return True

                            if self.is_proxy_capable is not None:
                                return True

                            if self.join_prune_interval is not None:
                                return True

                            if self.neighbor_count is not None:
                                return True

                            if self.neighbor_filter_name is not None:
                                return True

                            if self.override_interval is not None:
                                return True

                            if self.passive_interface is not None:
                                return True

                            if self.propagation_delay is not None:
                                return True

                            if self.prune_delay_enabled is not None:
                                return True

                            if self.virtual_interface is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interfaces'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface is not None:
                            for child_ref in self.interface:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Interfaces']['meta_info']


                class NetIoTunnels(object):
                    """
                    Tunnel information that NETIO has 
                    
                    .. attribute:: net_io_tunnel
                    
                    	PIM netio tunnel information
                    	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.net_io_tunnel = YList()
                        self.net_io_tunnel.parent = self
                        self.net_io_tunnel.name = 'net_io_tunnel'


                    class NetIoTunnel(object):
                        """
                        PIM netio tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.tunnel_name = None
                            self.group_address_netio = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress()
                            self.rp_address.parent = self
                            self.source_address = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress()
                            self.source_address.parent = self
                            self.source_address_netio = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self.vrf_name = None


                        class SourceAddress(object):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress']['meta_info']


                        class RpAddress(object):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress']['meta_info']


                        class SourceAddressNetio(object):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-netio'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio']['meta_info']


                        class GroupAddressNetio(object):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-netio'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.tunnel_name is None:
                                raise YPYModelError('Key property tunnel_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:net-io-tunnel[Cisco-IOS-XR-ipv4-pim-oper:tunnel-name = ' + str(self.tunnel_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.tunnel_name is not None:
                                return True

                            if self.group_address_netio is not None and self.group_address_netio._has_data():
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            if self.source_address is not None and self.source_address._has_data():
                                return True

                            if self.source_address_netio is not None and self.source_address_netio._has_data():
                                return True

                            if self.vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:net-io-tunnels'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.net_io_tunnel is not None:
                            for child_ref in self.net_io_tunnel:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels']['meta_info']


                class BidirDfStates(object):
                    """
                    Bidirectional PIM DF election state table
                    
                    .. attribute:: bidir_df_state
                    
                    	Bidirectional PIM DF Election Table Entry
                    	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bidir_df_state = YList()
                        self.bidir_df_state.parent = self
                        self.bidir_df_state.name = 'bidir_df_state'


                    class BidirDfState(object):
                        """
                        Bidirectional PIM DF Election Table Entry
                        
                        .. attribute:: election_state
                        
                        	DF Election State
                        	**type**\:  str
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: our_metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: our_metric_preference
                        
                        	MetricPreference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr>`
                        
                        .. attribute:: time_nano_seconds
                        
                        	Timer expires (nseconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: time_seconds
                        
                        	Timer expires (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.election_state = None
                            self.interface_name = None
                            self.our_metric = None
                            self.our_metric_preference = None
                            self.pim_interface_name = None
                            self.rp_address = None
                            self.rp_address_xr = Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self.time_nano_seconds = None
                            self.time_seconds = None


                        class RpAddressXr(object):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-state'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.election_state is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.our_metric is not None:
                                return True

                            if self.our_metric_preference is not None:
                                return True

                            if self.pim_interface_name is not None:
                                return True

                            if self.rp_address is not None:
                                return True

                            if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                                return True

                            if self.time_nano_seconds is not None:
                                return True

                            if self.time_seconds is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-states'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bidir_df_state is not None:
                            for child_ref in self.bidir_df_state:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates']['meta_info']


                class Topologies(object):
                    """
                    PIM topology table
                    
                    .. attribute:: topology
                    
                    	PIM topology information
                    	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.topology = YList()
                        self.topology.parent = self
                        self.topology.name = 'topology'


                    class Topology(object):
                        """
                        PIM topology information
                        
                        .. attribute:: alive
                        
                        	Alive time in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: anycast_rp_match
                        
                        	Group matches Anycast\-RP policy
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_route_target
                        
                        	Anycast\-RP RT
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: assume_alive
                        
                        	The Assume Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: bgp_join
                        
                        	BGP C JOIN
                        	**type**\:  bool
                        
                        .. attribute:: bgpjp_time
                        
                        	BGP C JP Time
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: connected
                        
                        	Is Connected ?
                        	**type**\:  bool
                        
                        .. attribute:: customer_routing_type
                        
                        	Type of Customer Routing in the MVPN
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: dont_check_connected
                        
                        	Do we need to make the connected check on this route ?
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	When this entry expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: extranet_route
                        
                        	Is a Extranet route ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr>`
                        
                        .. attribute:: inherit_alive
                        
                        	The Inherit Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: inherit_spt
                        
                        	The Inherit SPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: is_via_lsm
                        
                        	Via LSM
                        	**type**\:  bool
                        
                        .. attribute:: jp_status
                        
                        	Join\-Prune Status
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: limit_reached
                        
                        	Have we throttled the creation of routes or interfaces ?
                        	**type**\:  bool
                        
                        .. attribute:: low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_active
                        
                        	Is MoFRR Active?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_backup
                        
                        	Is this Mofrr Backup?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_primary
                        
                        	Is this Mofrr Primary?
                        	**type**\:  bool
                        
                        .. attribute:: orig_src_address
                        
                        	Orig Src Address
                        	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress>`
                        
                        .. attribute:: outgoing_interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface>`
                        
                        .. attribute:: probe_alive
                        
                        	The Probe Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                        
                        .. attribute:: proxy
                        
                        	Is the RPF target a proxy?
                        	**type**\:  bool
                        
                        .. attribute:: proxy_address
                        
                        	RPF Proxy address
                        	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress>`
                        
                        .. attribute:: really_alive
                        
                        	The Really Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: register_received
                        
                        	Have registers been received for this source ?
                        	**type**\:  bool
                        
                        .. attribute:: register_received_timer
                        
                        	Register Received Timer in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: remote_source
                        
                        	MSDP told us
                        	**type**\:  bool
                        
                        .. attribute:: rib_mo_frr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rp_address
                        
                        	RP Address (If rpt)
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor>`
                        
                        .. attribute:: rpf_proxy_enabled
                        
                        	Is rpf if proxy enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpt
                        
                        	RPT bit
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpt_xr
                        
                        	Is this on the RPT ?
                        	**type**\:  bool
                        
                        .. attribute:: sa_joined
                        
                        	BGP SA join
                        	**type**\:  bool
                        
                        .. attribute:: sa_received
                        
                        	BGP SA received
                        	**type**\:  bool
                        
                        .. attribute:: sa_sent
                        
                        	BGP SA sent
                        	**type**\:  bool
                        
                        .. attribute:: secondary_rpf_interface_name
                        
                        	Secondary Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: secondary_rpf_neighbor
                        
                        	Secondary RPF Neighbor
                        	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor>`
                        
                        .. attribute:: sending_null_registers
                        
                        	Are we sending null registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: sending_registers
                        
                        	Are we sending registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: signal_sources
                        
                        	Signal Sources on route?
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr>`
                        
                        .. attribute:: spt
                        
                        	Is this on the SPT ?
                        	**type**\:  bool
                        
                        .. attribute:: suppress_registers
                        
                        	When the Null register probe expires
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vxlan
                        
                        	Is this VXLAN?
                        	**type**\:  bool
                        
                        .. attribute:: wildcard
                        
                        	WC \-Wildcard
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.alive = None
                            self.anycast_rp_match = None
                            self.anycast_rp_route_target = None
                            self.assume_alive = None
                            self.bgp_join = None
                            self.bgpjp_time = None
                            self.connected = None
                            self.customer_routing_type = None
                            self.dont_check_connected = None
                            self.expiry = None
                            self.extranet_route = None
                            self.group_address = None
                            self.group_address_xr = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self.inherit_alive = None
                            self.inherit_spt = None
                            self.is_via_lsm = None
                            self.jp_status = None
                            self.jp_timer = None
                            self.last_hop = None
                            self.limit_reached = None
                            self.low_memory = None
                            self.mofrr_active = None
                            self.mofrr_backup = None
                            self.mofrr_enabled = None
                            self.mofrr_primary = None
                            self.orig_src_address = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress()
                            self.orig_src_address.parent = self
                            self.outgoing_interface = YList()
                            self.outgoing_interface.parent = self
                            self.outgoing_interface.name = 'outgoing_interface'
                            self.probe_alive = None
                            self.protocol = None
                            self.proxy = None
                            self.proxy_address = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress()
                            self.proxy_address.parent = self
                            self.really_alive = None
                            self.register_received = None
                            self.register_received_timer = None
                            self.remote_source = None
                            self.rib_mo_frr_enabled = None
                            self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress()
                            self.rp_address.parent = self
                            self.rpf_drop = None
                            self.rpf_extranet = None
                            self.rpf_interface_name = None
                            self.rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self.rpf_proxy_enabled = None
                            self.rpf_root = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot()
                            self.rpf_root.parent = self
                            self.rpf_safi = None
                            self.rpf_table_name = None
                            self.rpf_vrf_name = None
                            self.rpt = None
                            self.rpt_xr = None
                            self.sa_joined = None
                            self.sa_received = None
                            self.sa_sent = None
                            self.secondary_rpf_interface_name = None
                            self.secondary_rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor()
                            self.secondary_rpf_neighbor.parent = self
                            self.sending_null_registers = None
                            self.sending_registers = None
                            self.signal_sources = None
                            self.source_address = None
                            self.source_address_xr = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self.spt = None
                            self.suppress_registers = None
                            self.uptime = None
                            self.vxlan = None
                            self.wildcard = None


                        class GroupAddressXr(object):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr']['meta_info']


                        class SourceAddressXr(object):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr']['meta_info']


                        class RpAddress(object):
                            """
                            RP Address (If rpt)
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress']['meta_info']


                        class RpfNeighbor(object):
                            """
                            RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor']['meta_info']


                        class SecondaryRpfNeighbor(object):
                            """
                            Secondary RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:secondary-rpf-neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor']['meta_info']


                        class RpfRoot(object):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-root'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot']['meta_info']


                        class ProxyAddress(object):
                            """
                            RPF Proxy address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:proxy-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress']['meta_info']


                        class OrigSrcAddress(object):
                            """
                            Orig Src Address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:orig-src-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress']['meta_info']


                        class OutgoingInterface(object):
                            """
                            Outgoing interface list
                            
                            .. attribute:: admin_boundary
                            
                            	Is this an administrative boundary ?
                            	**type**\:  bool
                            
                            .. attribute:: assert_timer
                            
                            	Assert Timer in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: assert_winner
                            
                            	Assert Winner
                            	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner>`
                            
                            .. attribute:: bgp_c_mcast_join
                            
                            	BGP C\-Mcast join
                            	**type**\:  bool
                            
                            .. attribute:: bgp_c_mcast_prune_delay_timer
                            
                            	BGP C\-MCAST Prune Suppression in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: data_mdt_join
                            
                            	Data MDT join
                            	**type**\:  bool
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: extranet_interface
                            
                            	Is this an Extranet Interface ?
                            	**type**\:  bool
                            
                            .. attribute:: forwarding_state
                            
                            	Forward or Prune
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: igmp_membership
                            
                            	IGMP membership
                            	**type**\:  bool
                            
                            .. attribute:: immediate_state
                            
                            	Immediate fwding state
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: interface_name
                            
                            	Interface Identifier
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_interest_info
                            
                            	Internal Interest
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: jp_state
                            
                            	Join\-Prune State
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: jp_timer
                            
                            	Join\-Prune Timer (secs)
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: last_hop
                            
                            	Are we last hop ?
                            	**type**\:  bool
                            
                            .. attribute:: local_mdt_join
                            
                            	Default MDT Join
                            	**type**\:  bool
                            
                            .. attribute:: local_members
                            
                            	Local Information
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: mdt_safi_join
                            
                            	MDT Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mldp_inband_mdt
                            
                            	MLDP Inband MDT interface
                            	**type**\:  bool
                            
                            .. attribute:: mldp_stale
                            
                            	OLE is stale
                            	**type**\:  bool
                            
                            .. attribute:: mvp_nv6_safi_join
                            
                            	MVPN IPv6 Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mvpn_safi_join
                            
                            	MVPN Safi join
                            	**type**\:  bool
                            
                            .. attribute:: sa_prune
                            
                            	BGP SA Prune state
                            	**type**\:  bool
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: vrf_name
                            
                            	VRF which physically owns
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.admin_boundary = None
                                self.assert_timer = None
                                self.assert_winner = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner()
                                self.assert_winner.parent = self
                                self.bgp_c_mcast_join = None
                                self.bgp_c_mcast_prune_delay_timer = None
                                self.data_mdt_join = None
                                self.expiry = None
                                self.extranet_interface = None
                                self.forwarding_state = None
                                self.igmp_membership = None
                                self.immediate_state = None
                                self.interface_name = None
                                self.internal_interest_info = None
                                self.jp_state = None
                                self.jp_timer = None
                                self.last_hop = None
                                self.local_mdt_join = None
                                self.local_members = None
                                self.mdt_safi_join = None
                                self.mldp_inband_mdt = None
                                self.mldp_stale = None
                                self.mvp_nv6_safi_join = None
                                self.mvpn_safi_join = None
                                self.sa_prune = None
                                self.uptime = None
                                self.vrf_name = None


                            class AssertWinner(object):
                                """
                                Assert Winner
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:assert-winner'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:outgoing-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.admin_boundary is not None:
                                    return True

                                if self.assert_timer is not None:
                                    return True

                                if self.assert_winner is not None and self.assert_winner._has_data():
                                    return True

                                if self.bgp_c_mcast_join is not None:
                                    return True

                                if self.bgp_c_mcast_prune_delay_timer is not None:
                                    return True

                                if self.data_mdt_join is not None:
                                    return True

                                if self.expiry is not None:
                                    return True

                                if self.extranet_interface is not None:
                                    return True

                                if self.forwarding_state is not None:
                                    return True

                                if self.igmp_membership is not None:
                                    return True

                                if self.immediate_state is not None:
                                    return True

                                if self.interface_name is not None:
                                    return True

                                if self.internal_interest_info is not None:
                                    return True

                                if self.jp_state is not None:
                                    return True

                                if self.jp_timer is not None:
                                    return True

                                if self.last_hop is not None:
                                    return True

                                if self.local_mdt_join is not None:
                                    return True

                                if self.local_members is not None:
                                    return True

                                if self.mdt_safi_join is not None:
                                    return True

                                if self.mldp_inband_mdt is not None:
                                    return True

                                if self.mldp_stale is not None:
                                    return True

                                if self.mvp_nv6_safi_join is not None:
                                    return True

                                if self.mvpn_safi_join is not None:
                                    return True

                                if self.sa_prune is not None:
                                    return True

                                if self.uptime is not None:
                                    return True

                                if self.vrf_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.alive is not None:
                                return True

                            if self.anycast_rp_match is not None:
                                return True

                            if self.anycast_rp_route_target is not None:
                                return True

                            if self.assume_alive is not None:
                                return True

                            if self.bgp_join is not None:
                                return True

                            if self.bgpjp_time is not None:
                                return True

                            if self.connected is not None:
                                return True

                            if self.customer_routing_type is not None:
                                return True

                            if self.dont_check_connected is not None:
                                return True

                            if self.expiry is not None:
                                return True

                            if self.extranet_route is not None:
                                return True

                            if self.group_address is not None:
                                return True

                            if self.group_address_xr is not None and self.group_address_xr._has_data():
                                return True

                            if self.inherit_alive is not None:
                                return True

                            if self.inherit_spt is not None:
                                return True

                            if self.is_via_lsm is not None:
                                return True

                            if self.jp_status is not None:
                                return True

                            if self.jp_timer is not None:
                                return True

                            if self.last_hop is not None:
                                return True

                            if self.limit_reached is not None:
                                return True

                            if self.low_memory is not None:
                                return True

                            if self.mofrr_active is not None:
                                return True

                            if self.mofrr_backup is not None:
                                return True

                            if self.mofrr_enabled is not None:
                                return True

                            if self.mofrr_primary is not None:
                                return True

                            if self.orig_src_address is not None and self.orig_src_address._has_data():
                                return True

                            if self.outgoing_interface is not None:
                                for child_ref in self.outgoing_interface:
                                    if child_ref._has_data():
                                        return True

                            if self.probe_alive is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.proxy is not None:
                                return True

                            if self.proxy_address is not None and self.proxy_address._has_data():
                                return True

                            if self.really_alive is not None:
                                return True

                            if self.register_received is not None:
                                return True

                            if self.register_received_timer is not None:
                                return True

                            if self.remote_source is not None:
                                return True

                            if self.rib_mo_frr_enabled is not None:
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            if self.rpf_drop is not None:
                                return True

                            if self.rpf_extranet is not None:
                                return True

                            if self.rpf_interface_name is not None:
                                return True

                            if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                return True

                            if self.rpf_proxy_enabled is not None:
                                return True

                            if self.rpf_root is not None and self.rpf_root._has_data():
                                return True

                            if self.rpf_safi is not None:
                                return True

                            if self.rpf_table_name is not None:
                                return True

                            if self.rpf_vrf_name is not None:
                                return True

                            if self.rpt is not None:
                                return True

                            if self.rpt_xr is not None:
                                return True

                            if self.sa_joined is not None:
                                return True

                            if self.sa_received is not None:
                                return True

                            if self.sa_sent is not None:
                                return True

                            if self.secondary_rpf_interface_name is not None:
                                return True

                            if self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor._has_data():
                                return True

                            if self.sending_null_registers is not None:
                                return True

                            if self.sending_registers is not None:
                                return True

                            if self.signal_sources is not None:
                                return True

                            if self.source_address is not None:
                                return True

                            if self.source_address_xr is not None and self.source_address_xr._has_data():
                                return True

                            if self.spt is not None:
                                return True

                            if self.suppress_registers is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            if self.vxlan is not None:
                                return True

                            if self.wildcard is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topologies'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.topology is not None:
                            for child_ref in self.topology:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Topologies']['meta_info']


                class BgpAfs(object):
                    """
                    PIM BGP SAFI table
                    
                    .. attribute:: bgp_af
                    
                    	PIM BGP SAFI information
                    	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bgp_af = YList()
                        self.bgp_af.parent = self
                        self.bgp_af.name = 'bgp_af'


                    class BgpAf(object):
                        """
                        PIM BGP SAFI information
                        
                        .. attribute:: extranet_path_count
                        
                        	Count of dependent extranet paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group
                        
                        	Group address
                        	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group>`
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: is_bgp_added
                        
                        	SAFI learnt from BGP
                        	**type**\:  bool
                        
                        .. attribute:: next_hop
                        
                        	Next hop address
                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop>`
                        
                        .. attribute:: route_distinguisher
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**length:** 0..256
                        
                        .. attribute:: source
                        
                        	Source address
                        	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source>`
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.extranet_path_count = None
                            self.group = Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group()
                            self.group.parent = self
                            self.group_address = None
                            self.is_bgp_added = None
                            self.next_hop = Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop()
                            self.next_hop.parent = self
                            self.route_distinguisher = None
                            self.source = Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source()
                            self.source.parent = self
                            self.source_address = None


                        class Source(object):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source']['meta_info']


                        class Group(object):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group']['meta_info']


                        class NextHop(object):
                            """
                            Next hop address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:next-hop'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bgp-af'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.extranet_path_count is not None:
                                return True

                            if self.group is not None and self.group._has_data():
                                return True

                            if self.group_address is not None:
                                return True

                            if self.is_bgp_added is not None:
                                return True

                            if self.next_hop is not None and self.next_hop._has_data():
                                return True

                            if self.route_distinguisher is not None:
                                return True

                            if self.source is not None and self.source._has_data():
                                return True

                            if self.source_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bgp-afs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bgp_af is not None:
                            for child_ref in self.bgp_af:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.BgpAfs']['meta_info']


                class AutoRp(object):
                    """
                    PIM Auto\-RP information
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:auto-rp'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.AutoRp']['meta_info']


                class TopologyInterfaceFlagRouteCounts(object):
                    """
                    Route count for topology with interface flag set
                    
                    .. attribute:: topology_interface_flag_route_count
                    
                    	Route count for topology with interface flag set
                    	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.topology_interface_flag_route_count = YList()
                        self.topology_interface_flag_route_count.parent = self
                        self.topology_interface_flag_route_count.name = 'topology_interface_flag_route_count'


                    class TopologyInterfaceFlagRouteCount(object):
                        """
                        Route count for topology with interface flag
                        set
                        
                        .. attribute:: interface_flag  <key>
                        
                        	Interface flag
                        	**type**\:   :py:class:`PimTopologyInterfaceFlagEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlagEnum>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_flag = None
                            self.active_group_ranges = None
                            self.group_address = Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                            self.group_address.parent = self
                            self.group_ranges = None
                            self.groute_count = None
                            self.is_node_low_memory = None
                            self.sg_route_count = None
                            self.sgr_route_count = None


                        class GroupAddress(object):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_flag is None:
                                raise YPYModelError('Key property interface_flag is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology-interface-flag-route-count[Cisco-IOS-XR-ipv4-pim-oper:interface-flag = ' + str(self.interface_flag) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_flag is not None:
                                return True

                            if self.active_group_ranges is not None:
                                return True

                            if self.group_address is not None and self.group_address._has_data():
                                return True

                            if self.group_ranges is not None:
                                return True

                            if self.groute_count is not None:
                                return True

                            if self.is_node_low_memory is not None:
                                return True

                            if self.sg_route_count is not None:
                                return True

                            if self.sgr_route_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology-interface-flag-route-counts'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.topology_interface_flag_route_count is not None:
                            for child_ref in self.topology_interface_flag_route_count:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts']['meta_info']


                class GroupMapSources(object):
                    """
                    PIM group\-mapping with source information
                    
                    .. attribute:: group_map_source
                    
                    	PIM Group Mapping Entry with source information
                    	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_map_source = YList()
                        self.group_map_source.parent = self
                        self.group_map_source.name = 'group_map_source'


                    class GroupMapSource(object):
                        """
                        PIM Group Mapping Entry with source information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                        
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	RP Priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.client = None
                            self.expires = None
                            self.group_map_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self.holdtime = None
                            self.prefix = None
                            self.prefix_length = None
                            self.priority = None
                            self.protocol = None
                            self.rp_address = None
                            self.source_of_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self.uptime = None


                        class SourceOfInformation(object):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation']['meta_info']


                        class GroupMapInformation(object):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.client = None
                                self.group_count = None
                                self.is_override = None
                                self.is_used = None
                                self.mrib_active = None
                                self.prefix = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self.prefix_length = None
                                self.priority = None
                                self.protocol = None
                                self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self


                            class Prefix(object):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix']['meta_info']


                            class RpAddress(object):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.client is not None:
                                    return True

                                if self.group_count is not None:
                                    return True

                                if self.is_override is not None:
                                    return True

                                if self.is_used is not None:
                                    return True

                                if self.mrib_active is not None:
                                    return True

                                if self.prefix is not None and self.prefix._has_data():
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.priority is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.rp_address is not None and self.rp_address._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-source'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.client is not None:
                                return True

                            if self.expires is not None:
                                return True

                            if self.group_map_information is not None and self.group_map_information._has_data():
                                return True

                            if self.holdtime is not None:
                                return True

                            if self.prefix is not None:
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None:
                                return True

                            if self.source_of_information is not None and self.source_of_information._has_data():
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-sources'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_map_source is not None:
                            for child_ref in self.group_map_source:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources']['meta_info']


                class TrafficCounters(object):
                    """
                    PIM message traffic counters
                    
                    .. attribute:: boundary_acl_rx_drop
                    
                    	Inc. JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: boundary_acl_tx_drop
                    
                    	Out JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_error
                    
                    	Checksum errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: format_error
                    
                    	Malformed packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert_batched
                    
                    	Batched Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_data_register
                    
                    	Data Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_ecmp_redirect
                    
                    	Input Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb_error
                    
                    	No IDB for intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_pim_error
                    
                    	PIM Disabled on intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_error
                    
                    	No VRF for idb error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_null_register
                    
                    	Null Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim_version_error
                    
                    	Invalid PIM version error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: inputs
                    
                    	Packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_destination_packets
                    
                    	Control Packets with Invalid Destination
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_join_prunes
                    
                    	PIM invalid Join/Prunes received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_registers
                    
                    	PIM invalid registers received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_local_source_address
                    
                    	Data MDT Join msgs dropped due to local source addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_idb
                    
                    	Data MDT Join msgs dropped due to idb missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_vrf
                    
                    	Data MDT Join msgs dropped due to vrf missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_null_local_address
                    
                    	Data MDT Join msgs dropped due to null local addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_bad_type
                    
                    	Data MDT TLV bad type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_received
                    
                    	Data MDT Join Msgs received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_sent
                    
                    	Data MDT Join Msgs sent
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_joins_drop_multiple_encapsulation
                    
                    	MDT Join msgs dropped due to multiple Encap limitation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_send_queue_full
                    
                    	Packets dropped since mdt send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_socket_error
                    
                    	MDT Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_invalid_lsm_identifier
                    
                    	 Invalid LSM ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_mdt_socket_connection
                    
                    	Packets dropped since no mdt socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_source_address
                    
                    	Packets dropped since no source address
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: non_supported_packets
                    
                    	PIM non supported pckets
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert_batched
                    
                    	Batched Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_data_register
                    
                    	Data Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_ecmp_redirect
                    
                    	Output Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello_bytes
                    
                    	Output Hello Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_join_group
                    
                    	Output Join Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_join_prune_bytes
                    
                    	Output JP Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_loop_error
                    
                    	Output on loopback error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_null_register
                    
                    	Null Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_prune_group
                    
                    	Output Prune Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: outputs
                    
                    	Packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_dequeued
                    
                    	Packets Dequeued per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_enqueued
                    
                    	Packets Enqueued per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_packman_error
                    
                    	Packets Dropped due to Pakman Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue
                    
                    	Packet queue state and statistics
                    	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue>`
                    
                    .. attribute:: packet_queue_last_clear
                    
                    	Time in seconds since the last clear of all packet queues stats
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: packet_queue_length
                    
                    	Packet Queue Length per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_size
                    
                    	Packet Queue Size per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_read_socket_error
                    
                    	Packet Read Socket Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_tail_drop
                    
                    	Packet Tail Drop per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_standby
                    
                    	Packets Dropped due to Standby Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pakman_error
                    
                    	Pakman packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: send_queue_full
                    
                    	Packets dropped since send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_error
                    
                    	Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: standby_packets_error
                    
                    	Packets received in standby state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: truncated_pim_packets
                    
                    	Packets dropped due to truncated Joins or Prunes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.boundary_acl_rx_drop = None
                        self.boundary_acl_tx_drop = None
                        self.checksum_error = None
                        self.elapsed_time = None
                        self.format_error = None
                        self.input_assert = None
                        self.input_assert_batched = None
                        self.input_bsr_message = None
                        self.input_candidate_rp_advertisement = None
                        self.input_data_register = None
                        self.input_df_election = None
                        self.input_ecmp_redirect = None
                        self.input_hello = None
                        self.input_jp = None
                        self.input_no_idb_error = None
                        self.input_no_pim_error = None
                        self.input_no_vrf_error = None
                        self.input_null_register = None
                        self.input_pim_version_error = None
                        self.input_register_stop = None
                        self.inputs = None
                        self.invalid_destination_packets = None
                        self.invalid_join_prunes = None
                        self.invalid_registers = None
                        self.mdt_drop_local_source_address = None
                        self.mdt_drop_no_idb = None
                        self.mdt_drop_no_vrf = None
                        self.mdt_drop_null_local_address = None
                        self.mdt_join_bad_type = None
                        self.mdt_join_tlv_received = None
                        self.mdt_join_tlv_sent = None
                        self.mdt_joins_drop_multiple_encapsulation = None
                        self.mdt_send_queue_full = None
                        self.mdt_socket_error = None
                        self.mldp_mdt_invalid_lsm_identifier = None
                        self.no_mdt_socket_connection = None
                        self.no_socket_connection = None
                        self.no_source_address = None
                        self.non_supported_packets = None
                        self.output_assert = None
                        self.output_assert_batched = None
                        self.output_bsr_message = None
                        self.output_candidate_rp_advertisement = None
                        self.output_data_register = None
                        self.output_df_election = None
                        self.output_ecmp_redirect = None
                        self.output_hello = None
                        self.output_hello_bytes = None
                        self.output_join_group = None
                        self.output_join_prune_bytes = None
                        self.output_jp = None
                        self.output_loop_error = None
                        self.output_null_register = None
                        self.output_prune_group = None
                        self.output_register_stop = None
                        self.outputs = None
                        self.packet_dequeued = YLeafList()
                        self.packet_dequeued.parent = self
                        self.packet_dequeued.name = 'packet_dequeued'
                        self.packet_enqueued = YLeafList()
                        self.packet_enqueued.parent = self
                        self.packet_enqueued.name = 'packet_enqueued'
                        self.packet_packman_error = None
                        self.packet_queue = YList()
                        self.packet_queue.parent = self
                        self.packet_queue.name = 'packet_queue'
                        self.packet_queue_last_clear = None
                        self.packet_queue_length = YLeafList()
                        self.packet_queue_length.parent = self
                        self.packet_queue_length.name = 'packet_queue_length'
                        self.packet_queue_size = YLeafList()
                        self.packet_queue_size.parent = self
                        self.packet_queue_size.name = 'packet_queue_size'
                        self.packet_read_socket_error = None
                        self.packet_tail_drop = YLeafList()
                        self.packet_tail_drop.parent = self
                        self.packet_tail_drop.name = 'packet_tail_drop'
                        self.packets_standby = None
                        self.pakman_error = None
                        self.send_queue_full = None
                        self.socket_error = None
                        self.standby_packets_error = None
                        self.truncated_pim_packets = None


                    class PacketQueue(object):
                        """
                        Packet queue state and statistics
                        
                        .. attribute:: packet_queue_priority
                        
                        	Priority of this packet queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: packet_queue_state
                        
                        	State of the queue
                        	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState>`
                        
                        .. attribute:: packet_queue_stats
                        
                        	Statistics about the queue
                        	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.packet_queue_priority = None
                            self.packet_queue_state = Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState()
                            self.packet_queue_state.parent = self
                            self.packet_queue_stats = Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats()
                            self.packet_queue_stats.parent = self


                        class PacketQueueState(object):
                            """
                            State of the queue
                            
                            .. attribute:: max_queue_size
                            
                            	Maximum size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_bytes
                            
                            	Size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_packets
                            
                            	Size of queue in number of packets
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.max_queue_size = None
                                self.queue_size_bytes = None
                                self.queue_size_packets = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:packet-queue-state'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.max_queue_size is not None:
                                    return True

                                if self.queue_size_bytes is not None:
                                    return True

                                if self.queue_size_packets is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState']['meta_info']


                        class PacketQueueStats(object):
                            """
                            Statistics about the queue
                            
                            .. attribute:: dequeued_packets
                            
                            	Total number of packets dequeued from this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: enqueued_packets
                            
                            	Total number of packets enqueued to this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high_water_mark_bytes
                            
                            	Highest number of bytes enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: high_water_mark_packets
                            
                            	Highest number of packets enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tail_drops
                            
                            	Number packets dropped from this queue due to max size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dequeued_packets = None
                                self.enqueued_packets = None
                                self.high_water_mark_bytes = None
                                self.high_water_mark_packets = None
                                self.tail_drops = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:packet-queue-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dequeued_packets is not None:
                                    return True

                                if self.enqueued_packets is not None:
                                    return True

                                if self.high_water_mark_bytes is not None:
                                    return True

                                if self.high_water_mark_packets is not None:
                                    return True

                                if self.tail_drops is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:packet-queue'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.packet_queue_priority is not None:
                                return True

                            if self.packet_queue_state is not None and self.packet_queue_state._has_data():
                                return True

                            if self.packet_queue_stats is not None and self.packet_queue_stats._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:traffic-counters'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.boundary_acl_rx_drop is not None:
                            return True

                        if self.boundary_acl_tx_drop is not None:
                            return True

                        if self.checksum_error is not None:
                            return True

                        if self.elapsed_time is not None:
                            return True

                        if self.format_error is not None:
                            return True

                        if self.input_assert is not None:
                            return True

                        if self.input_assert_batched is not None:
                            return True

                        if self.input_bsr_message is not None:
                            return True

                        if self.input_candidate_rp_advertisement is not None:
                            return True

                        if self.input_data_register is not None:
                            return True

                        if self.input_df_election is not None:
                            return True

                        if self.input_ecmp_redirect is not None:
                            return True

                        if self.input_hello is not None:
                            return True

                        if self.input_jp is not None:
                            return True

                        if self.input_no_idb_error is not None:
                            return True

                        if self.input_no_pim_error is not None:
                            return True

                        if self.input_no_vrf_error is not None:
                            return True

                        if self.input_null_register is not None:
                            return True

                        if self.input_pim_version_error is not None:
                            return True

                        if self.input_register_stop is not None:
                            return True

                        if self.inputs is not None:
                            return True

                        if self.invalid_destination_packets is not None:
                            return True

                        if self.invalid_join_prunes is not None:
                            return True

                        if self.invalid_registers is not None:
                            return True

                        if self.mdt_drop_local_source_address is not None:
                            return True

                        if self.mdt_drop_no_idb is not None:
                            return True

                        if self.mdt_drop_no_vrf is not None:
                            return True

                        if self.mdt_drop_null_local_address is not None:
                            return True

                        if self.mdt_join_bad_type is not None:
                            return True

                        if self.mdt_join_tlv_received is not None:
                            return True

                        if self.mdt_join_tlv_sent is not None:
                            return True

                        if self.mdt_joins_drop_multiple_encapsulation is not None:
                            return True

                        if self.mdt_send_queue_full is not None:
                            return True

                        if self.mdt_socket_error is not None:
                            return True

                        if self.mldp_mdt_invalid_lsm_identifier is not None:
                            return True

                        if self.no_mdt_socket_connection is not None:
                            return True

                        if self.no_socket_connection is not None:
                            return True

                        if self.no_source_address is not None:
                            return True

                        if self.non_supported_packets is not None:
                            return True

                        if self.output_assert is not None:
                            return True

                        if self.output_assert_batched is not None:
                            return True

                        if self.output_bsr_message is not None:
                            return True

                        if self.output_candidate_rp_advertisement is not None:
                            return True

                        if self.output_data_register is not None:
                            return True

                        if self.output_df_election is not None:
                            return True

                        if self.output_ecmp_redirect is not None:
                            return True

                        if self.output_hello is not None:
                            return True

                        if self.output_hello_bytes is not None:
                            return True

                        if self.output_join_group is not None:
                            return True

                        if self.output_join_prune_bytes is not None:
                            return True

                        if self.output_jp is not None:
                            return True

                        if self.output_loop_error is not None:
                            return True

                        if self.output_null_register is not None:
                            return True

                        if self.output_prune_group is not None:
                            return True

                        if self.output_register_stop is not None:
                            return True

                        if self.outputs is not None:
                            return True

                        if self.packet_dequeued is not None:
                            for child in self.packet_dequeued:
                                if child is not None:
                                    return True

                        if self.packet_enqueued is not None:
                            for child in self.packet_enqueued:
                                if child is not None:
                                    return True

                        if self.packet_packman_error is not None:
                            return True

                        if self.packet_queue is not None:
                            for child_ref in self.packet_queue:
                                if child_ref._has_data():
                                    return True

                        if self.packet_queue_last_clear is not None:
                            return True

                        if self.packet_queue_length is not None:
                            for child in self.packet_queue_length:
                                if child is not None:
                                    return True

                        if self.packet_queue_size is not None:
                            for child in self.packet_queue_size:
                                if child is not None:
                                    return True

                        if self.packet_read_socket_error is not None:
                            return True

                        if self.packet_tail_drop is not None:
                            for child in self.packet_tail_drop:
                                if child is not None:
                                    return True

                        if self.packets_standby is not None:
                            return True

                        if self.pakman_error is not None:
                            return True

                        if self.send_queue_full is not None:
                            return True

                        if self.socket_error is not None:
                            return True

                        if self.standby_packets_error is not None:
                            return True

                        if self.truncated_pim_packets is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters']['meta_info']


                class GroupMapRpfs(object):
                    """
                    PIM group mapping information
                    
                    .. attribute:: group_map_rpf
                    
                    	PIM group mapping entry
                    	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_map_rpf = YList()
                        self.group_map_rpf.parent = self
                        self.group_map_rpf.name = 'group_map_rpf'


                    class GroupMapRpf(object):
                        """
                        PIM group mapping entry
                        
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\:  bool
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClientEnum>`
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocolEnum>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_priority
                        
                        	RP priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.are_we_rp = None
                            self.client = None
                            self.group_map_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self.prefix = None
                            self.prefix_length = None
                            self.protocol = None
                            self.rp_address = None
                            self.rp_priority = None
                            self.rpf_interface_name = None
                            self.rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self.rpf_vrf_name = None


                        class RpfNeighbor(object):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor']['meta_info']


                        class GroupMapInformation(object):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.client = None
                                self.group_count = None
                                self.is_override = None
                                self.is_used = None
                                self.mrib_active = None
                                self.prefix = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self.prefix_length = None
                                self.priority = None
                                self.protocol = None
                                self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self


                            class Prefix(object):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix']['meta_info']


                            class RpAddress(object):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.client is not None:
                                    return True

                                if self.group_count is not None:
                                    return True

                                if self.is_override is not None:
                                    return True

                                if self.is_used is not None:
                                    return True

                                if self.mrib_active is not None:
                                    return True

                                if self.prefix is not None and self.prefix._has_data():
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.priority is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.rp_address is not None and self.rp_address._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpf'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.are_we_rp is not None:
                                return True

                            if self.client is not None:
                                return True

                            if self.group_map_information is not None and self.group_map_information._has_data():
                                return True

                            if self.prefix is not None:
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.rp_address is not None:
                                return True

                            if self.rp_priority is not None:
                                return True

                            if self.rpf_interface_name is not None:
                                return True

                            if self.rpf_neighbor is not None and self.rpf_neighbor._has_data():
                                return True

                            if self.rpf_vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-rpfs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_map_rpf is not None:
                            for child_ref in self.group_map_rpf:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs']['meta_info']


                class Summary(object):
                    """
                    PIM summary
                    
                    .. attribute:: bsr_candidate_rp_set_count
                    
                    	Current crp\-set count from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_limit
                    
                    	Maximum crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_threshold
                    
                    	Threshold crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_range_threshold
                    
                    	Threshold group range from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_count
                    
                    	Current group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_limit
                    
                    	Maximum group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_auto_rp_ranges_limit
                    
                    	Global Auto\-RP maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_count
                    
                    	Global BSR current crp\-set count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_limit
                    
                    	Global BSR maximum crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_threshold
                    
                    	Global BSR Threshold crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_count
                    
                    	Global BSR current group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_limit
                    
                    	Global BSR maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_threshold
                    
                    	Global BSR Threshold group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_register_limit
                    
                    	Maximum global registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bsr_ranges_threshold_reached
                    
                    	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_auto_rp_ranges_limit_reached
                    
                    	Is global AutoRP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_bsr_ranges_limit_reached
                    
                    	Is global BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_register_limit_reached
                    
                    	Is global PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_route_limit_reached
                    
                    	Is global route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_rxi_limit_reached
                    
                    	Is global interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_maximum_enforcement_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\:  bool
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: is_ranges_limit_reached
                    
                    	Is Auto\-RP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_route_limit_reached
                    
                    	Is route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: ranges_count
                    
                    	Current group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_limit
                    
                    	Maximum group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_threshold
                    
                    	OOR theshold of grange ranges from AutoRP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_count
                    
                    	Current registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit
                    
                    	Maximum registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit_reached
                    
                    	Is PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: register_threshold
                    
                    	Threshold registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_count
                    
                    	Current routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_limit
                    
                    	Maximum routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_low_water_mark
                    
                    	The number of routes below which the throttle on route creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_threshold
                    
                    	Threshold routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rxi_limit_reached
                    
                    	Is interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: rxi_low_water_mark
                    
                    	The rxi below which the throttle on interface creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_count
                    
                    	Current Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_limit
                    
                    	Maximum Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_threshold
                    
                    	Topology Interface State threshold
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bsr_candidate_rp_set_count = None
                        self.bsr_candidate_rp_set_limit = None
                        self.bsr_candidate_rp_set_threshold = None
                        self.bsr_range_threshold = None
                        self.bsr_ranges_count = None
                        self.bsr_ranges_limit = None
                        self.global_auto_rp_ranges_limit = None
                        self.global_bsr_candidate_rp_set_count = None
                        self.global_bsr_candidate_rp_set_limit = None
                        self.global_bsr_candidate_rp_set_threshold = None
                        self.global_bsr_ranges_count = None
                        self.global_bsr_ranges_limit = None
                        self.global_bsr_ranges_threshold = None
                        self.global_register_limit = None
                        self.is_bsr_ranges_threshold_reached = None
                        self.is_global_auto_rp_ranges_limit_reached = None
                        self.is_global_bsr_ranges_limit_reached = None
                        self.is_global_register_limit_reached = None
                        self.is_global_route_limit_reached = None
                        self.is_global_rxi_limit_reached = None
                        self.is_maximum_enforcement_disabled = None
                        self.is_node_low_memory = None
                        self.is_ranges_limit_reached = None
                        self.is_route_limit_reached = None
                        self.ranges_count = None
                        self.ranges_limit = None
                        self.ranges_threshold = None
                        self.register_count = None
                        self.register_limit = None
                        self.register_limit_reached = None
                        self.register_threshold = None
                        self.route_count = None
                        self.route_limit = None
                        self.route_low_water_mark = None
                        self.route_threshold = None
                        self.rxi_limit_reached = None
                        self.rxi_low_water_mark = None
                        self.topology_interface_state_count = None
                        self.topology_interface_state_limit = None
                        self.topology_interface_state_threshold = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bsr_candidate_rp_set_count is not None:
                            return True

                        if self.bsr_candidate_rp_set_limit is not None:
                            return True

                        if self.bsr_candidate_rp_set_threshold is not None:
                            return True

                        if self.bsr_range_threshold is not None:
                            return True

                        if self.bsr_ranges_count is not None:
                            return True

                        if self.bsr_ranges_limit is not None:
                            return True

                        if self.global_auto_rp_ranges_limit is not None:
                            return True

                        if self.global_bsr_candidate_rp_set_count is not None:
                            return True

                        if self.global_bsr_candidate_rp_set_limit is not None:
                            return True

                        if self.global_bsr_candidate_rp_set_threshold is not None:
                            return True

                        if self.global_bsr_ranges_count is not None:
                            return True

                        if self.global_bsr_ranges_limit is not None:
                            return True

                        if self.global_bsr_ranges_threshold is not None:
                            return True

                        if self.global_register_limit is not None:
                            return True

                        if self.is_bsr_ranges_threshold_reached is not None:
                            return True

                        if self.is_global_auto_rp_ranges_limit_reached is not None:
                            return True

                        if self.is_global_bsr_ranges_limit_reached is not None:
                            return True

                        if self.is_global_register_limit_reached is not None:
                            return True

                        if self.is_global_route_limit_reached is not None:
                            return True

                        if self.is_global_rxi_limit_reached is not None:
                            return True

                        if self.is_maximum_enforcement_disabled is not None:
                            return True

                        if self.is_node_low_memory is not None:
                            return True

                        if self.is_ranges_limit_reached is not None:
                            return True

                        if self.is_route_limit_reached is not None:
                            return True

                        if self.ranges_count is not None:
                            return True

                        if self.ranges_limit is not None:
                            return True

                        if self.ranges_threshold is not None:
                            return True

                        if self.register_count is not None:
                            return True

                        if self.register_limit is not None:
                            return True

                        if self.register_limit_reached is not None:
                            return True

                        if self.register_threshold is not None:
                            return True

                        if self.route_count is not None:
                            return True

                        if self.route_limit is not None:
                            return True

                        if self.route_low_water_mark is not None:
                            return True

                        if self.route_threshold is not None:
                            return True

                        if self.rxi_limit_reached is not None:
                            return True

                        if self.rxi_low_water_mark is not None:
                            return True

                        if self.topology_interface_state_count is not None:
                            return True

                        if self.topology_interface_state_limit is not None:
                            return True

                        if self.topology_interface_state_threshold is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Summary']['meta_info']


                class Gre(object):
                    """
                    GRE information
                    
                    .. attribute:: gre_hashes
                    
                    	GRE hash
                    	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes>`
                    
                    .. attribute:: gre_next_hops
                    
                    	GRE destination neighbor table
                    	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.gre_hashes = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes()
                        self.gre_hashes.parent = self
                        self.gre_next_hops = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops()
                        self.gre_next_hops.parent = self


                    class GreHashes(object):
                        """
                        GRE hash
                        
                        .. attribute:: gre_hash
                        
                        	PIM GRE Hashed Underlying Interface
                        	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.gre_hash = YList()
                            self.gre_hash.parent = self
                            self.gre_hash.name = 'gre_hash'


                        class GreHash(object):
                            """
                            PIM GRE Hashed Underlying Interface
                            
                            .. attribute:: destination_address  <key>
                            
                            	Destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: ifname  <key>
                            
                            	GRE Tunnel Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_address  <key>
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.destination_address = None
                                self.ifname = None
                                self.source_address = None
                                self.next_hop_interface = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.destination_address is None:
                                    raise YPYModelError('Key property destination_address is None')
                                if self.ifname is None:
                                    raise YPYModelError('Key property ifname is None')
                                if self.source_address is None:
                                    raise YPYModelError('Key property source_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-hash[Cisco-IOS-XR-ipv4-pim-oper:destination-address = ' + str(self.destination_address) + '][Cisco-IOS-XR-ipv4-pim-oper:ifname = ' + str(self.ifname) + '][Cisco-IOS-XR-ipv4-pim-oper:source-address = ' + str(self.source_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.destination_address is not None:
                                    return True

                                if self.ifname is not None:
                                    return True

                                if self.source_address is not None:
                                    return True

                                if self.next_hop_interface is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-hashes'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.gre_hash is not None:
                                for child_ref in self.gre_hash:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes']['meta_info']


                    class GreNextHops(object):
                        """
                        GRE destination neighbor table
                        
                        .. attribute:: gre_next_hop
                        
                        	PIM GRE address next\-hop information
                        	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.gre_next_hop = YList()
                            self.gre_next_hop.parent = self
                            self.gre_next_hop.name = 'gre_next_hop'


                        class GreNextHop(object):
                            """
                            PIM GRE address next\-hop information
                            
                            .. attribute:: destination_address  <key>
                            
                            	GRE destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: gre_path
                            
                            	GRE Paths list
                            	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath>`
                            
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.destination_address = None
                                self.gre_path = YList()
                                self.gre_path.parent = self
                                self.gre_path.name = 'gre_path'
                                self.is_connected = None
                                self.metric = None
                                self.metric_preference = None
                                self.registered_address = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                self.registered_address.parent = self


                            class RegisteredAddress(object):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:registered-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress']['meta_info']


                            class GrePath(object):
                                """
                                GRE Paths list
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: gre_interface_name
                                
                                	GRE Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: gre_neighbor
                                
                                	GRE neighbor
                                	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                                
                                .. attribute:: gre_next_hop
                                
                                	GRE nexthop
                                	**type**\:   :py:class:`GreNextHop_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_>`
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_gre_interface_disabled
                                
                                	Is the gre interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.extranet_vrf_name = None
                                    self.gre_interface_name = None
                                    self.gre_neighbor = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                    self.gre_neighbor.parent = self
                                    self.gre_next_hop = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_()
                                    self.gre_next_hop.parent = self
                                    self.is_connector_attribute_present = None
                                    self.is_gre_interface_disabled = None
                                    self.is_via_lsm = None


                                class GreNeighbor(object):
                                    """
                                    GRE neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-neighbor'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor']['meta_info']


                                class GreNextHop_(object):
                                    """
                                    GRE nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.extranet_vrf_name is not None:
                                        return True

                                    if self.gre_interface_name is not None:
                                        return True

                                    if self.gre_neighbor is not None and self.gre_neighbor._has_data():
                                        return True

                                    if self.gre_next_hop is not None and self.gre_next_hop._has_data():
                                        return True

                                    if self.is_connector_attribute_present is not None:
                                        return True

                                    if self.is_gre_interface_disabled is not None:
                                        return True

                                    if self.is_via_lsm is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.destination_address is None:
                                    raise YPYModelError('Key property destination_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hop[Cisco-IOS-XR-ipv4-pim-oper:destination-address = ' + str(self.destination_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.destination_address is not None:
                                    return True

                                if self.gre_path is not None:
                                    for child_ref in self.gre_path:
                                        if child_ref._has_data():
                                            return True

                                if self.is_connected is not None:
                                    return True

                                if self.metric is not None:
                                    return True

                                if self.metric_preference is not None:
                                    return True

                                if self.registered_address is not None and self.registered_address._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre-next-hops'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.gre_next_hop is not None:
                                for child_ref in self.gre_next_hop:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:gre'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.gre_hashes is not None and self.gre_hashes._has_data():
                            return True

                        if self.gre_next_hops is not None and self.gre_next_hops._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Gre']['meta_info']


                class BidirDfWinners(object):
                    """
                    Bidirectional PIM DF election winner table
                    
                    .. attribute:: bidir_df_winner
                    
                    	Bidirectional PIM DF election table entry
                    	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bidir_df_winner = YList()
                        self.bidir_df_winner.parent = self
                        self.bidir_df_winner.name = 'bidir_df_winner'


                    class BidirDfWinner(object):
                        """
                        Bidirectional PIM DF election table entry
                        
                        .. attribute:: are_we_df
                        
                        	Are we DF
                        	**type**\:  bool
                        
                        .. attribute:: df_winner
                        
                        	DF Winner
                        	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner>`
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                        
                        .. attribute:: rp_lan
                        
                        	Is this the RP LAN
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.are_we_df = None
                            self.df_winner = Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner()
                            self.df_winner.parent = self
                            self.interface_name = None
                            self.metric = None
                            self.metric_preference = None
                            self.pim_interface_name = None
                            self.rp_address = None
                            self.rp_address_xr = Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self.rp_lan = None
                            self.uptime = None


                        class RpAddressXr(object):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr']['meta_info']


                        class DfWinner(object):
                            """
                            DF Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:df-winner'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winner'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.are_we_df is not None:
                                return True

                            if self.df_winner is not None and self.df_winner._has_data():
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.metric is not None:
                                return True

                            if self.metric_preference is not None:
                                return True

                            if self.pim_interface_name is not None:
                                return True

                            if self.rp_address is not None:
                                return True

                            if self.rp_address_xr is not None and self.rp_address_xr._has_data():
                                return True

                            if self.rp_lan is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bidir-df-winners'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bidir_df_winner is not None:
                            for child_ref in self.bidir_df_winner:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners']['meta_info']


                class TableContexts(object):
                    """
                    PIM table context list
                    
                    .. attribute:: table_context
                    
                    	PIM table context information
                    	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TableContexts.TableContext>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.table_context = YList()
                        self.table_context.parent = self
                        self.table_context.name = 'table_context'


                    class TableContext(object):
                        """
                        PIM table context information
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: saf_name
                        
                        	SAF name
                        	**type**\:   :py:class:`PimSafiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafiEnum>`
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: topology_name
                        
                        	Topology name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.afi = None
                            self.is_active = None
                            self.is_ital_registration_done = None
                            self.is_rib_convergence = None
                            self.is_rib_convergence_received = None
                            self.is_rib_registration_done = None
                            self.rpf_registrations = None
                            self.saf_name = None
                            self.safi = None
                            self.table_id = None
                            self.table_name = None
                            self.topology_name = None
                            self.vrf_id = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:table-context'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.afi is not None:
                                return True

                            if self.is_active is not None:
                                return True

                            if self.is_ital_registration_done is not None:
                                return True

                            if self.is_rib_convergence is not None:
                                return True

                            if self.is_rib_convergence_received is not None:
                                return True

                            if self.is_rib_registration_done is not None:
                                return True

                            if self.rpf_registrations is not None:
                                return True

                            if self.saf_name is not None:
                                return True

                            if self.safi is not None:
                                return True

                            if self.table_id is not None:
                                return True

                            if self.table_name is not None:
                                return True

                            if self.topology_name is not None:
                                return True

                            if self.vrf_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.TableContexts.TableContext']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:table-contexts'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.table_context is not None:
                            for child_ref in self.table_context:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.TableContexts']['meta_info']


                class NeighborSummaries(object):
                    """
                    PIM neighbor summary table
                    
                    .. attribute:: neighbor_summary
                    
                    	PIM neighbor summary information
                    	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.neighbor_summary = YList()
                        self.neighbor_summary.parent = self
                        self.neighbor_summary.name = 'neighbor_summary'


                    class NeighborSummary(object):
                        """
                        PIM neighbor summary information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: number_of_external_neighbors
                        
                        	Number of external neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: number_of_neighbors
                        
                        	Number of neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.number_of_external_neighbors = None
                            self.number_of_neighbors = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-summary[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.number_of_external_neighbors is not None:
                                return True

                            if self.number_of_neighbors is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-summaries'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.neighbor_summary is not None:
                            for child_ref in self.neighbor_summary:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries']['meta_info']


                class Context(object):
                    """
                    PIM context information
                    
                    .. attribute:: active_table_count
                    
                    	Number of active Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: allow_rp_configured
                    
                    	Allow RP Configured
                    	**type**\:  bool
                    
                    .. attribute:: allow_rp_group_list
                    
                    	Allow RP Group\-List ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: allow_rp_rp_list
                    
                    	Allow RP RP\-list ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: anycast_rp_configured
                    
                    	Anycast\-RP config
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_policy_name
                    
                    	Anycast\-RP Policy Name
                    	**type**\:  str
                    
                    .. attribute:: anycast_rp_range
                    
                    	Anycast\-RP Ranges
                    	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange>`
                    
                    .. attribute:: bgp_auto_discovery_configured
                    
                    	BGP Auto\-Discovery configured
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery_type
                    
                    	BGP Auto Discovery Type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_i_pmsi_added
                    
                    	BGP I\-PMSI Added
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_address
                    
                    	BGP remote interface address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: bgp_remote_interface
                    
                    	BGP remote interface handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: bgp_remote_interface_name
                    
                    	BGP remote interface name
                    	**type**\:  str
                    
                    .. attribute:: bgp_remote_on
                    
                    	BGP remote interface status
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_state
                    
                    	BGP remote interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_source_active_announce
                    
                    	Send BGP Source\-Active Announcements
                    	**type**\:  bool
                    
                    .. attribute:: export_route_target
                    
                    	Export Route Targets
                    	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget>`
                    
                    .. attribute:: gin_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: gin_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: gin_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: import_route_target
                    
                    	Import Route Targets
                    	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget>`
                    
                    .. attribute:: in_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: in_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: in_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_signaling_local_enabled
                    
                    	Inband signaling Local enabled
                    	**type**\:  bool
                    
                    .. attribute:: in_band_signaling_remote_enabled
                    
                    	Inband signaling Remote enabled
                    	**type**\:  bool
                    
                    .. attribute:: inter_autonomous_system_enabled
                    
                    	Inter\-AS Enabled
                    	**type**\:  bool
                    
                    .. attribute:: ir_maximum_mdt_aggregation
                    
                    	IR MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_announce_interval
                    
                    	IR Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_switchover_interval
                    
                    	IR Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_interface
                    
                    	IRMDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: ir_mdt_mtu
                    
                    	IRMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_name
                    
                    	IR MDT Name
                    	**type**\:  str
                    
                    .. attribute:: ir_mdt_rpf_identifier
                    
                    	IR RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_tail_label
                    
                    	IR Tail Label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active
                    	**type**\:  bool
                    
                    .. attribute:: is_active_ital
                    
                    	Active ITAL
                    	**type**\:  bool
                    
                    .. attribute:: is_all_interface_disable_operation
                    
                    	PIM all interface disable operation
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_enabled
                    
                    	Auto RP Listen Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_sock_add
                    
                    	Auto RP listen sock add
                    	**type**\:  bool
                    
                    .. attribute:: is_create_gin_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_in_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_ir_mdt_interface
                    
                    	Create IR MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mdt_interface
                    
                    	Create MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mldp_mdt_interface
                    
                    	Create MLDP MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_rsvp_te_mdt_interface
                    
                    	Create RSVP\-TE MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_default_granges
                    
                    	Default granges
                    	**type**\:  bool
                    
                    .. attribute:: is_gin_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_in_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_ir_mdt_owner
                    
                    	IR MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_added
                    
                    	VRF LPTS filter added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_m_host_publish_pending
                    
                    	Publish pending for MHost Default interface
                    	**type**\:  bool
                    
                    .. attribute:: is_mdt_owner
                    
                    	MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mldp_mdt_owner
                    
                    	MLDP MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mrib_register
                    
                    	MRIB Register
                    	**type**\:  bool
                    
                    .. attribute:: is_multicast_rib_registration
                    
                    	Mcast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converge_received
                    
                    	PIM NSF RIB converge received
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converged
                    
                    	PIM NSF RIB converged
                    	**type**\:  bool
                    
                    .. attribute:: is_redistribution_reset
                    
                    	Pending redist reset
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_added
                    
                    	VRF LPTS filter added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_add_required
                    
                    	VRF required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_added
                    
                    	VRF added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_enabled
                    
                    	PIM RIB multiplath enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_interface_hash
                    
                    	PIM RIB multipath interface hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_hash
                    
                    	PIM RIB multipath source based hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_next_hop_hash
                    
                    	PIM RIB multipath source\-nexthop hash
                    	**type**\:  bool
                    
                    .. attribute:: is_routing_enabled
                    
                    	Routing Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rsvp_te_mdt_owner
                    
                    	RSVP\-TE MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_add_required
                    
                    	VRF required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_added
                    
                    	VRF added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_add_required
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_added
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind
                    
                    	VRF bound on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind_required
                    
                    	VRF bind required on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_unicast_rib_registration
                    
                    	Ucast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: maximum_mdt_aggregation
                    
                    	MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_announce_interval
                    
                    	Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_switchover_interval
                    
                    	Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_default_group
                    
                    	MDT Default group
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_gre_remote_rpf_identifier
                    
                    	GRE\-MDT Remote RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_gre_rpf_identifier
                    
                    	GRE\-MDT RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_interface
                    
                    	MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mdt_mtu
                    
                    	MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_neighbor_filter_name
                    
                    	MDT Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: mdt_partitioned_ir_control_identifier
                    
                    	Partitioned IR MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_partitioned_mdt_control_identifier
                    
                    	Partitioned MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mhost_default_interface_config
                    
                    	Configured Mhost Defint
                    	**type**\:  str
                    
                    .. attribute:: mhost_interface
                    
                    	MHost handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mldp_auto_rp_announce_tree_added
                    
                    	MLDP Autorp Announce Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_auto_rp_discovery_tree_added
                    
                    	MLDP Autorp Discovery Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_bsr_control_tree_added
                    
                    	MLDP BSR Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_control_head_lsm_identifier
                    
                    	MLDP MVPN Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_local_label
                    
                    	Partitioned MDT Head local label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_lsm_identifier
                    
                    	MLDP Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_maximum_mdt_aggregation
                    
                    	MLDP MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_announce_interval
                    
                    	MLDP Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_switchover_interval
                    
                    	MLDP Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_interface
                    
                    	MLDP MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mldp_mdt_mtu
                    
                    	MLDP MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_name
                    
                    	MLDP MDT Name
                    	**type**\:  str
                    
                    .. attribute:: mldp_mdt_remote_rpf_identifier
                    
                    	MLDP Remote RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_rpf_identifier
                    
                    	MLDP RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partioned_mp2m_ptree
                    
                    	MP2MP Partitioned MDT tree
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_head_lsm_identifier
                    
                    	Partitioned MDT Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partitioned_mdt_configured
                    
                    	MLDP Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_mdt_identifier
                    
                    	MLDP Partitioned MDT Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_head_lsm_identifier
                    
                    	MLDP Remote Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_partitioned_mdt_configured
                    
                    	MLDP Remote Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_root_address
                    
                    	MLDP Root addresses
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_root_count
                    
                    	MLDP Root count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: murib_id
                    
                    	MURIB ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: non_default_vrf_count_on_socket
                    
                    	Count of non\-default vrfs on raw socket
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: organization_unique_identifier
                    
                    	OUI for VPN\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mpte_li_drop
                    
                    	Route LI updates dropped for P2MP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redistribution_reset_count
                    
                    	Redist reset count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_default_group
                    
                    	Remote Default Group
                    	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup>`
                    
                    .. attribute:: remote_table_id
                    
                    	Remote Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_distinguisher
                    
                    	RD value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: rpf_default_table
                    
                    	RPF Default Table
                    	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable>`
                    
                    .. attribute:: rpf_id
                    
                    	RPF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_policy_name
                    
                    	RPF topology selection route\-policy name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_maximum_mdt_aggregation
                    
                    	RSVP\-TE MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_announce_interval
                    
                    	RSVP\-TE Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_switchover_interval
                    
                    	RSVP\-TE Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_interface
                    
                    	RSVP\-TEMDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rsvp_te_mdt_mtu
                    
                    	RSVP\-TEMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_name
                    
                    	RSVP\-TE MDT Name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_mdt_rpf_identifier
                    
                    	RSVP\-TE RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_static_p2mp_count
                    
                    	Number of Static P2MP\-TE MDT
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	PIM is using MuRIB
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_time
                    
                    	S,G Expiry Time Configured, in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: sg_expiry_timer_configured
                    
                    	S,G Expiry Timer Configured
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_timer_sg_list
                    
                    	S,G expiry timer ACL name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: stale_rd_present
                    
                    	RD is stale
                    	**type**\:  bool
                    
                    .. attribute:: suppress_pim_data_mdt_tlv
                    
                    	Suppress PIM Data\-MDT TLV Announcements
                    	**type**\:  bool
                    
                    .. attribute:: suppress_shared_tree_join
                    
                    	Suppress Shared\-Tree Joins
                    	**type**\:  bool
                    
                    .. attribute:: table_count
                    
                    	Number of configured Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: umh
                    
                    	Join UMH Core\-Tree
                    	**type**\:  bool
                    
                    .. attribute:: valid_rd_present
                    
                    	RD is valid
                    	**type**\:  bool
                    
                    .. attribute:: vpn_index
                    
                    	VPN Index
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.active_table_count = None
                        self.allow_rp_configured = None
                        self.allow_rp_group_list = None
                        self.allow_rp_rp_list = None
                        self.anycast_rp_configured = None
                        self.anycast_rp_policy_name = None
                        self.anycast_rp_range = YList()
                        self.anycast_rp_range.parent = self
                        self.anycast_rp_range.name = 'anycast_rp_range'
                        self.bgp_auto_discovery_configured = None
                        self.bgp_auto_discovery_type = None
                        self.bgp_i_pmsi_added = None
                        self.bgp_remote_address = None
                        self.bgp_remote_interface = None
                        self.bgp_remote_interface_name = None
                        self.bgp_remote_on = None
                        self.bgp_remote_state = None
                        self.bgp_source_active_announce = None
                        self.export_route_target = YList()
                        self.export_route_target.parent = self
                        self.export_route_target.name = 'export_route_target'
                        self.gin_b_and_mdt_data_announce_interval = None
                        self.gin_b_and_mdt_data_switchover_interval = None
                        self.gin_b_and_mdt_interface = None
                        self.gin_b_and_mdt_mtu = None
                        self.gin_b_and_mdt_name = None
                        self.gin_b_and_mdt_rpf_identifier = None
                        self.gin_band_maximum_mdt_aggregation = None
                        self.import_route_target = YList()
                        self.import_route_target.parent = self
                        self.import_route_target.name = 'import_route_target'
                        self.in_b_and_mdt_data_announce_interval = None
                        self.in_b_and_mdt_data_switchover_interval = None
                        self.in_b_and_mdt_interface = None
                        self.in_b_and_mdt_mtu = None
                        self.in_b_and_mdt_name = None
                        self.in_b_and_mdt_rpf_identifier = None
                        self.in_band_maximum_mdt_aggregation = None
                        self.in_band_signaling_local_enabled = None
                        self.in_band_signaling_remote_enabled = None
                        self.inter_autonomous_system_enabled = None
                        self.ir_maximum_mdt_aggregation = None
                        self.ir_mdt_data_announce_interval = None
                        self.ir_mdt_data_switchover_interval = None
                        self.ir_mdt_interface = None
                        self.ir_mdt_mtu = None
                        self.ir_mdt_name = None
                        self.ir_mdt_rpf_identifier = None
                        self.ir_mdt_tail_label = None
                        self.is_active = None
                        self.is_active_ital = None
                        self.is_all_interface_disable_operation = None
                        self.is_auto_rp_listen_enabled = None
                        self.is_auto_rp_listen_sock_add = None
                        self.is_create_gin_b_and_mdt_interface = None
                        self.is_create_in_b_and_mdt_interface = None
                        self.is_create_ir_mdt_interface = None
                        self.is_create_mdt_interface = None
                        self.is_create_mldp_mdt_interface = None
                        self.is_create_rsvp_te_mdt_interface = None
                        self.is_default_granges = None
                        self.is_gin_b_and_mdt_owner = None
                        self.is_in_b_and_mdt_owner = None
                        self.is_ir_mdt_owner = None
                        self.is_lpts_socket_add_required = None
                        self.is_lpts_socket_added = None
                        self.is_m_host_publish_pending = None
                        self.is_mdt_owner = None
                        self.is_mldp_mdt_owner = None
                        self.is_mrib_register = None
                        self.is_multicast_rib_registration = None
                        self.is_pim_nsf_rib_converge_received = None
                        self.is_pim_nsf_rib_converged = None
                        self.is_redistribution_reset = None
                        self.is_register_injection_lpts_socket_add_required = None
                        self.is_register_injection_lpts_socket_added = None
                        self.is_register_injection_socket_add_required = None
                        self.is_register_injection_socket_added = None
                        self.is_rib_multipath_enabled = None
                        self.is_rib_multipath_interface_hash = None
                        self.is_rib_multipath_source_hash = None
                        self.is_rib_multipath_source_next_hop_hash = None
                        self.is_routing_enabled = None
                        self.is_rsvp_te_mdt_owner = None
                        self.is_socket_add_required = None
                        self.is_socket_added = None
                        self.is_udp_socket_add_required = None
                        self.is_udp_socket_added = None
                        self.is_udp_socket_bind = None
                        self.is_udp_socket_bind_required = None
                        self.is_unicast_rib_registration = None
                        self.maximum_mdt_aggregation = None
                        self.mdt_data_announce_interval = None
                        self.mdt_data_switchover_interval = None
                        self.mdt_default_group = None
                        self.mdt_gre_remote_rpf_identifier = None
                        self.mdt_gre_rpf_identifier = None
                        self.mdt_interface = None
                        self.mdt_mtu = None
                        self.mdt_neighbor_filter_name = None
                        self.mdt_partitioned_ir_control_identifier = None
                        self.mdt_partitioned_mdt_control_identifier = None
                        self.mhost_default_interface_config = None
                        self.mhost_interface = None
                        self.mldp_auto_rp_announce_tree_added = None
                        self.mldp_auto_rp_discovery_tree_added = None
                        self.mldp_bsr_control_tree_added = None
                        self.mldp_control_head_lsm_identifier = None
                        self.mldp_head_local_label = None
                        self.mldp_head_lsm_identifier = None
                        self.mldp_maximum_mdt_aggregation = None
                        self.mldp_mdt_data_announce_interval = None
                        self.mldp_mdt_data_switchover_interval = None
                        self.mldp_mdt_interface = None
                        self.mldp_mdt_mtu = None
                        self.mldp_mdt_name = None
                        self.mldp_mdt_remote_rpf_identifier = None
                        self.mldp_mdt_rpf_identifier = None
                        self.mldp_partioned_mp2m_ptree = None
                        self.mldp_partitioned_head_lsm_identifier = None
                        self.mldp_partitioned_mdt_configured = None
                        self.mldp_partitioned_mdt_identifier = None
                        self.mldp_remote_head_lsm_identifier = None
                        self.mldp_remote_partitioned_mdt_configured = None
                        self.mldp_root_address = YLeafList()
                        self.mldp_root_address.parent = self
                        self.mldp_root_address.name = 'mldp_root_address'
                        self.mldp_root_count = None
                        self.murib_id = None
                        self.neighbor_filter_name = None
                        self.non_default_vrf_count_on_socket = None
                        self.organization_unique_identifier = None
                        self.p2mpte_li_drop = None
                        self.redistribution_reset_count = None
                        self.remote_default_group = Ipv6Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup()
                        self.remote_default_group.parent = self
                        self.remote_table_id = None
                        self.route_distinguisher = None
                        self.rpf_default_table = Ipv6Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable()
                        self.rpf_default_table.parent = self
                        self.rpf_id = None
                        self.rpf_policy_name = None
                        self.rsvp_te_maximum_mdt_aggregation = None
                        self.rsvp_te_mdt_data_announce_interval = None
                        self.rsvp_te_mdt_data_switchover_interval = None
                        self.rsvp_te_mdt_interface = None
                        self.rsvp_te_mdt_mtu = None
                        self.rsvp_te_mdt_name = None
                        self.rsvp_te_mdt_rpf_identifier = None
                        self.rsvp_te_mdt_static_p2mp_count = None
                        self.rump_enabled = None
                        self.sg_expiry_time = None
                        self.sg_expiry_timer_configured = None
                        self.sg_expiry_timer_sg_list = None
                        self.stale_rd_present = None
                        self.suppress_pim_data_mdt_tlv = None
                        self.suppress_shared_tree_join = None
                        self.table_count = None
                        self.table_id = None
                        self.umh = None
                        self.valid_rd_present = None
                        self.vpn_index = None
                        self.vrf_id = None


                    class RemoteDefaultGroup(object):
                        """
                        Remote Default Group
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:remote-default-group'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup']['meta_info']


                    class RpfDefaultTable(object):
                        """
                        RPF Default Table
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.afi = None
                            self.is_active = None
                            self.is_ital_registration_done = None
                            self.is_rib_convergence = None
                            self.is_rib_convergence_received = None
                            self.is_rib_registration_done = None
                            self.rpf_registrations = None
                            self.safi = None
                            self.table_id = None
                            self.table_name = None
                            self.vrf_id = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-default-table'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.afi is not None:
                                return True

                            if self.is_active is not None:
                                return True

                            if self.is_ital_registration_done is not None:
                                return True

                            if self.is_rib_convergence is not None:
                                return True

                            if self.is_rib_convergence_received is not None:
                                return True

                            if self.is_rib_registration_done is not None:
                                return True

                            if self.rpf_registrations is not None:
                                return True

                            if self.safi is not None:
                                return True

                            if self.table_id is not None:
                                return True

                            if self.table_name is not None:
                                return True

                            if self.vrf_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable']['meta_info']


                    class ExportRouteTarget(object):
                        """
                        Export Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.anycast_rp = None
                            self.anycast_rp_marked = None
                            self.bgp_auto_discovery = None
                            self.configured = None
                            self.route_target = None
                            self.segment_border = None
                            self.update_pending = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:export-route-target'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.anycast_rp is not None:
                                return True

                            if self.anycast_rp_marked is not None:
                                return True

                            if self.bgp_auto_discovery is not None:
                                return True

                            if self.configured is not None:
                                return True

                            if self.route_target is not None:
                                return True

                            if self.segment_border is not None:
                                return True

                            if self.update_pending is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget']['meta_info']


                    class ImportRouteTarget(object):
                        """
                        Import Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.anycast_rp = None
                            self.anycast_rp_marked = None
                            self.bgp_auto_discovery = None
                            self.configured = None
                            self.route_target = None
                            self.segment_border = None
                            self.update_pending = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:import-route-target'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.anycast_rp is not None:
                                return True

                            if self.anycast_rp_marked is not None:
                                return True

                            if self.bgp_auto_discovery is not None:
                                return True

                            if self.configured is not None:
                                return True

                            if self.route_target is not None:
                                return True

                            if self.segment_border is not None:
                                return True

                            if self.update_pending is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget']['meta_info']


                    class AnycastRpRange(object):
                        """
                        Anycast\-RP Ranges
                        
                        .. attribute:: ancast_rp_marked
                        
                        	Anycast\-RP Range marked
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Anycast\-RP Range Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Anycast\-RP Range Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ancast_rp_marked = None
                            self.prefix = Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None


                        class Prefix(object):
                            """
                            Anycast\-RP Range Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:anycast-rp-range'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ancast_rp_marked is not None:
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:context'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.active_table_count is not None:
                            return True

                        if self.allow_rp_configured is not None:
                            return True

                        if self.allow_rp_group_list is not None:
                            return True

                        if self.allow_rp_rp_list is not None:
                            return True

                        if self.anycast_rp_configured is not None:
                            return True

                        if self.anycast_rp_policy_name is not None:
                            return True

                        if self.anycast_rp_range is not None:
                            for child_ref in self.anycast_rp_range:
                                if child_ref._has_data():
                                    return True

                        if self.bgp_auto_discovery_configured is not None:
                            return True

                        if self.bgp_auto_discovery_type is not None:
                            return True

                        if self.bgp_i_pmsi_added is not None:
                            return True

                        if self.bgp_remote_address is not None:
                            return True

                        if self.bgp_remote_interface is not None:
                            return True

                        if self.bgp_remote_interface_name is not None:
                            return True

                        if self.bgp_remote_on is not None:
                            return True

                        if self.bgp_remote_state is not None:
                            return True

                        if self.bgp_source_active_announce is not None:
                            return True

                        if self.export_route_target is not None:
                            for child_ref in self.export_route_target:
                                if child_ref._has_data():
                                    return True

                        if self.gin_b_and_mdt_data_announce_interval is not None:
                            return True

                        if self.gin_b_and_mdt_data_switchover_interval is not None:
                            return True

                        if self.gin_b_and_mdt_interface is not None:
                            return True

                        if self.gin_b_and_mdt_mtu is not None:
                            return True

                        if self.gin_b_and_mdt_name is not None:
                            return True

                        if self.gin_b_and_mdt_rpf_identifier is not None:
                            return True

                        if self.gin_band_maximum_mdt_aggregation is not None:
                            return True

                        if self.import_route_target is not None:
                            for child_ref in self.import_route_target:
                                if child_ref._has_data():
                                    return True

                        if self.in_b_and_mdt_data_announce_interval is not None:
                            return True

                        if self.in_b_and_mdt_data_switchover_interval is not None:
                            return True

                        if self.in_b_and_mdt_interface is not None:
                            return True

                        if self.in_b_and_mdt_mtu is not None:
                            return True

                        if self.in_b_and_mdt_name is not None:
                            return True

                        if self.in_b_and_mdt_rpf_identifier is not None:
                            return True

                        if self.in_band_maximum_mdt_aggregation is not None:
                            return True

                        if self.in_band_signaling_local_enabled is not None:
                            return True

                        if self.in_band_signaling_remote_enabled is not None:
                            return True

                        if self.inter_autonomous_system_enabled is not None:
                            return True

                        if self.ir_maximum_mdt_aggregation is not None:
                            return True

                        if self.ir_mdt_data_announce_interval is not None:
                            return True

                        if self.ir_mdt_data_switchover_interval is not None:
                            return True

                        if self.ir_mdt_interface is not None:
                            return True

                        if self.ir_mdt_mtu is not None:
                            return True

                        if self.ir_mdt_name is not None:
                            return True

                        if self.ir_mdt_rpf_identifier is not None:
                            return True

                        if self.ir_mdt_tail_label is not None:
                            return True

                        if self.is_active is not None:
                            return True

                        if self.is_active_ital is not None:
                            return True

                        if self.is_all_interface_disable_operation is not None:
                            return True

                        if self.is_auto_rp_listen_enabled is not None:
                            return True

                        if self.is_auto_rp_listen_sock_add is not None:
                            return True

                        if self.is_create_gin_b_and_mdt_interface is not None:
                            return True

                        if self.is_create_in_b_and_mdt_interface is not None:
                            return True

                        if self.is_create_ir_mdt_interface is not None:
                            return True

                        if self.is_create_mdt_interface is not None:
                            return True

                        if self.is_create_mldp_mdt_interface is not None:
                            return True

                        if self.is_create_rsvp_te_mdt_interface is not None:
                            return True

                        if self.is_default_granges is not None:
                            return True

                        if self.is_gin_b_and_mdt_owner is not None:
                            return True

                        if self.is_in_b_and_mdt_owner is not None:
                            return True

                        if self.is_ir_mdt_owner is not None:
                            return True

                        if self.is_lpts_socket_add_required is not None:
                            return True

                        if self.is_lpts_socket_added is not None:
                            return True

                        if self.is_m_host_publish_pending is not None:
                            return True

                        if self.is_mdt_owner is not None:
                            return True

                        if self.is_mldp_mdt_owner is not None:
                            return True

                        if self.is_mrib_register is not None:
                            return True

                        if self.is_multicast_rib_registration is not None:
                            return True

                        if self.is_pim_nsf_rib_converge_received is not None:
                            return True

                        if self.is_pim_nsf_rib_converged is not None:
                            return True

                        if self.is_redistribution_reset is not None:
                            return True

                        if self.is_register_injection_lpts_socket_add_required is not None:
                            return True

                        if self.is_register_injection_lpts_socket_added is not None:
                            return True

                        if self.is_register_injection_socket_add_required is not None:
                            return True

                        if self.is_register_injection_socket_added is not None:
                            return True

                        if self.is_rib_multipath_enabled is not None:
                            return True

                        if self.is_rib_multipath_interface_hash is not None:
                            return True

                        if self.is_rib_multipath_source_hash is not None:
                            return True

                        if self.is_rib_multipath_source_next_hop_hash is not None:
                            return True

                        if self.is_routing_enabled is not None:
                            return True

                        if self.is_rsvp_te_mdt_owner is not None:
                            return True

                        if self.is_socket_add_required is not None:
                            return True

                        if self.is_socket_added is not None:
                            return True

                        if self.is_udp_socket_add_required is not None:
                            return True

                        if self.is_udp_socket_added is not None:
                            return True

                        if self.is_udp_socket_bind is not None:
                            return True

                        if self.is_udp_socket_bind_required is not None:
                            return True

                        if self.is_unicast_rib_registration is not None:
                            return True

                        if self.maximum_mdt_aggregation is not None:
                            return True

                        if self.mdt_data_announce_interval is not None:
                            return True

                        if self.mdt_data_switchover_interval is not None:
                            return True

                        if self.mdt_default_group is not None:
                            return True

                        if self.mdt_gre_remote_rpf_identifier is not None:
                            return True

                        if self.mdt_gre_rpf_identifier is not None:
                            return True

                        if self.mdt_interface is not None:
                            return True

                        if self.mdt_mtu is not None:
                            return True

                        if self.mdt_neighbor_filter_name is not None:
                            return True

                        if self.mdt_partitioned_ir_control_identifier is not None:
                            return True

                        if self.mdt_partitioned_mdt_control_identifier is not None:
                            return True

                        if self.mhost_default_interface_config is not None:
                            return True

                        if self.mhost_interface is not None:
                            return True

                        if self.mldp_auto_rp_announce_tree_added is not None:
                            return True

                        if self.mldp_auto_rp_discovery_tree_added is not None:
                            return True

                        if self.mldp_bsr_control_tree_added is not None:
                            return True

                        if self.mldp_control_head_lsm_identifier is not None:
                            return True

                        if self.mldp_head_local_label is not None:
                            return True

                        if self.mldp_head_lsm_identifier is not None:
                            return True

                        if self.mldp_maximum_mdt_aggregation is not None:
                            return True

                        if self.mldp_mdt_data_announce_interval is not None:
                            return True

                        if self.mldp_mdt_data_switchover_interval is not None:
                            return True

                        if self.mldp_mdt_interface is not None:
                            return True

                        if self.mldp_mdt_mtu is not None:
                            return True

                        if self.mldp_mdt_name is not None:
                            return True

                        if self.mldp_mdt_remote_rpf_identifier is not None:
                            return True

                        if self.mldp_mdt_rpf_identifier is not None:
                            return True

                        if self.mldp_partioned_mp2m_ptree is not None:
                            return True

                        if self.mldp_partitioned_head_lsm_identifier is not None:
                            return True

                        if self.mldp_partitioned_mdt_configured is not None:
                            return True

                        if self.mldp_partitioned_mdt_identifier is not None:
                            return True

                        if self.mldp_remote_head_lsm_identifier is not None:
                            return True

                        if self.mldp_remote_partitioned_mdt_configured is not None:
                            return True

                        if self.mldp_root_address is not None:
                            for child in self.mldp_root_address:
                                if child is not None:
                                    return True

                        if self.mldp_root_count is not None:
                            return True

                        if self.murib_id is not None:
                            return True

                        if self.neighbor_filter_name is not None:
                            return True

                        if self.non_default_vrf_count_on_socket is not None:
                            return True

                        if self.organization_unique_identifier is not None:
                            return True

                        if self.p2mpte_li_drop is not None:
                            return True

                        if self.redistribution_reset_count is not None:
                            return True

                        if self.remote_default_group is not None and self.remote_default_group._has_data():
                            return True

                        if self.remote_table_id is not None:
                            return True

                        if self.route_distinguisher is not None:
                            return True

                        if self.rpf_default_table is not None and self.rpf_default_table._has_data():
                            return True

                        if self.rpf_id is not None:
                            return True

                        if self.rpf_policy_name is not None:
                            return True

                        if self.rsvp_te_maximum_mdt_aggregation is not None:
                            return True

                        if self.rsvp_te_mdt_data_announce_interval is not None:
                            return True

                        if self.rsvp_te_mdt_data_switchover_interval is not None:
                            return True

                        if self.rsvp_te_mdt_interface is not None:
                            return True

                        if self.rsvp_te_mdt_mtu is not None:
                            return True

                        if self.rsvp_te_mdt_name is not None:
                            return True

                        if self.rsvp_te_mdt_rpf_identifier is not None:
                            return True

                        if self.rsvp_te_mdt_static_p2mp_count is not None:
                            return True

                        if self.rump_enabled is not None:
                            return True

                        if self.sg_expiry_time is not None:
                            return True

                        if self.sg_expiry_timer_configured is not None:
                            return True

                        if self.sg_expiry_timer_sg_list is not None:
                            return True

                        if self.stale_rd_present is not None:
                            return True

                        if self.suppress_pim_data_mdt_tlv is not None:
                            return True

                        if self.suppress_shared_tree_join is not None:
                            return True

                        if self.table_count is not None:
                            return True

                        if self.table_id is not None:
                            return True

                        if self.umh is not None:
                            return True

                        if self.valid_rd_present is not None:
                            return True

                        if self.vpn_index is not None:
                            return True

                        if self.vrf_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Context']['meta_info']


                class TopologyEntryFlagRouteCounts(object):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: topology_entry_flag_route_count
                    
                    	Route count for topology with entry flag set
                    	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.topology_entry_flag_route_count = YList()
                        self.topology_entry_flag_route_count.parent = self
                        self.topology_entry_flag_route_count.name = 'topology_entry_flag_route_count'


                    class TopologyEntryFlagRouteCount(object):
                        """
                        Route count for topology with entry flag set
                        
                        .. attribute:: entry_flag  <key>
                        
                        	entry flag
                        	**type**\:   :py:class:`PimTopologyEntryFlagEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlagEnum>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.entry_flag = None
                            self.active_group_ranges = None
                            self.group_address = Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                            self.group_address.parent = self
                            self.group_ranges = None
                            self.groute_count = None
                            self.is_node_low_memory = None
                            self.sg_route_count = None
                            self.sgr_route_count = None


                        class GroupAddress(object):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.entry_flag is None:
                                raise YPYModelError('Key property entry_flag is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology-entry-flag-route-count[Cisco-IOS-XR-ipv4-pim-oper:entry-flag = ' + str(self.entry_flag) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.entry_flag is not None:
                                return True

                            if self.active_group_ranges is not None:
                                return True

                            if self.group_address is not None and self.group_address._has_data():
                                return True

                            if self.group_ranges is not None:
                                return True

                            if self.groute_count is not None:
                                return True

                            if self.is_node_low_memory is not None:
                                return True

                            if self.sg_route_count is not None:
                                return True

                            if self.sgr_route_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:topology-entry-flag-route-counts'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.topology_entry_flag_route_count is not None:
                            for child_ref in self.topology_entry_flag_route_count:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts']['meta_info']


                class RpfRedirect(object):
                    """
                    PIM ECMP RPF\-redirect bundle
                    
                    .. attribute:: bundle_interfaces
                    
                    	PIM ECMP RPF\-redirect bundle information
                    	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces>`
                    
                    .. attribute:: redirect_route_databases
                    
                    	PIM ECMP RPF\-redirect route database
                    	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bundle_interfaces = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces()
                        self.bundle_interfaces.parent = self
                        self.redirect_route_databases = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases()
                        self.redirect_route_databases.parent = self


                    class RedirectRouteDatabases(object):
                        """
                        PIM ECMP RPF\-redirect route database
                        
                        .. attribute:: redirect_route_database
                        
                        	PIM ECMP RPF\-redirect route information
                        	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.redirect_route_database = YList()
                            self.redirect_route_database.parent = self
                            self.redirect_route_database.name = 'redirect_route_database'


                        class RedirectRouteDatabase(object):
                            """
                            PIM ECMP RPF\-redirect route information
                            
                            .. attribute:: bandwidth
                            
                            	Bandwidth in Kbps
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Group ddress
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                            
                            .. attribute:: interface
                            
                            	Outgoing interface list
                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bandwidth = None
                                self.group_address = None
                                self.group_address_xr = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self.interface = YList()
                                self.interface.parent = self
                                self.interface.name = 'interface'
                                self.source_address = None
                                self.source_address_xr = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self.uptime = None


                            class GroupAddressXr(object):
                                """
                                Group ddress
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr']['meta_info']


                            class SourceAddressXr(object):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr']['meta_info']


                            class Interface(object):
                                """
                                Outgoing interface list
                                
                                .. attribute:: expiry
                                
                                	Expiry in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: is_outgoing_interface
                                
                                	Is outgoing Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface
                                
                                	Is RPF Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_snoop_interface
                                
                                	Is snooping Interface
                                	**type**\:  bool
                                
                                .. attribute:: rpf_address
                                
                                	RPF Address
                                	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                                
                                .. attribute:: uptime
                                
                                	Uptime in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.expiry = None
                                    self.interface_name = None
                                    self.is_outgoing_interface = None
                                    self.is_rpf_interface = None
                                    self.is_snoop_interface = None
                                    self.rpf_address = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                    self.rpf_address.parent = self
                                    self.uptime = None


                                class RpfAddress(object):
                                    """
                                    RPF Address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.expiry is not None:
                                        return True

                                    if self.interface_name is not None:
                                        return True

                                    if self.is_outgoing_interface is not None:
                                        return True

                                    if self.is_rpf_interface is not None:
                                        return True

                                    if self.is_snoop_interface is not None:
                                        return True

                                    if self.rpf_address is not None and self.rpf_address._has_data():
                                        return True

                                    if self.uptime is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-database'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bandwidth is not None:
                                    return True

                                if self.group_address is not None:
                                    return True

                                if self.group_address_xr is not None and self.group_address_xr._has_data():
                                    return True

                                if self.interface is not None:
                                    for child_ref in self.interface:
                                        if child_ref._has_data():
                                            return True

                                if self.source_address is not None:
                                    return True

                                if self.source_address_xr is not None and self.source_address_xr._has_data():
                                    return True

                                if self.uptime is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:redirect-route-databases'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.redirect_route_database is not None:
                                for child_ref in self.redirect_route_database:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases']['meta_info']


                    class BundleInterfaces(object):
                        """
                        PIM ECMP RPF\-redirect bundle information
                        
                        .. attribute:: bundle_interface
                        
                        	PIM ECMP RPF\-redirect bundle interface information
                        	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bundle_interface = YList()
                            self.bundle_interface.parent = self
                            self.bundle_interface.name = 'bundle_interface'


                        class BundleInterface(object):
                            """
                            PIM ECMP RPF\-redirect bundle interface
                            information
                            
                            .. attribute:: allocated_bandwidth
                            
                            	Bandwidth allocated in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: allocated_threshold_bandwidth
                            
                            	Configured threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_bandwidth
                            
                            	Bandwidth available in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_threshold_bandwidth
                            
                            	Available threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: bundle_name
                            
                            	Bundle name
                            	**type**\:  str
                            
                            	**length:** 1..32
                            
                            .. attribute:: interface_name
                            
                            	Bundle interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: rpf_redirect_bundle_name
                            
                            	RPF redirect bundle name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: rpf_redirect_interface_name
                            
                            	RPF redirect interface name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: snooping_bandwidth_used
                            
                            	Bandwidth used by snooped entries in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: topology_bandwidth_used
                            
                            	Bandwidth used by topology in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: total_bandwidth
                            
                            	Total bandwidth used in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.allocated_bandwidth = None
                                self.allocated_threshold_bandwidth = None
                                self.available_bandwidth = None
                                self.available_threshold_bandwidth = None
                                self.bundle_name = None
                                self.interface_name = None
                                self.rpf_redirect_bundle_name = None
                                self.rpf_redirect_interface_name = None
                                self.snooping_bandwidth_used = None
                                self.topology_bandwidth_used = None
                                self.total_bandwidth = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bundle-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.allocated_bandwidth is not None:
                                    return True

                                if self.allocated_threshold_bandwidth is not None:
                                    return True

                                if self.available_bandwidth is not None:
                                    return True

                                if self.available_threshold_bandwidth is not None:
                                    return True

                                if self.bundle_name is not None:
                                    return True

                                if self.interface_name is not None:
                                    return True

                                if self.rpf_redirect_bundle_name is not None:
                                    return True

                                if self.rpf_redirect_interface_name is not None:
                                    return True

                                if self.snooping_bandwidth_used is not None:
                                    return True

                                if self.topology_bandwidth_used is not None:
                                    return True

                                if self.total_bandwidth is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:bundle-interfaces'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bundle_interface is not None:
                                for child_ref in self.bundle_interface:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rpf-redirect'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bundle_interfaces is not None and self.bundle_interfaces._has_data():
                            return True

                        if self.redirect_route_databases is not None and self.redirect_route_databases._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect']['meta_info']


                class Tunnels(object):
                    """
                    Tunnels information that PIM has
                    
                    .. attribute:: tunnel
                    
                    	PIM tunnel information
                    	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.tunnel = YList()
                        self.tunnel.parent = self
                        self.tunnel.name = 'tunnel'


                    class Tunnel(object):
                        """
                        PIM tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.tunnel_name = None
                            self.group_address_netio = Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress()
                            self.rp_address.parent = self
                            self.source_address = Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress()
                            self.source_address.parent = self
                            self.source_address_netio = Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self.vrf_name = None


                        class SourceAddress(object):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress']['meta_info']


                        class RpAddress(object):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress']['meta_info']


                        class SourceAddressNetio(object):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address-netio'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio']['meta_info']


                        class GroupAddressNetio(object):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-address-netio'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.tunnel_name is None:
                                raise YPYModelError('Key property tunnel_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:tunnel[Cisco-IOS-XR-ipv4-pim-oper:tunnel-name = ' + str(self.tunnel_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.tunnel_name is not None:
                                return True

                            if self.group_address_netio is not None and self.group_address_netio._has_data():
                                return True

                            if self.rp_address is not None and self.rp_address._has_data():
                                return True

                            if self.source_address is not None and self.source_address._has_data():
                                return True

                            if self.source_address_netio is not None and self.source_address_netio._has_data():
                                return True

                            if self.vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:tunnels'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.tunnel is not None:
                            for child_ref in self.tunnel:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Tunnels']['meta_info']


                class MulticastStaticRoutes(object):
                    """
                    PIM multicast static route table
                    
                    .. attribute:: multicast_static_route
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.multicast_static_route = YList()
                        self.multicast_static_route.parent = self
                        self.multicast_static_route.name = 'multicast_static_route'


                    class MulticastStaticRoute(object):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: address
                        
                        	Network address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: distance
                        
                        	Distance
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_via_lsm
                        
                        	LSM flag
                        	**type**\:  bool
                        
                        .. attribute:: nexthop
                        
                        	Next Hop
                        	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: prefix_length_xr
                        
                        	Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.address = None
                            self.distance = None
                            self.interface_name = None
                            self.is_via_lsm = None
                            self.nexthop = Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                            self.nexthop.parent = self
                            self.prefix = Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                            self.prefix.parent = self
                            self.prefix_length = None
                            self.prefix_length_xr = None


                        class Prefix(object):
                            """
                            Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix']['meta_info']


                        class Nexthop(object):
                            """
                            Next Hop
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:nexthop'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-route'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.address is not None:
                                return True

                            if self.distance is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.is_via_lsm is not None:
                                return True

                            if self.nexthop is not None and self.nexthop._has_data():
                                return True

                            if self.prefix is not None and self.prefix._has_data():
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.prefix_length_xr is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:multicast-static-routes'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.multicast_static_route is not None:
                            for child_ref in self.multicast_static_route:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes']['meta_info']


                class GroupMapMatchSources(object):
                    """
                    Find the matching group\-mapping with source
                    information on specified group address
                    
                    .. attribute:: group_map_match_source
                    
                    	PIM group\-matching mapping entry with source information
                    	**type**\: list of    :py:class:`GroupMapMatchSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_map_match_source = YList()
                        self.group_map_match_source.parent = self
                        self.group_map_match_source.name = 'group_map_match_source'


                    class GroupMapMatchSource(object):
                        """
                        PIM group\-matching mapping entry with source
                        information
                        
                        .. attribute:: group_address  <key>
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.group_address = None
                            self.expires = None
                            self.group_map_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self.holdtime = None
                            self.source_of_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self.uptime = None


                        class SourceOfInformation(object):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-of-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation']['meta_info']


                        class GroupMapInformation(object):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClientEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClientEnum>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocolEnum>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.client = None
                                self.group_count = None
                                self.is_override = None
                                self.is_used = None
                                self.mrib_active = None
                                self.prefix = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self.prefix_length = None
                                self.priority = None
                                self.protocol = None
                                self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self


                            class Prefix(object):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:prefix'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix']['meta_info']


                            class RpAddress(object):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.client is not None:
                                    return True

                                if self.group_count is not None:
                                    return True

                                if self.is_override is not None:
                                    return True

                                if self.is_used is not None:
                                    return True

                                if self.mrib_active is not None:
                                    return True

                                if self.prefix is not None and self.prefix._has_data():
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.priority is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.rp_address is not None and self.rp_address._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.group_address is None:
                                raise YPYModelError('Key property group_address is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-source[Cisco-IOS-XR-ipv4-pim-oper:group-address = ' + str(self.group_address) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.group_address is not None:
                                return True

                            if self.expires is not None:
                                return True

                            if self.group_map_information is not None and self.group_map_information._has_data():
                                return True

                            if self.holdtime is not None:
                                return True

                            if self.source_of_information is not None and self.source_of_information._has_data():
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:group-map-match-sources'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_map_match_source is not None:
                            for child_ref in self.group_map_match_source:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources']['meta_info']


                class Neighbors(object):
                    """
                    PIM neighbor table
                    
                    .. attribute:: neighbor
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.neighbor = YList()
                        self.neighbor.parent = self
                        self.neighbor.name = 'neighbor'


                    class Neighbor(object):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dr_priority = None
                            self.expires = None
                            self.expiry_timer = None
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.is_batch_asserts_capable = None
                            self.is_bfd_state = None
                            self.is_bidirectional_capable = None
                            self.is_dr_priority_capable = None
                            self.is_ecmp_redirect_capable = None
                            self.is_proxy_capable = None
                            self.is_this_neighbor_dr = None
                            self.is_this_neighbor_us = None
                            self.neighbor_address = None
                            self.neighbor_address_xr = YList()
                            self.neighbor_address_xr.parent = self
                            self.neighbor_address_xr.name = 'neighbor_address_xr'
                            self.override_interval = None
                            self.propagation_delay = None
                            self.uptime = None


                        class NeighborAddressXr(object):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                                return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dr_priority is not None:
                                return True

                            if self.expires is not None:
                                return True

                            if self.expiry_timer is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.interface_name_xr is not None:
                                return True

                            if self.is_batch_asserts_capable is not None:
                                return True

                            if self.is_bfd_state is not None:
                                return True

                            if self.is_bidirectional_capable is not None:
                                return True

                            if self.is_dr_priority_capable is not None:
                                return True

                            if self.is_ecmp_redirect_capable is not None:
                                return True

                            if self.is_proxy_capable is not None:
                                return True

                            if self.is_this_neighbor_dr is not None:
                                return True

                            if self.is_this_neighbor_us is not None:
                                return True

                            if self.neighbor_address is not None:
                                return True

                            if self.neighbor_address_xr is not None:
                                for child_ref in self.neighbor_address_xr:
                                    if child_ref._has_data():
                                        return True

                            if self.override_interval is not None:
                                return True

                            if self.propagation_delay is not None:
                                return True

                            if self.uptime is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:neighbors'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.neighbor is not None:
                            for child_ref in self.neighbor:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf.Neighbors']['meta_info']

                @property
                def _common_path(self):
                    if self.vrf_name is None:
                        raise YPYModelError('Key property vrf_name is None')

                    return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:vrfs/Cisco-IOS-XR-ipv4-pim-oper:vrf[Cisco-IOS-XR-ipv4-pim-oper:vrf-name = ' + str(self.vrf_name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.vrf_name is not None:
                        return True

                    if self.auto_rp is not None and self.auto_rp._has_data():
                        return True

                    if self.bgp_afs is not None and self.bgp_afs._has_data():
                        return True

                    if self.bidir_df_states is not None and self.bidir_df_states._has_data():
                        return True

                    if self.bidir_df_winners is not None and self.bidir_df_winners._has_data():
                        return True

                    if self.bsr is not None and self.bsr._has_data():
                        return True

                    if self.context is not None and self.context._has_data():
                        return True

                    if self.gre is not None and self.gre._has_data():
                        return True

                    if self.group_map_match_rpfs is not None and self.group_map_match_rpfs._has_data():
                        return True

                    if self.group_map_match_sources is not None and self.group_map_match_sources._has_data():
                        return True

                    if self.group_map_rpfs is not None and self.group_map_rpfs._has_data():
                        return True

                    if self.group_map_sources is not None and self.group_map_sources._has_data():
                        return True

                    if self.ifrs_interfaces is not None and self.ifrs_interfaces._has_data():
                        return True

                    if self.ifrs_summary is not None and self.ifrs_summary._has_data():
                        return True

                    if self.interface_old_formats is not None and self.interface_old_formats._has_data():
                        return True

                    if self.interface_statistics is not None and self.interface_statistics._has_data():
                        return True

                    if self.interfaces is not None and self.interfaces._has_data():
                        return True

                    if self.jp_statistics is not None and self.jp_statistics._has_data():
                        return True

                    if self.mib_databases is not None and self.mib_databases._has_data():
                        return True

                    if self.multicast_static_routes is not None and self.multicast_static_routes._has_data():
                        return True

                    if self.neighbor_old_formats is not None and self.neighbor_old_formats._has_data():
                        return True

                    if self.neighbor_summaries is not None and self.neighbor_summaries._has_data():
                        return True

                    if self.neighbors is not None and self.neighbors._has_data():
                        return True

                    if self.net_io_tunnels is not None and self.net_io_tunnels._has_data():
                        return True

                    if self.ranges is not None and self.ranges._has_data():
                        return True

                    if self.route_policy is not None and self.route_policy._has_data():
                        return True

                    if self.rpf_redirect is not None and self.rpf_redirect._has_data():
                        return True

                    if self.rpf_summary is not None and self.rpf_summary._has_data():
                        return True

                    if self.safs is not None and self.safs._has_data():
                        return True

                    if self.summary is not None and self.summary._has_data():
                        return True

                    if self.table_contexts is not None and self.table_contexts._has_data():
                        return True

                    if self.topologies is not None and self.topologies._has_data():
                        return True

                    if self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts._has_data():
                        return True

                    if self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts._has_data():
                        return True

                    if self.topology_route_count is not None and self.topology_route_count._has_data():
                        return True

                    if self.traffic_counters is not None and self.traffic_counters._has_data():
                        return True

                    if self.tunnels is not None and self.tunnels._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Ipv6Pim.Active.Vrfs.Vrf']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:vrfs'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.vrf is not None:
                    for child_ref in self.vrf:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                return meta._meta_table['Ipv6Pim.Active.Vrfs']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/Cisco-IOS-XR-ipv4-pim-oper:active'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.default_context is not None and self.default_context._has_data():
                return True

            if self.process is not None and self.process._has_data():
                return True

            if self.vrfs is not None and self.vrfs._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
            return meta._meta_table['Ipv6Pim.Active']['meta_info']

    @property
    def _common_path(self):

        return '/Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim'

    def is_config(self):
        ''' Returns True if this instance represents config data else returns False '''
        return False

    def _has_data(self):
        if not self.is_config():
            return False
        if self.active is not None and self.active._has_data():
            return True

        if self.standby is not None and self.standby._has_data():
            return True

        return False

    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
        return meta._meta_table['Ipv6Pim']['meta_info']


class Pim6Ma(object):
    """
    pim6 ma
    
    .. attribute:: active
    
    	Active Process
    	**type**\:   :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active>`
    
    .. attribute:: standby
    
    	Standby Process
    	**type**\:   :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby>`
    
    

    """

    _prefix = 'ipv4-pim-oper'
    _revision = '2015-11-09'

    def __init__(self):
        self.active = Pim6Ma.Active()
        self.active.parent = self
        self.standby = Pim6Ma.Standby()
        self.standby.parent = self


    class Active(object):
        """
        Active Process
        
        .. attribute:: interface_table
        
        	Interface Table
        	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable>`
        
        .. attribute:: pim_ma_summary
        
        	PIM MA summary
        	**type**\:   :py:class:`PimMaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.PimMaSummary>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.interface_table = Pim6Ma.Active.InterfaceTable()
            self.interface_table.parent = self
            self.pim_ma_summary = Pim6Ma.Active.PimMaSummary()
            self.pim_ma_summary.parent = self


        class InterfaceTable(object):
            """
            Interface Table
            
            .. attribute:: interface_by_handles
            
            	Table of PIM MA interfaces indexed by handle
            	**type**\:   :py:class:`InterfaceByHandles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByHandles>`
            
            .. attribute:: interface_by_names
            
            	Table of PIM MA interfaces indexed by name
            	**type**\:   :py:class:`InterfaceByNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByNames>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.interface_by_handles = Pim6Ma.Active.InterfaceTable.InterfaceByHandles()
                self.interface_by_handles.parent = self
                self.interface_by_names = Pim6Ma.Active.InterfaceTable.InterfaceByNames()
                self.interface_by_names.parent = self


            class InterfaceByHandles(object):
                """
                Table of PIM MA interfaces indexed by handle
                
                .. attribute:: interface_by_handle
                
                	PIM MA interface referenced by handle
                	**type**\: list of    :py:class:`InterfaceByHandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_by_handle = YList()
                    self.interface_by_handle.parent = self
                    self.interface_by_handle.name = 'interface_by_handle'


                class InterfaceByHandle(object):
                    """
                    PIM MA interface referenced by handle
                    
                    .. attribute:: interface_handle  <key>
                    
                    	Interface handle
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterfaceEnum>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_handle = None
                        self.interface_name_xr = None
                        self.interface_type = None
                        self.rp_address = Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress()
                        self.rp_address.parent = self
                        self.source_address = Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress()
                        self.source_address.parent = self
                        self.vrf_name = None


                    class RpAddress(object):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress']['meta_info']


                    class SourceAddress(object):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_handle is None:
                            raise YPYModelError('Key property interface_handle is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:interface-table/Cisco-IOS-XR-ipv4-pim-oper:interface-by-handles/Cisco-IOS-XR-ipv4-pim-oper:interface-by-handle[Cisco-IOS-XR-ipv4-pim-oper:interface-handle = ' + str(self.interface_handle) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_handle is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.interface_type is not None:
                            return True

                        if self.rp_address is not None and self.rp_address._has_data():
                            return True

                        if self.source_address is not None and self.source_address._has_data():
                            return True

                        if self.vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:interface-table/Cisco-IOS-XR-ipv4-pim-oper:interface-by-handles'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_by_handle is not None:
                        for child_ref in self.interface_by_handle:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim6Ma.Active.InterfaceTable.InterfaceByHandles']['meta_info']


            class InterfaceByNames(object):
                """
                Table of PIM MA interfaces indexed by name
                
                .. attribute:: interface_by_name
                
                	PIM MA interface referenced by name
                	**type**\: list of    :py:class:`InterfaceByName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_by_name = YList()
                    self.interface_by_name.parent = self
                    self.interface_by_name.name = 'interface_by_name'


                class InterfaceByName(object):
                    """
                    PIM MA interface referenced by name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterfaceEnum>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.interface_type = None
                        self.rp_address = Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress()
                        self.rp_address.parent = self
                        self.source_address = Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress()
                        self.source_address.parent = self
                        self.vrf_name = None


                    class RpAddress(object):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress']['meta_info']


                    class SourceAddress(object):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:interface-table/Cisco-IOS-XR-ipv4-pim-oper:interface-by-names/Cisco-IOS-XR-ipv4-pim-oper:interface-by-name[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.interface_type is not None:
                            return True

                        if self.rp_address is not None and self.rp_address._has_data():
                            return True

                        if self.source_address is not None and self.source_address._has_data():
                            return True

                        if self.vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:interface-table/Cisco-IOS-XR-ipv4-pim-oper:interface-by-names'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_by_name is not None:
                        for child_ref in self.interface_by_name:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim6Ma.Active.InterfaceTable.InterfaceByNames']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:interface-table'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.interface_by_handles is not None and self.interface_by_handles._has_data():
                    return True

                if self.interface_by_names is not None and self.interface_by_names._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                return meta._meta_table['Pim6Ma.Active.InterfaceTable']['meta_info']


        class PimMaSummary(object):
            """
            PIM MA summary
            
            .. attribute:: decap_interface_count
            
            	Decap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: encap_interface_count
            
            	Encap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: is_edm_connection_open
            
            	EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_im_connection_open
            
            	IM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_netio_connection_open
            
            	Netio Connection Open
            	**type**\:  bool
            
            .. attribute:: is_standby_edm_connection_open
            
            	Standby EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: mdt_interface_count
            
            	MDT Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.decap_interface_count = None
                self.encap_interface_count = None
                self.is_edm_connection_open = None
                self.is_im_connection_open = None
                self.is_netio_connection_open = None
                self.is_standby_edm_connection_open = None
                self.mdt_interface_count = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/Cisco-IOS-XR-ipv4-pim-oper:active/Cisco-IOS-XR-ipv4-pim-oper:pim-ma-summary'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.decap_interface_count is not None:
                    return True

                if self.encap_interface_count is not None:
                    return True

                if self.is_edm_connection_open is not None:
                    return True

                if self.is_im_connection_open is not None:
                    return True

                if self.is_netio_connection_open is not None:
                    return True

                if self.is_standby_edm_connection_open is not None:
                    return True

                if self.mdt_interface_count is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                return meta._meta_table['Pim6Ma.Active.PimMaSummary']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/Cisco-IOS-XR-ipv4-pim-oper:active'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.interface_table is not None and self.interface_table._has_data():
                return True

            if self.pim_ma_summary is not None and self.pim_ma_summary._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
            return meta._meta_table['Pim6Ma.Active']['meta_info']


    class Standby(object):
        """
        Standby Process
        
        .. attribute:: interface_table
        
        	Interface Table
        	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable>`
        
        .. attribute:: pim_ma_summary
        
        	PIM MA summary
        	**type**\:   :py:class:`PimMaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.PimMaSummary>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.interface_table = Pim6Ma.Standby.InterfaceTable()
            self.interface_table.parent = self
            self.pim_ma_summary = Pim6Ma.Standby.PimMaSummary()
            self.pim_ma_summary.parent = self


        class InterfaceTable(object):
            """
            Interface Table
            
            .. attribute:: interface_by_handles
            
            	Table of PIM MA interfaces indexed by handle
            	**type**\:   :py:class:`InterfaceByHandles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByHandles>`
            
            .. attribute:: interface_by_names
            
            	Table of PIM MA interfaces indexed by name
            	**type**\:   :py:class:`InterfaceByNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByNames>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.interface_by_handles = Pim6Ma.Standby.InterfaceTable.InterfaceByHandles()
                self.interface_by_handles.parent = self
                self.interface_by_names = Pim6Ma.Standby.InterfaceTable.InterfaceByNames()
                self.interface_by_names.parent = self


            class InterfaceByHandles(object):
                """
                Table of PIM MA interfaces indexed by handle
                
                .. attribute:: interface_by_handle
                
                	PIM MA interface referenced by handle
                	**type**\: list of    :py:class:`InterfaceByHandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_by_handle = YList()
                    self.interface_by_handle.parent = self
                    self.interface_by_handle.name = 'interface_by_handle'


                class InterfaceByHandle(object):
                    """
                    PIM MA interface referenced by handle
                    
                    .. attribute:: interface_handle  <key>
                    
                    	Interface handle
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterfaceEnum>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_handle = None
                        self.interface_name_xr = None
                        self.interface_type = None
                        self.rp_address = Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress()
                        self.rp_address.parent = self
                        self.source_address = Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress()
                        self.source_address.parent = self
                        self.vrf_name = None


                    class RpAddress(object):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress']['meta_info']


                    class SourceAddress(object):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_handle is None:
                            raise YPYModelError('Key property interface_handle is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:interface-table/Cisco-IOS-XR-ipv4-pim-oper:interface-by-handles/Cisco-IOS-XR-ipv4-pim-oper:interface-by-handle[Cisco-IOS-XR-ipv4-pim-oper:interface-handle = ' + str(self.interface_handle) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_handle is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.interface_type is not None:
                            return True

                        if self.rp_address is not None and self.rp_address._has_data():
                            return True

                        if self.source_address is not None and self.source_address._has_data():
                            return True

                        if self.vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:interface-table/Cisco-IOS-XR-ipv4-pim-oper:interface-by-handles'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_by_handle is not None:
                        for child_ref in self.interface_by_handle:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim6Ma.Standby.InterfaceTable.InterfaceByHandles']['meta_info']


            class InterfaceByNames(object):
                """
                Table of PIM MA interfaces indexed by name
                
                .. attribute:: interface_by_name
                
                	PIM MA interface referenced by name
                	**type**\: list of    :py:class:`InterfaceByName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_by_name = YList()
                    self.interface_by_name.parent = self
                    self.interface_by_name.name = 'interface_by_name'


                class InterfaceByName(object):
                    """
                    PIM MA interface referenced by name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterfaceEnum>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.interface_type = None
                        self.rp_address = Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress()
                        self.rp_address.parent = self
                        self.source_address = Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress()
                        self.source_address.parent = self
                        self.vrf_name = None


                    class RpAddress(object):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:rp-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress']['meta_info']


                    class SourceAddress(object):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfiEnum>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-pim-oper:source-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.ipv4_address is not None:
                                return True

                            if self.ipv6_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                            return meta._meta_table['Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:interface-table/Cisco-IOS-XR-ipv4-pim-oper:interface-by-names/Cisco-IOS-XR-ipv4-pim-oper:interface-by-name[Cisco-IOS-XR-ipv4-pim-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.interface_name_xr is not None:
                            return True

                        if self.interface_type is not None:
                            return True

                        if self.rp_address is not None and self.rp_address._has_data():
                            return True

                        if self.source_address is not None and self.source_address._has_data():
                            return True

                        if self.vrf_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                        return meta._meta_table['Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:interface-table/Cisco-IOS-XR-ipv4-pim-oper:interface-by-names'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_by_name is not None:
                        for child_ref in self.interface_by_name:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                    return meta._meta_table['Pim6Ma.Standby.InterfaceTable.InterfaceByNames']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:interface-table'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.interface_by_handles is not None and self.interface_by_handles._has_data():
                    return True

                if self.interface_by_names is not None and self.interface_by_names._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                return meta._meta_table['Pim6Ma.Standby.InterfaceTable']['meta_info']


        class PimMaSummary(object):
            """
            PIM MA summary
            
            .. attribute:: decap_interface_count
            
            	Decap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: encap_interface_count
            
            	Encap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: is_edm_connection_open
            
            	EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_im_connection_open
            
            	IM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_netio_connection_open
            
            	Netio Connection Open
            	**type**\:  bool
            
            .. attribute:: is_standby_edm_connection_open
            
            	Standby EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: mdt_interface_count
            
            	MDT Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.decap_interface_count = None
                self.encap_interface_count = None
                self.is_edm_connection_open = None
                self.is_im_connection_open = None
                self.is_netio_connection_open = None
                self.is_standby_edm_connection_open = None
                self.mdt_interface_count = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/Cisco-IOS-XR-ipv4-pim-oper:standby/Cisco-IOS-XR-ipv4-pim-oper:pim-ma-summary'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.decap_interface_count is not None:
                    return True

                if self.encap_interface_count is not None:
                    return True

                if self.is_edm_connection_open is not None:
                    return True

                if self.is_im_connection_open is not None:
                    return True

                if self.is_netio_connection_open is not None:
                    return True

                if self.is_standby_edm_connection_open is not None:
                    return True

                if self.mdt_interface_count is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
                return meta._meta_table['Pim6Ma.Standby.PimMaSummary']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/Cisco-IOS-XR-ipv4-pim-oper:standby'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.interface_table is not None and self.interface_table._has_data():
                return True

            if self.pim_ma_summary is not None and self.pim_ma_summary._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
            return meta._meta_table['Pim6Ma.Standby']['meta_info']

    @property
    def _common_path(self):

        return '/Cisco-IOS-XR-ipv4-pim-oper:pim6-ma'

    def is_config(self):
        ''' Returns True if this instance represents config data else returns False '''
        return False

    def _has_data(self):
        if not self.is_config():
            return False
        if self.active is not None and self.active._has_data():
            return True

        if self.standby is not None and self.standby._has_data():
            return True

        return False

    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_pim_oper as meta
        return meta._meta_table['Pim6Ma']['meta_info']


