""" Cisco_IOS_XR_ipv6_ospfv3_cfg 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ipv6\-ospfv3 package configuration.

This module contains definitions
for the following management objects\:
  ospfv3\: OSPFv3 configuration

This YANG module augments the
  Cisco\-IOS\-XR\-snmp\-agent\-cfg
module with configuration data.

Copyright (c) 2013\-2016 by Cisco Systems, Inc.
All rights reserved.

"""


import re
import collections

from enum import Enum

from ydk.types import Empty, YList, YLeafList, DELETE, Decimal64, FixedBitsDict

from ydk.errors import YPYError, YPYModelError



class Ospfv3AddressFamilyEnum(Enum):
    """
    Ospfv3AddressFamilyEnum

    Ospfv3 address family

    .. data:: ipv6 = 1

    	IPv6 address family

    """

    ipv6 = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
        return meta._meta_table['Ospfv3AddressFamilyEnum']


class Ospfv3AuthenticationEnum(Enum):
    """
    Ospfv3AuthenticationEnum

    Ospfv3 authentication

    .. data:: md5 = 1

    	MD5 algorithm

    .. data:: sha1 = 2

    	SHA1 algorithm

    """

    md5 = 1

    sha1 = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
        return meta._meta_table['Ospfv3AuthenticationEnum']


class Ospfv3AuthenticationType2Enum(Enum):
    """
    Ospfv3AuthenticationType2Enum

    Ospfv3 authentication type2

    .. data:: null = 0

    	NULL authentication

    .. data:: md5 = 1

    	MD5 algorithm

    .. data:: sha1 = 2

    	SHA1 algorithm

    """

    null = 0

    md5 = 1

    sha1 = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
        return meta._meta_table['Ospfv3AuthenticationType2Enum']


class Ospfv3BfdEnableModeEnum(Enum):
    """
    Ospfv3BfdEnableModeEnum

    Ospfv3bfd enable mode

    .. data:: disable = 0

    	Disable Mode - Prevent inheritance

    .. data:: default = 1

    	Default Mode - Default BFD behavior

    .. data:: strict = 2

    	Strict Mode - Hold down adj until BFD sesion up

    """

    disable = 0

    default = 1

    strict = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
        return meta._meta_table['Ospfv3BfdEnableModeEnum']


class Ospfv3DomainIdEnum(Enum):
    """
    Ospfv3DomainIdEnum

    Ospfv3 domain id

    .. data:: type0005 = 5

    	Type 0x0005

    .. data:: type0105 = 261

    	Type 0x0105

    .. data:: type0205 = 517

    	Type 0x0205

    .. data:: type8005 = 32773

    	Type 0x8005

    """

    type0005 = 5

    type0105 = 261

    type0205 = 517

    type8005 = 32773


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
        return meta._meta_table['Ospfv3DomainIdEnum']


class Ospfv3EigrpRouteEnum(Enum):
    """
    Ospfv3EigrpRouteEnum

    Ospfv3 eigrp route

    .. data:: internal = 16384

    	EIGRP internal routes

    .. data:: external = 32768

    	EIGRP external routes

    """

    internal = 16384

    external = 32768


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
        return meta._meta_table['Ospfv3EigrpRouteEnum']


class Ospfv3EncryptionAlgorithmEnum(Enum):
    """
    Ospfv3EncryptionAlgorithmEnum

    Ospfv3 encryption algorithm

    .. data:: null = 0

    	Use NULL encryption

    .. data:: des = 1

    	Use the DES algorithm

    .. data:: Y_3des = 2

    	Use the triple DES algorithm

    .. data:: aes = 3

    	Use the AES algorithm

    .. data:: aes192 = 4

    	Use the 192-bit AES algorithm

    .. data:: aes256 = 5

    	Use the 256-bit AES algorithm

    """

    null = 0

    des = 1

    Y_3des = 2

    aes = 3

    aes192 = 4

    aes256 = 5


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
        return meta._meta_table['Ospfv3EncryptionAlgorithmEnum']


class Ospfv3ExternalRouteEnum(Enum):
    """
    Ospfv3ExternalRouteEnum

    Ospfv3 external route

    .. data:: external1 = 8

    	External type 1 routes

    .. data:: external2 = 16

    	External type 2 routes

    .. data:: external = 24

    	External (type 1 and 2) routes

    """

    external1 = 8

    external2 = 16

    external = 24


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
        return meta._meta_table['Ospfv3ExternalRouteEnum']


class Ospfv3FastRerouteEnum(Enum):
    """
    Ospfv3FastRerouteEnum

    Ospfv3 fast reroute

    .. data:: none = 0

    	Disable

    .. data:: per_link = 1

    	Per link

    .. data:: per_prefix = 2

    	Per prefix

    """

    none = 0

    per_link = 1

    per_prefix = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
        return meta._meta_table['Ospfv3FastRerouteEnum']


class Ospfv3FastReroutePriorityEnum(Enum):
    """
    Ospfv3FastReroutePriorityEnum

    Ospfv3 fast reroute priority

    .. data:: critical = 0

    	Critical

    .. data:: high = 1

    	High

    .. data:: medium = 2

    	Medium

    .. data:: low = 3

    	Low

    """

    critical = 0

    high = 1

    medium = 2

    low = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
        return meta._meta_table['Ospfv3FastReroutePriorityEnum']


class Ospfv3FastRerouteTiebreakersEnum(Enum):
    """
    Ospfv3FastRerouteTiebreakersEnum

    Ospfv3 fast reroute tiebreakers

    .. data:: downstream = 0

    	Downstream

    .. data:: line_card_disjoint = 1

    	LC Disjoint

    .. data:: lowest_metric = 2

    	Lowest metric

    .. data:: node_protect = 3

    	Node protection

    .. data:: primary_path = 4

    	Primary path

    .. data:: secondary_path = 5

    	Secondar path

    .. data:: srlg_disjoint = 6

    	SRLG

    """

    downstream = 0

    line_card_disjoint = 1

    lowest_metric = 2

    node_protect = 3

    primary_path = 4

    secondary_path = 5

    srlg_disjoint = 6


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
        return meta._meta_table['Ospfv3FastRerouteTiebreakersEnum']


class Ospfv3InternalRouteEnum(Enum):
    """
    Ospfv3InternalRouteEnum

    Ospfv3 internal route

    .. data:: internal = 6

    	OSPFv3 internal routes

    """

    internal = 6


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
        return meta._meta_table['Ospfv3InternalRouteEnum']


class Ospfv3IsisRouteEnum(Enum):
    """
    Ospfv3IsisRouteEnum

    Ospfv3isis route

    .. data:: level1 = 64

    	IS-IS level-1 routes

    .. data:: level2 = 128

    	IS-IS level-2 routes

    .. data:: level1_and2 = 192

    	IS-IS level-1 and level-2 routes

    """

    level1 = 64

    level2 = 128

    level1_and2 = 192


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
        return meta._meta_table['Ospfv3IsisRouteEnum']


class Ospfv3LogAdjEnum(Enum):
    """
    Ospfv3LogAdjEnum

    Ospfv3 log adj

    .. data:: suppress = 0

    	No output

    .. data:: brief = 1

    	Limited output

    .. data:: detail = 2

    	Verbose output

    """

    suppress = 0

    brief = 1

    detail = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
        return meta._meta_table['Ospfv3LogAdjEnum']


class Ospfv3MetricEnum(Enum):
    """
    Ospfv3MetricEnum

    Ospfv3 metric

    .. data:: type1 = 1

    	OSPFv3 external type 1 metrics

    .. data:: type2 = 2

    	OSPFv3 external type 2 metrics

    """

    type1 = 1

    type2 = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
        return meta._meta_table['Ospfv3MetricEnum']


class Ospfv3NetworkEnum(Enum):
    """
    Ospfv3NetworkEnum

    Ospfv3 network

    .. data:: broadcast = 1

    	Broadcast multi-access network

    .. data:: non_broadcast = 2

    	Non-broadcast multi-access network

    .. data:: point_to_point = 3

    	Point-to-point network

    .. data:: point_to_multipoint = 4

    	Point-to-multipoint network

    .. data:: non_broadcast_point_to_multipoint = 5

    	Non-broadcast point-to-multipoint network

    """

    broadcast = 1

    non_broadcast = 2

    point_to_point = 3

    point_to_multipoint = 4

    non_broadcast_point_to_multipoint = 5


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
        return meta._meta_table['Ospfv3NetworkEnum']


class Ospfv3NsrEnum(Enum):
    """
    Ospfv3NsrEnum

    Ospfv3nsr

    .. data:: true = 1

    	Enable non-stop routing

    .. data:: false = 2

    	Disable non-stop routing

    """

    true = 1

    false = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
        return meta._meta_table['Ospfv3NsrEnum']


class Ospfv3NssaExternalRouteEnum(Enum):
    """
    Ospfv3NssaExternalRouteEnum

    Ospfv3nssa external route

    .. data:: external1 = 4096

    	NSSA external type 1 routes

    .. data:: external2 = 8192

    	NSSA external type 2 routes

    .. data:: external = 12288

    	NSSA external (type 1 and 2) routes

    """

    external1 = 4096

    external2 = 8192

    external = 12288


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
        return meta._meta_table['Ospfv3NssaExternalRouteEnum']


class Ospfv3ProtocolEnum(Enum):
    """
    Ospfv3ProtocolEnum

    Ospfv3 protocol

    .. data:: all = 0

    	All

    .. data:: connected = 1

    	Connected

    .. data:: static = 3

    	Static

    .. data:: bgp = 4

    	BGP

    .. data:: isis = 6

    	ISIS

    .. data:: ospfv3 = 7

    	OSPFv3

    .. data:: eigrp = 8

    	EIGRP

    """

    all = 0

    connected = 1

    static = 3

    bgp = 4

    isis = 6

    ospfv3 = 7

    eigrp = 8


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
        return meta._meta_table['Ospfv3ProtocolEnum']


class Ospfv3ProtocolType2Enum(Enum):
    """
    Ospfv3ProtocolType2Enum

    Ospfv3 protocol type2

    .. data:: connected = 1

    	Connected

    .. data:: static = 3

    	Static

    .. data:: bgp = 4

    	BGP

    .. data:: isis = 6

    	ISIS

    .. data:: ospfv3 = 7

    	OSPFv3

    .. data:: eigrp = 8

    	EIGRP

    .. data:: subscriber = 9

    	Subscriber

    .. data:: application = 10

    	Application

    .. data:: mobile = 11

    	Mobile

    """

    connected = 1

    static = 3

    bgp = 4

    isis = 6

    ospfv3 = 7

    eigrp = 8

    subscriber = 9

    application = 10

    mobile = 11


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
        return meta._meta_table['Ospfv3ProtocolType2Enum']


class Ospfv3SubsequentAddressFamilyEnum(Enum):
    """
    Ospfv3SubsequentAddressFamilyEnum

    Ospfv3 subsequent address family

    .. data:: unicast = 1

    	Unicast subsequent address family

    """

    unicast = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
        return meta._meta_table['Ospfv3SubsequentAddressFamilyEnum']


class TraceBufSizeEnum(Enum):
    """
    TraceBufSizeEnum

    Trace buf size

    .. data:: disable = 0

    	Disable trace

    .. data:: one = 256

    	trace buffer size 256

    .. data:: two = 512

    	trace buffer size 512

    .. data:: three = 1024

    	trace buffer size 1024

    .. data:: four = 2048

    	trace buffer size 2048

    .. data:: five = 4096

    	trace buffer size 4096

    .. data:: six = 8192

    	trace buffer size 8192

    .. data:: seven = 16384

    	trace buffer size 16384

    .. data:: eight = 32768

    	trace buffer size 32768

    .. data:: nine = 65536

    	trace buffer size 65536

    """

    disable = 0

    one = 256

    two = 512

    three = 1024

    four = 2048

    five = 4096

    six = 8192

    seven = 16384

    eight = 32768

    nine = 65536


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
        return meta._meta_table['TraceBufSizeEnum']



class Ospfv3(object):
    """
    OSPFv3 configuration
    
    .. attribute:: dns_name_lookup
    
    	Enable OSPFv3 router IDs as DNS names
    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
    
    .. attribute:: processes
    
    	OSPFv3 processes
    	**type**\:   :py:class:`Processes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes>`
    
    

    """

    _prefix = 'ipv6-ospfv3-cfg'
    _revision = '2015-11-09'

    def __init__(self):
        self.dns_name_lookup = None
        self.processes = Ospfv3.Processes()
        self.processes.parent = self


    class Processes(object):
        """
        OSPFv3 processes
        
        .. attribute:: process
        
        	An OSPFv3 process
        	**type**\: list of    :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process>`
        
        

        """

        _prefix = 'ipv6-ospfv3-cfg'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.process = YList()
            self.process.parent = self
            self.process.name = 'process'


        class Process(object):
            """
            An OSPFv3 process
            
            .. attribute:: process_name  <key>
            
            	OSPFv3 process name
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: af
            
            	Address Family (AF)
            	**type**\:   :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Af>`
            
            	**presence node**\: True
            
            .. attribute:: default_vrf
            
            	Default VRF related configuration
            	**type**\:   :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf>`
            
            .. attribute:: enable
            
            	Enable OSPFv3
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: nsr
            
            	Enable non\-stop routing
            	**type**\:   :py:class:`Ospfv3NsrEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3NsrEnum>`
            
            	**default value**\: true
            
            .. attribute:: protocol_shutdown
            
            	Enable protocol shutdown
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: trace_bufs
            
            	Configuration to change size of trace buffer
            	**type**\:   :py:class:`TraceBufs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.TraceBufs>`
            
            .. attribute:: vrfs
            
            	VRF related configuration
            	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs>`
            
            

            """

            _prefix = 'ipv6-ospfv3-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.process_name = None
                self.af = None
                self.default_vrf = Ospfv3.Processes.Process.DefaultVrf()
                self.default_vrf.parent = self
                self.enable = None
                self.nsr = None
                self.protocol_shutdown = None
                self.trace_bufs = Ospfv3.Processes.Process.TraceBufs()
                self.trace_bufs.parent = self
                self.vrfs = Ospfv3.Processes.Process.Vrfs()
                self.vrfs.parent = self


            class DefaultVrf(object):
                """
                Default VRF related configuration
                
                .. attribute:: area_addresses
                
                	Area configuration
                	**type**\:   :py:class:`AreaAddresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses>`
                
                .. attribute:: authentication
                
                	Authenticate OSPFv3 packets
                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.Authentication>`
                
                .. attribute:: auto_cost
                
                	Calculate interface cost according to bandwidth
                	**type**\:   :py:class:`AutoCost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AutoCost>`
                
                	**presence node**\: True
                
                .. attribute:: bfd
                
                	Configure BFD parameters
                	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.Bfd>`
                
                .. attribute:: cost
                
                	Interface cost
                	**type**\:  int
                
                	**range:** 1..65535
                
                .. attribute:: database_filter
                
                	Database filter
                	**type**\:   :py:class:`DatabaseFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.DatabaseFilter>`
                
                .. attribute:: dead_interval
                
                	Interval after which a neighbor is declared dead (in seconds)
                	**type**\:  int
                
                	**range:** 1..65535
                
                	**units**\: second
                
                .. attribute:: default_information
                
                	Control distribution of default information
                	**type**\:   :py:class:`DefaultInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.DefaultInformation>`
                
                .. attribute:: default_metric
                
                	Set metric of redistributed routes
                	**type**\:  int
                
                	**range:** 1..16777214
                
                .. attribute:: demand_circuit
                
                	Enable/disable demand circuit operation
                	**type**\:  bool
                
                .. attribute:: distance
                
                	Define an administrative distance
                	**type**\:   :py:class:`Distance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.Distance>`
                
                .. attribute:: distribute_list
                
                	Filter prefixes to/from RIB
                	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.DistributeList>`
                
                .. attribute:: distribute_list_out
                
                	Filter prefixes from RIB 
                	**type**\:   :py:class:`DistributeListOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.DistributeListOut>`
                
                .. attribute:: encryption
                
                	Encrypt and authenticate OSPFv3 packets
                	**type**\:   :py:class:`Encryption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.Encryption>`
                
                .. attribute:: fast_reroute
                
                	Fast\-reroute instance scoped parameters
                	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.FastReroute>`
                
                .. attribute:: flood_reduction
                
                	Enable/disable flood reduction
                	**type**\:  bool
                
                .. attribute:: graceful_restart
                
                	Graceful restart configuration
                	**type**\:   :py:class:`GracefulRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.GracefulRestart>`
                
                .. attribute:: hello_interval
                
                	Time between HELLO packets
                	**type**\:  int
                
                	**range:** 1..65535
                
                	**units**\: second
                
                .. attribute:: ignore
                
                	Do not complain about a specified event
                	**type**\:   :py:class:`Ignore <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.Ignore>`
                
                .. attribute:: instance
                
                	Instance ID
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: ldp_sync
                
                	Enable/Disable MPLS LDP sync
                	**type**\:  bool
                
                .. attribute:: log_adjacency_changes
                
                	Log changes in adjacency state
                	**type**\:   :py:class:`Ospfv3LogAdjEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3LogAdjEnum>`
                
                .. attribute:: maximum
                
                	Set OSPFv3 limits
                	**type**\:   :py:class:`Maximum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.Maximum>`
                
                .. attribute:: mtu_ignore
                
                	Enable/disable ignoring of MTU in DBD packets
                	**type**\:  bool
                
                .. attribute:: network
                
                	Specify network type
                	**type**\:   :py:class:`Ospfv3NetworkEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3NetworkEnum>`
                
                .. attribute:: packet_size
                
                	Limit size of OSPFv3 packets
                	**type**\:  int
                
                	**range:** 256..10000
                
                .. attribute:: passive
                
                	Enable/disable routing updates on an interface
                	**type**\:  bool
                
                .. attribute:: prefix_suppression
                
                	Enable/disable prefix suppression on an interface
                	**type**\:  bool
                
                .. attribute:: priority
                
                	Specify router priority
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: process_scope
                
                	Process scope configuration
                	**type**\:   :py:class:`ProcessScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.ProcessScope>`
                
                .. attribute:: redistributes
                
                	Redistribute information from another routing protocol
                	**type**\:   :py:class:`Redistributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.Redistributes>`
                
                .. attribute:: retransmit_interval
                
                	Specify the transmit interval in seconds
                	**type**\:  int
                
                	**range:** 1..65535
                
                	**units**\: second
                
                .. attribute:: router_id
                
                	Specify the router ID for this OSPFv3 process in IPv4 address format
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: snmp
                
                	SNMP configuration
                	**type**\:   :py:class:`Snmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.Snmp>`
                
                .. attribute:: spf_prefix_priority_disable
                
                	SPF prefix prioritization disabled
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: spf_prefix_priority_policy
                
                	Route policy for SPF prefix prioritization
                	**type**\:  str
                
                .. attribute:: stub_router
                
                	Stub router configuration
                	**type**\:   :py:class:`StubRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.StubRouter>`
                
                .. attribute:: summary_prefixes
                
                	Summarize redistributed routes matching prefix/length
                	**type**\:   :py:class:`SummaryPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes>`
                
                .. attribute:: timers
                
                	Adjust routing timers
                	**type**\:   :py:class:`Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.Timers>`
                
                .. attribute:: transmit_delay
                
                	Specify the transmit delay in seconds
                	**type**\:  int
                
                	**range:** 1..65535
                
                	**units**\: second
                
                

                """

                _prefix = 'ipv6-ospfv3-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.area_addresses = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses()
                    self.area_addresses.parent = self
                    self.authentication = Ospfv3.Processes.Process.DefaultVrf.Authentication()
                    self.authentication.parent = self
                    self.auto_cost = None
                    self.bfd = Ospfv3.Processes.Process.DefaultVrf.Bfd()
                    self.bfd.parent = self
                    self.cost = None
                    self.database_filter = Ospfv3.Processes.Process.DefaultVrf.DatabaseFilter()
                    self.database_filter.parent = self
                    self.dead_interval = None
                    self.default_information = Ospfv3.Processes.Process.DefaultVrf.DefaultInformation()
                    self.default_information.parent = self
                    self.default_metric = None
                    self.demand_circuit = None
                    self.distance = Ospfv3.Processes.Process.DefaultVrf.Distance()
                    self.distance.parent = self
                    self.distribute_list = Ospfv3.Processes.Process.DefaultVrf.DistributeList()
                    self.distribute_list.parent = self
                    self.distribute_list_out = Ospfv3.Processes.Process.DefaultVrf.DistributeListOut()
                    self.distribute_list_out.parent = self
                    self.encryption = Ospfv3.Processes.Process.DefaultVrf.Encryption()
                    self.encryption.parent = self
                    self.fast_reroute = Ospfv3.Processes.Process.DefaultVrf.FastReroute()
                    self.fast_reroute.parent = self
                    self.flood_reduction = None
                    self.graceful_restart = Ospfv3.Processes.Process.DefaultVrf.GracefulRestart()
                    self.graceful_restart.parent = self
                    self.hello_interval = None
                    self.ignore = Ospfv3.Processes.Process.DefaultVrf.Ignore()
                    self.ignore.parent = self
                    self.instance = None
                    self.ldp_sync = None
                    self.log_adjacency_changes = None
                    self.maximum = Ospfv3.Processes.Process.DefaultVrf.Maximum()
                    self.maximum.parent = self
                    self.mtu_ignore = None
                    self.network = None
                    self.packet_size = None
                    self.passive = None
                    self.prefix_suppression = None
                    self.priority = None
                    self.process_scope = Ospfv3.Processes.Process.DefaultVrf.ProcessScope()
                    self.process_scope.parent = self
                    self.redistributes = Ospfv3.Processes.Process.DefaultVrf.Redistributes()
                    self.redistributes.parent = self
                    self.retransmit_interval = None
                    self.router_id = None
                    self.snmp = Ospfv3.Processes.Process.DefaultVrf.Snmp()
                    self.snmp.parent = self
                    self.spf_prefix_priority_disable = None
                    self.spf_prefix_priority_policy = None
                    self.stub_router = Ospfv3.Processes.Process.DefaultVrf.StubRouter()
                    self.stub_router.parent = self
                    self.summary_prefixes = Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes()
                    self.summary_prefixes.parent = self
                    self.timers = Ospfv3.Processes.Process.DefaultVrf.Timers()
                    self.timers.parent = self
                    self.transmit_delay = None


                class AreaAddresses(object):
                    """
                    Area configuration
                    
                    .. attribute:: area_address
                    
                    	Configuration for a particular area
                    	**type**\: list of    :py:class:`AreaAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress>`
                    
                    .. attribute:: area_area_id
                    
                    	Configuration for a particular area
                    	**type**\: list of    :py:class:`AreaAreaId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.area_address = YList()
                        self.area_address.parent = self
                        self.area_address.name = 'area_address'
                        self.area_area_id = YList()
                        self.area_area_id.parent = self
                        self.area_area_id.name = 'area_area_id'


                    class AreaAddress(object):
                        """
                        Configuration for a particular area
                        
                        .. attribute:: address  <key>
                        
                        	Area ID if in IP address format
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: area_scope
                        
                        	Area Scope Configuration
                        	**type**\:   :py:class:`AreaScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope>`
                        
                        .. attribute:: authentication
                        
                        	Authenticate OSPFv3 packets
                        	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Configure BFD parameters
                        	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Bfd>`
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Database filter
                        	**type**\:   :py:class:`DatabaseFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead (in seconds)
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        	**units**\: second
                        
                        .. attribute:: default_cost
                        
                        	Set the summary default\-cost of a NSSA/stub area
                        	**type**\:  int
                        
                        	**range:** 0..16777215
                        
                        .. attribute:: demand_circuit
                        
                        	Enable/disable demand circuit operation
                        	**type**\:  bool
                        
                        .. attribute:: distribute_list
                        
                        	Filter prefixes to/from RIB
                        	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.DistributeList>`
                        
                        .. attribute:: enable
                        
                        	Enable OSPFv3 area
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: encryption
                        
                        	Encrypt and authenticate OSPFv3 packets
                        	**type**\:   :py:class:`Encryption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Encryption>`
                        
                        .. attribute:: flood_reduction
                        
                        	Enable/disable flood reduction
                        	**type**\:  bool
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        	**units**\: second
                        
                        .. attribute:: instance
                        
                        	Instance ID
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interfaces
                        
                        	OSPFv3 interfaces
                        	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces>`
                        
                        .. attribute:: ldp_sync
                        
                        	Enable/Disable MPLS LDP sync
                        	**type**\:  bool
                        
                        .. attribute:: mtu_ignore
                        
                        	Enable/disable ignoring of MTU in DBD packets
                        	**type**\:  bool
                        
                        .. attribute:: network
                        
                        	Specify network type
                        	**type**\:   :py:class:`Ospfv3NetworkEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3NetworkEnum>`
                        
                        .. attribute:: nssa
                        
                        	Specify area as a NSSA area.  Allowed only in non\-backbone areas
                        	**type**\:   :py:class:`Nssa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Nssa>`
                        
                        .. attribute:: packet_size
                        
                        	Limit size of OSPFv3 packets
                        	**type**\:  int
                        
                        	**range:** 256..10000
                        
                        .. attribute:: passive
                        
                        	Enable/disable routing updates on an interface
                        	**type**\:  bool
                        
                        .. attribute:: prefix_suppression
                        
                        	Enable/disable prefix suppression on an interface
                        	**type**\:  bool
                        
                        .. attribute:: priority
                        
                        	Specify router priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: ranges
                        
                        	Range configuration
                        	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Ranges>`
                        
                        .. attribute:: retransmit_interval
                        
                        	Specify the transmit interval in seconds
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        	**units**\: second
                        
                        .. attribute:: sham_links
                        
                        	Sham Link sub\-mode
                        	**type**\:   :py:class:`ShamLinks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinks>`
                        
                        .. attribute:: stub
                        
                        	Specify area as a stub area.  Allowed only in non\-backbone areas
                        	**type**\:  bool
                        
                        .. attribute:: transmit_delay
                        
                        	Specify the transmit delay in seconds
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        	**units**\: second
                        
                        .. attribute:: virtual_links
                        
                        	Virtual link sub\-mode
                        	**type**\:   :py:class:`VirtualLinks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinks>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.address = None
                            self.area_scope = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope()
                            self.area_scope.parent = self
                            self.authentication = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Authentication()
                            self.authentication.parent = self
                            self.bfd = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Bfd()
                            self.bfd.parent = self
                            self.cost = None
                            self.database_filter = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.DatabaseFilter()
                            self.database_filter.parent = self
                            self.dead_interval = None
                            self.default_cost = None
                            self.demand_circuit = None
                            self.distribute_list = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.DistributeList()
                            self.distribute_list.parent = self
                            self.enable = None
                            self.encryption = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Encryption()
                            self.encryption.parent = self
                            self.flood_reduction = None
                            self.hello_interval = None
                            self.instance = None
                            self.interfaces = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces()
                            self.interfaces.parent = self
                            self.ldp_sync = None
                            self.mtu_ignore = None
                            self.network = None
                            self.nssa = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Nssa()
                            self.nssa.parent = self
                            self.packet_size = None
                            self.passive = None
                            self.prefix_suppression = None
                            self.priority = None
                            self.ranges = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Ranges()
                            self.ranges.parent = self
                            self.retransmit_interval = None
                            self.sham_links = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinks()
                            self.sham_links.parent = self
                            self.stub = None
                            self.transmit_delay = None
                            self.virtual_links = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinks()
                            self.virtual_links.parent = self


                        class Authentication(object):
                            """
                            Authenticate OSPFv3 packets
                            
                            .. attribute:: algorithm
                            
                            	Use the MD5 or SHA1 algorithm
                            	**type**\:   :py:class:`Ospfv3AuthenticationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationEnum>`
                            
                            .. attribute:: enable
                            
                            	Authenticate packets
                            	**type**\:  bool
                            
                            .. attribute:: password
                            
                            	Specify MD5 or SHA1 password
                            	**type**\:  str
                            
                            	**pattern:** (!.+)\|([^!].+)
                            
                            .. attribute:: spi
                            
                            	Use IPSec AH authentication. Specify the Security Parameter Index (SPI) value
                            	**type**\:  int
                            
                            	**range:** 256..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.algorithm = None
                                self.enable = None
                                self.password = None
                                self.spi = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:authentication'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.algorithm is not None:
                                    return True

                                if self.enable is not None:
                                    return True

                                if self.password is not None:
                                    return True

                                if self.spi is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Authentication']['meta_info']


                        class Bfd(object):
                            """
                            Configure BFD parameters
                            
                            .. attribute:: detection_multiplier
                            
                            	Detect multiplier
                            	**type**\:  int
                            
                            	**range:** 2..50
                            
                            .. attribute:: fast_detect_mode
                            
                            	Enable or disable BFD fast detection
                            	**type**\:   :py:class:`Ospfv3BfdEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3BfdEnableModeEnum>`
                            
                            .. attribute:: interval
                            
                            	Hello interval in milli\-seconds
                            	**type**\:  int
                            
                            	**range:** 3..30000
                            
                            	**units**\: millisecond
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.detection_multiplier = None
                                self.fast_detect_mode = None
                                self.interval = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:bfd'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.detection_multiplier is not None:
                                    return True

                                if self.fast_detect_mode is not None:
                                    return True

                                if self.interval is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Bfd']['meta_info']


                        class Ranges(object):
                            """
                            Range configuration
                            
                            .. attribute:: range
                            
                            	Summarize inter\-area routes matching prefix/length
                            	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Ranges.Range>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.range = YList()
                                self.range.parent = self
                                self.range.name = 'range'


                            class Range(object):
                                """
                                Summarize inter\-area routes matching
                                prefix/length
                                
                                .. attribute:: prefix  <key>
                                
                                	IPv6 prefix format
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length  <key>
                                
                                	IPV6 prefix length
                                	**type**\:  int
                                
                                	**range:** 0..128
                                
                                .. attribute:: cost
                                
                                	Specified metric for this range
                                	**type**\:  int
                                
                                	**range:** 1..16777214
                                
                                .. attribute:: not_advertise
                                
                                	Do not advertise address range
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.prefix = None
                                    self.prefix_length = None
                                    self.cost = None
                                    self.not_advertise = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.prefix is None:
                                        raise YPYModelError('Key property prefix is None')
                                    if self.prefix_length is None:
                                        raise YPYModelError('Key property prefix_length is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:range[Cisco-IOS-XR-ipv6-ospfv3-cfg:prefix = ' + str(self.prefix) + '][Cisco-IOS-XR-ipv6-ospfv3-cfg:prefix-length = ' + str(self.prefix_length) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.prefix is not None:
                                        return True

                                    if self.prefix_length is not None:
                                        return True

                                    if self.cost is not None:
                                        return True

                                    if self.not_advertise is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Ranges.Range']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:ranges'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.range is not None:
                                    for child_ref in self.range:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Ranges']['meta_info']


                        class Encryption(object):
                            """
                            Encrypt and authenticate OSPFv3 packets
                            
                            .. attribute:: authentication_algorithm
                            
                            	Use the NULL, MD5 or SHA1 algorithm
                            	**type**\:   :py:class:`Ospfv3AuthenticationType2Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationType2Enum>`
                            
                            .. attribute:: authentication_password
                            
                            	Specify MD5 or SHA1 password
                            	**type**\:  str
                            
                            	**pattern:** (!.+)\|([^!].+)
                            
                            .. attribute:: enable
                            
                            	Authenticate packets
                            	**type**\:  bool
                            
                            .. attribute:: encryption_algorithm
                            
                            	Specify the encryption algorithm
                            	**type**\:   :py:class:`Ospfv3EncryptionAlgorithmEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EncryptionAlgorithmEnum>`
                            
                            .. attribute:: encryption_password
                            
                            	Encryption password
                            	**type**\:  str
                            
                            	**pattern:** (!.+)\|([^!].+)
                            
                            .. attribute:: spi
                            
                            	Use IPSec ESP authentication. Specify the Security Parameter Index (SPI) value
                            	**type**\:  int
                            
                            	**range:** 256..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.authentication_algorithm = None
                                self.authentication_password = None
                                self.enable = None
                                self.encryption_algorithm = None
                                self.encryption_password = None
                                self.spi = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:encryption'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.authentication_algorithm is not None:
                                    return True

                                if self.authentication_password is not None:
                                    return True

                                if self.enable is not None:
                                    return True

                                if self.encryption_algorithm is not None:
                                    return True

                                if self.encryption_password is not None:
                                    return True

                                if self.spi is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Encryption']['meta_info']


                        class Nssa(object):
                            """
                            Specify area as a NSSA area.  Allowed only in
                            non\-backbone areas
                            
                            .. attribute:: default_info_originate
                            
                            	Originate Type 7 default into NSSA area
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: metric
                            
                            	Only valid with DefaultInfoOriginate
                            	**type**\:  int
                            
                            	**range:** 0..16777214
                            
                            .. attribute:: metric_type
                            
                            	Only valid with DefaultInfoOriginate
                            	**type**\:   :py:class:`Ospfv3MetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3MetricEnum>`
                            
                            .. attribute:: no_redistribution
                            
                            	No redistribution into this NSSA area
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: no_summary
                            
                            	Do not send summary LSA into NSSA
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.default_info_originate = None
                                self.metric = None
                                self.metric_type = None
                                self.no_redistribution = None
                                self.no_summary = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:nssa'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.default_info_originate is not None:
                                    return True

                                if self.metric is not None:
                                    return True

                                if self.metric_type is not None:
                                    return True

                                if self.no_redistribution is not None:
                                    return True

                                if self.no_summary is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Nssa']['meta_info']


                        class DatabaseFilter(object):
                            """
                            Database filter
                            
                            .. attribute:: all
                            
                            	All
                            	**type**\:   :py:class:`All <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.all = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.DatabaseFilter.All()
                                self.all.parent = self


                            class All(object):
                                """
                                All
                                
                                .. attribute:: out
                                
                                	Enable or disable database\-filter
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.out = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:all'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.out is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.DatabaseFilter.All']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:database-filter'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.all is not None and self.all._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.DatabaseFilter']['meta_info']


                        class DistributeList(object):
                            """
                            Filter prefixes to/from RIB
                            
                            .. attribute:: in_
                            
                            	Filter prefixes installed to RIB
                            	**type**\:   :py:class:`In_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.DistributeList.In_>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.in_ = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.DistributeList.In_()
                                self.in_.parent = self


                            class In_(object):
                                """
                                Filter prefixes installed to RIB
                                
                                .. attribute:: prefix_list
                                
                                	Filter prefixes based on an IPv6 prefix\-list
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.prefix_list = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:in'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.prefix_list is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.DistributeList.In_']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:distribute-list'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.in_ is not None and self.in_._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.DistributeList']['meta_info']


                        class Interfaces(object):
                            """
                            OSPFv3 interfaces
                            
                            .. attribute:: interface
                            
                            	OSPFv3 interface
                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface = YList()
                                self.interface.parent = self
                                self.interface.name = 'interface'


                            class Interface(object):
                                """
                                OSPFv3 interface
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface to configure
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: authentication
                                
                                	Authenticate OSPFv3 packets
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.Authentication>`
                                
                                .. attribute:: bfd
                                
                                	Configure BFD parameters
                                	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.Bfd>`
                                
                                .. attribute:: cost
                                
                                	Interface cost
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: database_filter
                                
                                	Database filter
                                	**type**\:   :py:class:`DatabaseFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.DatabaseFilter>`
                                
                                .. attribute:: dead_interval
                                
                                	Interval after which a neighbor is declared dead (in seconds)
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: demand_circuit
                                
                                	Enable/disable demand circuit operation
                                	**type**\:  bool
                                
                                .. attribute:: distribute_list
                                
                                	Filter prefixes to/from RIB
                                	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.DistributeList>`
                                
                                .. attribute:: enable
                                
                                	Enable OSPFv3 interface
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: encryption
                                
                                	Encrypt and authenticate OSPFv3 packets
                                	**type**\:   :py:class:`Encryption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.Encryption>`
                                
                                .. attribute:: fast_reroute
                                
                                	Fast\-reroute configuration
                                	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute>`
                                
                                .. attribute:: flood_reduction
                                
                                	Enable/disable flood reduction
                                	**type**\:  bool
                                
                                .. attribute:: hello_interval
                                
                                	Time between HELLO packets
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: instance
                                
                                	Instance ID
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ldp_sync
                                
                                	Enable/Disable MPLS LDP sync
                                	**type**\:  bool
                                
                                .. attribute:: mtu_ignore
                                
                                	Enable/disable ignoring of MTU in DBD packets
                                	**type**\:  bool
                                
                                .. attribute:: neighbors
                                
                                	Specify a neighbor router
                                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.Neighbors>`
                                
                                .. attribute:: network
                                
                                	Specify network type
                                	**type**\:   :py:class:`Ospfv3NetworkEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3NetworkEnum>`
                                
                                .. attribute:: packet_size
                                
                                	Limit size of OSPFv3 packets
                                	**type**\:  int
                                
                                	**range:** 256..10000
                                
                                .. attribute:: passive
                                
                                	Enable/disable routing updates on an interface
                                	**type**\:  bool
                                
                                .. attribute:: prefix_suppression
                                
                                	Enable/disable prefix suppression on an interface
                                	**type**\:  bool
                                
                                .. attribute:: priority
                                
                                	Specify router priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: retransmit_interval
                                
                                	Specify the transmit interval in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: transmit_delay
                                
                                	Specify the transmit delay in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_name = None
                                    self.authentication = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.Authentication()
                                    self.authentication.parent = self
                                    self.bfd = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.Bfd()
                                    self.bfd.parent = self
                                    self.cost = None
                                    self.database_filter = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.DatabaseFilter()
                                    self.database_filter.parent = self
                                    self.dead_interval = None
                                    self.demand_circuit = None
                                    self.distribute_list = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.DistributeList()
                                    self.distribute_list.parent = self
                                    self.enable = None
                                    self.encryption = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.Encryption()
                                    self.encryption.parent = self
                                    self.fast_reroute = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute()
                                    self.fast_reroute.parent = self
                                    self.flood_reduction = None
                                    self.hello_interval = None
                                    self.instance = None
                                    self.ldp_sync = None
                                    self.mtu_ignore = None
                                    self.neighbors = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.Neighbors()
                                    self.neighbors.parent = self
                                    self.network = None
                                    self.packet_size = None
                                    self.passive = None
                                    self.prefix_suppression = None
                                    self.priority = None
                                    self.retransmit_interval = None
                                    self.transmit_delay = None


                                class Authentication(object):
                                    """
                                    Authenticate OSPFv3 packets
                                    
                                    .. attribute:: algorithm
                                    
                                    	Use the MD5 or SHA1 algorithm
                                    	**type**\:   :py:class:`Ospfv3AuthenticationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationEnum>`
                                    
                                    .. attribute:: enable
                                    
                                    	Authenticate packets
                                    	**type**\:  bool
                                    
                                    .. attribute:: password
                                    
                                    	Specify MD5 or SHA1 password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: spi
                                    
                                    	Use IPSec AH authentication. Specify the Security Parameter Index (SPI) value
                                    	**type**\:  int
                                    
                                    	**range:** 256..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.algorithm = None
                                        self.enable = None
                                        self.password = None
                                        self.spi = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:authentication'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.algorithm is not None:
                                            return True

                                        if self.enable is not None:
                                            return True

                                        if self.password is not None:
                                            return True

                                        if self.spi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.Authentication']['meta_info']


                                class Neighbors(object):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: neighbor
                                    
                                    	IPv6 address
                                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.Neighbors.Neighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.neighbor = YList()
                                        self.neighbor.parent = self
                                        self.neighbor.name = 'neighbor'


                                    class Neighbor(object):
                                        """
                                        IPv6 address
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	IPV6 address
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: cost
                                        
                                        	OSPFv3 cost for point\-to\-multipoint neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: database_filter
                                        
                                        	Filter OSPFv3 LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: poll_interval
                                        
                                        	OSPFv3 dead\-router polling interval (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: priority
                                        
                                        	OSPFv3 priority of non\-broadcast neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: zone
                                        
                                        	Zone
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.neighbor_address = None
                                            self.cost = None
                                            self.database_filter = None
                                            self.poll_interval = None
                                            self.priority = None
                                            self.zone = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.neighbor_address is None:
                                                raise YPYModelError('Key property neighbor_address is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:neighbor[Cisco-IOS-XR-ipv6-ospfv3-cfg:neighbor-address = ' + str(self.neighbor_address) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.neighbor_address is not None:
                                                return True

                                            if self.cost is not None:
                                                return True

                                            if self.database_filter is not None:
                                                return True

                                            if self.poll_interval is not None:
                                                return True

                                            if self.priority is not None:
                                                return True

                                            if self.zone is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.Neighbors.Neighbor']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:neighbors'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.neighbor is not None:
                                            for child_ref in self.neighbor:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.Neighbors']['meta_info']


                                class Encryption(object):
                                    """
                                    Encrypt and authenticate OSPFv3 packets
                                    
                                    .. attribute:: authentication_algorithm
                                    
                                    	Use the NULL, MD5 or SHA1 algorithm
                                    	**type**\:   :py:class:`Ospfv3AuthenticationType2Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationType2Enum>`
                                    
                                    .. attribute:: authentication_password
                                    
                                    	Specify MD5 or SHA1 password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: enable
                                    
                                    	Authenticate packets
                                    	**type**\:  bool
                                    
                                    .. attribute:: encryption_algorithm
                                    
                                    	Specify the encryption algorithm
                                    	**type**\:   :py:class:`Ospfv3EncryptionAlgorithmEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EncryptionAlgorithmEnum>`
                                    
                                    .. attribute:: encryption_password
                                    
                                    	Encryption password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: spi
                                    
                                    	Use IPSec ESP authentication. Specify the Security Parameter Index (SPI) value
                                    	**type**\:  int
                                    
                                    	**range:** 256..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.authentication_algorithm = None
                                        self.authentication_password = None
                                        self.enable = None
                                        self.encryption_algorithm = None
                                        self.encryption_password = None
                                        self.spi = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:encryption'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.authentication_algorithm is not None:
                                            return True

                                        if self.authentication_password is not None:
                                            return True

                                        if self.enable is not None:
                                            return True

                                        if self.encryption_algorithm is not None:
                                            return True

                                        if self.encryption_password is not None:
                                            return True

                                        if self.spi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.Encryption']['meta_info']


                                class Bfd(object):
                                    """
                                    Configure BFD parameters
                                    
                                    .. attribute:: detection_multiplier
                                    
                                    	Detect multiplier
                                    	**type**\:  int
                                    
                                    	**range:** 2..50
                                    
                                    .. attribute:: fast_detect_mode
                                    
                                    	Enable or disable BFD fast detection
                                    	**type**\:   :py:class:`Ospfv3BfdEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3BfdEnableModeEnum>`
                                    
                                    .. attribute:: interval
                                    
                                    	Hello interval in milli\-seconds
                                    	**type**\:  int
                                    
                                    	**range:** 3..30000
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.detection_multiplier = None
                                        self.fast_detect_mode = None
                                        self.interval = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:bfd'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.detection_multiplier is not None:
                                            return True

                                        if self.fast_detect_mode is not None:
                                            return True

                                        if self.interval is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.Bfd']['meta_info']


                                class DatabaseFilter(object):
                                    """
                                    Database filter
                                    
                                    .. attribute:: all
                                    
                                    	All
                                    	**type**\:   :py:class:`All <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.DatabaseFilter.All>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.all = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.DatabaseFilter.All()
                                        self.all.parent = self


                                    class All(object):
                                        """
                                        All
                                        
                                        .. attribute:: out
                                        
                                        	Enable or disable database\-filter
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.out = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:all'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.out is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.DatabaseFilter.All']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:database-filter'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.all is not None and self.all._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.DatabaseFilter']['meta_info']


                                class DistributeList(object):
                                    """
                                    Filter prefixes to/from RIB
                                    
                                    .. attribute:: in_
                                    
                                    	Filter prefixes installed to RIB
                                    	**type**\:   :py:class:`In_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.DistributeList.In_>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.in_ = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.DistributeList.In_()
                                        self.in_.parent = self


                                    class In_(object):
                                        """
                                        Filter prefixes installed to RIB
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Filter prefixes based on an IPv6 prefix\-list
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.prefix_list = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:in'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.prefix_list is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.DistributeList.In_']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:distribute-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.in_ is not None and self.in_._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.DistributeList']['meta_info']


                                class FastReroute(object):
                                    """
                                    Fast\-reroute configuration
                                    
                                    .. attribute:: fast_reroute_enable
                                    
                                    	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                    	**type**\:   :py:class:`Ospfv3FastRerouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3FastRerouteEnum>`
                                    
                                    .. attribute:: per_link
                                    
                                    	Fast\-reroute per\-link configuration
                                    	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink>`
                                    
                                    .. attribute:: per_prefix
                                    
                                    	Fast\-reroute per\-link configuration
                                    	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.fast_reroute_enable = None
                                        self.per_link = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink()
                                        self.per_link.parent = self
                                        self.per_prefix = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix()
                                        self.per_prefix.parent = self


                                    class PerLink(object):
                                        """
                                        Fast\-reroute per\-link configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.candidate_interfaces = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self.exclude_interfaces = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self.fast_reroute_use_candidate_only = None


                                        class CandidateInterfaces(object):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.candidate_interface = YList()
                                                self.candidate_interface.parent = self
                                                self.candidate_interface.name = 'candidate_interface'


                                            class CandidateInterface(object):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.interface_name is None:
                                                        raise YPYModelError('Key property interface_name is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink.CandidateInterfaces.CandidateInterface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interfaces'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.candidate_interface is not None:
                                                    for child_ref in self.candidate_interface:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink.CandidateInterfaces']['meta_info']


                                        class ExcludeInterfaces(object):
                                            """
                                            Fast\-reroute per\-link/per\-prefix exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.exclude_interface = YList()
                                                self.exclude_interface.parent = self
                                                self.exclude_interface.name = 'exclude_interface'


                                            class ExcludeInterface(object):
                                                """
                                                Exclude an interface from becoming a backup
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.interface_name is None:
                                                        raise YPYModelError('Key property interface_name is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interfaces'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.exclude_interface is not None:
                                                    for child_ref in self.exclude_interface:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink.ExcludeInterfaces']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-link'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.candidate_interfaces is not None and self.candidate_interfaces._has_data():
                                                return True

                                            if self.exclude_interfaces is not None and self.exclude_interfaces._has_data():
                                                return True

                                            if self.fast_reroute_use_candidate_only is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink']['meta_info']


                                    class PerPrefix(object):
                                        """
                                        Fast\-reroute per\-link configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.candidate_interfaces = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self.exclude_interfaces = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self.fast_reroute_use_candidate_only = None


                                        class CandidateInterfaces(object):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.candidate_interface = YList()
                                                self.candidate_interface.parent = self
                                                self.candidate_interface.name = 'candidate_interface'


                                            class CandidateInterface(object):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.interface_name is None:
                                                        raise YPYModelError('Key property interface_name is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interfaces'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.candidate_interface is not None:
                                                    for child_ref in self.candidate_interface:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix.CandidateInterfaces']['meta_info']


                                        class ExcludeInterfaces(object):
                                            """
                                            Fast\-reroute per\-link/per\-prefix exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.exclude_interface = YList()
                                                self.exclude_interface.parent = self
                                                self.exclude_interface.name = 'exclude_interface'


                                            class ExcludeInterface(object):
                                                """
                                                Exclude an interface from becoming a backup
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.interface_name is None:
                                                        raise YPYModelError('Key property interface_name is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interfaces'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.exclude_interface is not None:
                                                    for child_ref in self.exclude_interface:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix.ExcludeInterfaces']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-prefix'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.candidate_interfaces is not None and self.candidate_interfaces._has_data():
                                                return True

                                            if self.exclude_interfaces is not None and self.exclude_interfaces._has_data():
                                                return True

                                            if self.fast_reroute_use_candidate_only is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:fast-reroute'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.fast_reroute_enable is not None:
                                            return True

                                        if self.per_link is not None and self.per_link._has_data():
                                            return True

                                        if self.per_prefix is not None and self.per_prefix._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.interface_name is None:
                                        raise YPYModelError('Key property interface_name is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_name is not None:
                                        return True

                                    if self.authentication is not None and self.authentication._has_data():
                                        return True

                                    if self.bfd is not None and self.bfd._has_data():
                                        return True

                                    if self.cost is not None:
                                        return True

                                    if self.database_filter is not None and self.database_filter._has_data():
                                        return True

                                    if self.dead_interval is not None:
                                        return True

                                    if self.demand_circuit is not None:
                                        return True

                                    if self.distribute_list is not None and self.distribute_list._has_data():
                                        return True

                                    if self.enable is not None:
                                        return True

                                    if self.encryption is not None and self.encryption._has_data():
                                        return True

                                    if self.fast_reroute is not None and self.fast_reroute._has_data():
                                        return True

                                    if self.flood_reduction is not None:
                                        return True

                                    if self.hello_interval is not None:
                                        return True

                                    if self.instance is not None:
                                        return True

                                    if self.ldp_sync is not None:
                                        return True

                                    if self.mtu_ignore is not None:
                                        return True

                                    if self.neighbors is not None and self.neighbors._has_data():
                                        return True

                                    if self.network is not None:
                                        return True

                                    if self.packet_size is not None:
                                        return True

                                    if self.passive is not None:
                                        return True

                                    if self.prefix_suppression is not None:
                                        return True

                                    if self.priority is not None:
                                        return True

                                    if self.retransmit_interval is not None:
                                        return True

                                    if self.transmit_delay is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces.Interface']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:interfaces'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface is not None:
                                    for child_ref in self.interface:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Interfaces']['meta_info']


                        class AreaScope(object):
                            """
                            Area Scope Configuration
                            
                            .. attribute:: fast_reroute
                            
                            	Fast\-reroute configuration
                            	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.fast_reroute = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute()
                                self.fast_reroute.parent = self


                            class FastReroute(object):
                                """
                                Fast\-reroute configuration
                                
                                .. attribute:: fast_reroute_enable
                                
                                	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                	**type**\:   :py:class:`Ospfv3FastRerouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3FastRerouteEnum>`
                                
                                .. attribute:: per_link
                                
                                	Fast\-reroute per\-link configuration
                                	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink>`
                                
                                .. attribute:: per_prefix
                                
                                	Fast\-reroute per\-link configuration
                                	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.fast_reroute_enable = None
                                    self.per_link = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink()
                                    self.per_link.parent = self
                                    self.per_prefix = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix()
                                    self.per_prefix.parent = self


                                class PerLink(object):
                                    """
                                    Fast\-reroute per\-link configuration
                                    
                                    .. attribute:: candidate_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                    	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces>`
                                    
                                    .. attribute:: exclude_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix exclude interface configuration
                                    	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces>`
                                    
                                    .. attribute:: fast_reroute_use_candidate_only
                                    
                                    	Use only interfaces on the candidate list as a backup path
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.candidate_interfaces = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces()
                                        self.candidate_interfaces.parent = self
                                        self.exclude_interfaces = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces()
                                        self.exclude_interfaces.parent = self
                                        self.fast_reroute_use_candidate_only = None


                                    class CandidateInterfaces(object):
                                        """
                                        Fast\-reroute per\-link/per\-prefix candidate
                                        interface configuration
                                        
                                        .. attribute:: candidate_interface
                                        
                                        	Candidate backup interface
                                        	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.candidate_interface = YList()
                                            self.candidate_interface.parent = self
                                            self.candidate_interface.name = 'candidate_interface'


                                        class CandidateInterface(object):
                                            """
                                            Candidate backup interface
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.interface_name is None:
                                                    raise YPYModelError('Key property interface_name is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interfaces'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.candidate_interface is not None:
                                                for child_ref in self.candidate_interface:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces']['meta_info']


                                    class ExcludeInterfaces(object):
                                        """
                                        Fast\-reroute per\-link/per\-prefix exclude
                                        interface configuration
                                        
                                        .. attribute:: exclude_interface
                                        
                                        	Exclude an interface from becoming a backup
                                        	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.exclude_interface = YList()
                                            self.exclude_interface.parent = self
                                            self.exclude_interface.name = 'exclude_interface'


                                        class ExcludeInterface(object):
                                            """
                                            Exclude an interface from becoming a backup
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.interface_name is None:
                                                    raise YPYModelError('Key property interface_name is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interfaces'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.exclude_interface is not None:
                                                for child_ref in self.exclude_interface:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-link'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.candidate_interfaces is not None and self.candidate_interfaces._has_data():
                                            return True

                                        if self.exclude_interfaces is not None and self.exclude_interfaces._has_data():
                                            return True

                                        if self.fast_reroute_use_candidate_only is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink']['meta_info']


                                class PerPrefix(object):
                                    """
                                    Fast\-reroute per\-link configuration
                                    
                                    .. attribute:: candidate_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                    	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                    
                                    .. attribute:: exclude_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix exclude interface configuration
                                    	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                    
                                    .. attribute:: fast_reroute_use_candidate_only
                                    
                                    	Use only interfaces on the candidate list as a backup path
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.candidate_interfaces = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces()
                                        self.candidate_interfaces.parent = self
                                        self.exclude_interfaces = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                        self.exclude_interfaces.parent = self
                                        self.fast_reroute_use_candidate_only = None


                                    class CandidateInterfaces(object):
                                        """
                                        Fast\-reroute per\-link/per\-prefix candidate
                                        interface configuration
                                        
                                        .. attribute:: candidate_interface
                                        
                                        	Candidate backup interface
                                        	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.candidate_interface = YList()
                                            self.candidate_interface.parent = self
                                            self.candidate_interface.name = 'candidate_interface'


                                        class CandidateInterface(object):
                                            """
                                            Candidate backup interface
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.interface_name is None:
                                                    raise YPYModelError('Key property interface_name is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interfaces'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.candidate_interface is not None:
                                                for child_ref in self.candidate_interface:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces']['meta_info']


                                    class ExcludeInterfaces(object):
                                        """
                                        Fast\-reroute per\-link/per\-prefix exclude
                                        interface configuration
                                        
                                        .. attribute:: exclude_interface
                                        
                                        	Exclude an interface from becoming a backup
                                        	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.exclude_interface = YList()
                                            self.exclude_interface.parent = self
                                            self.exclude_interface.name = 'exclude_interface'


                                        class ExcludeInterface(object):
                                            """
                                            Exclude an interface from becoming a backup
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.interface_name is None:
                                                    raise YPYModelError('Key property interface_name is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interfaces'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.exclude_interface is not None:
                                                for child_ref in self.exclude_interface:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-prefix'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.candidate_interfaces is not None and self.candidate_interfaces._has_data():
                                            return True

                                        if self.exclude_interfaces is not None and self.exclude_interfaces._has_data():
                                            return True

                                        if self.fast_reroute_use_candidate_only is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:fast-reroute'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.fast_reroute_enable is not None:
                                        return True

                                    if self.per_link is not None and self.per_link._has_data():
                                        return True

                                    if self.per_prefix is not None and self.per_prefix._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:area-scope'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.fast_reroute is not None and self.fast_reroute._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope']['meta_info']


                        class ShamLinks(object):
                            """
                            Sham Link sub\-mode
                            
                            .. attribute:: sham_link
                            
                            	ShamLink local and remote endpoints
                            	**type**\: list of    :py:class:`ShamLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinks.ShamLink>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.sham_link = YList()
                                self.sham_link.parent = self
                                self.sham_link.name = 'sham_link'


                            class ShamLink(object):
                                """
                                ShamLink local and remote endpoints
                                
                                .. attribute:: destination_address  <key>
                                
                                	Remote sham\-link endpoint
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address  <key>
                                
                                	Local sham\-link endpoint
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: authentication
                                
                                	Authenticate OSPFv3 packets
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinks.ShamLink.Authentication>`
                                
                                .. attribute:: dead_interval
                                
                                	Interval after which a neighbor is declared dead (in seconds)
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: enable
                                
                                	Enable sham link
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: encryption
                                
                                	Encrypt and authenticate OSPFv3 packets
                                	**type**\:   :py:class:`Encryption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinks.ShamLink.Encryption>`
                                
                                .. attribute:: hello_interval
                                
                                	Time between HELLO packets
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: retransmit_interval
                                
                                	Specify the transmit interval in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: transmit_delay
                                
                                	Specify the transmit delay in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.destination_address = None
                                    self.source_address = None
                                    self.authentication = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinks.ShamLink.Authentication()
                                    self.authentication.parent = self
                                    self.dead_interval = None
                                    self.enable = None
                                    self.encryption = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinks.ShamLink.Encryption()
                                    self.encryption.parent = self
                                    self.hello_interval = None
                                    self.retransmit_interval = None
                                    self.transmit_delay = None


                                class Authentication(object):
                                    """
                                    Authenticate OSPFv3 packets
                                    
                                    .. attribute:: algorithm
                                    
                                    	Use the MD5 or SHA1 algorithm
                                    	**type**\:   :py:class:`Ospfv3AuthenticationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationEnum>`
                                    
                                    .. attribute:: enable
                                    
                                    	Authenticate packets
                                    	**type**\:  bool
                                    
                                    .. attribute:: password
                                    
                                    	Specify MD5 or SHA1 password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: spi
                                    
                                    	Use IPSec AH authentication. Specify the Security Parameter Index (SPI) value
                                    	**type**\:  int
                                    
                                    	**range:** 256..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.algorithm = None
                                        self.enable = None
                                        self.password = None
                                        self.spi = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:authentication'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.algorithm is not None:
                                            return True

                                        if self.enable is not None:
                                            return True

                                        if self.password is not None:
                                            return True

                                        if self.spi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinks.ShamLink.Authentication']['meta_info']


                                class Encryption(object):
                                    """
                                    Encrypt and authenticate OSPFv3 packets
                                    
                                    .. attribute:: authentication_algorithm
                                    
                                    	Use the NULL, MD5 or SHA1 algorithm
                                    	**type**\:   :py:class:`Ospfv3AuthenticationType2Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationType2Enum>`
                                    
                                    .. attribute:: authentication_password
                                    
                                    	Specify MD5 or SHA1 password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: enable
                                    
                                    	Authenticate packets
                                    	**type**\:  bool
                                    
                                    .. attribute:: encryption_algorithm
                                    
                                    	Specify the encryption algorithm
                                    	**type**\:   :py:class:`Ospfv3EncryptionAlgorithmEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EncryptionAlgorithmEnum>`
                                    
                                    .. attribute:: encryption_password
                                    
                                    	Encryption password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: spi
                                    
                                    	Use IPSec ESP authentication. Specify the Security Parameter Index (SPI) value
                                    	**type**\:  int
                                    
                                    	**range:** 256..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.authentication_algorithm = None
                                        self.authentication_password = None
                                        self.enable = None
                                        self.encryption_algorithm = None
                                        self.encryption_password = None
                                        self.spi = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:encryption'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.authentication_algorithm is not None:
                                            return True

                                        if self.authentication_password is not None:
                                            return True

                                        if self.enable is not None:
                                            return True

                                        if self.encryption_algorithm is not None:
                                            return True

                                        if self.encryption_password is not None:
                                            return True

                                        if self.spi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinks.ShamLink.Encryption']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.destination_address is None:
                                        raise YPYModelError('Key property destination_address is None')
                                    if self.source_address is None:
                                        raise YPYModelError('Key property source_address is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:sham-link[Cisco-IOS-XR-ipv6-ospfv3-cfg:destination-address = ' + str(self.destination_address) + '][Cisco-IOS-XR-ipv6-ospfv3-cfg:source-address = ' + str(self.source_address) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.destination_address is not None:
                                        return True

                                    if self.source_address is not None:
                                        return True

                                    if self.authentication is not None and self.authentication._has_data():
                                        return True

                                    if self.dead_interval is not None:
                                        return True

                                    if self.enable is not None:
                                        return True

                                    if self.encryption is not None and self.encryption._has_data():
                                        return True

                                    if self.hello_interval is not None:
                                        return True

                                    if self.retransmit_interval is not None:
                                        return True

                                    if self.transmit_delay is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinks.ShamLink']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:sham-links'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.sham_link is not None:
                                    for child_ref in self.sham_link:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinks']['meta_info']


                        class VirtualLinks(object):
                            """
                            Virtual link sub\-mode
                            
                            .. attribute:: virtual_link
                            
                            	Router ID of virtual link neighbor
                            	**type**\: list of    :py:class:`VirtualLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinks.VirtualLink>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.virtual_link = YList()
                                self.virtual_link.parent = self
                                self.virtual_link.name = 'virtual_link'


                            class VirtualLink(object):
                                """
                                Router ID of virtual link neighbor
                                
                                .. attribute:: virtual_link_address  <key>
                                
                                	Router ID of virtual link neighbor
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: authentication
                                
                                	Authenticate OSPFv3 packets
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinks.VirtualLink.Authentication>`
                                
                                .. attribute:: dead_interval
                                
                                	Interval after which a neighbor is declared dead (in seconds)
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: enable
                                
                                	Enabled virtual link
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: encryption
                                
                                	Encrypt and authenticate OSPFv3 packets
                                	**type**\:   :py:class:`Encryption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinks.VirtualLink.Encryption>`
                                
                                .. attribute:: hello_interval
                                
                                	Time between HELLO packets
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: retransmit_interval
                                
                                	Specify the transmit interval in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: transmit_delay
                                
                                	Specify the transmit delay in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.virtual_link_address = None
                                    self.authentication = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinks.VirtualLink.Authentication()
                                    self.authentication.parent = self
                                    self.dead_interval = None
                                    self.enable = None
                                    self.encryption = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinks.VirtualLink.Encryption()
                                    self.encryption.parent = self
                                    self.hello_interval = None
                                    self.retransmit_interval = None
                                    self.transmit_delay = None


                                class Authentication(object):
                                    """
                                    Authenticate OSPFv3 packets
                                    
                                    .. attribute:: algorithm
                                    
                                    	Use the MD5 or SHA1 algorithm
                                    	**type**\:   :py:class:`Ospfv3AuthenticationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationEnum>`
                                    
                                    .. attribute:: enable
                                    
                                    	Authenticate packets
                                    	**type**\:  bool
                                    
                                    .. attribute:: password
                                    
                                    	Specify MD5 or SHA1 password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: spi
                                    
                                    	Use IPSec AH authentication. Specify the Security Parameter Index (SPI) value
                                    	**type**\:  int
                                    
                                    	**range:** 256..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.algorithm = None
                                        self.enable = None
                                        self.password = None
                                        self.spi = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:authentication'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.algorithm is not None:
                                            return True

                                        if self.enable is not None:
                                            return True

                                        if self.password is not None:
                                            return True

                                        if self.spi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinks.VirtualLink.Authentication']['meta_info']


                                class Encryption(object):
                                    """
                                    Encrypt and authenticate OSPFv3 packets
                                    
                                    .. attribute:: authentication_algorithm
                                    
                                    	Use the NULL, MD5 or SHA1 algorithm
                                    	**type**\:   :py:class:`Ospfv3AuthenticationType2Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationType2Enum>`
                                    
                                    .. attribute:: authentication_password
                                    
                                    	Specify MD5 or SHA1 password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: enable
                                    
                                    	Authenticate packets
                                    	**type**\:  bool
                                    
                                    .. attribute:: encryption_algorithm
                                    
                                    	Specify the encryption algorithm
                                    	**type**\:   :py:class:`Ospfv3EncryptionAlgorithmEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EncryptionAlgorithmEnum>`
                                    
                                    .. attribute:: encryption_password
                                    
                                    	Encryption password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: spi
                                    
                                    	Use IPSec ESP authentication. Specify the Security Parameter Index (SPI) value
                                    	**type**\:  int
                                    
                                    	**range:** 256..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.authentication_algorithm = None
                                        self.authentication_password = None
                                        self.enable = None
                                        self.encryption_algorithm = None
                                        self.encryption_password = None
                                        self.spi = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:encryption'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.authentication_algorithm is not None:
                                            return True

                                        if self.authentication_password is not None:
                                            return True

                                        if self.enable is not None:
                                            return True

                                        if self.encryption_algorithm is not None:
                                            return True

                                        if self.encryption_password is not None:
                                            return True

                                        if self.spi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinks.VirtualLink.Encryption']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.virtual_link_address is None:
                                        raise YPYModelError('Key property virtual_link_address is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:virtual-link[Cisco-IOS-XR-ipv6-ospfv3-cfg:virtual-link-address = ' + str(self.virtual_link_address) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.virtual_link_address is not None:
                                        return True

                                    if self.authentication is not None and self.authentication._has_data():
                                        return True

                                    if self.dead_interval is not None:
                                        return True

                                    if self.enable is not None:
                                        return True

                                    if self.encryption is not None and self.encryption._has_data():
                                        return True

                                    if self.hello_interval is not None:
                                        return True

                                    if self.retransmit_interval is not None:
                                        return True

                                    if self.transmit_delay is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinks.VirtualLink']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:virtual-links'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.virtual_link is not None:
                                    for child_ref in self.virtual_link:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinks']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.address is None:
                                raise YPYModelError('Key property address is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:area-address[Cisco-IOS-XR-ipv6-ospfv3-cfg:address = ' + str(self.address) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.address is not None:
                                return True

                            if self.area_scope is not None and self.area_scope._has_data():
                                return True

                            if self.authentication is not None and self.authentication._has_data():
                                return True

                            if self.bfd is not None and self.bfd._has_data():
                                return True

                            if self.cost is not None:
                                return True

                            if self.database_filter is not None and self.database_filter._has_data():
                                return True

                            if self.dead_interval is not None:
                                return True

                            if self.default_cost is not None:
                                return True

                            if self.demand_circuit is not None:
                                return True

                            if self.distribute_list is not None and self.distribute_list._has_data():
                                return True

                            if self.enable is not None:
                                return True

                            if self.encryption is not None and self.encryption._has_data():
                                return True

                            if self.flood_reduction is not None:
                                return True

                            if self.hello_interval is not None:
                                return True

                            if self.instance is not None:
                                return True

                            if self.interfaces is not None and self.interfaces._has_data():
                                return True

                            if self.ldp_sync is not None:
                                return True

                            if self.mtu_ignore is not None:
                                return True

                            if self.network is not None:
                                return True

                            if self.nssa is not None and self.nssa._has_data():
                                return True

                            if self.packet_size is not None:
                                return True

                            if self.passive is not None:
                                return True

                            if self.prefix_suppression is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.ranges is not None and self.ranges._has_data():
                                return True

                            if self.retransmit_interval is not None:
                                return True

                            if self.sham_links is not None and self.sham_links._has_data():
                                return True

                            if self.stub is not None:
                                return True

                            if self.transmit_delay is not None:
                                return True

                            if self.virtual_links is not None and self.virtual_links._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress']['meta_info']


                    class AreaAreaId(object):
                        """
                        Configuration for a particular area
                        
                        .. attribute:: area_id  <key>
                        
                        	Area ID if in integer format
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: area_scope
                        
                        	Area Scope Configuration
                        	**type**\:   :py:class:`AreaScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope>`
                        
                        .. attribute:: authentication
                        
                        	Authenticate OSPFv3 packets
                        	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Configure BFD parameters
                        	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Bfd>`
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Database filter
                        	**type**\:   :py:class:`DatabaseFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead (in seconds)
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        	**units**\: second
                        
                        .. attribute:: default_cost
                        
                        	Set the summary default\-cost of a NSSA/stub area
                        	**type**\:  int
                        
                        	**range:** 0..16777215
                        
                        .. attribute:: demand_circuit
                        
                        	Enable/disable demand circuit operation
                        	**type**\:  bool
                        
                        .. attribute:: distribute_list
                        
                        	Filter prefixes to/from RIB
                        	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.DistributeList>`
                        
                        .. attribute:: enable
                        
                        	Enable OSPFv3 area
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: encryption
                        
                        	Encrypt and authenticate OSPFv3 packets
                        	**type**\:   :py:class:`Encryption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Encryption>`
                        
                        .. attribute:: flood_reduction
                        
                        	Enable/disable flood reduction
                        	**type**\:  bool
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        	**units**\: second
                        
                        .. attribute:: instance
                        
                        	Instance ID
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interfaces
                        
                        	OSPFv3 interfaces
                        	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces>`
                        
                        .. attribute:: ldp_sync
                        
                        	Enable/Disable MPLS LDP sync
                        	**type**\:  bool
                        
                        .. attribute:: mtu_ignore
                        
                        	Enable/disable ignoring of MTU in DBD packets
                        	**type**\:  bool
                        
                        .. attribute:: network
                        
                        	Specify network type
                        	**type**\:   :py:class:`Ospfv3NetworkEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3NetworkEnum>`
                        
                        .. attribute:: nssa
                        
                        	Specify area as a NSSA area.  Allowed only in non\-backbone areas
                        	**type**\:   :py:class:`Nssa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Nssa>`
                        
                        .. attribute:: packet_size
                        
                        	Limit size of OSPFv3 packets
                        	**type**\:  int
                        
                        	**range:** 256..10000
                        
                        .. attribute:: passive
                        
                        	Enable/disable routing updates on an interface
                        	**type**\:  bool
                        
                        .. attribute:: prefix_suppression
                        
                        	Enable/disable prefix suppression on an interface
                        	**type**\:  bool
                        
                        .. attribute:: priority
                        
                        	Specify router priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: ranges
                        
                        	Range configuration
                        	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Ranges>`
                        
                        .. attribute:: retransmit_interval
                        
                        	Specify the transmit interval in seconds
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        	**units**\: second
                        
                        .. attribute:: sham_links
                        
                        	Sham Link sub\-mode
                        	**type**\:   :py:class:`ShamLinks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinks>`
                        
                        .. attribute:: stub
                        
                        	Specify area as a stub area.  Allowed only in non\-backbone areas
                        	**type**\:  bool
                        
                        .. attribute:: transmit_delay
                        
                        	Specify the transmit delay in seconds
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        	**units**\: second
                        
                        .. attribute:: virtual_links
                        
                        	Virtual link sub\-mode
                        	**type**\:   :py:class:`VirtualLinks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinks>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.area_id = None
                            self.area_scope = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope()
                            self.area_scope.parent = self
                            self.authentication = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Authentication()
                            self.authentication.parent = self
                            self.bfd = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Bfd()
                            self.bfd.parent = self
                            self.cost = None
                            self.database_filter = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.DatabaseFilter()
                            self.database_filter.parent = self
                            self.dead_interval = None
                            self.default_cost = None
                            self.demand_circuit = None
                            self.distribute_list = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.DistributeList()
                            self.distribute_list.parent = self
                            self.enable = None
                            self.encryption = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Encryption()
                            self.encryption.parent = self
                            self.flood_reduction = None
                            self.hello_interval = None
                            self.instance = None
                            self.interfaces = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces()
                            self.interfaces.parent = self
                            self.ldp_sync = None
                            self.mtu_ignore = None
                            self.network = None
                            self.nssa = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Nssa()
                            self.nssa.parent = self
                            self.packet_size = None
                            self.passive = None
                            self.prefix_suppression = None
                            self.priority = None
                            self.ranges = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Ranges()
                            self.ranges.parent = self
                            self.retransmit_interval = None
                            self.sham_links = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinks()
                            self.sham_links.parent = self
                            self.stub = None
                            self.transmit_delay = None
                            self.virtual_links = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinks()
                            self.virtual_links.parent = self


                        class Authentication(object):
                            """
                            Authenticate OSPFv3 packets
                            
                            .. attribute:: algorithm
                            
                            	Use the MD5 or SHA1 algorithm
                            	**type**\:   :py:class:`Ospfv3AuthenticationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationEnum>`
                            
                            .. attribute:: enable
                            
                            	Authenticate packets
                            	**type**\:  bool
                            
                            .. attribute:: password
                            
                            	Specify MD5 or SHA1 password
                            	**type**\:  str
                            
                            	**pattern:** (!.+)\|([^!].+)
                            
                            .. attribute:: spi
                            
                            	Use IPSec AH authentication. Specify the Security Parameter Index (SPI) value
                            	**type**\:  int
                            
                            	**range:** 256..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.algorithm = None
                                self.enable = None
                                self.password = None
                                self.spi = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:authentication'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.algorithm is not None:
                                    return True

                                if self.enable is not None:
                                    return True

                                if self.password is not None:
                                    return True

                                if self.spi is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Authentication']['meta_info']


                        class Bfd(object):
                            """
                            Configure BFD parameters
                            
                            .. attribute:: detection_multiplier
                            
                            	Detect multiplier
                            	**type**\:  int
                            
                            	**range:** 2..50
                            
                            .. attribute:: fast_detect_mode
                            
                            	Enable or disable BFD fast detection
                            	**type**\:   :py:class:`Ospfv3BfdEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3BfdEnableModeEnum>`
                            
                            .. attribute:: interval
                            
                            	Hello interval in milli\-seconds
                            	**type**\:  int
                            
                            	**range:** 3..30000
                            
                            	**units**\: millisecond
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.detection_multiplier = None
                                self.fast_detect_mode = None
                                self.interval = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:bfd'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.detection_multiplier is not None:
                                    return True

                                if self.fast_detect_mode is not None:
                                    return True

                                if self.interval is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Bfd']['meta_info']


                        class Ranges(object):
                            """
                            Range configuration
                            
                            .. attribute:: range
                            
                            	Summarize inter\-area routes matching prefix/length
                            	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Ranges.Range>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.range = YList()
                                self.range.parent = self
                                self.range.name = 'range'


                            class Range(object):
                                """
                                Summarize inter\-area routes matching
                                prefix/length
                                
                                .. attribute:: prefix  <key>
                                
                                	IPv6 prefix format
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length  <key>
                                
                                	IPV6 prefix length
                                	**type**\:  int
                                
                                	**range:** 0..128
                                
                                .. attribute:: cost
                                
                                	Specified metric for this range
                                	**type**\:  int
                                
                                	**range:** 1..16777214
                                
                                .. attribute:: not_advertise
                                
                                	Do not advertise address range
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.prefix = None
                                    self.prefix_length = None
                                    self.cost = None
                                    self.not_advertise = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.prefix is None:
                                        raise YPYModelError('Key property prefix is None')
                                    if self.prefix_length is None:
                                        raise YPYModelError('Key property prefix_length is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:range[Cisco-IOS-XR-ipv6-ospfv3-cfg:prefix = ' + str(self.prefix) + '][Cisco-IOS-XR-ipv6-ospfv3-cfg:prefix-length = ' + str(self.prefix_length) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.prefix is not None:
                                        return True

                                    if self.prefix_length is not None:
                                        return True

                                    if self.cost is not None:
                                        return True

                                    if self.not_advertise is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Ranges.Range']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:ranges'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.range is not None:
                                    for child_ref in self.range:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Ranges']['meta_info']


                        class Encryption(object):
                            """
                            Encrypt and authenticate OSPFv3 packets
                            
                            .. attribute:: authentication_algorithm
                            
                            	Use the NULL, MD5 or SHA1 algorithm
                            	**type**\:   :py:class:`Ospfv3AuthenticationType2Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationType2Enum>`
                            
                            .. attribute:: authentication_password
                            
                            	Specify MD5 or SHA1 password
                            	**type**\:  str
                            
                            	**pattern:** (!.+)\|([^!].+)
                            
                            .. attribute:: enable
                            
                            	Authenticate packets
                            	**type**\:  bool
                            
                            .. attribute:: encryption_algorithm
                            
                            	Specify the encryption algorithm
                            	**type**\:   :py:class:`Ospfv3EncryptionAlgorithmEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EncryptionAlgorithmEnum>`
                            
                            .. attribute:: encryption_password
                            
                            	Encryption password
                            	**type**\:  str
                            
                            	**pattern:** (!.+)\|([^!].+)
                            
                            .. attribute:: spi
                            
                            	Use IPSec ESP authentication. Specify the Security Parameter Index (SPI) value
                            	**type**\:  int
                            
                            	**range:** 256..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.authentication_algorithm = None
                                self.authentication_password = None
                                self.enable = None
                                self.encryption_algorithm = None
                                self.encryption_password = None
                                self.spi = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:encryption'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.authentication_algorithm is not None:
                                    return True

                                if self.authentication_password is not None:
                                    return True

                                if self.enable is not None:
                                    return True

                                if self.encryption_algorithm is not None:
                                    return True

                                if self.encryption_password is not None:
                                    return True

                                if self.spi is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Encryption']['meta_info']


                        class Nssa(object):
                            """
                            Specify area as a NSSA area.  Allowed only in
                            non\-backbone areas
                            
                            .. attribute:: default_info_originate
                            
                            	Originate Type 7 default into NSSA area
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: metric
                            
                            	Only valid with DefaultInfoOriginate
                            	**type**\:  int
                            
                            	**range:** 0..16777214
                            
                            .. attribute:: metric_type
                            
                            	Only valid with DefaultInfoOriginate
                            	**type**\:   :py:class:`Ospfv3MetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3MetricEnum>`
                            
                            .. attribute:: no_redistribution
                            
                            	No redistribution into this NSSA area
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: no_summary
                            
                            	Do not send summary LSA into NSSA
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.default_info_originate = None
                                self.metric = None
                                self.metric_type = None
                                self.no_redistribution = None
                                self.no_summary = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:nssa'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.default_info_originate is not None:
                                    return True

                                if self.metric is not None:
                                    return True

                                if self.metric_type is not None:
                                    return True

                                if self.no_redistribution is not None:
                                    return True

                                if self.no_summary is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Nssa']['meta_info']


                        class DatabaseFilter(object):
                            """
                            Database filter
                            
                            .. attribute:: all
                            
                            	All
                            	**type**\:   :py:class:`All <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.all = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.DatabaseFilter.All()
                                self.all.parent = self


                            class All(object):
                                """
                                All
                                
                                .. attribute:: out
                                
                                	Enable or disable database\-filter
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.out = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:all'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.out is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.DatabaseFilter.All']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:database-filter'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.all is not None and self.all._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.DatabaseFilter']['meta_info']


                        class DistributeList(object):
                            """
                            Filter prefixes to/from RIB
                            
                            .. attribute:: in_
                            
                            	Filter prefixes installed to RIB
                            	**type**\:   :py:class:`In_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.DistributeList.In_>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.in_ = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.DistributeList.In_()
                                self.in_.parent = self


                            class In_(object):
                                """
                                Filter prefixes installed to RIB
                                
                                .. attribute:: prefix_list
                                
                                	Filter prefixes based on an IPv6 prefix\-list
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.prefix_list = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:in'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.prefix_list is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.DistributeList.In_']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:distribute-list'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.in_ is not None and self.in_._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.DistributeList']['meta_info']


                        class Interfaces(object):
                            """
                            OSPFv3 interfaces
                            
                            .. attribute:: interface
                            
                            	OSPFv3 interface
                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface = YList()
                                self.interface.parent = self
                                self.interface.name = 'interface'


                            class Interface(object):
                                """
                                OSPFv3 interface
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface to configure
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: authentication
                                
                                	Authenticate OSPFv3 packets
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Authentication>`
                                
                                .. attribute:: bfd
                                
                                	Configure BFD parameters
                                	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Bfd>`
                                
                                .. attribute:: cost
                                
                                	Interface cost
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: database_filter
                                
                                	Database filter
                                	**type**\:   :py:class:`DatabaseFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DatabaseFilter>`
                                
                                .. attribute:: dead_interval
                                
                                	Interval after which a neighbor is declared dead (in seconds)
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: demand_circuit
                                
                                	Enable/disable demand circuit operation
                                	**type**\:  bool
                                
                                .. attribute:: distribute_list
                                
                                	Filter prefixes to/from RIB
                                	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DistributeList>`
                                
                                .. attribute:: enable
                                
                                	Enable OSPFv3 interface
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: encryption
                                
                                	Encrypt and authenticate OSPFv3 packets
                                	**type**\:   :py:class:`Encryption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Encryption>`
                                
                                .. attribute:: fast_reroute
                                
                                	Fast\-reroute configuration
                                	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute>`
                                
                                .. attribute:: flood_reduction
                                
                                	Enable/disable flood reduction
                                	**type**\:  bool
                                
                                .. attribute:: hello_interval
                                
                                	Time between HELLO packets
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: instance
                                
                                	Instance ID
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ldp_sync
                                
                                	Enable/Disable MPLS LDP sync
                                	**type**\:  bool
                                
                                .. attribute:: mtu_ignore
                                
                                	Enable/disable ignoring of MTU in DBD packets
                                	**type**\:  bool
                                
                                .. attribute:: neighbors
                                
                                	Specify a neighbor router
                                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Neighbors>`
                                
                                .. attribute:: network
                                
                                	Specify network type
                                	**type**\:   :py:class:`Ospfv3NetworkEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3NetworkEnum>`
                                
                                .. attribute:: packet_size
                                
                                	Limit size of OSPFv3 packets
                                	**type**\:  int
                                
                                	**range:** 256..10000
                                
                                .. attribute:: passive
                                
                                	Enable/disable routing updates on an interface
                                	**type**\:  bool
                                
                                .. attribute:: prefix_suppression
                                
                                	Enable/disable prefix suppression on an interface
                                	**type**\:  bool
                                
                                .. attribute:: priority
                                
                                	Specify router priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: retransmit_interval
                                
                                	Specify the transmit interval in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: transmit_delay
                                
                                	Specify the transmit delay in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_name = None
                                    self.authentication = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Authentication()
                                    self.authentication.parent = self
                                    self.bfd = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Bfd()
                                    self.bfd.parent = self
                                    self.cost = None
                                    self.database_filter = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DatabaseFilter()
                                    self.database_filter.parent = self
                                    self.dead_interval = None
                                    self.demand_circuit = None
                                    self.distribute_list = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DistributeList()
                                    self.distribute_list.parent = self
                                    self.enable = None
                                    self.encryption = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Encryption()
                                    self.encryption.parent = self
                                    self.fast_reroute = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute()
                                    self.fast_reroute.parent = self
                                    self.flood_reduction = None
                                    self.hello_interval = None
                                    self.instance = None
                                    self.ldp_sync = None
                                    self.mtu_ignore = None
                                    self.neighbors = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Neighbors()
                                    self.neighbors.parent = self
                                    self.network = None
                                    self.packet_size = None
                                    self.passive = None
                                    self.prefix_suppression = None
                                    self.priority = None
                                    self.retransmit_interval = None
                                    self.transmit_delay = None


                                class Authentication(object):
                                    """
                                    Authenticate OSPFv3 packets
                                    
                                    .. attribute:: algorithm
                                    
                                    	Use the MD5 or SHA1 algorithm
                                    	**type**\:   :py:class:`Ospfv3AuthenticationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationEnum>`
                                    
                                    .. attribute:: enable
                                    
                                    	Authenticate packets
                                    	**type**\:  bool
                                    
                                    .. attribute:: password
                                    
                                    	Specify MD5 or SHA1 password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: spi
                                    
                                    	Use IPSec AH authentication. Specify the Security Parameter Index (SPI) value
                                    	**type**\:  int
                                    
                                    	**range:** 256..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.algorithm = None
                                        self.enable = None
                                        self.password = None
                                        self.spi = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:authentication'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.algorithm is not None:
                                            return True

                                        if self.enable is not None:
                                            return True

                                        if self.password is not None:
                                            return True

                                        if self.spi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Authentication']['meta_info']


                                class Neighbors(object):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: neighbor
                                    
                                    	IPv6 address
                                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Neighbors.Neighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.neighbor = YList()
                                        self.neighbor.parent = self
                                        self.neighbor.name = 'neighbor'


                                    class Neighbor(object):
                                        """
                                        IPv6 address
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	IPV6 address
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: cost
                                        
                                        	OSPFv3 cost for point\-to\-multipoint neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: database_filter
                                        
                                        	Filter OSPFv3 LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: poll_interval
                                        
                                        	OSPFv3 dead\-router polling interval (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: priority
                                        
                                        	OSPFv3 priority of non\-broadcast neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: zone
                                        
                                        	Zone
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.neighbor_address = None
                                            self.cost = None
                                            self.database_filter = None
                                            self.poll_interval = None
                                            self.priority = None
                                            self.zone = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.neighbor_address is None:
                                                raise YPYModelError('Key property neighbor_address is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:neighbor[Cisco-IOS-XR-ipv6-ospfv3-cfg:neighbor-address = ' + str(self.neighbor_address) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.neighbor_address is not None:
                                                return True

                                            if self.cost is not None:
                                                return True

                                            if self.database_filter is not None:
                                                return True

                                            if self.poll_interval is not None:
                                                return True

                                            if self.priority is not None:
                                                return True

                                            if self.zone is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Neighbors.Neighbor']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:neighbors'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.neighbor is not None:
                                            for child_ref in self.neighbor:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Neighbors']['meta_info']


                                class Encryption(object):
                                    """
                                    Encrypt and authenticate OSPFv3 packets
                                    
                                    .. attribute:: authentication_algorithm
                                    
                                    	Use the NULL, MD5 or SHA1 algorithm
                                    	**type**\:   :py:class:`Ospfv3AuthenticationType2Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationType2Enum>`
                                    
                                    .. attribute:: authentication_password
                                    
                                    	Specify MD5 or SHA1 password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: enable
                                    
                                    	Authenticate packets
                                    	**type**\:  bool
                                    
                                    .. attribute:: encryption_algorithm
                                    
                                    	Specify the encryption algorithm
                                    	**type**\:   :py:class:`Ospfv3EncryptionAlgorithmEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EncryptionAlgorithmEnum>`
                                    
                                    .. attribute:: encryption_password
                                    
                                    	Encryption password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: spi
                                    
                                    	Use IPSec ESP authentication. Specify the Security Parameter Index (SPI) value
                                    	**type**\:  int
                                    
                                    	**range:** 256..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.authentication_algorithm = None
                                        self.authentication_password = None
                                        self.enable = None
                                        self.encryption_algorithm = None
                                        self.encryption_password = None
                                        self.spi = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:encryption'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.authentication_algorithm is not None:
                                            return True

                                        if self.authentication_password is not None:
                                            return True

                                        if self.enable is not None:
                                            return True

                                        if self.encryption_algorithm is not None:
                                            return True

                                        if self.encryption_password is not None:
                                            return True

                                        if self.spi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Encryption']['meta_info']


                                class Bfd(object):
                                    """
                                    Configure BFD parameters
                                    
                                    .. attribute:: detection_multiplier
                                    
                                    	Detect multiplier
                                    	**type**\:  int
                                    
                                    	**range:** 2..50
                                    
                                    .. attribute:: fast_detect_mode
                                    
                                    	Enable or disable BFD fast detection
                                    	**type**\:   :py:class:`Ospfv3BfdEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3BfdEnableModeEnum>`
                                    
                                    .. attribute:: interval
                                    
                                    	Hello interval in milli\-seconds
                                    	**type**\:  int
                                    
                                    	**range:** 3..30000
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.detection_multiplier = None
                                        self.fast_detect_mode = None
                                        self.interval = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:bfd'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.detection_multiplier is not None:
                                            return True

                                        if self.fast_detect_mode is not None:
                                            return True

                                        if self.interval is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Bfd']['meta_info']


                                class DatabaseFilter(object):
                                    """
                                    Database filter
                                    
                                    .. attribute:: all
                                    
                                    	All
                                    	**type**\:   :py:class:`All <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DatabaseFilter.All>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.all = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DatabaseFilter.All()
                                        self.all.parent = self


                                    class All(object):
                                        """
                                        All
                                        
                                        .. attribute:: out
                                        
                                        	Enable or disable database\-filter
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.out = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:all'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.out is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DatabaseFilter.All']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:database-filter'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.all is not None and self.all._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DatabaseFilter']['meta_info']


                                class DistributeList(object):
                                    """
                                    Filter prefixes to/from RIB
                                    
                                    .. attribute:: in_
                                    
                                    	Filter prefixes installed to RIB
                                    	**type**\:   :py:class:`In_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DistributeList.In_>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.in_ = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DistributeList.In_()
                                        self.in_.parent = self


                                    class In_(object):
                                        """
                                        Filter prefixes installed to RIB
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Filter prefixes based on an IPv6 prefix\-list
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.prefix_list = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:in'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.prefix_list is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DistributeList.In_']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:distribute-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.in_ is not None and self.in_._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DistributeList']['meta_info']


                                class FastReroute(object):
                                    """
                                    Fast\-reroute configuration
                                    
                                    .. attribute:: fast_reroute_enable
                                    
                                    	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                    	**type**\:   :py:class:`Ospfv3FastRerouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3FastRerouteEnum>`
                                    
                                    .. attribute:: per_link
                                    
                                    	Fast\-reroute per\-link configuration
                                    	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink>`
                                    
                                    .. attribute:: per_prefix
                                    
                                    	Fast\-reroute per\-link configuration
                                    	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.fast_reroute_enable = None
                                        self.per_link = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink()
                                        self.per_link.parent = self
                                        self.per_prefix = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix()
                                        self.per_prefix.parent = self


                                    class PerLink(object):
                                        """
                                        Fast\-reroute per\-link configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.candidate_interfaces = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self.exclude_interfaces = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self.fast_reroute_use_candidate_only = None


                                        class CandidateInterfaces(object):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.candidate_interface = YList()
                                                self.candidate_interface.parent = self
                                                self.candidate_interface.name = 'candidate_interface'


                                            class CandidateInterface(object):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.interface_name is None:
                                                        raise YPYModelError('Key property interface_name is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink.CandidateInterfaces.CandidateInterface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interfaces'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.candidate_interface is not None:
                                                    for child_ref in self.candidate_interface:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink.CandidateInterfaces']['meta_info']


                                        class ExcludeInterfaces(object):
                                            """
                                            Fast\-reroute per\-link/per\-prefix exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.exclude_interface = YList()
                                                self.exclude_interface.parent = self
                                                self.exclude_interface.name = 'exclude_interface'


                                            class ExcludeInterface(object):
                                                """
                                                Exclude an interface from becoming a backup
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.interface_name is None:
                                                        raise YPYModelError('Key property interface_name is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interfaces'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.exclude_interface is not None:
                                                    for child_ref in self.exclude_interface:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink.ExcludeInterfaces']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-link'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.candidate_interfaces is not None and self.candidate_interfaces._has_data():
                                                return True

                                            if self.exclude_interfaces is not None and self.exclude_interfaces._has_data():
                                                return True

                                            if self.fast_reroute_use_candidate_only is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink']['meta_info']


                                    class PerPrefix(object):
                                        """
                                        Fast\-reroute per\-link configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.candidate_interfaces = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self.exclude_interfaces = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self.fast_reroute_use_candidate_only = None


                                        class CandidateInterfaces(object):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.candidate_interface = YList()
                                                self.candidate_interface.parent = self
                                                self.candidate_interface.name = 'candidate_interface'


                                            class CandidateInterface(object):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.interface_name is None:
                                                        raise YPYModelError('Key property interface_name is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interfaces'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.candidate_interface is not None:
                                                    for child_ref in self.candidate_interface:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix.CandidateInterfaces']['meta_info']


                                        class ExcludeInterfaces(object):
                                            """
                                            Fast\-reroute per\-link/per\-prefix exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.exclude_interface = YList()
                                                self.exclude_interface.parent = self
                                                self.exclude_interface.name = 'exclude_interface'


                                            class ExcludeInterface(object):
                                                """
                                                Exclude an interface from becoming a backup
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.interface_name is None:
                                                        raise YPYModelError('Key property interface_name is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interfaces'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.exclude_interface is not None:
                                                    for child_ref in self.exclude_interface:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix.ExcludeInterfaces']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-prefix'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.candidate_interfaces is not None and self.candidate_interfaces._has_data():
                                                return True

                                            if self.exclude_interfaces is not None and self.exclude_interfaces._has_data():
                                                return True

                                            if self.fast_reroute_use_candidate_only is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:fast-reroute'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.fast_reroute_enable is not None:
                                            return True

                                        if self.per_link is not None and self.per_link._has_data():
                                            return True

                                        if self.per_prefix is not None and self.per_prefix._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.interface_name is None:
                                        raise YPYModelError('Key property interface_name is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_name is not None:
                                        return True

                                    if self.authentication is not None and self.authentication._has_data():
                                        return True

                                    if self.bfd is not None and self.bfd._has_data():
                                        return True

                                    if self.cost is not None:
                                        return True

                                    if self.database_filter is not None and self.database_filter._has_data():
                                        return True

                                    if self.dead_interval is not None:
                                        return True

                                    if self.demand_circuit is not None:
                                        return True

                                    if self.distribute_list is not None and self.distribute_list._has_data():
                                        return True

                                    if self.enable is not None:
                                        return True

                                    if self.encryption is not None and self.encryption._has_data():
                                        return True

                                    if self.fast_reroute is not None and self.fast_reroute._has_data():
                                        return True

                                    if self.flood_reduction is not None:
                                        return True

                                    if self.hello_interval is not None:
                                        return True

                                    if self.instance is not None:
                                        return True

                                    if self.ldp_sync is not None:
                                        return True

                                    if self.mtu_ignore is not None:
                                        return True

                                    if self.neighbors is not None and self.neighbors._has_data():
                                        return True

                                    if self.network is not None:
                                        return True

                                    if self.packet_size is not None:
                                        return True

                                    if self.passive is not None:
                                        return True

                                    if self.prefix_suppression is not None:
                                        return True

                                    if self.priority is not None:
                                        return True

                                    if self.retransmit_interval is not None:
                                        return True

                                    if self.transmit_delay is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces.Interface']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:interfaces'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface is not None:
                                    for child_ref in self.interface:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Interfaces']['meta_info']


                        class AreaScope(object):
                            """
                            Area Scope Configuration
                            
                            .. attribute:: fast_reroute
                            
                            	Fast\-reroute configuration
                            	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.fast_reroute = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute()
                                self.fast_reroute.parent = self


                            class FastReroute(object):
                                """
                                Fast\-reroute configuration
                                
                                .. attribute:: fast_reroute_enable
                                
                                	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                	**type**\:   :py:class:`Ospfv3FastRerouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3FastRerouteEnum>`
                                
                                .. attribute:: per_link
                                
                                	Fast\-reroute per\-link configuration
                                	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink>`
                                
                                .. attribute:: per_prefix
                                
                                	Fast\-reroute per\-link configuration
                                	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.fast_reroute_enable = None
                                    self.per_link = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink()
                                    self.per_link.parent = self
                                    self.per_prefix = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix()
                                    self.per_prefix.parent = self


                                class PerLink(object):
                                    """
                                    Fast\-reroute per\-link configuration
                                    
                                    .. attribute:: candidate_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                    	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces>`
                                    
                                    .. attribute:: exclude_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix exclude interface configuration
                                    	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces>`
                                    
                                    .. attribute:: fast_reroute_use_candidate_only
                                    
                                    	Use only interfaces on the candidate list as a backup path
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.candidate_interfaces = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces()
                                        self.candidate_interfaces.parent = self
                                        self.exclude_interfaces = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces()
                                        self.exclude_interfaces.parent = self
                                        self.fast_reroute_use_candidate_only = None


                                    class CandidateInterfaces(object):
                                        """
                                        Fast\-reroute per\-link/per\-prefix candidate
                                        interface configuration
                                        
                                        .. attribute:: candidate_interface
                                        
                                        	Candidate backup interface
                                        	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.candidate_interface = YList()
                                            self.candidate_interface.parent = self
                                            self.candidate_interface.name = 'candidate_interface'


                                        class CandidateInterface(object):
                                            """
                                            Candidate backup interface
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.interface_name is None:
                                                    raise YPYModelError('Key property interface_name is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interfaces'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.candidate_interface is not None:
                                                for child_ref in self.candidate_interface:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces']['meta_info']


                                    class ExcludeInterfaces(object):
                                        """
                                        Fast\-reroute per\-link/per\-prefix exclude
                                        interface configuration
                                        
                                        .. attribute:: exclude_interface
                                        
                                        	Exclude an interface from becoming a backup
                                        	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.exclude_interface = YList()
                                            self.exclude_interface.parent = self
                                            self.exclude_interface.name = 'exclude_interface'


                                        class ExcludeInterface(object):
                                            """
                                            Exclude an interface from becoming a backup
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.interface_name is None:
                                                    raise YPYModelError('Key property interface_name is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interfaces'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.exclude_interface is not None:
                                                for child_ref in self.exclude_interface:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-link'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.candidate_interfaces is not None and self.candidate_interfaces._has_data():
                                            return True

                                        if self.exclude_interfaces is not None and self.exclude_interfaces._has_data():
                                            return True

                                        if self.fast_reroute_use_candidate_only is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink']['meta_info']


                                class PerPrefix(object):
                                    """
                                    Fast\-reroute per\-link configuration
                                    
                                    .. attribute:: candidate_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                    	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                    
                                    .. attribute:: exclude_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix exclude interface configuration
                                    	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                    
                                    .. attribute:: fast_reroute_use_candidate_only
                                    
                                    	Use only interfaces on the candidate list as a backup path
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.candidate_interfaces = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces()
                                        self.candidate_interfaces.parent = self
                                        self.exclude_interfaces = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                        self.exclude_interfaces.parent = self
                                        self.fast_reroute_use_candidate_only = None


                                    class CandidateInterfaces(object):
                                        """
                                        Fast\-reroute per\-link/per\-prefix candidate
                                        interface configuration
                                        
                                        .. attribute:: candidate_interface
                                        
                                        	Candidate backup interface
                                        	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.candidate_interface = YList()
                                            self.candidate_interface.parent = self
                                            self.candidate_interface.name = 'candidate_interface'


                                        class CandidateInterface(object):
                                            """
                                            Candidate backup interface
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.interface_name is None:
                                                    raise YPYModelError('Key property interface_name is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interfaces'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.candidate_interface is not None:
                                                for child_ref in self.candidate_interface:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces']['meta_info']


                                    class ExcludeInterfaces(object):
                                        """
                                        Fast\-reroute per\-link/per\-prefix exclude
                                        interface configuration
                                        
                                        .. attribute:: exclude_interface
                                        
                                        	Exclude an interface from becoming a backup
                                        	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.exclude_interface = YList()
                                            self.exclude_interface.parent = self
                                            self.exclude_interface.name = 'exclude_interface'


                                        class ExcludeInterface(object):
                                            """
                                            Exclude an interface from becoming a backup
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.interface_name is None:
                                                    raise YPYModelError('Key property interface_name is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interfaces'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.exclude_interface is not None:
                                                for child_ref in self.exclude_interface:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-prefix'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.candidate_interfaces is not None and self.candidate_interfaces._has_data():
                                            return True

                                        if self.exclude_interfaces is not None and self.exclude_interfaces._has_data():
                                            return True

                                        if self.fast_reroute_use_candidate_only is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:fast-reroute'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.fast_reroute_enable is not None:
                                        return True

                                    if self.per_link is not None and self.per_link._has_data():
                                        return True

                                    if self.per_prefix is not None and self.per_prefix._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:area-scope'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.fast_reroute is not None and self.fast_reroute._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope']['meta_info']


                        class ShamLinks(object):
                            """
                            Sham Link sub\-mode
                            
                            .. attribute:: sham_link
                            
                            	ShamLink local and remote endpoints
                            	**type**\: list of    :py:class:`ShamLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinks.ShamLink>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.sham_link = YList()
                                self.sham_link.parent = self
                                self.sham_link.name = 'sham_link'


                            class ShamLink(object):
                                """
                                ShamLink local and remote endpoints
                                
                                .. attribute:: destination_address  <key>
                                
                                	Remote sham\-link endpoint
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address  <key>
                                
                                	Local sham\-link endpoint
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: authentication
                                
                                	Authenticate OSPFv3 packets
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinks.ShamLink.Authentication>`
                                
                                .. attribute:: dead_interval
                                
                                	Interval after which a neighbor is declared dead (in seconds)
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: enable
                                
                                	Enable sham link
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: encryption
                                
                                	Encrypt and authenticate OSPFv3 packets
                                	**type**\:   :py:class:`Encryption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinks.ShamLink.Encryption>`
                                
                                .. attribute:: hello_interval
                                
                                	Time between HELLO packets
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: retransmit_interval
                                
                                	Specify the transmit interval in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: transmit_delay
                                
                                	Specify the transmit delay in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.destination_address = None
                                    self.source_address = None
                                    self.authentication = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinks.ShamLink.Authentication()
                                    self.authentication.parent = self
                                    self.dead_interval = None
                                    self.enable = None
                                    self.encryption = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinks.ShamLink.Encryption()
                                    self.encryption.parent = self
                                    self.hello_interval = None
                                    self.retransmit_interval = None
                                    self.transmit_delay = None


                                class Authentication(object):
                                    """
                                    Authenticate OSPFv3 packets
                                    
                                    .. attribute:: algorithm
                                    
                                    	Use the MD5 or SHA1 algorithm
                                    	**type**\:   :py:class:`Ospfv3AuthenticationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationEnum>`
                                    
                                    .. attribute:: enable
                                    
                                    	Authenticate packets
                                    	**type**\:  bool
                                    
                                    .. attribute:: password
                                    
                                    	Specify MD5 or SHA1 password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: spi
                                    
                                    	Use IPSec AH authentication. Specify the Security Parameter Index (SPI) value
                                    	**type**\:  int
                                    
                                    	**range:** 256..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.algorithm = None
                                        self.enable = None
                                        self.password = None
                                        self.spi = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:authentication'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.algorithm is not None:
                                            return True

                                        if self.enable is not None:
                                            return True

                                        if self.password is not None:
                                            return True

                                        if self.spi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinks.ShamLink.Authentication']['meta_info']


                                class Encryption(object):
                                    """
                                    Encrypt and authenticate OSPFv3 packets
                                    
                                    .. attribute:: authentication_algorithm
                                    
                                    	Use the NULL, MD5 or SHA1 algorithm
                                    	**type**\:   :py:class:`Ospfv3AuthenticationType2Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationType2Enum>`
                                    
                                    .. attribute:: authentication_password
                                    
                                    	Specify MD5 or SHA1 password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: enable
                                    
                                    	Authenticate packets
                                    	**type**\:  bool
                                    
                                    .. attribute:: encryption_algorithm
                                    
                                    	Specify the encryption algorithm
                                    	**type**\:   :py:class:`Ospfv3EncryptionAlgorithmEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EncryptionAlgorithmEnum>`
                                    
                                    .. attribute:: encryption_password
                                    
                                    	Encryption password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: spi
                                    
                                    	Use IPSec ESP authentication. Specify the Security Parameter Index (SPI) value
                                    	**type**\:  int
                                    
                                    	**range:** 256..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.authentication_algorithm = None
                                        self.authentication_password = None
                                        self.enable = None
                                        self.encryption_algorithm = None
                                        self.encryption_password = None
                                        self.spi = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:encryption'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.authentication_algorithm is not None:
                                            return True

                                        if self.authentication_password is not None:
                                            return True

                                        if self.enable is not None:
                                            return True

                                        if self.encryption_algorithm is not None:
                                            return True

                                        if self.encryption_password is not None:
                                            return True

                                        if self.spi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinks.ShamLink.Encryption']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.destination_address is None:
                                        raise YPYModelError('Key property destination_address is None')
                                    if self.source_address is None:
                                        raise YPYModelError('Key property source_address is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:sham-link[Cisco-IOS-XR-ipv6-ospfv3-cfg:destination-address = ' + str(self.destination_address) + '][Cisco-IOS-XR-ipv6-ospfv3-cfg:source-address = ' + str(self.source_address) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.destination_address is not None:
                                        return True

                                    if self.source_address is not None:
                                        return True

                                    if self.authentication is not None and self.authentication._has_data():
                                        return True

                                    if self.dead_interval is not None:
                                        return True

                                    if self.enable is not None:
                                        return True

                                    if self.encryption is not None and self.encryption._has_data():
                                        return True

                                    if self.hello_interval is not None:
                                        return True

                                    if self.retransmit_interval is not None:
                                        return True

                                    if self.transmit_delay is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinks.ShamLink']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:sham-links'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.sham_link is not None:
                                    for child_ref in self.sham_link:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinks']['meta_info']


                        class VirtualLinks(object):
                            """
                            Virtual link sub\-mode
                            
                            .. attribute:: virtual_link
                            
                            	Router ID of virtual link neighbor
                            	**type**\: list of    :py:class:`VirtualLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinks.VirtualLink>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.virtual_link = YList()
                                self.virtual_link.parent = self
                                self.virtual_link.name = 'virtual_link'


                            class VirtualLink(object):
                                """
                                Router ID of virtual link neighbor
                                
                                .. attribute:: virtual_link_address  <key>
                                
                                	Router ID of virtual link neighbor
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: authentication
                                
                                	Authenticate OSPFv3 packets
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinks.VirtualLink.Authentication>`
                                
                                .. attribute:: dead_interval
                                
                                	Interval after which a neighbor is declared dead (in seconds)
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: enable
                                
                                	Enabled virtual link
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: encryption
                                
                                	Encrypt and authenticate OSPFv3 packets
                                	**type**\:   :py:class:`Encryption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinks.VirtualLink.Encryption>`
                                
                                .. attribute:: hello_interval
                                
                                	Time between HELLO packets
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: retransmit_interval
                                
                                	Specify the transmit interval in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: transmit_delay
                                
                                	Specify the transmit delay in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.virtual_link_address = None
                                    self.authentication = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinks.VirtualLink.Authentication()
                                    self.authentication.parent = self
                                    self.dead_interval = None
                                    self.enable = None
                                    self.encryption = Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinks.VirtualLink.Encryption()
                                    self.encryption.parent = self
                                    self.hello_interval = None
                                    self.retransmit_interval = None
                                    self.transmit_delay = None


                                class Authentication(object):
                                    """
                                    Authenticate OSPFv3 packets
                                    
                                    .. attribute:: algorithm
                                    
                                    	Use the MD5 or SHA1 algorithm
                                    	**type**\:   :py:class:`Ospfv3AuthenticationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationEnum>`
                                    
                                    .. attribute:: enable
                                    
                                    	Authenticate packets
                                    	**type**\:  bool
                                    
                                    .. attribute:: password
                                    
                                    	Specify MD5 or SHA1 password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: spi
                                    
                                    	Use IPSec AH authentication. Specify the Security Parameter Index (SPI) value
                                    	**type**\:  int
                                    
                                    	**range:** 256..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.algorithm = None
                                        self.enable = None
                                        self.password = None
                                        self.spi = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:authentication'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.algorithm is not None:
                                            return True

                                        if self.enable is not None:
                                            return True

                                        if self.password is not None:
                                            return True

                                        if self.spi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinks.VirtualLink.Authentication']['meta_info']


                                class Encryption(object):
                                    """
                                    Encrypt and authenticate OSPFv3 packets
                                    
                                    .. attribute:: authentication_algorithm
                                    
                                    	Use the NULL, MD5 or SHA1 algorithm
                                    	**type**\:   :py:class:`Ospfv3AuthenticationType2Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationType2Enum>`
                                    
                                    .. attribute:: authentication_password
                                    
                                    	Specify MD5 or SHA1 password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: enable
                                    
                                    	Authenticate packets
                                    	**type**\:  bool
                                    
                                    .. attribute:: encryption_algorithm
                                    
                                    	Specify the encryption algorithm
                                    	**type**\:   :py:class:`Ospfv3EncryptionAlgorithmEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EncryptionAlgorithmEnum>`
                                    
                                    .. attribute:: encryption_password
                                    
                                    	Encryption password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: spi
                                    
                                    	Use IPSec ESP authentication. Specify the Security Parameter Index (SPI) value
                                    	**type**\:  int
                                    
                                    	**range:** 256..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.authentication_algorithm = None
                                        self.authentication_password = None
                                        self.enable = None
                                        self.encryption_algorithm = None
                                        self.encryption_password = None
                                        self.spi = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:encryption'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.authentication_algorithm is not None:
                                            return True

                                        if self.authentication_password is not None:
                                            return True

                                        if self.enable is not None:
                                            return True

                                        if self.encryption_algorithm is not None:
                                            return True

                                        if self.encryption_password is not None:
                                            return True

                                        if self.spi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinks.VirtualLink.Encryption']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.virtual_link_address is None:
                                        raise YPYModelError('Key property virtual_link_address is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:virtual-link[Cisco-IOS-XR-ipv6-ospfv3-cfg:virtual-link-address = ' + str(self.virtual_link_address) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.virtual_link_address is not None:
                                        return True

                                    if self.authentication is not None and self.authentication._has_data():
                                        return True

                                    if self.dead_interval is not None:
                                        return True

                                    if self.enable is not None:
                                        return True

                                    if self.encryption is not None and self.encryption._has_data():
                                        return True

                                    if self.hello_interval is not None:
                                        return True

                                    if self.retransmit_interval is not None:
                                        return True

                                    if self.transmit_delay is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinks.VirtualLink']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:virtual-links'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.virtual_link is not None:
                                    for child_ref in self.virtual_link:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinks']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.area_id is None:
                                raise YPYModelError('Key property area_id is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:area-area-id[Cisco-IOS-XR-ipv6-ospfv3-cfg:area-id = ' + str(self.area_id) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.area_id is not None:
                                return True

                            if self.area_scope is not None and self.area_scope._has_data():
                                return True

                            if self.authentication is not None and self.authentication._has_data():
                                return True

                            if self.bfd is not None and self.bfd._has_data():
                                return True

                            if self.cost is not None:
                                return True

                            if self.database_filter is not None and self.database_filter._has_data():
                                return True

                            if self.dead_interval is not None:
                                return True

                            if self.default_cost is not None:
                                return True

                            if self.demand_circuit is not None:
                                return True

                            if self.distribute_list is not None and self.distribute_list._has_data():
                                return True

                            if self.enable is not None:
                                return True

                            if self.encryption is not None and self.encryption._has_data():
                                return True

                            if self.flood_reduction is not None:
                                return True

                            if self.hello_interval is not None:
                                return True

                            if self.instance is not None:
                                return True

                            if self.interfaces is not None and self.interfaces._has_data():
                                return True

                            if self.ldp_sync is not None:
                                return True

                            if self.mtu_ignore is not None:
                                return True

                            if self.network is not None:
                                return True

                            if self.nssa is not None and self.nssa._has_data():
                                return True

                            if self.packet_size is not None:
                                return True

                            if self.passive is not None:
                                return True

                            if self.prefix_suppression is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.ranges is not None and self.ranges._has_data():
                                return True

                            if self.retransmit_interval is not None:
                                return True

                            if self.sham_links is not None and self.sham_links._has_data():
                                return True

                            if self.stub is not None:
                                return True

                            if self.transmit_delay is not None:
                                return True

                            if self.virtual_links is not None and self.virtual_links._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:area-addresses'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return True

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.area_address is not None:
                            for child_ref in self.area_address:
                                if child_ref._has_data():
                                    return True

                        if self.area_area_id is not None:
                            for child_ref in self.area_area_id:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaAddresses']['meta_info']


                class Timers(object):
                    """
                    Adjust routing timers
                    
                    .. attribute:: lsa_timers
                    
                    	LSA timers
                    	**type**\:   :py:class:`LsaTimers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.Timers.LsaTimers>`
                    
                    .. attribute:: pacing
                    
                    	Pacing timers
                    	**type**\:   :py:class:`Pacing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.Timers.Pacing>`
                    
                    .. attribute:: throttle
                    
                    	Throttle timers
                    	**type**\:   :py:class:`Throttle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.Timers.Throttle>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.lsa_timers = Ospfv3.Processes.Process.DefaultVrf.Timers.LsaTimers()
                        self.lsa_timers.parent = self
                        self.pacing = Ospfv3.Processes.Process.DefaultVrf.Timers.Pacing()
                        self.pacing.parent = self
                        self.throttle = Ospfv3.Processes.Process.DefaultVrf.Timers.Throttle()
                        self.throttle.parent = self


                    class Pacing(object):
                        """
                        Pacing timers
                        
                        .. attribute:: flood
                        
                        	The minimum interval in milliseconds to pace limit flooding on interface
                        	**type**\:  int
                        
                        	**range:** 5..100
                        
                        	**units**\: millisecond
                        
                        .. attribute:: lsa_group
                        
                        	Interval in seconds at which LSAs are grouped and refreshed, checksummed, or aged
                        	**type**\:  int
                        
                        	**range:** 10..1800
                        
                        	**units**\: second
                        
                        .. attribute:: retransmission
                        
                        	The minimum interval in msec between neighbor retransmissions
                        	**type**\:  int
                        
                        	**range:** 5..100
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.flood = None
                            self.lsa_group = None
                            self.retransmission = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:pacing'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.flood is not None:
                                return True

                            if self.lsa_group is not None:
                                return True

                            if self.retransmission is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Timers.Pacing']['meta_info']


                    class LsaTimers(object):
                        """
                        LSA timers
                        
                        .. attribute:: arrival
                        
                        	The minimum interval in milliseconds between accepting the same LSA
                        	**type**\:  int
                        
                        	**range:** 0..60000
                        
                        	**units**\: millisecond
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.arrival = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:lsa-timers'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.arrival is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Timers.LsaTimers']['meta_info']


                    class Throttle(object):
                        """
                        Throttle timers
                        
                        .. attribute:: lsa
                        
                        	LSA throttle timers for all types of OSPF LSAs
                        	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.Timers.Throttle.Lsa>`
                        
                        .. attribute:: spf
                        
                        	SPF throttle timers
                        	**type**\:   :py:class:`Spf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.Timers.Throttle.Spf>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.lsa = Ospfv3.Processes.Process.DefaultVrf.Timers.Throttle.Lsa()
                            self.lsa.parent = self
                            self.spf = Ospfv3.Processes.Process.DefaultVrf.Timers.Throttle.Spf()
                            self.spf.parent = self


                        class Lsa(object):
                            """
                            LSA throttle timers for all types of OSPF LSAs
                            
                            .. attribute:: first_delay
                            
                            	Delay to generate first occurrence of LSA in milliseconds
                            	**type**\:  int
                            
                            	**range:** 0..600000
                            
                            	**units**\: millisecond
                            
                            .. attribute:: maximum_delay
                            
                            	Maximum delay between originating the same LSA in milliseconds
                            	**type**\:  int
                            
                            	**range:** 1..600000
                            
                            	**units**\: millisecond
                            
                            .. attribute:: minimum_delay
                            
                            	Minimum delay between originating the same LSA in milliseconds
                            	**type**\:  int
                            
                            	**range:** 1..600000
                            
                            	**units**\: millisecond
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.first_delay = None
                                self.maximum_delay = None
                                self.minimum_delay = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:lsa'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.first_delay is not None:
                                    return True

                                if self.maximum_delay is not None:
                                    return True

                                if self.minimum_delay is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Timers.Throttle.Lsa']['meta_info']


                        class Spf(object):
                            """
                            SPF throttle timers
                            
                            .. attribute:: first_delay
                            
                            	Initial delay between receiving a change and starting SPF in ms
                            	**type**\:  int
                            
                            	**range:** 1..600000
                            
                            .. attribute:: maximum_delay
                            
                            	Maximum wait time between consecutive SPF calculations in ms
                            	**type**\:  int
                            
                            	**range:** 1..600000
                            
                            .. attribute:: minimum_delay
                            
                            	Minimum hold time between consecutive SPF calculations in ms
                            	**type**\:  int
                            
                            	**range:** 1..600000
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.first_delay = None
                                self.maximum_delay = None
                                self.minimum_delay = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:spf'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.first_delay is not None:
                                    return True

                                if self.maximum_delay is not None:
                                    return True

                                if self.minimum_delay is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Timers.Throttle.Spf']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:throttle'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.lsa is not None and self.lsa._has_data():
                                return True

                            if self.spf is not None and self.spf._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Timers.Throttle']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:timers'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return True

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.lsa_timers is not None and self.lsa_timers._has_data():
                            return True

                        if self.pacing is not None and self.pacing._has_data():
                            return True

                        if self.throttle is not None and self.throttle._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Timers']['meta_info']


                class SummaryPrefixes(object):
                    """
                    Summarize redistributed routes matching
                    prefix/length
                    
                    .. attribute:: summary_prefix
                    
                    	IPv6 address
                    	**type**\: list of    :py:class:`SummaryPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefix>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.summary_prefix = YList()
                        self.summary_prefix.parent = self
                        self.summary_prefix.name = 'summary_prefix'


                    class SummaryPrefix(object):
                        """
                        IPv6 address
                        
                        .. attribute:: prefix  <key>
                        
                        	IPv6 prefix string format
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: prefix_length  <key>
                        
                        	IPV6 prefix length
                        	**type**\:  int
                        
                        	**range:** 0..128
                        
                        .. attribute:: not_advertise
                        
                        	Suppress routes matching prefix/length
                        	**type**\:  bool
                        
                        .. attribute:: tag
                        
                        	Tag
                        	**type**\:  int
                        
                        	**range:** 1..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.prefix = None
                            self.prefix_length = None
                            self.not_advertise = None
                            self.tag = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.prefix is None:
                                raise YPYModelError('Key property prefix is None')
                            if self.prefix_length is None:
                                raise YPYModelError('Key property prefix_length is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:summary-prefix[Cisco-IOS-XR-ipv6-ospfv3-cfg:prefix = ' + str(self.prefix) + '][Cisco-IOS-XR-ipv6-ospfv3-cfg:prefix-length = ' + str(self.prefix_length) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.prefix is not None:
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.not_advertise is not None:
                                return True

                            if self.tag is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefix']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:summary-prefixes'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return True

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.summary_prefix is not None:
                            for child_ref in self.summary_prefix:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes']['meta_info']


                class Snmp(object):
                    """
                    SNMP configuration
                    
                    .. attribute:: context
                    
                    	SNMP context configuration
                    	**type**\:  str
                    
                    .. attribute:: trap_rate_limit
                    
                    	SNMP trap rate configuration
                    	**type**\:   :py:class:`TrapRateLimit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.Snmp.TrapRateLimit>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.context = None
                        self.trap_rate_limit = Ospfv3.Processes.Process.DefaultVrf.Snmp.TrapRateLimit()
                        self.trap_rate_limit.parent = self


                    class TrapRateLimit(object):
                        """
                        SNMP trap rate configuration
                        
                        .. attribute:: max_window_traps
                        
                        	Max number of traps sent in window time
                        	**type**\:  int
                        
                        	**range:** 0..300
                        
                        .. attribute:: window_size
                        
                        	Trap rate limit sliding window size
                        	**type**\:  int
                        
                        	**range:** 2..60
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.max_window_traps = None
                            self.window_size = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:trap-rate-limit'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.max_window_traps is not None:
                                return True

                            if self.window_size is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Snmp.TrapRateLimit']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:snmp'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return True

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.context is not None:
                            return True

                        if self.trap_rate_limit is not None and self.trap_rate_limit._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Snmp']['meta_info']


                class FastReroute(object):
                    """
                    Fast\-reroute instance scoped parameters
                    
                    .. attribute:: per_link
                    
                    	Fast\-reroute per\-link global configuration
                    	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.FastReroute.PerLink>`
                    
                    .. attribute:: per_prefix
                    
                    	Fast\-reroute per\-prefix global configuration
                    	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.FastReroute.PerPrefix>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.per_link = Ospfv3.Processes.Process.DefaultVrf.FastReroute.PerLink()
                        self.per_link.parent = self
                        self.per_prefix = Ospfv3.Processes.Process.DefaultVrf.FastReroute.PerPrefix()
                        self.per_prefix.parent = self


                    class PerLink(object):
                        """
                        Fast\-reroute per\-link global configuration
                        
                        .. attribute:: priority
                        
                        	Fast\-reroute per\-link/per\-prefix priority\-limit command
                        	**type**\:   :py:class:`Ospfv3FastReroutePriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3FastReroutePriorityEnum>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.priority = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-link'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.priority is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.FastReroute.PerLink']['meta_info']


                    class PerPrefix(object):
                        """
                        Fast\-reroute per\-prefix global configuration
                        
                        .. attribute:: load_sharing_disable
                        
                        	Disable load sharing between multiple backups
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: priority
                        
                        	Fast\-reroute per\-link/per\-prefix priority\-limit command
                        	**type**\:   :py:class:`Ospfv3FastReroutePriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3FastReroutePriorityEnum>`
                        
                        .. attribute:: tiebreakers
                        
                        	Fast\-reroute tiebreakers configurations
                        	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.load_sharing_disable = None
                            self.priority = None
                            self.tiebreakers = Ospfv3.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers()
                            self.tiebreakers.parent = self


                        class Tiebreakers(object):
                            """
                            Fast\-reroute tiebreakers configurations
                            
                            .. attribute:: tiebreaker
                            
                            	Fast\-reroute tiebreakers configuration
                            	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.tiebreaker = YList()
                                self.tiebreaker.parent = self
                                self.tiebreaker.name = 'tiebreaker'


                            class Tiebreaker(object):
                                """
                                Fast\-reroute tiebreakers configuration
                                
                                .. attribute:: tiebreaker_type  <key>
                                
                                	Tiebreaker type
                                	**type**\:   :py:class:`Ospfv3FastRerouteTiebreakersEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3FastRerouteTiebreakersEnum>`
                                
                                .. attribute:: tiebreaker_index
                                
                                	Index value for a tiebreaker
                                	**type**\:  int
                                
                                	**range:** 1..255
                                
                                	**mandatory**\: True
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.tiebreaker_type = None
                                    self.tiebreaker_index = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.tiebreaker_type is None:
                                        raise YPYModelError('Key property tiebreaker_type is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:tiebreaker[Cisco-IOS-XR-ipv6-ospfv3-cfg:tiebreaker-type = ' + str(self.tiebreaker_type) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.tiebreaker_type is not None:
                                        return True

                                    if self.tiebreaker_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers.Tiebreaker']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:tiebreakers'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.tiebreaker is not None:
                                    for child_ref in self.tiebreaker:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-prefix'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.load_sharing_disable is not None:
                                return True

                            if self.priority is not None:
                                return True

                            if self.tiebreakers is not None and self.tiebreakers._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.FastReroute.PerPrefix']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:fast-reroute'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return True

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.per_link is not None and self.per_link._has_data():
                            return True

                        if self.per_prefix is not None and self.per_prefix._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.FastReroute']['meta_info']


                class Distance(object):
                    """
                    Define an administrative distance
                    
                    .. attribute:: administrative
                    
                    	Define an administrative distance
                    	**type**\:  int
                    
                    	**range:** 1..255
                    
                    .. attribute:: ospfv3
                    
                    	OSPFv3 administrative distance
                    	**type**\:   :py:class:`Ospfv3_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.Distance.Ospfv3_>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.administrative = None
                        self.ospfv3 = Ospfv3.Processes.Process.DefaultVrf.Distance.Ospfv3_()
                        self.ospfv3.parent = self


                    class Ospfv3_(object):
                        """
                        OSPFv3 administrative distance
                        
                        .. attribute:: external
                        
                        	Distance for external type 5 and type 7 routes
                        	**type**\:  int
                        
                        	**range:** 1..255
                        
                        .. attribute:: inter_area
                        
                        	Distance for inter\-area routes
                        	**type**\:  int
                        
                        	**range:** 1..255
                        
                        .. attribute:: intra_area
                        
                        	Distance for intra\-area routes
                        	**type**\:  int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.external = None
                            self.inter_area = None
                            self.intra_area = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:ospfv3'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.external is not None:
                                return True

                            if self.inter_area is not None:
                                return True

                            if self.intra_area is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Distance.Ospfv3_']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:distance'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return True

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.administrative is not None:
                            return True

                        if self.ospfv3 is not None and self.ospfv3._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Distance']['meta_info']


                class Maximum(object):
                    """
                    Set OSPFv3 limits
                    
                    .. attribute:: interfaces
                    
                    	Specify maximum number of interfaces
                    	**type**\:  int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: paths
                    
                    	Specify maximum number of paths per route
                    	**type**\:  int
                    
                    	**range:** 1..64
                    
                    .. attribute:: redistributed_prefixes
                    
                    	Limit number of redistributed prefixes
                    	**type**\:   :py:class:`RedistributedPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.Maximum.RedistributedPrefixes>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interfaces = None
                        self.paths = None
                        self.redistributed_prefixes = Ospfv3.Processes.Process.DefaultVrf.Maximum.RedistributedPrefixes()
                        self.redistributed_prefixes.parent = self


                    class RedistributedPrefixes(object):
                        """
                        Limit number of redistributed prefixes
                        
                        .. attribute:: prefixes
                        
                        	Maximum number of prefixes redistributed to protocol
                        	**type**\:  int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: threshold
                        
                        	Threshold value (%) at which to generate a warning message
                        	**type**\:  int
                        
                        	**range:** 1..100
                        
                        .. attribute:: warning_only
                        
                        	Only give warning message when limit is exceeded
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.prefixes = None
                            self.threshold = None
                            self.warning_only = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:redistributed-prefixes'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.prefixes is not None:
                                return True

                            if self.threshold is not None:
                                return True

                            if self.warning_only is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Maximum.RedistributedPrefixes']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:maximum'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return True

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interfaces is not None:
                            return True

                        if self.paths is not None:
                            return True

                        if self.redistributed_prefixes is not None and self.redistributed_prefixes._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Maximum']['meta_info']


                class Redistributes(object):
                    """
                    Redistribute information from another routing
                    protocol
                    
                    .. attribute:: redistribute
                    
                    	Redistribute information from another routing protocol
                    	**type**\: list of    :py:class:`Redistribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.Redistributes.Redistribute>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.redistribute = YList()
                        self.redistribute.parent = self
                        self.redistribute.name = 'redistribute'


                    class Redistribute(object):
                        """
                        Redistribute information from another routing
                        protocol
                        
                        .. attribute:: protocol_name  <key>
                        
                        	Protocol
                        	**type**\:   :py:class:`Ospfv3ProtocolType2Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3ProtocolType2Enum>`
                        
                        .. attribute:: bgp
                        
                        	bgp
                        	**type**\: list of    :py:class:`Bgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.Redistributes.Redistribute.Bgp>`
                        
                        .. attribute:: connected_or_static_or_subscriber_or_mobile
                        
                        	connected or static or subscriber or mobile
                        	**type**\:   :py:class:`ConnectedOrStaticOrSubscriberOrMobile <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.Redistributes.Redistribute.ConnectedOrStaticOrSubscriberOrMobile>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: eigrp
                        
                        	eigrp
                        	**type**\: list of    :py:class:`Eigrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.Redistributes.Redistribute.Eigrp>`
                        
                        .. attribute:: ospfv3_or_isis_or_application
                        
                        	ospfv3 or isis or application
                        	**type**\: list of    :py:class:`Ospfv3OrIsisOrApplication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.Redistributes.Redistribute.Ospfv3OrIsisOrApplication>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.protocol_name = None
                            self.bgp = YList()
                            self.bgp.parent = self
                            self.bgp.name = 'bgp'
                            self.connected_or_static_or_subscriber_or_mobile = None
                            self.eigrp = YList()
                            self.eigrp.parent = self
                            self.eigrp.name = 'eigrp'
                            self.ospfv3_or_isis_or_application = YList()
                            self.ospfv3_or_isis_or_application.parent = self
                            self.ospfv3_or_isis_or_application.name = 'ospfv3_or_isis_or_application'


                        class ConnectedOrStaticOrSubscriberOrMobile(object):
                            """
                            connected or static or subscriber or mobile
                            
                            .. attribute:: default_metric
                            
                            	OSPFv3 default metric
                            	**type**\:  int
                            
                            	**range:** 0..16777214
                            
                            .. attribute:: eigrp_route_type
                            
                            	EIGRP route type
                            	**type**\:   :py:class:`Ospfv3EigrpRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EigrpRouteEnum>`
                            
                            .. attribute:: external_route_type
                            
                            	Redistribute OSPFv3 external routes
                            	**type**\:   :py:class:`Ospfv3ExternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3ExternalRouteEnum>`
                            
                            .. attribute:: internal_route_type
                            
                            	Redistribute OSPFv3 routes
                            	**type**\:   :py:class:`Ospfv3InternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3InternalRouteEnum>`
                            
                            .. attribute:: isis_route_type
                            
                            	ISIS route type
                            	**type**\:   :py:class:`Ospfv3IsisRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3IsisRouteEnum>`
                            
                            .. attribute:: metric_type
                            
                            	OSPFv3 exterior metric type for redistributed routes
                            	**type**\:   :py:class:`Ospfv3MetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3MetricEnum>`
                            
                            .. attribute:: nssa_external_route_type
                            
                            	Redistribute OSPFv3 NSSA external routes
                            	**type**\:   :py:class:`Ospfv3NssaExternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3NssaExternalRouteEnum>`
                            
                            .. attribute:: preserve_med
                            
                            	Preserve (Multi\-Exit Discriminator) of BGP routes
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: preserve_med_info
                            
                            	Preserve Information (Multi\-Exit Discriminator) of BGP routes
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redistribute_route
                            
                            	Redistribution of OSPFv3 routes
                            	**type**\:  bool
                            
                            .. attribute:: route_policy_name
                            
                            	Route policy to redistribution
                            	**type**\:  str
                            
                            .. attribute:: tag
                            
                            	Tag for routes redistributed into OSPFv3
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: _is_presence
                            
                            	Is present if this instance represents presence container else not
                            	**type**\: bool
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self._is_presence = True
                                self.default_metric = None
                                self.eigrp_route_type = None
                                self.external_route_type = None
                                self.internal_route_type = None
                                self.isis_route_type = None
                                self.metric_type = None
                                self.nssa_external_route_type = None
                                self.preserve_med = None
                                self.preserve_med_info = None
                                self.redistribute_route = None
                                self.route_policy_name = None
                                self.tag = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:connected-or-static-or-subscriber-or-mobile'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self._is_presence:
                                    return True
                                if self.default_metric is not None:
                                    return True

                                if self.eigrp_route_type is not None:
                                    return True

                                if self.external_route_type is not None:
                                    return True

                                if self.internal_route_type is not None:
                                    return True

                                if self.isis_route_type is not None:
                                    return True

                                if self.metric_type is not None:
                                    return True

                                if self.nssa_external_route_type is not None:
                                    return True

                                if self.preserve_med is not None:
                                    return True

                                if self.preserve_med_info is not None:
                                    return True

                                if self.redistribute_route is not None:
                                    return True

                                if self.route_policy_name is not None:
                                    return True

                                if self.tag is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Redistributes.Redistribute.ConnectedOrStaticOrSubscriberOrMobile']['meta_info']


                        class Bgp(object):
                            """
                            bgp
                            
                            .. attribute:: as_xx  <key>
                            
                            	4\-byte AS number in asdot (X.Y) format \- first half (X)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: as_yy  <key>
                            
                            	4\-byte AS number in asdot (X.Y) format \- second half (Y), or 2\-byte AS number, or 4\-byte AS number in asplain format
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: default_metric
                            
                            	OSPFv3 default metric
                            	**type**\:  int
                            
                            	**range:** 0..16777214
                            
                            .. attribute:: eigrp_route_type
                            
                            	EIGRP route type
                            	**type**\:   :py:class:`Ospfv3EigrpRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EigrpRouteEnum>`
                            
                            .. attribute:: external_route_type
                            
                            	Redistribute OSPFv3 external routes
                            	**type**\:   :py:class:`Ospfv3ExternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3ExternalRouteEnum>`
                            
                            .. attribute:: internal_route_type
                            
                            	Redistribute OSPFv3 routes
                            	**type**\:   :py:class:`Ospfv3InternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3InternalRouteEnum>`
                            
                            .. attribute:: isis_route_type
                            
                            	ISIS route type
                            	**type**\:   :py:class:`Ospfv3IsisRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3IsisRouteEnum>`
                            
                            .. attribute:: metric_type
                            
                            	OSPFv3 exterior metric type for redistributed routes
                            	**type**\:   :py:class:`Ospfv3MetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3MetricEnum>`
                            
                            .. attribute:: nssa_external_route_type
                            
                            	Redistribute OSPFv3 NSSA external routes
                            	**type**\:   :py:class:`Ospfv3NssaExternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3NssaExternalRouteEnum>`
                            
                            .. attribute:: preserve_med
                            
                            	Preserve (Multi\-Exit Discriminator) of BGP routes
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: preserve_med_info
                            
                            	Preserve Information (Multi\-Exit Discriminator) of BGP routes
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redistribute_route
                            
                            	Redistribution of OSPFv3 routes
                            	**type**\:  bool
                            
                            .. attribute:: route_policy_name
                            
                            	Route policy to redistribution
                            	**type**\:  str
                            
                            .. attribute:: tag
                            
                            	Tag for routes redistributed into OSPFv3
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.as_xx = None
                                self.as_yy = None
                                self.default_metric = None
                                self.eigrp_route_type = None
                                self.external_route_type = None
                                self.internal_route_type = None
                                self.isis_route_type = None
                                self.metric_type = None
                                self.nssa_external_route_type = None
                                self.preserve_med = None
                                self.preserve_med_info = None
                                self.redistribute_route = None
                                self.route_policy_name = None
                                self.tag = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.as_xx is None:
                                    raise YPYModelError('Key property as_xx is None')
                                if self.as_yy is None:
                                    raise YPYModelError('Key property as_yy is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:bgp[Cisco-IOS-XR-ipv6-ospfv3-cfg:as-xx = ' + str(self.as_xx) + '][Cisco-IOS-XR-ipv6-ospfv3-cfg:as-yy = ' + str(self.as_yy) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.as_xx is not None:
                                    return True

                                if self.as_yy is not None:
                                    return True

                                if self.default_metric is not None:
                                    return True

                                if self.eigrp_route_type is not None:
                                    return True

                                if self.external_route_type is not None:
                                    return True

                                if self.internal_route_type is not None:
                                    return True

                                if self.isis_route_type is not None:
                                    return True

                                if self.metric_type is not None:
                                    return True

                                if self.nssa_external_route_type is not None:
                                    return True

                                if self.preserve_med is not None:
                                    return True

                                if self.preserve_med_info is not None:
                                    return True

                                if self.redistribute_route is not None:
                                    return True

                                if self.route_policy_name is not None:
                                    return True

                                if self.tag is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Redistributes.Redistribute.Bgp']['meta_info']


                        class Ospfv3OrIsisOrApplication(object):
                            """
                            ospfv3 or isis or application
                            
                            .. attribute:: process_name  <key>
                            
                            	ISIS process name if protocol is ISIS, or OSPFv3 process name if protocol is OSPFv3
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: default_metric
                            
                            	OSPFv3 default metric
                            	**type**\:  int
                            
                            	**range:** 0..16777214
                            
                            .. attribute:: eigrp_route_type
                            
                            	EIGRP route type
                            	**type**\:   :py:class:`Ospfv3EigrpRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EigrpRouteEnum>`
                            
                            .. attribute:: external_route_type
                            
                            	Redistribute OSPFv3 external routes
                            	**type**\:   :py:class:`Ospfv3ExternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3ExternalRouteEnum>`
                            
                            .. attribute:: internal_route_type
                            
                            	Redistribute OSPFv3 routes
                            	**type**\:   :py:class:`Ospfv3InternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3InternalRouteEnum>`
                            
                            .. attribute:: isis_route_type
                            
                            	ISIS route type
                            	**type**\:   :py:class:`Ospfv3IsisRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3IsisRouteEnum>`
                            
                            .. attribute:: metric_type
                            
                            	OSPFv3 exterior metric type for redistributed routes
                            	**type**\:   :py:class:`Ospfv3MetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3MetricEnum>`
                            
                            .. attribute:: nssa_external_route_type
                            
                            	Redistribute OSPFv3 NSSA external routes
                            	**type**\:   :py:class:`Ospfv3NssaExternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3NssaExternalRouteEnum>`
                            
                            .. attribute:: preserve_med
                            
                            	Preserve (Multi\-Exit Discriminator) of BGP routes
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: preserve_med_info
                            
                            	Preserve Information (Multi\-Exit Discriminator) of BGP routes
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redistribute_route
                            
                            	Redistribution of OSPFv3 routes
                            	**type**\:  bool
                            
                            .. attribute:: route_policy_name
                            
                            	Route policy to redistribution
                            	**type**\:  str
                            
                            .. attribute:: tag
                            
                            	Tag for routes redistributed into OSPFv3
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.process_name = None
                                self.default_metric = None
                                self.eigrp_route_type = None
                                self.external_route_type = None
                                self.internal_route_type = None
                                self.isis_route_type = None
                                self.metric_type = None
                                self.nssa_external_route_type = None
                                self.preserve_med = None
                                self.preserve_med_info = None
                                self.redistribute_route = None
                                self.route_policy_name = None
                                self.tag = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.process_name is None:
                                    raise YPYModelError('Key property process_name is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:ospfv3-or-isis-or-application[Cisco-IOS-XR-ipv6-ospfv3-cfg:process-name = ' + str(self.process_name) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.process_name is not None:
                                    return True

                                if self.default_metric is not None:
                                    return True

                                if self.eigrp_route_type is not None:
                                    return True

                                if self.external_route_type is not None:
                                    return True

                                if self.internal_route_type is not None:
                                    return True

                                if self.isis_route_type is not None:
                                    return True

                                if self.metric_type is not None:
                                    return True

                                if self.nssa_external_route_type is not None:
                                    return True

                                if self.preserve_med is not None:
                                    return True

                                if self.preserve_med_info is not None:
                                    return True

                                if self.redistribute_route is not None:
                                    return True

                                if self.route_policy_name is not None:
                                    return True

                                if self.tag is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Redistributes.Redistribute.Ospfv3OrIsisOrApplication']['meta_info']


                        class Eigrp(object):
                            """
                            eigrp
                            
                            .. attribute:: as_xx  <key>
                            
                            	4\-byte AS number in asdot (X.Y) format \- first half (X)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: default_metric
                            
                            	OSPFv3 default metric
                            	**type**\:  int
                            
                            	**range:** 0..16777214
                            
                            .. attribute:: eigrp_route_type
                            
                            	EIGRP route type
                            	**type**\:   :py:class:`Ospfv3EigrpRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EigrpRouteEnum>`
                            
                            .. attribute:: external_route_type
                            
                            	Redistribute OSPFv3 external routes
                            	**type**\:   :py:class:`Ospfv3ExternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3ExternalRouteEnum>`
                            
                            .. attribute:: internal_route_type
                            
                            	Redistribute OSPFv3 routes
                            	**type**\:   :py:class:`Ospfv3InternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3InternalRouteEnum>`
                            
                            .. attribute:: isis_route_type
                            
                            	ISIS route type
                            	**type**\:   :py:class:`Ospfv3IsisRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3IsisRouteEnum>`
                            
                            .. attribute:: metric_type
                            
                            	OSPFv3 exterior metric type for redistributed routes
                            	**type**\:   :py:class:`Ospfv3MetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3MetricEnum>`
                            
                            .. attribute:: nssa_external_route_type
                            
                            	Redistribute OSPFv3 NSSA external routes
                            	**type**\:   :py:class:`Ospfv3NssaExternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3NssaExternalRouteEnum>`
                            
                            .. attribute:: preserve_med
                            
                            	Preserve (Multi\-Exit Discriminator) of BGP routes
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: preserve_med_info
                            
                            	Preserve Information (Multi\-Exit Discriminator) of BGP routes
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redistribute_route
                            
                            	Redistribution of OSPFv3 routes
                            	**type**\:  bool
                            
                            .. attribute:: route_policy_name
                            
                            	Route policy to redistribution
                            	**type**\:  str
                            
                            .. attribute:: tag
                            
                            	Tag for routes redistributed into OSPFv3
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.as_xx = None
                                self.default_metric = None
                                self.eigrp_route_type = None
                                self.external_route_type = None
                                self.internal_route_type = None
                                self.isis_route_type = None
                                self.metric_type = None
                                self.nssa_external_route_type = None
                                self.preserve_med = None
                                self.preserve_med_info = None
                                self.redistribute_route = None
                                self.route_policy_name = None
                                self.tag = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.as_xx is None:
                                    raise YPYModelError('Key property as_xx is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:eigrp[Cisco-IOS-XR-ipv6-ospfv3-cfg:as-xx = ' + str(self.as_xx) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.as_xx is not None:
                                    return True

                                if self.default_metric is not None:
                                    return True

                                if self.eigrp_route_type is not None:
                                    return True

                                if self.external_route_type is not None:
                                    return True

                                if self.internal_route_type is not None:
                                    return True

                                if self.isis_route_type is not None:
                                    return True

                                if self.metric_type is not None:
                                    return True

                                if self.nssa_external_route_type is not None:
                                    return True

                                if self.preserve_med is not None:
                                    return True

                                if self.preserve_med_info is not None:
                                    return True

                                if self.redistribute_route is not None:
                                    return True

                                if self.route_policy_name is not None:
                                    return True

                                if self.tag is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Redistributes.Redistribute.Eigrp']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.protocol_name is None:
                                raise YPYModelError('Key property protocol_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:redistribute[Cisco-IOS-XR-ipv6-ospfv3-cfg:protocol-name = ' + str(self.protocol_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.protocol_name is not None:
                                return True

                            if self.bgp is not None:
                                for child_ref in self.bgp:
                                    if child_ref._has_data():
                                        return True

                            if self.connected_or_static_or_subscriber_or_mobile is not None and self.connected_or_static_or_subscriber_or_mobile._has_data():
                                return True

                            if self.eigrp is not None:
                                for child_ref in self.eigrp:
                                    if child_ref._has_data():
                                        return True

                            if self.ospfv3_or_isis_or_application is not None:
                                for child_ref in self.ospfv3_or_isis_or_application:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Redistributes.Redistribute']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:redistributes'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return True

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.redistribute is not None:
                            for child_ref in self.redistribute:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Redistributes']['meta_info']


                class Ignore(object):
                    """
                    Do not complain about a specified event
                    
                    .. attribute:: lsa
                    
                    	Do not complain upon receiving LSA of the specified type
                    	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.Ignore.Lsa>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.lsa = Ospfv3.Processes.Process.DefaultVrf.Ignore.Lsa()
                        self.lsa.parent = self


                    class Lsa(object):
                        """
                        Do not complain upon receiving LSA of the
                        specified type
                        
                        .. attribute:: mospf
                        
                        	Enable ignore of MOSPF type 6 LSA
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.mospf = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:lsa'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.mospf is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Ignore.Lsa']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:ignore'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return True

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.lsa is not None and self.lsa._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Ignore']['meta_info']


                class DistributeListOut(object):
                    """
                    Filter prefixes from RIB 
                    
                    .. attribute:: distribute_outs
                    
                    	Filter generated type\-5 LSAs
                    	**type**\:   :py:class:`DistributeOuts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.DistributeListOut.DistributeOuts>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.distribute_outs = Ospfv3.Processes.Process.DefaultVrf.DistributeListOut.DistributeOuts()
                        self.distribute_outs.parent = self


                    class DistributeOuts(object):
                        """
                        Filter generated type\-5 LSAs
                        
                        .. attribute:: distribute_out
                        
                        	Filter generated type\-5 LSAs
                        	**type**\: list of    :py:class:`DistributeOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.DistributeListOut.DistributeOuts.DistributeOut>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.distribute_out = YList()
                            self.distribute_out.parent = self
                            self.distribute_out.name = 'distribute_out'


                        class DistributeOut(object):
                            """
                            Filter generated type\-5 LSAs
                            
                            .. attribute:: protocol_name  <key>
                            
                            	none
                            	**type**\:   :py:class:`Ospfv3ProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3ProtocolEnum>`
                            
                            .. attribute:: as_yy_and_as_xx_and_process_name
                            
                            	keys\: as\-yy, as\-xx, process\-name
                            	**type**\: list of    :py:class:`AsYyAndAsXxAndProcessName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.DistributeListOut.DistributeOuts.DistributeOut.AsYyAndAsXxAndProcessName>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.protocol_name = None
                                self.as_yy_and_as_xx_and_process_name = YList()
                                self.as_yy_and_as_xx_and_process_name.parent = self
                                self.as_yy_and_as_xx_and_process_name.name = 'as_yy_and_as_xx_and_process_name'


                            class AsYyAndAsXxAndProcessName(object):
                                """
                                keys\: as\-yy, as\-xx, process\-name
                                
                                .. attribute:: as_xx  <key>
                                
                                	4\-byte AS number in asdot (X.Y) format \- first half (X)
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: as_yy  <key>
                                
                                	4\-byte AS number in asdot (X.Y) format \- second half (Y), or 2\-byte AS number, or 4\-byte AS number in asplain format
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: process_name  <key>
                                
                                	If ISIS or OSPFv3, specify the instance name
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: prefix_list
                                
                                	Prefix\-list name
                                	**type**\:  str
                                
                                	**mandatory**\: True
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.as_xx = None
                                    self.as_yy = None
                                    self.process_name = None
                                    self.prefix_list = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.as_xx is None:
                                        raise YPYModelError('Key property as_xx is None')
                                    if self.as_yy is None:
                                        raise YPYModelError('Key property as_yy is None')
                                    if self.process_name is None:
                                        raise YPYModelError('Key property process_name is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:as-yy-and-as-xx-and-process-name[Cisco-IOS-XR-ipv6-ospfv3-cfg:as-xx = ' + str(self.as_xx) + '][Cisco-IOS-XR-ipv6-ospfv3-cfg:as-yy = ' + str(self.as_yy) + '][Cisco-IOS-XR-ipv6-ospfv3-cfg:process-name = ' + str(self.process_name) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.as_xx is not None:
                                        return True

                                    if self.as_yy is not None:
                                        return True

                                    if self.process_name is not None:
                                        return True

                                    if self.prefix_list is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DistributeListOut.DistributeOuts.DistributeOut.AsYyAndAsXxAndProcessName']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.protocol_name is None:
                                    raise YPYModelError('Key property protocol_name is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:distribute-out[Cisco-IOS-XR-ipv6-ospfv3-cfg:protocol-name = ' + str(self.protocol_name) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.protocol_name is not None:
                                    return True

                                if self.as_yy_and_as_xx_and_process_name is not None:
                                    for child_ref in self.as_yy_and_as_xx_and_process_name:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DistributeListOut.DistributeOuts.DistributeOut']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:distribute-outs'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.distribute_out is not None:
                                for child_ref in self.distribute_out:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DistributeListOut.DistributeOuts']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:distribute-list-out'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return True

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.distribute_outs is not None and self.distribute_outs._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DistributeListOut']['meta_info']


                class DistributeList(object):
                    """
                    Filter prefixes to/from RIB
                    
                    .. attribute:: in_
                    
                    	Filter prefixes installed to RIB
                    	**type**\:   :py:class:`In_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.DistributeList.In_>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.in_ = Ospfv3.Processes.Process.DefaultVrf.DistributeList.In_()
                        self.in_.parent = self


                    class In_(object):
                        """
                        Filter prefixes installed to RIB
                        
                        .. attribute:: prefix_list
                        
                        	Filter prefixes based on an IPv6 prefix\-list
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.prefix_list = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:in'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.prefix_list is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DistributeList.In_']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:distribute-list'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return True

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.in_ is not None and self.in_._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DistributeList']['meta_info']


                class StubRouter(object):
                    """
                    Stub router configuration
                    
                    .. attribute:: max_metric
                    
                    	Stub router max\-metric configuration
                    	**type**\:   :py:class:`MaxMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.StubRouter.MaxMetric>`
                    
                    .. attribute:: rbit
                    
                    	Stub router R\-bit configuration
                    	**type**\:   :py:class:`Rbit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.StubRouter.Rbit>`
                    
                    .. attribute:: v6bit
                    
                    	Stub router V6\-bit configuration
                    	**type**\:   :py:class:`V6Bit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.StubRouter.V6Bit>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.max_metric = Ospfv3.Processes.Process.DefaultVrf.StubRouter.MaxMetric()
                        self.max_metric.parent = self
                        self.rbit = Ospfv3.Processes.Process.DefaultVrf.StubRouter.Rbit()
                        self.rbit.parent = self
                        self.v6bit = Ospfv3.Processes.Process.DefaultVrf.StubRouter.V6Bit()
                        self.v6bit.parent = self


                    class Rbit(object):
                        """
                        Stub router R\-bit configuration
                        
                        .. attribute:: always
                        
                        	Unconditionally enter stub router operational state
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: enable
                        
                        	Enabled stub router configuration mode
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: external_lsa
                        
                        	Advertise external LSAs with modified metric in stub router mode
                        	**type**\:  int
                        
                        	**range:** 1..16777214
                        
                        	**default value**\: 16711680
                        
                        .. attribute:: include_stub
                        
                        	Advertise stub links with maximum metric in stub router mode
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: on_proc_migration
                        
                        	Time (in seconds) to stay in stub router operational state
                        	**type**\:  int
                        
                        	**range:** 5..86400
                        
                        	**units**\: second
                        
                        .. attribute:: on_proc_restart
                        
                        	Time (in seconds) to stay in stub router operational state
                        	**type**\:  int
                        
                        	**range:** 5..86400
                        
                        	**units**\: second
                        
                        .. attribute:: on_startup
                        
                        	Enter stub router operational state on startup
                        	**type**\:   :py:class:`OnStartup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.StubRouter.Rbit.OnStartup>`
                        
                        .. attribute:: on_switchover
                        
                        	Time (in seconds) to stay in stub router operational state
                        	**type**\:  int
                        
                        	**range:** 5..86400
                        
                        	**units**\: second
                        
                        .. attribute:: summary_lsa
                        
                        	Advertise summary LSAs with modified metric in stub router mode
                        	**type**\:  int
                        
                        	**range:** 1..16777214
                        
                        	**default value**\: 16711680
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.always = None
                            self.enable = None
                            self.external_lsa = None
                            self.include_stub = None
                            self.on_proc_migration = None
                            self.on_proc_restart = None
                            self.on_startup = Ospfv3.Processes.Process.DefaultVrf.StubRouter.Rbit.OnStartup()
                            self.on_startup.parent = self
                            self.on_switchover = None
                            self.summary_lsa = None


                        class OnStartup(object):
                            """
                            Enter stub router operational state on startup
                            
                            .. attribute:: wait_for_bgp
                            
                            	Wait until BGP converges (only applicable to default VRF)
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: wait_time
                            
                            	Time (in seconds) to stay in stub router operational state
                            	**type**\:  int
                            
                            	**range:** 5..86400
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.wait_for_bgp = None
                                self.wait_time = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:on-startup'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.wait_for_bgp is not None:
                                    return True

                                if self.wait_time is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.StubRouter.Rbit.OnStartup']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:rbit'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.always is not None:
                                return True

                            if self.enable is not None:
                                return True

                            if self.external_lsa is not None:
                                return True

                            if self.include_stub is not None:
                                return True

                            if self.on_proc_migration is not None:
                                return True

                            if self.on_proc_restart is not None:
                                return True

                            if self.on_startup is not None and self.on_startup._has_data():
                                return True

                            if self.on_switchover is not None:
                                return True

                            if self.summary_lsa is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.StubRouter.Rbit']['meta_info']


                    class V6Bit(object):
                        """
                        Stub router V6\-bit configuration
                        
                        .. attribute:: always
                        
                        	Unconditionally enter stub router operational state
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: enable
                        
                        	Enabled stub router configuration mode
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: external_lsa
                        
                        	Advertise external LSAs with modified metric in stub router mode
                        	**type**\:  int
                        
                        	**range:** 1..16777214
                        
                        	**default value**\: 16711680
                        
                        .. attribute:: include_stub
                        
                        	Advertise stub links with maximum metric in stub router mode
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: on_proc_migration
                        
                        	Time (in seconds) to stay in stub router operational state
                        	**type**\:  int
                        
                        	**range:** 5..86400
                        
                        	**units**\: second
                        
                        .. attribute:: on_proc_restart
                        
                        	Time (in seconds) to stay in stub router operational state
                        	**type**\:  int
                        
                        	**range:** 5..86400
                        
                        	**units**\: second
                        
                        .. attribute:: on_startup
                        
                        	Enter stub router operational state on startup
                        	**type**\:   :py:class:`OnStartup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.StubRouter.V6Bit.OnStartup>`
                        
                        .. attribute:: on_switchover
                        
                        	Time (in seconds) to stay in stub router operational state
                        	**type**\:  int
                        
                        	**range:** 5..86400
                        
                        	**units**\: second
                        
                        .. attribute:: summary_lsa
                        
                        	Advertise summary LSAs with modified metric in stub router mode
                        	**type**\:  int
                        
                        	**range:** 1..16777214
                        
                        	**default value**\: 16711680
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.always = None
                            self.enable = None
                            self.external_lsa = None
                            self.include_stub = None
                            self.on_proc_migration = None
                            self.on_proc_restart = None
                            self.on_startup = Ospfv3.Processes.Process.DefaultVrf.StubRouter.V6Bit.OnStartup()
                            self.on_startup.parent = self
                            self.on_switchover = None
                            self.summary_lsa = None


                        class OnStartup(object):
                            """
                            Enter stub router operational state on startup
                            
                            .. attribute:: wait_for_bgp
                            
                            	Wait until BGP converges (only applicable to default VRF)
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: wait_time
                            
                            	Time (in seconds) to stay in stub router operational state
                            	**type**\:  int
                            
                            	**range:** 5..86400
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.wait_for_bgp = None
                                self.wait_time = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:on-startup'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.wait_for_bgp is not None:
                                    return True

                                if self.wait_time is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.StubRouter.V6Bit.OnStartup']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:v6bit'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.always is not None:
                                return True

                            if self.enable is not None:
                                return True

                            if self.external_lsa is not None:
                                return True

                            if self.include_stub is not None:
                                return True

                            if self.on_proc_migration is not None:
                                return True

                            if self.on_proc_restart is not None:
                                return True

                            if self.on_startup is not None and self.on_startup._has_data():
                                return True

                            if self.on_switchover is not None:
                                return True

                            if self.summary_lsa is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.StubRouter.V6Bit']['meta_info']


                    class MaxMetric(object):
                        """
                        Stub router max\-metric configuration
                        
                        .. attribute:: always
                        
                        	Unconditionally enter stub router operational state
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: enable
                        
                        	Enabled stub router configuration mode
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: external_lsa
                        
                        	Advertise external LSAs with modified metric in stub router mode
                        	**type**\:  int
                        
                        	**range:** 1..16777214
                        
                        	**default value**\: 16711680
                        
                        .. attribute:: include_stub
                        
                        	Advertise stub links with maximum metric in stub router mode
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: on_proc_migration
                        
                        	Time (in seconds) to stay in stub router operational state
                        	**type**\:  int
                        
                        	**range:** 5..86400
                        
                        	**units**\: second
                        
                        .. attribute:: on_proc_restart
                        
                        	Time (in seconds) to stay in stub router operational state
                        	**type**\:  int
                        
                        	**range:** 5..86400
                        
                        	**units**\: second
                        
                        .. attribute:: on_startup
                        
                        	Enter stub router operational state on startup
                        	**type**\:   :py:class:`OnStartup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.StubRouter.MaxMetric.OnStartup>`
                        
                        .. attribute:: on_switchover
                        
                        	Time (in seconds) to stay in stub router operational state
                        	**type**\:  int
                        
                        	**range:** 5..86400
                        
                        	**units**\: second
                        
                        .. attribute:: summary_lsa
                        
                        	Advertise summary LSAs with modified metric in stub router mode
                        	**type**\:  int
                        
                        	**range:** 1..16777214
                        
                        	**default value**\: 16711680
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.always = None
                            self.enable = None
                            self.external_lsa = None
                            self.include_stub = None
                            self.on_proc_migration = None
                            self.on_proc_restart = None
                            self.on_startup = Ospfv3.Processes.Process.DefaultVrf.StubRouter.MaxMetric.OnStartup()
                            self.on_startup.parent = self
                            self.on_switchover = None
                            self.summary_lsa = None


                        class OnStartup(object):
                            """
                            Enter stub router operational state on startup
                            
                            .. attribute:: wait_for_bgp
                            
                            	Wait until BGP converges (only applicable to default VRF)
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: wait_time
                            
                            	Time (in seconds) to stay in stub router operational state
                            	**type**\:  int
                            
                            	**range:** 5..86400
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.wait_for_bgp = None
                                self.wait_time = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:on-startup'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.wait_for_bgp is not None:
                                    return True

                                if self.wait_time is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.StubRouter.MaxMetric.OnStartup']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:max-metric'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.always is not None:
                                return True

                            if self.enable is not None:
                                return True

                            if self.external_lsa is not None:
                                return True

                            if self.include_stub is not None:
                                return True

                            if self.on_proc_migration is not None:
                                return True

                            if self.on_proc_restart is not None:
                                return True

                            if self.on_startup is not None and self.on_startup._has_data():
                                return True

                            if self.on_switchover is not None:
                                return True

                            if self.summary_lsa is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.StubRouter.MaxMetric']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:stub-router'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return True

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.max_metric is not None and self.max_metric._has_data():
                            return True

                        if self.rbit is not None and self.rbit._has_data():
                            return True

                        if self.v6bit is not None and self.v6bit._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.StubRouter']['meta_info']


                class Bfd(object):
                    """
                    Configure BFD parameters
                    
                    .. attribute:: detection_multiplier
                    
                    	Detect multiplier
                    	**type**\:  int
                    
                    	**range:** 2..50
                    
                    .. attribute:: fast_detect_mode
                    
                    	Enable or disable BFD fast detection
                    	**type**\:   :py:class:`Ospfv3BfdEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3BfdEnableModeEnum>`
                    
                    .. attribute:: interval
                    
                    	Hello interval in milli\-seconds
                    	**type**\:  int
                    
                    	**range:** 3..30000
                    
                    	**units**\: millisecond
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.detection_multiplier = None
                        self.fast_detect_mode = None
                        self.interval = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:bfd'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return True

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.detection_multiplier is not None:
                            return True

                        if self.fast_detect_mode is not None:
                            return True

                        if self.interval is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Bfd']['meta_info']


                class DatabaseFilter(object):
                    """
                    Database filter
                    
                    .. attribute:: all
                    
                    	All
                    	**type**\:   :py:class:`All <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.DatabaseFilter.All>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.all = Ospfv3.Processes.Process.DefaultVrf.DatabaseFilter.All()
                        self.all.parent = self


                    class All(object):
                        """
                        All
                        
                        .. attribute:: out
                        
                        	Enable out
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.out = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:all'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.out is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseFilter.All']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:database-filter'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return True

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.all is not None and self.all._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseFilter']['meta_info']


                class Authentication(object):
                    """
                    Authenticate OSPFv3 packets
                    
                    .. attribute:: algorithm
                    
                    	Use the MD5 or SHA1 algorithm
                    	**type**\:   :py:class:`Ospfv3AuthenticationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationEnum>`
                    
                    .. attribute:: enable
                    
                    	Authenticate packets
                    	**type**\:  bool
                    
                    .. attribute:: password
                    
                    	Specify MD5 or SHA1 password
                    	**type**\:  str
                    
                    	**pattern:** (!.+)\|([^!].+)
                    
                    .. attribute:: spi
                    
                    	Use IPSec AH authentication. Specify the Security Parameter Index (SPI) value
                    	**type**\:  int
                    
                    	**range:** 256..4294967295
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.algorithm = None
                        self.enable = None
                        self.password = None
                        self.spi = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:authentication'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return True

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.algorithm is not None:
                            return True

                        if self.enable is not None:
                            return True

                        if self.password is not None:
                            return True

                        if self.spi is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Authentication']['meta_info']


                class GracefulRestart(object):
                    """
                    Graceful restart configuration
                    
                    .. attribute:: enable
                    
                    	Enable graceful restart
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: helper
                    
                    	Disable router's helper support
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: interval
                    
                    	Minimum interval between graceful restarts (seconds)
                    	**type**\:  int
                    
                    	**range:** 90..3600
                    
                    	**units**\: second
                    
                    .. attribute:: lifetime
                    
                    	Maximum route lifetime following restart (seconds)
                    	**type**\:  int
                    
                    	**range:** 90..1800
                    
                    	**units**\: second
                    
                    .. attribute:: strict_lsa_checking
                    
                    	Terminate graceful restart helper mode if LSA changed
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.enable = None
                        self.helper = None
                        self.interval = None
                        self.lifetime = None
                        self.strict_lsa_checking = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:graceful-restart'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return True

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.enable is not None:
                            return True

                        if self.helper is not None:
                            return True

                        if self.interval is not None:
                            return True

                        if self.lifetime is not None:
                            return True

                        if self.strict_lsa_checking is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.GracefulRestart']['meta_info']


                class DefaultInformation(object):
                    """
                    Control distribution of default information
                    
                    .. attribute:: originate
                    
                    	Distribute a default route
                    	**type**\:   :py:class:`Originate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.DefaultInformation.Originate>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.originate = None


                    class Originate(object):
                        """
                        Distribute a default route
                        
                        .. attribute:: always
                        
                        	Always advertise default route
                        	**type**\:  bool
                        
                        	**mandatory**\: True
                        
                        .. attribute:: metric
                        
                        	OSPFv3 default metric
                        	**type**\:  int
                        
                        	**range:** 0..16777214
                        
                        .. attribute:: metric_type
                        
                        	OSPFv3 metric type for default routes
                        	**type**\:  int
                        
                        	**range:** 1..2
                        
                        .. attribute:: route_policy_name
                        
                        	Route policy to default\-information origination
                        	**type**\:  str
                        
                        .. attribute:: tag
                        
                        	Tag for default route
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: _is_presence
                        
                        	Is present if this instance represents presence container else not
                        	**type**\: bool
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self._is_presence = True
                            self.always = None
                            self.metric = None
                            self.metric_type = None
                            self.route_policy_name = None
                            self.tag = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:originate'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self._is_presence:
                                return True
                            if self.always is not None:
                                return True

                            if self.metric is not None:
                                return True

                            if self.metric_type is not None:
                                return True

                            if self.route_policy_name is not None:
                                return True

                            if self.tag is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DefaultInformation.Originate']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:default-information'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return True

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.originate is not None and self.originate._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DefaultInformation']['meta_info']


                class ProcessScope(object):
                    """
                    Process scope configuration
                    
                    .. attribute:: fast_reroute
                    
                    	Fast\-reroute configuration
                    	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.fast_reroute = Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute()
                        self.fast_reroute.parent = self


                    class FastReroute(object):
                        """
                        Fast\-reroute configuration
                        
                        .. attribute:: fast_reroute_enable
                        
                        	Enable/Disable Fast\-reroute per\-link or per\-prefix
                        	**type**\:   :py:class:`Ospfv3FastRerouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3FastRerouteEnum>`
                        
                        .. attribute:: per_link
                        
                        	Fast\-reroute per\-link configuration
                        	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink>`
                        
                        .. attribute:: per_prefix
                        
                        	Fast\-reroute per\-link configuration
                        	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.fast_reroute_enable = None
                            self.per_link = Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink()
                            self.per_link.parent = self
                            self.per_prefix = Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix()
                            self.per_prefix.parent = self


                        class PerLink(object):
                            """
                            Fast\-reroute per\-link configuration
                            
                            .. attribute:: candidate_interfaces
                            
                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces>`
                            
                            .. attribute:: exclude_interfaces
                            
                            	Fast\-reroute per\-link/per\-prefix exclude interface configuration
                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces>`
                            
                            .. attribute:: fast_reroute_use_candidate_only
                            
                            	Use only interfaces on the candidate list as a backup path
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.candidate_interfaces = Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces()
                                self.candidate_interfaces.parent = self
                                self.exclude_interfaces = Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces()
                                self.exclude_interfaces.parent = self
                                self.fast_reroute_use_candidate_only = None


                            class CandidateInterfaces(object):
                                """
                                Fast\-reroute per\-link/per\-prefix candidate
                                interface configuration
                                
                                .. attribute:: candidate_interface
                                
                                	Candidate backup interface
                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.candidate_interface = YList()
                                    self.candidate_interface.parent = self
                                    self.candidate_interface.name = 'candidate_interface'


                                class CandidateInterface(object):
                                    """
                                    Candidate backup interface
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.interface_name is None:
                                            raise YPYModelError('Key property interface_name is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interfaces'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.candidate_interface is not None:
                                        for child_ref in self.candidate_interface:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces']['meta_info']


                            class ExcludeInterfaces(object):
                                """
                                Fast\-reroute per\-link/per\-prefix exclude
                                interface configuration
                                
                                .. attribute:: exclude_interface
                                
                                	Exclude an interface from becoming a backup
                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.exclude_interface = YList()
                                    self.exclude_interface.parent = self
                                    self.exclude_interface.name = 'exclude_interface'


                                class ExcludeInterface(object):
                                    """
                                    Exclude an interface from becoming a backup
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.interface_name is None:
                                            raise YPYModelError('Key property interface_name is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interfaces'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.exclude_interface is not None:
                                        for child_ref in self.exclude_interface:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-link'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.candidate_interfaces is not None and self.candidate_interfaces._has_data():
                                    return True

                                if self.exclude_interfaces is not None and self.exclude_interfaces._has_data():
                                    return True

                                if self.fast_reroute_use_candidate_only is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink']['meta_info']


                        class PerPrefix(object):
                            """
                            Fast\-reroute per\-link configuration
                            
                            .. attribute:: candidate_interfaces
                            
                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces>`
                            
                            .. attribute:: exclude_interfaces
                            
                            	Fast\-reroute per\-link/per\-prefix exclude interface configuration
                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                            
                            .. attribute:: fast_reroute_use_candidate_only
                            
                            	Use only interfaces on the candidate list as a backup path
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.candidate_interfaces = Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces()
                                self.candidate_interfaces.parent = self
                                self.exclude_interfaces = Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                self.exclude_interfaces.parent = self
                                self.fast_reroute_use_candidate_only = None


                            class CandidateInterfaces(object):
                                """
                                Fast\-reroute per\-link/per\-prefix candidate
                                interface configuration
                                
                                .. attribute:: candidate_interface
                                
                                	Candidate backup interface
                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.candidate_interface = YList()
                                    self.candidate_interface.parent = self
                                    self.candidate_interface.name = 'candidate_interface'


                                class CandidateInterface(object):
                                    """
                                    Candidate backup interface
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.interface_name is None:
                                            raise YPYModelError('Key property interface_name is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interfaces'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.candidate_interface is not None:
                                        for child_ref in self.candidate_interface:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces']['meta_info']


                            class ExcludeInterfaces(object):
                                """
                                Fast\-reroute per\-link/per\-prefix exclude
                                interface configuration
                                
                                .. attribute:: exclude_interface
                                
                                	Exclude an interface from becoming a backup
                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.exclude_interface = YList()
                                    self.exclude_interface.parent = self
                                    self.exclude_interface.name = 'exclude_interface'


                                class ExcludeInterface(object):
                                    """
                                    Exclude an interface from becoming a backup
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.interface_name is None:
                                            raise YPYModelError('Key property interface_name is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interfaces'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.exclude_interface is not None:
                                        for child_ref in self.exclude_interface:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.candidate_interfaces is not None and self.candidate_interfaces._has_data():
                                    return True

                                if self.exclude_interfaces is not None and self.exclude_interfaces._has_data():
                                    return True

                                if self.fast_reroute_use_candidate_only is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:fast-reroute'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.fast_reroute_enable is not None:
                                return True

                            if self.per_link is not None and self.per_link._has_data():
                                return True

                            if self.per_prefix is not None and self.per_prefix._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ProcessScope.FastReroute']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:process-scope'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return True

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.fast_reroute is not None and self.fast_reroute._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ProcessScope']['meta_info']


                class Encryption(object):
                    """
                    Encrypt and authenticate OSPFv3 packets
                    
                    .. attribute:: authentication_algorithm
                    
                    	Use the NULL, MD5 or SHA1 algorithm
                    	**type**\:   :py:class:`Ospfv3AuthenticationType2Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationType2Enum>`
                    
                    .. attribute:: authentication_password
                    
                    	Specify MD5 or SHA1 password
                    	**type**\:  str
                    
                    	**pattern:** (!.+)\|([^!].+)
                    
                    .. attribute:: enable
                    
                    	Authenticate packets
                    	**type**\:  bool
                    
                    .. attribute:: encryption_algorithm
                    
                    	Specify the encryption algorithm
                    	**type**\:   :py:class:`Ospfv3EncryptionAlgorithmEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EncryptionAlgorithmEnum>`
                    
                    .. attribute:: encryption_password
                    
                    	Encryption password
                    	**type**\:  str
                    
                    	**pattern:** (!.+)\|([^!].+)
                    
                    .. attribute:: spi
                    
                    	Use IPSec ESP authentication. Specify the Security Parameter Index (SPI) value
                    	**type**\:  int
                    
                    	**range:** 256..4294967295
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.authentication_algorithm = None
                        self.authentication_password = None
                        self.enable = None
                        self.encryption_algorithm = None
                        self.encryption_password = None
                        self.spi = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:encryption'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return True

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.authentication_algorithm is not None:
                            return True

                        if self.authentication_password is not None:
                            return True

                        if self.enable is not None:
                            return True

                        if self.encryption_algorithm is not None:
                            return True

                        if self.encryption_password is not None:
                            return True

                        if self.spi is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Encryption']['meta_info']


                class AutoCost(object):
                    """
                    Calculate interface cost according to bandwidth
                    
                    .. attribute:: disable
                    
                    	Specify 'true' to assign cost based on interface type
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: reference_bandwidth
                    
                    	Specify reference bandwidth for cost computations in terms of Mbits per second
                    	**type**\:  int
                    
                    	**range:** 1..4294967
                    
                    	**units**\: Mbit/s
                    
                    .. attribute:: _is_presence
                    
                    	Is present if this instance represents presence container else not
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ipv6-ospfv3-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self._is_presence = True
                        self.disable = None
                        self.reference_bandwidth = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:auto-cost'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return True

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self._is_presence:
                            return True
                        if self.disable is not None:
                            return True

                        if self.reference_bandwidth is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AutoCost']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:default-vrf'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return True

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.area_addresses is not None and self.area_addresses._has_data():
                        return True

                    if self.authentication is not None and self.authentication._has_data():
                        return True

                    if self.auto_cost is not None and self.auto_cost._has_data():
                        return True

                    if self.bfd is not None and self.bfd._has_data():
                        return True

                    if self.cost is not None:
                        return True

                    if self.database_filter is not None and self.database_filter._has_data():
                        return True

                    if self.dead_interval is not None:
                        return True

                    if self.default_information is not None and self.default_information._has_data():
                        return True

                    if self.default_metric is not None:
                        return True

                    if self.demand_circuit is not None:
                        return True

                    if self.distance is not None and self.distance._has_data():
                        return True

                    if self.distribute_list is not None and self.distribute_list._has_data():
                        return True

                    if self.distribute_list_out is not None and self.distribute_list_out._has_data():
                        return True

                    if self.encryption is not None and self.encryption._has_data():
                        return True

                    if self.fast_reroute is not None and self.fast_reroute._has_data():
                        return True

                    if self.flood_reduction is not None:
                        return True

                    if self.graceful_restart is not None and self.graceful_restart._has_data():
                        return True

                    if self.hello_interval is not None:
                        return True

                    if self.ignore is not None and self.ignore._has_data():
                        return True

                    if self.instance is not None:
                        return True

                    if self.ldp_sync is not None:
                        return True

                    if self.log_adjacency_changes is not None:
                        return True

                    if self.maximum is not None and self.maximum._has_data():
                        return True

                    if self.mtu_ignore is not None:
                        return True

                    if self.network is not None:
                        return True

                    if self.packet_size is not None:
                        return True

                    if self.passive is not None:
                        return True

                    if self.prefix_suppression is not None:
                        return True

                    if self.priority is not None:
                        return True

                    if self.process_scope is not None and self.process_scope._has_data():
                        return True

                    if self.redistributes is not None and self.redistributes._has_data():
                        return True

                    if self.retransmit_interval is not None:
                        return True

                    if self.router_id is not None:
                        return True

                    if self.snmp is not None and self.snmp._has_data():
                        return True

                    if self.spf_prefix_priority_disable is not None:
                        return True

                    if self.spf_prefix_priority_policy is not None:
                        return True

                    if self.stub_router is not None and self.stub_router._has_data():
                        return True

                    if self.summary_prefixes is not None and self.summary_prefixes._has_data():
                        return True

                    if self.timers is not None and self.timers._has_data():
                        return True

                    if self.transmit_delay is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf']['meta_info']


            class Vrfs(object):
                """
                VRF related configuration
                
                .. attribute:: vrf
                
                	Configuration for a particular OSPF VRF
                	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf>`
                
                

                """

                _prefix = 'ipv6-ospfv3-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.vrf = YList()
                    self.vrf.parent = self
                    self.vrf.name = 'vrf'


                class Vrf(object):
                    """
                    Configuration for a particular OSPF VRF
                    
                    .. attribute:: vrf_name  <key>
                    
                    	Name for this VRF
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: area_addresses
                    
                    	Area configuration
                    	**type**\:   :py:class:`AreaAddresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses>`
                    
                    .. attribute:: authentication
                    
                    	Authenticate OSPFv3 packets
                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Authentication>`
                    
                    .. attribute:: auto_cost
                    
                    	Calculate interface cost according to bandwidth
                    	**type**\:   :py:class:`AutoCost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AutoCost>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: bfd
                    
                    	Configure BFD parameters
                    	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Bfd>`
                    
                    .. attribute:: capability
                    
                    	OSPFv3 Capability
                    	**type**\:   :py:class:`Capability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Capability>`
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\:  int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Database filter
                    	**type**\:   :py:class:`DatabaseFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead (in seconds)
                    	**type**\:  int
                    
                    	**range:** 1..65535
                    
                    	**units**\: second
                    
                    .. attribute:: default_information
                    
                    	Control distribution of default information
                    	**type**\:   :py:class:`DefaultInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.DefaultInformation>`
                    
                    .. attribute:: default_metric
                    
                    	Set metric of redistributed routes
                    	**type**\:  int
                    
                    	**range:** 1..16777214
                    
                    .. attribute:: demand_circuit
                    
                    	Enable/disable demand circuit operation
                    	**type**\:  bool
                    
                    .. attribute:: distance
                    
                    	Define an administrative distance
                    	**type**\:   :py:class:`Distance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Distance>`
                    
                    .. attribute:: distribute_list
                    
                    	Filter prefixes to/from RIB
                    	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.DistributeList>`
                    
                    .. attribute:: distribute_list_out
                    
                    	Filter prefixes from RIB 
                    	**type**\:   :py:class:`DistributeListOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.DistributeListOut>`
                    
                    .. attribute:: domain_id
                    
                    	OSPFv3 Domain ID
                    	**type**\:   :py:class:`DomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.DomainId>`
                    
                    .. attribute:: enable
                    
                    	Enable OSPFv3 VRF configuration
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: encryption
                    
                    	Encrypt and authenticate OSPFv3 packets
                    	**type**\:   :py:class:`Encryption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Encryption>`
                    
                    .. attribute:: fast_reroute
                    
                    	Fast\-reroute instance scoped parameters
                    	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.FastReroute>`
                    
                    .. attribute:: flood_reduction
                    
                    	Enable/disable flood reduction
                    	**type**\:  bool
                    
                    .. attribute:: graceful_restart
                    
                    	Graceful restart configuration
                    	**type**\:   :py:class:`GracefulRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.GracefulRestart>`
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\:  int
                    
                    	**range:** 1..65535
                    
                    	**units**\: second
                    
                    .. attribute:: ignore
                    
                    	Do not complain about a specified event
                    	**type**\:   :py:class:`Ignore <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Ignore>`
                    
                    .. attribute:: instance
                    
                    	Instance ID
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: log_adjacency_changes
                    
                    	Log changes in adjacency state
                    	**type**\:   :py:class:`Ospfv3LogAdjEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3LogAdjEnum>`
                    
                    .. attribute:: maximum
                    
                    	Set OSPFv3 limits
                    	**type**\:   :py:class:`Maximum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Maximum>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Enable/disable ignoring of MTU in DBD packets
                    	**type**\:  bool
                    
                    .. attribute:: network
                    
                    	Specify network type
                    	**type**\:   :py:class:`Ospfv3NetworkEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3NetworkEnum>`
                    
                    .. attribute:: packet_size
                    
                    	Limit size of OSPFv3 packets
                    	**type**\:  int
                    
                    	**range:** 256..10000
                    
                    .. attribute:: passive
                    
                    	Enable/disable routing updates on an interface
                    	**type**\:  bool
                    
                    .. attribute:: prefix_suppression
                    
                    	Enable/disable prefix suppression on an interface
                    	**type**\:  bool
                    
                    .. attribute:: priority
                    
                    	Specify router priority
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: process_scope
                    
                    	Process scope configuration
                    	**type**\:   :py:class:`ProcessScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope>`
                    
                    .. attribute:: redistributes
                    
                    	Redistribute information from another routing protocol
                    	**type**\:   :py:class:`Redistributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Redistributes>`
                    
                    .. attribute:: retransmit_interval
                    
                    	Specify the transmit interval in seconds
                    	**type**\:  int
                    
                    	**range:** 1..65535
                    
                    	**units**\: second
                    
                    .. attribute:: router_id
                    
                    	Specify the router ID for this OSPFv3 process in IPv4 address format
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: snmp
                    
                    	SNMP configuration
                    	**type**\:   :py:class:`Snmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Snmp>`
                    
                    .. attribute:: snmpvrf_trap
                    
                    	Enable SNMP trap configuration in a VRF
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spf_prefix_priority_policy
                    
                    	Route policy for SPF prefix prioritization
                    	**type**\:  str
                    
                    .. attribute:: stub_router
                    
                    	Stub router configuration
                    	**type**\:   :py:class:`StubRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.StubRouter>`
                    
                    .. attribute:: summary_prefixes
                    
                    	Summarize redistributed routes matching prefix/length
                    	**type**\:   :py:class:`SummaryPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes>`
                    
                    .. attribute:: timers
                    
                    	Adjust routing timers
                    	**type**\:   :py:class:`Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Timers>`
                    
                    .. attribute:: transmit_delay
                    
                    	Specify the transmit delay in seconds
                    	**type**\:  int
                    
                    	**range:** 1..65535
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.vrf_name = None
                        self.area_addresses = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses()
                        self.area_addresses.parent = self
                        self.authentication = Ospfv3.Processes.Process.Vrfs.Vrf.Authentication()
                        self.authentication.parent = self
                        self.auto_cost = None
                        self.bfd = Ospfv3.Processes.Process.Vrfs.Vrf.Bfd()
                        self.bfd.parent = self
                        self.capability = Ospfv3.Processes.Process.Vrfs.Vrf.Capability()
                        self.capability.parent = self
                        self.cost = None
                        self.database_filter = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseFilter()
                        self.database_filter.parent = self
                        self.dead_interval = None
                        self.default_information = Ospfv3.Processes.Process.Vrfs.Vrf.DefaultInformation()
                        self.default_information.parent = self
                        self.default_metric = None
                        self.demand_circuit = None
                        self.distance = Ospfv3.Processes.Process.Vrfs.Vrf.Distance()
                        self.distance.parent = self
                        self.distribute_list = Ospfv3.Processes.Process.Vrfs.Vrf.DistributeList()
                        self.distribute_list.parent = self
                        self.distribute_list_out = Ospfv3.Processes.Process.Vrfs.Vrf.DistributeListOut()
                        self.distribute_list_out.parent = self
                        self.domain_id = Ospfv3.Processes.Process.Vrfs.Vrf.DomainId()
                        self.domain_id.parent = self
                        self.enable = None
                        self.encryption = Ospfv3.Processes.Process.Vrfs.Vrf.Encryption()
                        self.encryption.parent = self
                        self.fast_reroute = Ospfv3.Processes.Process.Vrfs.Vrf.FastReroute()
                        self.fast_reroute.parent = self
                        self.flood_reduction = None
                        self.graceful_restart = Ospfv3.Processes.Process.Vrfs.Vrf.GracefulRestart()
                        self.graceful_restart.parent = self
                        self.hello_interval = None
                        self.ignore = Ospfv3.Processes.Process.Vrfs.Vrf.Ignore()
                        self.ignore.parent = self
                        self.instance = None
                        self.log_adjacency_changes = None
                        self.maximum = Ospfv3.Processes.Process.Vrfs.Vrf.Maximum()
                        self.maximum.parent = self
                        self.mtu_ignore = None
                        self.network = None
                        self.packet_size = None
                        self.passive = None
                        self.prefix_suppression = None
                        self.priority = None
                        self.process_scope = Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope()
                        self.process_scope.parent = self
                        self.redistributes = Ospfv3.Processes.Process.Vrfs.Vrf.Redistributes()
                        self.redistributes.parent = self
                        self.retransmit_interval = None
                        self.router_id = None
                        self.snmp = Ospfv3.Processes.Process.Vrfs.Vrf.Snmp()
                        self.snmp.parent = self
                        self.snmpvrf_trap = None
                        self.spf_prefix_priority_policy = None
                        self.stub_router = Ospfv3.Processes.Process.Vrfs.Vrf.StubRouter()
                        self.stub_router.parent = self
                        self.summary_prefixes = Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes()
                        self.summary_prefixes.parent = self
                        self.timers = Ospfv3.Processes.Process.Vrfs.Vrf.Timers()
                        self.timers.parent = self
                        self.transmit_delay = None


                    class Capability(object):
                        """
                        OSPFv3 Capability
                        
                        .. attribute:: vrf_lite
                        
                        	Enable VRF Lite
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.vrf_lite = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:capability'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.vrf_lite is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Capability']['meta_info']


                    class DomainId(object):
                        """
                        OSPFv3 Domain ID
                        
                        .. attribute:: primary_domain_id
                        
                        	OSPF Primary domain ID
                        	**type**\:   :py:class:`PrimaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.DomainId.PrimaryDomainId>`
                        
                        .. attribute:: secondary_domain_ids
                        
                        	Secondary domain ID Table
                        	**type**\:   :py:class:`SecondaryDomainIds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.primary_domain_id = Ospfv3.Processes.Process.Vrfs.Vrf.DomainId.PrimaryDomainId()
                            self.primary_domain_id.parent = self
                            self.secondary_domain_ids = Ospfv3.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds()
                            self.secondary_domain_ids.parent = self


                        class SecondaryDomainIds(object):
                            """
                            Secondary domain ID Table
                            
                            .. attribute:: secondary_domain_id
                            
                            	OSPF Secondary domain ID
                            	**type**\: list of    :py:class:`SecondaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds.SecondaryDomainId>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.secondary_domain_id = YList()
                                self.secondary_domain_id.parent = self
                                self.secondary_domain_id.name = 'secondary_domain_id'


                            class SecondaryDomainId(object):
                                """
                                OSPF Secondary domain ID
                                
                                .. attribute:: domain_id_name  <key>
                                
                                	Secondary domain ID value
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: domain_id_type  <key>
                                
                                	Secondary domain ID type
                                	**type**\:   :py:class:`Ospfv3DomainIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3DomainIdEnum>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.domain_id_name = None
                                    self.domain_id_type = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.domain_id_name is None:
                                        raise YPYModelError('Key property domain_id_name is None')
                                    if self.domain_id_type is None:
                                        raise YPYModelError('Key property domain_id_type is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:secondary-domain-id[Cisco-IOS-XR-ipv6-ospfv3-cfg:domain-id-name = ' + str(self.domain_id_name) + '][Cisco-IOS-XR-ipv6-ospfv3-cfg:domain-id-type = ' + str(self.domain_id_type) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.domain_id_name is not None:
                                        return True

                                    if self.domain_id_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds.SecondaryDomainId']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:secondary-domain-ids'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.secondary_domain_id is not None:
                                    for child_ref in self.secondary_domain_id:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds']['meta_info']


                        class PrimaryDomainId(object):
                            """
                            OSPF Primary domain ID
                            
                            .. attribute:: domain_id_name
                            
                            	Primary domain ID value
                            	**type**\:  str
                            
                            .. attribute:: domain_id_type
                            
                            	Primary domain ID type
                            	**type**\:   :py:class:`Ospfv3DomainIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3DomainIdEnum>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.domain_id_name = None
                                self.domain_id_type = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:primary-domain-id'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.domain_id_name is not None:
                                    return True

                                if self.domain_id_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DomainId.PrimaryDomainId']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:domain-id'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.primary_domain_id is not None and self.primary_domain_id._has_data():
                                return True

                            if self.secondary_domain_ids is not None and self.secondary_domain_ids._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DomainId']['meta_info']


                    class AreaAddresses(object):
                        """
                        Area configuration
                        
                        .. attribute:: area_address
                        
                        	Configuration for a particular area
                        	**type**\: list of    :py:class:`AreaAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress>`
                        
                        .. attribute:: area_area_id
                        
                        	Configuration for a particular area
                        	**type**\: list of    :py:class:`AreaAreaId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.area_address = YList()
                            self.area_address.parent = self
                            self.area_address.name = 'area_address'
                            self.area_area_id = YList()
                            self.area_area_id.parent = self
                            self.area_area_id.name = 'area_area_id'


                        class AreaAddress(object):
                            """
                            Configuration for a particular area
                            
                            .. attribute:: address  <key>
                            
                            	Area ID if in IP address format
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: area_scope
                            
                            	Area Scope Configuration
                            	**type**\:   :py:class:`AreaScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope>`
                            
                            .. attribute:: authentication
                            
                            	Authenticate OSPFv3 packets
                            	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Authentication>`
                            
                            .. attribute:: bfd
                            
                            	Configure BFD parameters
                            	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Bfd>`
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Database filter
                            	**type**\:   :py:class:`DatabaseFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.DatabaseFilter>`
                            
                            .. attribute:: dead_interval
                            
                            	Interval after which a neighbor is declared dead (in seconds)
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**units**\: second
                            
                            .. attribute:: default_cost
                            
                            	Set the summary default\-cost of a NSSA/stub area
                            	**type**\:  int
                            
                            	**range:** 0..16777215
                            
                            .. attribute:: demand_circuit
                            
                            	Enable/disable demand circuit operation
                            	**type**\:  bool
                            
                            .. attribute:: distribute_list
                            
                            	Filter prefixes to/from RIB
                            	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.DistributeList>`
                            
                            .. attribute:: enable
                            
                            	Enable OSPFv3 area
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: encryption
                            
                            	Encrypt and authenticate OSPFv3 packets
                            	**type**\:   :py:class:`Encryption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Encryption>`
                            
                            .. attribute:: flood_reduction
                            
                            	Enable/disable flood reduction
                            	**type**\:  bool
                            
                            .. attribute:: hello_interval
                            
                            	Time between HELLO packets
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**units**\: second
                            
                            .. attribute:: instance
                            
                            	Instance ID
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interfaces
                            
                            	OSPFv3 interfaces
                            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces>`
                            
                            .. attribute:: ldp_sync
                            
                            	Enable/Disable MPLS LDP sync
                            	**type**\:  bool
                            
                            .. attribute:: mtu_ignore
                            
                            	Enable/disable ignoring of MTU in DBD packets
                            	**type**\:  bool
                            
                            .. attribute:: network
                            
                            	Specify network type
                            	**type**\:   :py:class:`Ospfv3NetworkEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3NetworkEnum>`
                            
                            .. attribute:: nssa
                            
                            	Specify area as a NSSA area.  Allowed only in non\-backbone areas
                            	**type**\:   :py:class:`Nssa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Nssa>`
                            
                            .. attribute:: packet_size
                            
                            	Limit size of OSPFv3 packets
                            	**type**\:  int
                            
                            	**range:** 256..10000
                            
                            .. attribute:: passive
                            
                            	Enable/disable routing updates on an interface
                            	**type**\:  bool
                            
                            .. attribute:: prefix_suppression
                            
                            	Enable/disable prefix suppression on an interface
                            	**type**\:  bool
                            
                            .. attribute:: priority
                            
                            	Specify router priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ranges
                            
                            	Range configuration
                            	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Ranges>`
                            
                            .. attribute:: retransmit_interval
                            
                            	Specify the transmit interval in seconds
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**units**\: second
                            
                            .. attribute:: sham_links
                            
                            	Sham Link sub\-mode
                            	**type**\:   :py:class:`ShamLinks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinks>`
                            
                            .. attribute:: stub
                            
                            	Specify area as a stub area.  Allowed only in non\-backbone areas
                            	**type**\:  bool
                            
                            .. attribute:: transmit_delay
                            
                            	Specify the transmit delay in seconds
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**units**\: second
                            
                            .. attribute:: virtual_links
                            
                            	Virtual link sub\-mode
                            	**type**\:   :py:class:`VirtualLinks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinks>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.address = None
                                self.area_scope = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope()
                                self.area_scope.parent = self
                                self.authentication = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Authentication()
                                self.authentication.parent = self
                                self.bfd = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Bfd()
                                self.bfd.parent = self
                                self.cost = None
                                self.database_filter = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.DatabaseFilter()
                                self.database_filter.parent = self
                                self.dead_interval = None
                                self.default_cost = None
                                self.demand_circuit = None
                                self.distribute_list = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.DistributeList()
                                self.distribute_list.parent = self
                                self.enable = None
                                self.encryption = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Encryption()
                                self.encryption.parent = self
                                self.flood_reduction = None
                                self.hello_interval = None
                                self.instance = None
                                self.interfaces = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces()
                                self.interfaces.parent = self
                                self.ldp_sync = None
                                self.mtu_ignore = None
                                self.network = None
                                self.nssa = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Nssa()
                                self.nssa.parent = self
                                self.packet_size = None
                                self.passive = None
                                self.prefix_suppression = None
                                self.priority = None
                                self.ranges = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Ranges()
                                self.ranges.parent = self
                                self.retransmit_interval = None
                                self.sham_links = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinks()
                                self.sham_links.parent = self
                                self.stub = None
                                self.transmit_delay = None
                                self.virtual_links = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinks()
                                self.virtual_links.parent = self


                            class Authentication(object):
                                """
                                Authenticate OSPFv3 packets
                                
                                .. attribute:: algorithm
                                
                                	Use the MD5 or SHA1 algorithm
                                	**type**\:   :py:class:`Ospfv3AuthenticationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationEnum>`
                                
                                .. attribute:: enable
                                
                                	Authenticate packets
                                	**type**\:  bool
                                
                                .. attribute:: password
                                
                                	Specify MD5 or SHA1 password
                                	**type**\:  str
                                
                                	**pattern:** (!.+)\|([^!].+)
                                
                                .. attribute:: spi
                                
                                	Use IPSec AH authentication. Specify the Security Parameter Index (SPI) value
                                	**type**\:  int
                                
                                	**range:** 256..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.algorithm = None
                                    self.enable = None
                                    self.password = None
                                    self.spi = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:authentication'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.algorithm is not None:
                                        return True

                                    if self.enable is not None:
                                        return True

                                    if self.password is not None:
                                        return True

                                    if self.spi is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Authentication']['meta_info']


                            class Bfd(object):
                                """
                                Configure BFD parameters
                                
                                .. attribute:: detection_multiplier
                                
                                	Detect multiplier
                                	**type**\:  int
                                
                                	**range:** 2..50
                                
                                .. attribute:: fast_detect_mode
                                
                                	Enable or disable BFD fast detection
                                	**type**\:   :py:class:`Ospfv3BfdEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3BfdEnableModeEnum>`
                                
                                .. attribute:: interval
                                
                                	Hello interval in milli\-seconds
                                	**type**\:  int
                                
                                	**range:** 3..30000
                                
                                	**units**\: millisecond
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.detection_multiplier = None
                                    self.fast_detect_mode = None
                                    self.interval = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:bfd'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.detection_multiplier is not None:
                                        return True

                                    if self.fast_detect_mode is not None:
                                        return True

                                    if self.interval is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Bfd']['meta_info']


                            class Ranges(object):
                                """
                                Range configuration
                                
                                .. attribute:: range
                                
                                	Summarize inter\-area routes matching prefix/length
                                	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Ranges.Range>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.range = YList()
                                    self.range.parent = self
                                    self.range.name = 'range'


                                class Range(object):
                                    """
                                    Summarize inter\-area routes matching
                                    prefix/length
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	IPv6 prefix format
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length  <key>
                                    
                                    	IPV6 prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: cost
                                    
                                    	Specified metric for this range
                                    	**type**\:  int
                                    
                                    	**range:** 1..16777214
                                    
                                    .. attribute:: not_advertise
                                    
                                    	Do not advertise address range
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.prefix = None
                                        self.prefix_length = None
                                        self.cost = None
                                        self.not_advertise = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.prefix is None:
                                            raise YPYModelError('Key property prefix is None')
                                        if self.prefix_length is None:
                                            raise YPYModelError('Key property prefix_length is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:range[Cisco-IOS-XR-ipv6-ospfv3-cfg:prefix = ' + str(self.prefix) + '][Cisco-IOS-XR-ipv6-ospfv3-cfg:prefix-length = ' + str(self.prefix_length) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.prefix is not None:
                                            return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.cost is not None:
                                            return True

                                        if self.not_advertise is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Ranges.Range']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:ranges'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.range is not None:
                                        for child_ref in self.range:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Ranges']['meta_info']


                            class Encryption(object):
                                """
                                Encrypt and authenticate OSPFv3 packets
                                
                                .. attribute:: authentication_algorithm
                                
                                	Use the NULL, MD5 or SHA1 algorithm
                                	**type**\:   :py:class:`Ospfv3AuthenticationType2Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationType2Enum>`
                                
                                .. attribute:: authentication_password
                                
                                	Specify MD5 or SHA1 password
                                	**type**\:  str
                                
                                	**pattern:** (!.+)\|([^!].+)
                                
                                .. attribute:: enable
                                
                                	Authenticate packets
                                	**type**\:  bool
                                
                                .. attribute:: encryption_algorithm
                                
                                	Specify the encryption algorithm
                                	**type**\:   :py:class:`Ospfv3EncryptionAlgorithmEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EncryptionAlgorithmEnum>`
                                
                                .. attribute:: encryption_password
                                
                                	Encryption password
                                	**type**\:  str
                                
                                	**pattern:** (!.+)\|([^!].+)
                                
                                .. attribute:: spi
                                
                                	Use IPSec ESP authentication. Specify the Security Parameter Index (SPI) value
                                	**type**\:  int
                                
                                	**range:** 256..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.authentication_algorithm = None
                                    self.authentication_password = None
                                    self.enable = None
                                    self.encryption_algorithm = None
                                    self.encryption_password = None
                                    self.spi = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:encryption'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.authentication_algorithm is not None:
                                        return True

                                    if self.authentication_password is not None:
                                        return True

                                    if self.enable is not None:
                                        return True

                                    if self.encryption_algorithm is not None:
                                        return True

                                    if self.encryption_password is not None:
                                        return True

                                    if self.spi is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Encryption']['meta_info']


                            class Nssa(object):
                                """
                                Specify area as a NSSA area.  Allowed only in
                                non\-backbone areas
                                
                                .. attribute:: default_info_originate
                                
                                	Originate Type 7 default into NSSA area
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: metric
                                
                                	Only valid with DefaultInfoOriginate
                                	**type**\:  int
                                
                                	**range:** 0..16777214
                                
                                .. attribute:: metric_type
                                
                                	Only valid with DefaultInfoOriginate
                                	**type**\:   :py:class:`Ospfv3MetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3MetricEnum>`
                                
                                .. attribute:: no_redistribution
                                
                                	No redistribution into this NSSA area
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: no_summary
                                
                                	Do not send summary LSA into NSSA
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.default_info_originate = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.no_redistribution = None
                                    self.no_summary = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:nssa'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.default_info_originate is not None:
                                        return True

                                    if self.metric is not None:
                                        return True

                                    if self.metric_type is not None:
                                        return True

                                    if self.no_redistribution is not None:
                                        return True

                                    if self.no_summary is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Nssa']['meta_info']


                            class DatabaseFilter(object):
                                """
                                Database filter
                                
                                .. attribute:: all
                                
                                	All
                                	**type**\:   :py:class:`All <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.all = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.DatabaseFilter.All()
                                    self.all.parent = self


                                class All(object):
                                    """
                                    All
                                    
                                    .. attribute:: out
                                    
                                    	Enable or disable database\-filter
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.out = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:all'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.out is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.DatabaseFilter.All']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:database-filter'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.all is not None and self.all._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.DatabaseFilter']['meta_info']


                            class DistributeList(object):
                                """
                                Filter prefixes to/from RIB
                                
                                .. attribute:: in_
                                
                                	Filter prefixes installed to RIB
                                	**type**\:   :py:class:`In_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.DistributeList.In_>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.in_ = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.DistributeList.In_()
                                    self.in_.parent = self


                                class In_(object):
                                    """
                                    Filter prefixes installed to RIB
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Filter prefixes based on an IPv6 prefix\-list
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.prefix_list = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:in'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.prefix_list is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.DistributeList.In_']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:distribute-list'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.in_ is not None and self.in_._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.DistributeList']['meta_info']


                            class Interfaces(object):
                                """
                                OSPFv3 interfaces
                                
                                .. attribute:: interface
                                
                                	OSPFv3 interface
                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface = YList()
                                    self.interface.parent = self
                                    self.interface.name = 'interface'


                                class Interface(object):
                                    """
                                    OSPFv3 interface
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface to configure
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: authentication
                                    
                                    	Authenticate OSPFv3 packets
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.Authentication>`
                                    
                                    .. attribute:: bfd
                                    
                                    	Configure BFD parameters
                                    	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.Bfd>`
                                    
                                    .. attribute:: cost
                                    
                                    	Interface cost
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: database_filter
                                    
                                    	Database filter
                                    	**type**\:   :py:class:`DatabaseFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.DatabaseFilter>`
                                    
                                    .. attribute:: dead_interval
                                    
                                    	Interval after which a neighbor is declared dead (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: demand_circuit
                                    
                                    	Enable/disable demand circuit operation
                                    	**type**\:  bool
                                    
                                    .. attribute:: distribute_list
                                    
                                    	Filter prefixes to/from RIB
                                    	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.DistributeList>`
                                    
                                    .. attribute:: enable
                                    
                                    	Enable OSPFv3 interface
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: encryption
                                    
                                    	Encrypt and authenticate OSPFv3 packets
                                    	**type**\:   :py:class:`Encryption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.Encryption>`
                                    
                                    .. attribute:: fast_reroute
                                    
                                    	Fast\-reroute configuration
                                    	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute>`
                                    
                                    .. attribute:: flood_reduction
                                    
                                    	Enable/disable flood reduction
                                    	**type**\:  bool
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Time between HELLO packets
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: instance
                                    
                                    	Instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ldp_sync
                                    
                                    	Enable/Disable MPLS LDP sync
                                    	**type**\:  bool
                                    
                                    .. attribute:: mtu_ignore
                                    
                                    	Enable/disable ignoring of MTU in DBD packets
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbors
                                    
                                    	Specify a neighbor router
                                    	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.Neighbors>`
                                    
                                    .. attribute:: network
                                    
                                    	Specify network type
                                    	**type**\:   :py:class:`Ospfv3NetworkEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3NetworkEnum>`
                                    
                                    .. attribute:: packet_size
                                    
                                    	Limit size of OSPFv3 packets
                                    	**type**\:  int
                                    
                                    	**range:** 256..10000
                                    
                                    .. attribute:: passive
                                    
                                    	Enable/disable routing updates on an interface
                                    	**type**\:  bool
                                    
                                    .. attribute:: prefix_suppression
                                    
                                    	Enable/disable prefix suppression on an interface
                                    	**type**\:  bool
                                    
                                    .. attribute:: priority
                                    
                                    	Specify router priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: retransmit_interval
                                    
                                    	Specify the transmit interval in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: transmit_delay
                                    
                                    	Specify the transmit delay in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None
                                        self.authentication = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.Authentication()
                                        self.authentication.parent = self
                                        self.bfd = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.Bfd()
                                        self.bfd.parent = self
                                        self.cost = None
                                        self.database_filter = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.DatabaseFilter()
                                        self.database_filter.parent = self
                                        self.dead_interval = None
                                        self.demand_circuit = None
                                        self.distribute_list = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.DistributeList()
                                        self.distribute_list.parent = self
                                        self.enable = None
                                        self.encryption = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.Encryption()
                                        self.encryption.parent = self
                                        self.fast_reroute = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute()
                                        self.fast_reroute.parent = self
                                        self.flood_reduction = None
                                        self.hello_interval = None
                                        self.instance = None
                                        self.ldp_sync = None
                                        self.mtu_ignore = None
                                        self.neighbors = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.Neighbors()
                                        self.neighbors.parent = self
                                        self.network = None
                                        self.packet_size = None
                                        self.passive = None
                                        self.prefix_suppression = None
                                        self.priority = None
                                        self.retransmit_interval = None
                                        self.transmit_delay = None


                                    class Authentication(object):
                                        """
                                        Authenticate OSPFv3 packets
                                        
                                        .. attribute:: algorithm
                                        
                                        	Use the MD5 or SHA1 algorithm
                                        	**type**\:   :py:class:`Ospfv3AuthenticationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationEnum>`
                                        
                                        .. attribute:: enable
                                        
                                        	Authenticate packets
                                        	**type**\:  bool
                                        
                                        .. attribute:: password
                                        
                                        	Specify MD5 or SHA1 password
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: spi
                                        
                                        	Use IPSec AH authentication. Specify the Security Parameter Index (SPI) value
                                        	**type**\:  int
                                        
                                        	**range:** 256..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.algorithm = None
                                            self.enable = None
                                            self.password = None
                                            self.spi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:authentication'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.algorithm is not None:
                                                return True

                                            if self.enable is not None:
                                                return True

                                            if self.password is not None:
                                                return True

                                            if self.spi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.Authentication']['meta_info']


                                    class Neighbors(object):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: neighbor
                                        
                                        	IPv6 address
                                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.Neighbors.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.neighbor = YList()
                                            self.neighbor.parent = self
                                            self.neighbor.name = 'neighbor'


                                        class Neighbor(object):
                                            """
                                            IPv6 address
                                            
                                            .. attribute:: neighbor_address  <key>
                                            
                                            	IPV6 address
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: cost
                                            
                                            	OSPFv3 cost for point\-to\-multipoint neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: database_filter
                                            
                                            	Filter OSPFv3 LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: poll_interval
                                            
                                            	OSPFv3 dead\-router polling interval (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: priority
                                            
                                            	OSPFv3 priority of non\-broadcast neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: zone
                                            
                                            	Zone
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.neighbor_address = None
                                                self.cost = None
                                                self.database_filter = None
                                                self.poll_interval = None
                                                self.priority = None
                                                self.zone = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.neighbor_address is None:
                                                    raise YPYModelError('Key property neighbor_address is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:neighbor[Cisco-IOS-XR-ipv6-ospfv3-cfg:neighbor-address = ' + str(self.neighbor_address) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.neighbor_address is not None:
                                                    return True

                                                if self.cost is not None:
                                                    return True

                                                if self.database_filter is not None:
                                                    return True

                                                if self.poll_interval is not None:
                                                    return True

                                                if self.priority is not None:
                                                    return True

                                                if self.zone is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.Neighbors.Neighbor']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:neighbors'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.neighbor is not None:
                                                for child_ref in self.neighbor:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.Neighbors']['meta_info']


                                    class Encryption(object):
                                        """
                                        Encrypt and authenticate OSPFv3 packets
                                        
                                        .. attribute:: authentication_algorithm
                                        
                                        	Use the NULL, MD5 or SHA1 algorithm
                                        	**type**\:   :py:class:`Ospfv3AuthenticationType2Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationType2Enum>`
                                        
                                        .. attribute:: authentication_password
                                        
                                        	Specify MD5 or SHA1 password
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: enable
                                        
                                        	Authenticate packets
                                        	**type**\:  bool
                                        
                                        .. attribute:: encryption_algorithm
                                        
                                        	Specify the encryption algorithm
                                        	**type**\:   :py:class:`Ospfv3EncryptionAlgorithmEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EncryptionAlgorithmEnum>`
                                        
                                        .. attribute:: encryption_password
                                        
                                        	Encryption password
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: spi
                                        
                                        	Use IPSec ESP authentication. Specify the Security Parameter Index (SPI) value
                                        	**type**\:  int
                                        
                                        	**range:** 256..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.authentication_algorithm = None
                                            self.authentication_password = None
                                            self.enable = None
                                            self.encryption_algorithm = None
                                            self.encryption_password = None
                                            self.spi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:encryption'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.authentication_algorithm is not None:
                                                return True

                                            if self.authentication_password is not None:
                                                return True

                                            if self.enable is not None:
                                                return True

                                            if self.encryption_algorithm is not None:
                                                return True

                                            if self.encryption_password is not None:
                                                return True

                                            if self.spi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.Encryption']['meta_info']


                                    class Bfd(object):
                                        """
                                        Configure BFD parameters
                                        
                                        .. attribute:: detection_multiplier
                                        
                                        	Detect multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 2..50
                                        
                                        .. attribute:: fast_detect_mode
                                        
                                        	Enable or disable BFD fast detection
                                        	**type**\:   :py:class:`Ospfv3BfdEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3BfdEnableModeEnum>`
                                        
                                        .. attribute:: interval
                                        
                                        	Hello interval in milli\-seconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.detection_multiplier = None
                                            self.fast_detect_mode = None
                                            self.interval = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:bfd'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.detection_multiplier is not None:
                                                return True

                                            if self.fast_detect_mode is not None:
                                                return True

                                            if self.interval is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.Bfd']['meta_info']


                                    class DatabaseFilter(object):
                                        """
                                        Database filter
                                        
                                        .. attribute:: all
                                        
                                        	All
                                        	**type**\:   :py:class:`All <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.DatabaseFilter.All>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.all = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.DatabaseFilter.All()
                                            self.all.parent = self


                                        class All(object):
                                            """
                                            All
                                            
                                            .. attribute:: out
                                            
                                            	Enable or disable database\-filter
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.out = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:all'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.out is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.DatabaseFilter.All']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:database-filter'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.all is not None and self.all._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.DatabaseFilter']['meta_info']


                                    class DistributeList(object):
                                        """
                                        Filter prefixes to/from RIB
                                        
                                        .. attribute:: in_
                                        
                                        	Filter prefixes installed to RIB
                                        	**type**\:   :py:class:`In_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.DistributeList.In_>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.in_ = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.DistributeList.In_()
                                            self.in_.parent = self


                                        class In_(object):
                                            """
                                            Filter prefixes installed to RIB
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Filter prefixes based on an IPv6 prefix\-list
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix_list = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix_list is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.DistributeList.In_']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:distribute-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.in_ is not None and self.in_._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.DistributeList']['meta_info']


                                    class FastReroute(object):
                                        """
                                        Fast\-reroute configuration
                                        
                                        .. attribute:: fast_reroute_enable
                                        
                                        	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                        	**type**\:   :py:class:`Ospfv3FastRerouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3FastRerouteEnum>`
                                        
                                        .. attribute:: per_link
                                        
                                        	Fast\-reroute per\-link configuration
                                        	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink>`
                                        
                                        .. attribute:: per_prefix
                                        
                                        	Fast\-reroute per\-link configuration
                                        	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.fast_reroute_enable = None
                                            self.per_link = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink()
                                            self.per_link.parent = self
                                            self.per_prefix = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix()
                                            self.per_prefix.parent = self


                                        class PerLink(object):
                                            """
                                            Fast\-reroute per\-link configuration
                                            
                                            .. attribute:: candidate_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink.CandidateInterfaces>`
                                            
                                            .. attribute:: exclude_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix exclude interface configuration
                                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink.ExcludeInterfaces>`
                                            
                                            .. attribute:: fast_reroute_use_candidate_only
                                            
                                            	Use only interfaces on the candidate list as a backup path
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.candidate_interfaces = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self.exclude_interfaces = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self.fast_reroute_use_candidate_only = None


                                            class CandidateInterfaces(object):
                                                """
                                                Fast\-reroute per\-link/per\-prefix candidate
                                                interface configuration
                                                
                                                .. attribute:: candidate_interface
                                                
                                                	Candidate backup interface
                                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.candidate_interface = YList()
                                                    self.candidate_interface.parent = self
                                                    self.candidate_interface.name = 'candidate_interface'


                                                class CandidateInterface(object):
                                                    """
                                                    Candidate backup interface
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-cfg'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                                        if self.interface_name is None:
                                                            raise YPYModelError('Key property interface_name is None')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return True

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink.CandidateInterfaces.CandidateInterface']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interfaces'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.candidate_interface is not None:
                                                        for child_ref in self.candidate_interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink.CandidateInterfaces']['meta_info']


                                            class ExcludeInterfaces(object):
                                                """
                                                Fast\-reroute per\-link/per\-prefix exclude
                                                interface configuration
                                                
                                                .. attribute:: exclude_interface
                                                
                                                	Exclude an interface from becoming a backup
                                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.exclude_interface = YList()
                                                    self.exclude_interface.parent = self
                                                    self.exclude_interface.name = 'exclude_interface'


                                                class ExcludeInterface(object):
                                                    """
                                                    Exclude an interface from becoming a backup
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-cfg'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                                        if self.interface_name is None:
                                                            raise YPYModelError('Key property interface_name is None')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return True

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interfaces'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.exclude_interface is not None:
                                                        for child_ref in self.exclude_interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink.ExcludeInterfaces']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-link'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.candidate_interfaces is not None and self.candidate_interfaces._has_data():
                                                    return True

                                                if self.exclude_interfaces is not None and self.exclude_interfaces._has_data():
                                                    return True

                                                if self.fast_reroute_use_candidate_only is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerLink']['meta_info']


                                        class PerPrefix(object):
                                            """
                                            Fast\-reroute per\-link configuration
                                            
                                            .. attribute:: candidate_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix.CandidateInterfaces>`
                                            
                                            .. attribute:: exclude_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix exclude interface configuration
                                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix.ExcludeInterfaces>`
                                            
                                            .. attribute:: fast_reroute_use_candidate_only
                                            
                                            	Use only interfaces on the candidate list as a backup path
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.candidate_interfaces = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self.exclude_interfaces = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self.fast_reroute_use_candidate_only = None


                                            class CandidateInterfaces(object):
                                                """
                                                Fast\-reroute per\-link/per\-prefix candidate
                                                interface configuration
                                                
                                                .. attribute:: candidate_interface
                                                
                                                	Candidate backup interface
                                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.candidate_interface = YList()
                                                    self.candidate_interface.parent = self
                                                    self.candidate_interface.name = 'candidate_interface'


                                                class CandidateInterface(object):
                                                    """
                                                    Candidate backup interface
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-cfg'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                                        if self.interface_name is None:
                                                            raise YPYModelError('Key property interface_name is None')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return True

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interfaces'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.candidate_interface is not None:
                                                        for child_ref in self.candidate_interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix.CandidateInterfaces']['meta_info']


                                            class ExcludeInterfaces(object):
                                                """
                                                Fast\-reroute per\-link/per\-prefix exclude
                                                interface configuration
                                                
                                                .. attribute:: exclude_interface
                                                
                                                	Exclude an interface from becoming a backup
                                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.exclude_interface = YList()
                                                    self.exclude_interface.parent = self
                                                    self.exclude_interface.name = 'exclude_interface'


                                                class ExcludeInterface(object):
                                                    """
                                                    Exclude an interface from becoming a backup
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-cfg'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                                        if self.interface_name is None:
                                                            raise YPYModelError('Key property interface_name is None')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return True

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interfaces'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.exclude_interface is not None:
                                                        for child_ref in self.exclude_interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix.ExcludeInterfaces']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.candidate_interfaces is not None and self.candidate_interfaces._has_data():
                                                    return True

                                                if self.exclude_interfaces is not None and self.exclude_interfaces._has_data():
                                                    return True

                                                if self.fast_reroute_use_candidate_only is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute.PerPrefix']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:fast-reroute'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.fast_reroute_enable is not None:
                                                return True

                                            if self.per_link is not None and self.per_link._has_data():
                                                return True

                                            if self.per_prefix is not None and self.per_prefix._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface.FastReroute']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.interface_name is None:
                                            raise YPYModelError('Key property interface_name is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        if self.authentication is not None and self.authentication._has_data():
                                            return True

                                        if self.bfd is not None and self.bfd._has_data():
                                            return True

                                        if self.cost is not None:
                                            return True

                                        if self.database_filter is not None and self.database_filter._has_data():
                                            return True

                                        if self.dead_interval is not None:
                                            return True

                                        if self.demand_circuit is not None:
                                            return True

                                        if self.distribute_list is not None and self.distribute_list._has_data():
                                            return True

                                        if self.enable is not None:
                                            return True

                                        if self.encryption is not None and self.encryption._has_data():
                                            return True

                                        if self.fast_reroute is not None and self.fast_reroute._has_data():
                                            return True

                                        if self.flood_reduction is not None:
                                            return True

                                        if self.hello_interval is not None:
                                            return True

                                        if self.instance is not None:
                                            return True

                                        if self.ldp_sync is not None:
                                            return True

                                        if self.mtu_ignore is not None:
                                            return True

                                        if self.neighbors is not None and self.neighbors._has_data():
                                            return True

                                        if self.network is not None:
                                            return True

                                        if self.packet_size is not None:
                                            return True

                                        if self.passive is not None:
                                            return True

                                        if self.prefix_suppression is not None:
                                            return True

                                        if self.priority is not None:
                                            return True

                                        if self.retransmit_interval is not None:
                                            return True

                                        if self.transmit_delay is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces.Interface']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:interfaces'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface is not None:
                                        for child_ref in self.interface:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Interfaces']['meta_info']


                            class AreaScope(object):
                                """
                                Area Scope Configuration
                                
                                .. attribute:: fast_reroute
                                
                                	Fast\-reroute configuration
                                	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.fast_reroute = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute()
                                    self.fast_reroute.parent = self


                                class FastReroute(object):
                                    """
                                    Fast\-reroute configuration
                                    
                                    .. attribute:: fast_reroute_enable
                                    
                                    	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                    	**type**\:   :py:class:`Ospfv3FastRerouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3FastRerouteEnum>`
                                    
                                    .. attribute:: per_link
                                    
                                    	Fast\-reroute per\-link configuration
                                    	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink>`
                                    
                                    .. attribute:: per_prefix
                                    
                                    	Fast\-reroute per\-link configuration
                                    	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.fast_reroute_enable = None
                                        self.per_link = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink()
                                        self.per_link.parent = self
                                        self.per_prefix = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix()
                                        self.per_prefix.parent = self


                                    class PerLink(object):
                                        """
                                        Fast\-reroute per\-link configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.candidate_interfaces = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self.exclude_interfaces = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self.fast_reroute_use_candidate_only = None


                                        class CandidateInterfaces(object):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.candidate_interface = YList()
                                                self.candidate_interface.parent = self
                                                self.candidate_interface.name = 'candidate_interface'


                                            class CandidateInterface(object):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.interface_name is None:
                                                        raise YPYModelError('Key property interface_name is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interfaces'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.candidate_interface is not None:
                                                    for child_ref in self.candidate_interface:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces']['meta_info']


                                        class ExcludeInterfaces(object):
                                            """
                                            Fast\-reroute per\-link/per\-prefix exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.exclude_interface = YList()
                                                self.exclude_interface.parent = self
                                                self.exclude_interface.name = 'exclude_interface'


                                            class ExcludeInterface(object):
                                                """
                                                Exclude an interface from becoming a backup
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.interface_name is None:
                                                        raise YPYModelError('Key property interface_name is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interfaces'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.exclude_interface is not None:
                                                    for child_ref in self.exclude_interface:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-link'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.candidate_interfaces is not None and self.candidate_interfaces._has_data():
                                                return True

                                            if self.exclude_interfaces is not None and self.exclude_interfaces._has_data():
                                                return True

                                            if self.fast_reroute_use_candidate_only is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink']['meta_info']


                                    class PerPrefix(object):
                                        """
                                        Fast\-reroute per\-link configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.candidate_interfaces = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self.exclude_interfaces = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self.fast_reroute_use_candidate_only = None


                                        class CandidateInterfaces(object):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.candidate_interface = YList()
                                                self.candidate_interface.parent = self
                                                self.candidate_interface.name = 'candidate_interface'


                                            class CandidateInterface(object):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.interface_name is None:
                                                        raise YPYModelError('Key property interface_name is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interfaces'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.candidate_interface is not None:
                                                    for child_ref in self.candidate_interface:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces']['meta_info']


                                        class ExcludeInterfaces(object):
                                            """
                                            Fast\-reroute per\-link/per\-prefix exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.exclude_interface = YList()
                                                self.exclude_interface.parent = self
                                                self.exclude_interface.name = 'exclude_interface'


                                            class ExcludeInterface(object):
                                                """
                                                Exclude an interface from becoming a backup
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.interface_name is None:
                                                        raise YPYModelError('Key property interface_name is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interfaces'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.exclude_interface is not None:
                                                    for child_ref in self.exclude_interface:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-prefix'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.candidate_interfaces is not None and self.candidate_interfaces._has_data():
                                                return True

                                            if self.exclude_interfaces is not None and self.exclude_interfaces._has_data():
                                                return True

                                            if self.fast_reroute_use_candidate_only is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:fast-reroute'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.fast_reroute_enable is not None:
                                            return True

                                        if self.per_link is not None and self.per_link._has_data():
                                            return True

                                        if self.per_prefix is not None and self.per_prefix._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:area-scope'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.fast_reroute is not None and self.fast_reroute._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope']['meta_info']


                            class ShamLinks(object):
                                """
                                Sham Link sub\-mode
                                
                                .. attribute:: sham_link
                                
                                	ShamLink local and remote endpoints
                                	**type**\: list of    :py:class:`ShamLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinks.ShamLink>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.sham_link = YList()
                                    self.sham_link.parent = self
                                    self.sham_link.name = 'sham_link'


                                class ShamLink(object):
                                    """
                                    ShamLink local and remote endpoints
                                    
                                    .. attribute:: destination_address  <key>
                                    
                                    	Remote sham\-link endpoint
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address  <key>
                                    
                                    	Local sham\-link endpoint
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: authentication
                                    
                                    	Authenticate OSPFv3 packets
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinks.ShamLink.Authentication>`
                                    
                                    .. attribute:: dead_interval
                                    
                                    	Interval after which a neighbor is declared dead (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: enable
                                    
                                    	Enable sham link
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: encryption
                                    
                                    	Encrypt and authenticate OSPFv3 packets
                                    	**type**\:   :py:class:`Encryption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinks.ShamLink.Encryption>`
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Time between HELLO packets
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: retransmit_interval
                                    
                                    	Specify the transmit interval in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: transmit_delay
                                    
                                    	Specify the transmit delay in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.destination_address = None
                                        self.source_address = None
                                        self.authentication = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinks.ShamLink.Authentication()
                                        self.authentication.parent = self
                                        self.dead_interval = None
                                        self.enable = None
                                        self.encryption = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinks.ShamLink.Encryption()
                                        self.encryption.parent = self
                                        self.hello_interval = None
                                        self.retransmit_interval = None
                                        self.transmit_delay = None


                                    class Authentication(object):
                                        """
                                        Authenticate OSPFv3 packets
                                        
                                        .. attribute:: algorithm
                                        
                                        	Use the MD5 or SHA1 algorithm
                                        	**type**\:   :py:class:`Ospfv3AuthenticationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationEnum>`
                                        
                                        .. attribute:: enable
                                        
                                        	Authenticate packets
                                        	**type**\:  bool
                                        
                                        .. attribute:: password
                                        
                                        	Specify MD5 or SHA1 password
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: spi
                                        
                                        	Use IPSec AH authentication. Specify the Security Parameter Index (SPI) value
                                        	**type**\:  int
                                        
                                        	**range:** 256..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.algorithm = None
                                            self.enable = None
                                            self.password = None
                                            self.spi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:authentication'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.algorithm is not None:
                                                return True

                                            if self.enable is not None:
                                                return True

                                            if self.password is not None:
                                                return True

                                            if self.spi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinks.ShamLink.Authentication']['meta_info']


                                    class Encryption(object):
                                        """
                                        Encrypt and authenticate OSPFv3 packets
                                        
                                        .. attribute:: authentication_algorithm
                                        
                                        	Use the NULL, MD5 or SHA1 algorithm
                                        	**type**\:   :py:class:`Ospfv3AuthenticationType2Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationType2Enum>`
                                        
                                        .. attribute:: authentication_password
                                        
                                        	Specify MD5 or SHA1 password
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: enable
                                        
                                        	Authenticate packets
                                        	**type**\:  bool
                                        
                                        .. attribute:: encryption_algorithm
                                        
                                        	Specify the encryption algorithm
                                        	**type**\:   :py:class:`Ospfv3EncryptionAlgorithmEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EncryptionAlgorithmEnum>`
                                        
                                        .. attribute:: encryption_password
                                        
                                        	Encryption password
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: spi
                                        
                                        	Use IPSec ESP authentication. Specify the Security Parameter Index (SPI) value
                                        	**type**\:  int
                                        
                                        	**range:** 256..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.authentication_algorithm = None
                                            self.authentication_password = None
                                            self.enable = None
                                            self.encryption_algorithm = None
                                            self.encryption_password = None
                                            self.spi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:encryption'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.authentication_algorithm is not None:
                                                return True

                                            if self.authentication_password is not None:
                                                return True

                                            if self.enable is not None:
                                                return True

                                            if self.encryption_algorithm is not None:
                                                return True

                                            if self.encryption_password is not None:
                                                return True

                                            if self.spi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinks.ShamLink.Encryption']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.destination_address is None:
                                            raise YPYModelError('Key property destination_address is None')
                                        if self.source_address is None:
                                            raise YPYModelError('Key property source_address is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:sham-link[Cisco-IOS-XR-ipv6-ospfv3-cfg:destination-address = ' + str(self.destination_address) + '][Cisco-IOS-XR-ipv6-ospfv3-cfg:source-address = ' + str(self.source_address) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.destination_address is not None:
                                            return True

                                        if self.source_address is not None:
                                            return True

                                        if self.authentication is not None and self.authentication._has_data():
                                            return True

                                        if self.dead_interval is not None:
                                            return True

                                        if self.enable is not None:
                                            return True

                                        if self.encryption is not None and self.encryption._has_data():
                                            return True

                                        if self.hello_interval is not None:
                                            return True

                                        if self.retransmit_interval is not None:
                                            return True

                                        if self.transmit_delay is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinks.ShamLink']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:sham-links'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.sham_link is not None:
                                        for child_ref in self.sham_link:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinks']['meta_info']


                            class VirtualLinks(object):
                                """
                                Virtual link sub\-mode
                                
                                .. attribute:: virtual_link
                                
                                	Router ID of virtual link neighbor
                                	**type**\: list of    :py:class:`VirtualLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinks.VirtualLink>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.virtual_link = YList()
                                    self.virtual_link.parent = self
                                    self.virtual_link.name = 'virtual_link'


                                class VirtualLink(object):
                                    """
                                    Router ID of virtual link neighbor
                                    
                                    .. attribute:: virtual_link_address  <key>
                                    
                                    	Router ID of virtual link neighbor
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: authentication
                                    
                                    	Authenticate OSPFv3 packets
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinks.VirtualLink.Authentication>`
                                    
                                    .. attribute:: dead_interval
                                    
                                    	Interval after which a neighbor is declared dead (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: enable
                                    
                                    	Enabled virtual link
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: encryption
                                    
                                    	Encrypt and authenticate OSPFv3 packets
                                    	**type**\:   :py:class:`Encryption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinks.VirtualLink.Encryption>`
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Time between HELLO packets
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: retransmit_interval
                                    
                                    	Specify the transmit interval in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: transmit_delay
                                    
                                    	Specify the transmit delay in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.virtual_link_address = None
                                        self.authentication = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinks.VirtualLink.Authentication()
                                        self.authentication.parent = self
                                        self.dead_interval = None
                                        self.enable = None
                                        self.encryption = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinks.VirtualLink.Encryption()
                                        self.encryption.parent = self
                                        self.hello_interval = None
                                        self.retransmit_interval = None
                                        self.transmit_delay = None


                                    class Authentication(object):
                                        """
                                        Authenticate OSPFv3 packets
                                        
                                        .. attribute:: algorithm
                                        
                                        	Use the MD5 or SHA1 algorithm
                                        	**type**\:   :py:class:`Ospfv3AuthenticationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationEnum>`
                                        
                                        .. attribute:: enable
                                        
                                        	Authenticate packets
                                        	**type**\:  bool
                                        
                                        .. attribute:: password
                                        
                                        	Specify MD5 or SHA1 password
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: spi
                                        
                                        	Use IPSec AH authentication. Specify the Security Parameter Index (SPI) value
                                        	**type**\:  int
                                        
                                        	**range:** 256..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.algorithm = None
                                            self.enable = None
                                            self.password = None
                                            self.spi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:authentication'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.algorithm is not None:
                                                return True

                                            if self.enable is not None:
                                                return True

                                            if self.password is not None:
                                                return True

                                            if self.spi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinks.VirtualLink.Authentication']['meta_info']


                                    class Encryption(object):
                                        """
                                        Encrypt and authenticate OSPFv3 packets
                                        
                                        .. attribute:: authentication_algorithm
                                        
                                        	Use the NULL, MD5 or SHA1 algorithm
                                        	**type**\:   :py:class:`Ospfv3AuthenticationType2Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationType2Enum>`
                                        
                                        .. attribute:: authentication_password
                                        
                                        	Specify MD5 or SHA1 password
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: enable
                                        
                                        	Authenticate packets
                                        	**type**\:  bool
                                        
                                        .. attribute:: encryption_algorithm
                                        
                                        	Specify the encryption algorithm
                                        	**type**\:   :py:class:`Ospfv3EncryptionAlgorithmEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EncryptionAlgorithmEnum>`
                                        
                                        .. attribute:: encryption_password
                                        
                                        	Encryption password
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: spi
                                        
                                        	Use IPSec ESP authentication. Specify the Security Parameter Index (SPI) value
                                        	**type**\:  int
                                        
                                        	**range:** 256..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.authentication_algorithm = None
                                            self.authentication_password = None
                                            self.enable = None
                                            self.encryption_algorithm = None
                                            self.encryption_password = None
                                            self.spi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:encryption'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.authentication_algorithm is not None:
                                                return True

                                            if self.authentication_password is not None:
                                                return True

                                            if self.enable is not None:
                                                return True

                                            if self.encryption_algorithm is not None:
                                                return True

                                            if self.encryption_password is not None:
                                                return True

                                            if self.spi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinks.VirtualLink.Encryption']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.virtual_link_address is None:
                                            raise YPYModelError('Key property virtual_link_address is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:virtual-link[Cisco-IOS-XR-ipv6-ospfv3-cfg:virtual-link-address = ' + str(self.virtual_link_address) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.virtual_link_address is not None:
                                            return True

                                        if self.authentication is not None and self.authentication._has_data():
                                            return True

                                        if self.dead_interval is not None:
                                            return True

                                        if self.enable is not None:
                                            return True

                                        if self.encryption is not None and self.encryption._has_data():
                                            return True

                                        if self.hello_interval is not None:
                                            return True

                                        if self.retransmit_interval is not None:
                                            return True

                                        if self.transmit_delay is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinks.VirtualLink']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:virtual-links'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.virtual_link is not None:
                                        for child_ref in self.virtual_link:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinks']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.address is None:
                                    raise YPYModelError('Key property address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:area-address[Cisco-IOS-XR-ipv6-ospfv3-cfg:address = ' + str(self.address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.address is not None:
                                    return True

                                if self.area_scope is not None and self.area_scope._has_data():
                                    return True

                                if self.authentication is not None and self.authentication._has_data():
                                    return True

                                if self.bfd is not None and self.bfd._has_data():
                                    return True

                                if self.cost is not None:
                                    return True

                                if self.database_filter is not None and self.database_filter._has_data():
                                    return True

                                if self.dead_interval is not None:
                                    return True

                                if self.default_cost is not None:
                                    return True

                                if self.demand_circuit is not None:
                                    return True

                                if self.distribute_list is not None and self.distribute_list._has_data():
                                    return True

                                if self.enable is not None:
                                    return True

                                if self.encryption is not None and self.encryption._has_data():
                                    return True

                                if self.flood_reduction is not None:
                                    return True

                                if self.hello_interval is not None:
                                    return True

                                if self.instance is not None:
                                    return True

                                if self.interfaces is not None and self.interfaces._has_data():
                                    return True

                                if self.ldp_sync is not None:
                                    return True

                                if self.mtu_ignore is not None:
                                    return True

                                if self.network is not None:
                                    return True

                                if self.nssa is not None and self.nssa._has_data():
                                    return True

                                if self.packet_size is not None:
                                    return True

                                if self.passive is not None:
                                    return True

                                if self.prefix_suppression is not None:
                                    return True

                                if self.priority is not None:
                                    return True

                                if self.ranges is not None and self.ranges._has_data():
                                    return True

                                if self.retransmit_interval is not None:
                                    return True

                                if self.sham_links is not None and self.sham_links._has_data():
                                    return True

                                if self.stub is not None:
                                    return True

                                if self.transmit_delay is not None:
                                    return True

                                if self.virtual_links is not None and self.virtual_links._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress']['meta_info']


                        class AreaAreaId(object):
                            """
                            Configuration for a particular area
                            
                            .. attribute:: area_id  <key>
                            
                            	Area ID if in integer format
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: area_scope
                            
                            	Area Scope Configuration
                            	**type**\:   :py:class:`AreaScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope>`
                            
                            .. attribute:: authentication
                            
                            	Authenticate OSPFv3 packets
                            	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Authentication>`
                            
                            .. attribute:: bfd
                            
                            	Configure BFD parameters
                            	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Bfd>`
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Database filter
                            	**type**\:   :py:class:`DatabaseFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.DatabaseFilter>`
                            
                            .. attribute:: dead_interval
                            
                            	Interval after which a neighbor is declared dead (in seconds)
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**units**\: second
                            
                            .. attribute:: default_cost
                            
                            	Set the summary default\-cost of a NSSA/stub area
                            	**type**\:  int
                            
                            	**range:** 0..16777215
                            
                            .. attribute:: demand_circuit
                            
                            	Enable/disable demand circuit operation
                            	**type**\:  bool
                            
                            .. attribute:: distribute_list
                            
                            	Filter prefixes to/from RIB
                            	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.DistributeList>`
                            
                            .. attribute:: enable
                            
                            	Enable OSPFv3 area
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: encryption
                            
                            	Encrypt and authenticate OSPFv3 packets
                            	**type**\:   :py:class:`Encryption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Encryption>`
                            
                            .. attribute:: flood_reduction
                            
                            	Enable/disable flood reduction
                            	**type**\:  bool
                            
                            .. attribute:: hello_interval
                            
                            	Time between HELLO packets
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**units**\: second
                            
                            .. attribute:: instance
                            
                            	Instance ID
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interfaces
                            
                            	OSPFv3 interfaces
                            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces>`
                            
                            .. attribute:: ldp_sync
                            
                            	Enable/Disable MPLS LDP sync
                            	**type**\:  bool
                            
                            .. attribute:: mtu_ignore
                            
                            	Enable/disable ignoring of MTU in DBD packets
                            	**type**\:  bool
                            
                            .. attribute:: network
                            
                            	Specify network type
                            	**type**\:   :py:class:`Ospfv3NetworkEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3NetworkEnum>`
                            
                            .. attribute:: nssa
                            
                            	Specify area as a NSSA area.  Allowed only in non\-backbone areas
                            	**type**\:   :py:class:`Nssa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Nssa>`
                            
                            .. attribute:: packet_size
                            
                            	Limit size of OSPFv3 packets
                            	**type**\:  int
                            
                            	**range:** 256..10000
                            
                            .. attribute:: passive
                            
                            	Enable/disable routing updates on an interface
                            	**type**\:  bool
                            
                            .. attribute:: prefix_suppression
                            
                            	Enable/disable prefix suppression on an interface
                            	**type**\:  bool
                            
                            .. attribute:: priority
                            
                            	Specify router priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ranges
                            
                            	Range configuration
                            	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Ranges>`
                            
                            .. attribute:: retransmit_interval
                            
                            	Specify the transmit interval in seconds
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**units**\: second
                            
                            .. attribute:: sham_links
                            
                            	Sham Link sub\-mode
                            	**type**\:   :py:class:`ShamLinks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinks>`
                            
                            .. attribute:: stub
                            
                            	Specify area as a stub area.  Allowed only in non\-backbone areas
                            	**type**\:  bool
                            
                            .. attribute:: transmit_delay
                            
                            	Specify the transmit delay in seconds
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**units**\: second
                            
                            .. attribute:: virtual_links
                            
                            	Virtual link sub\-mode
                            	**type**\:   :py:class:`VirtualLinks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinks>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.area_id = None
                                self.area_scope = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope()
                                self.area_scope.parent = self
                                self.authentication = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Authentication()
                                self.authentication.parent = self
                                self.bfd = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Bfd()
                                self.bfd.parent = self
                                self.cost = None
                                self.database_filter = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.DatabaseFilter()
                                self.database_filter.parent = self
                                self.dead_interval = None
                                self.default_cost = None
                                self.demand_circuit = None
                                self.distribute_list = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.DistributeList()
                                self.distribute_list.parent = self
                                self.enable = None
                                self.encryption = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Encryption()
                                self.encryption.parent = self
                                self.flood_reduction = None
                                self.hello_interval = None
                                self.instance = None
                                self.interfaces = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces()
                                self.interfaces.parent = self
                                self.ldp_sync = None
                                self.mtu_ignore = None
                                self.network = None
                                self.nssa = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Nssa()
                                self.nssa.parent = self
                                self.packet_size = None
                                self.passive = None
                                self.prefix_suppression = None
                                self.priority = None
                                self.ranges = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Ranges()
                                self.ranges.parent = self
                                self.retransmit_interval = None
                                self.sham_links = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinks()
                                self.sham_links.parent = self
                                self.stub = None
                                self.transmit_delay = None
                                self.virtual_links = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinks()
                                self.virtual_links.parent = self


                            class Authentication(object):
                                """
                                Authenticate OSPFv3 packets
                                
                                .. attribute:: algorithm
                                
                                	Use the MD5 or SHA1 algorithm
                                	**type**\:   :py:class:`Ospfv3AuthenticationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationEnum>`
                                
                                .. attribute:: enable
                                
                                	Authenticate packets
                                	**type**\:  bool
                                
                                .. attribute:: password
                                
                                	Specify MD5 or SHA1 password
                                	**type**\:  str
                                
                                	**pattern:** (!.+)\|([^!].+)
                                
                                .. attribute:: spi
                                
                                	Use IPSec AH authentication. Specify the Security Parameter Index (SPI) value
                                	**type**\:  int
                                
                                	**range:** 256..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.algorithm = None
                                    self.enable = None
                                    self.password = None
                                    self.spi = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:authentication'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.algorithm is not None:
                                        return True

                                    if self.enable is not None:
                                        return True

                                    if self.password is not None:
                                        return True

                                    if self.spi is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Authentication']['meta_info']


                            class Bfd(object):
                                """
                                Configure BFD parameters
                                
                                .. attribute:: detection_multiplier
                                
                                	Detect multiplier
                                	**type**\:  int
                                
                                	**range:** 2..50
                                
                                .. attribute:: fast_detect_mode
                                
                                	Enable or disable BFD fast detection
                                	**type**\:   :py:class:`Ospfv3BfdEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3BfdEnableModeEnum>`
                                
                                .. attribute:: interval
                                
                                	Hello interval in milli\-seconds
                                	**type**\:  int
                                
                                	**range:** 3..30000
                                
                                	**units**\: millisecond
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.detection_multiplier = None
                                    self.fast_detect_mode = None
                                    self.interval = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:bfd'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.detection_multiplier is not None:
                                        return True

                                    if self.fast_detect_mode is not None:
                                        return True

                                    if self.interval is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Bfd']['meta_info']


                            class Ranges(object):
                                """
                                Range configuration
                                
                                .. attribute:: range
                                
                                	Summarize inter\-area routes matching prefix/length
                                	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Ranges.Range>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.range = YList()
                                    self.range.parent = self
                                    self.range.name = 'range'


                                class Range(object):
                                    """
                                    Summarize inter\-area routes matching
                                    prefix/length
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	IPv6 prefix format
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length  <key>
                                    
                                    	IPV6 prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: cost
                                    
                                    	Specified metric for this range
                                    	**type**\:  int
                                    
                                    	**range:** 1..16777214
                                    
                                    .. attribute:: not_advertise
                                    
                                    	Do not advertise address range
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.prefix = None
                                        self.prefix_length = None
                                        self.cost = None
                                        self.not_advertise = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.prefix is None:
                                            raise YPYModelError('Key property prefix is None')
                                        if self.prefix_length is None:
                                            raise YPYModelError('Key property prefix_length is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:range[Cisco-IOS-XR-ipv6-ospfv3-cfg:prefix = ' + str(self.prefix) + '][Cisco-IOS-XR-ipv6-ospfv3-cfg:prefix-length = ' + str(self.prefix_length) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.prefix is not None:
                                            return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.cost is not None:
                                            return True

                                        if self.not_advertise is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Ranges.Range']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:ranges'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.range is not None:
                                        for child_ref in self.range:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Ranges']['meta_info']


                            class Encryption(object):
                                """
                                Encrypt and authenticate OSPFv3 packets
                                
                                .. attribute:: authentication_algorithm
                                
                                	Use the NULL, MD5 or SHA1 algorithm
                                	**type**\:   :py:class:`Ospfv3AuthenticationType2Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationType2Enum>`
                                
                                .. attribute:: authentication_password
                                
                                	Specify MD5 or SHA1 password
                                	**type**\:  str
                                
                                	**pattern:** (!.+)\|([^!].+)
                                
                                .. attribute:: enable
                                
                                	Authenticate packets
                                	**type**\:  bool
                                
                                .. attribute:: encryption_algorithm
                                
                                	Specify the encryption algorithm
                                	**type**\:   :py:class:`Ospfv3EncryptionAlgorithmEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EncryptionAlgorithmEnum>`
                                
                                .. attribute:: encryption_password
                                
                                	Encryption password
                                	**type**\:  str
                                
                                	**pattern:** (!.+)\|([^!].+)
                                
                                .. attribute:: spi
                                
                                	Use IPSec ESP authentication. Specify the Security Parameter Index (SPI) value
                                	**type**\:  int
                                
                                	**range:** 256..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.authentication_algorithm = None
                                    self.authentication_password = None
                                    self.enable = None
                                    self.encryption_algorithm = None
                                    self.encryption_password = None
                                    self.spi = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:encryption'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.authentication_algorithm is not None:
                                        return True

                                    if self.authentication_password is not None:
                                        return True

                                    if self.enable is not None:
                                        return True

                                    if self.encryption_algorithm is not None:
                                        return True

                                    if self.encryption_password is not None:
                                        return True

                                    if self.spi is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Encryption']['meta_info']


                            class Nssa(object):
                                """
                                Specify area as a NSSA area.  Allowed only in
                                non\-backbone areas
                                
                                .. attribute:: default_info_originate
                                
                                	Originate Type 7 default into NSSA area
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: metric
                                
                                	Only valid with DefaultInfoOriginate
                                	**type**\:  int
                                
                                	**range:** 0..16777214
                                
                                .. attribute:: metric_type
                                
                                	Only valid with DefaultInfoOriginate
                                	**type**\:   :py:class:`Ospfv3MetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3MetricEnum>`
                                
                                .. attribute:: no_redistribution
                                
                                	No redistribution into this NSSA area
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: no_summary
                                
                                	Do not send summary LSA into NSSA
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.default_info_originate = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.no_redistribution = None
                                    self.no_summary = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:nssa'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.default_info_originate is not None:
                                        return True

                                    if self.metric is not None:
                                        return True

                                    if self.metric_type is not None:
                                        return True

                                    if self.no_redistribution is not None:
                                        return True

                                    if self.no_summary is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Nssa']['meta_info']


                            class DatabaseFilter(object):
                                """
                                Database filter
                                
                                .. attribute:: all
                                
                                	All
                                	**type**\:   :py:class:`All <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.all = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.DatabaseFilter.All()
                                    self.all.parent = self


                                class All(object):
                                    """
                                    All
                                    
                                    .. attribute:: out
                                    
                                    	Enable or disable database\-filter
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.out = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:all'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.out is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.DatabaseFilter.All']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:database-filter'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.all is not None and self.all._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.DatabaseFilter']['meta_info']


                            class DistributeList(object):
                                """
                                Filter prefixes to/from RIB
                                
                                .. attribute:: in_
                                
                                	Filter prefixes installed to RIB
                                	**type**\:   :py:class:`In_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.DistributeList.In_>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.in_ = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.DistributeList.In_()
                                    self.in_.parent = self


                                class In_(object):
                                    """
                                    Filter prefixes installed to RIB
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Filter prefixes based on an IPv6 prefix\-list
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.prefix_list = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:in'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.prefix_list is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.DistributeList.In_']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:distribute-list'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.in_ is not None and self.in_._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.DistributeList']['meta_info']


                            class Interfaces(object):
                                """
                                OSPFv3 interfaces
                                
                                .. attribute:: interface
                                
                                	OSPFv3 interface
                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface = YList()
                                    self.interface.parent = self
                                    self.interface.name = 'interface'


                                class Interface(object):
                                    """
                                    OSPFv3 interface
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface to configure
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: authentication
                                    
                                    	Authenticate OSPFv3 packets
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Authentication>`
                                    
                                    .. attribute:: bfd
                                    
                                    	Configure BFD parameters
                                    	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Bfd>`
                                    
                                    .. attribute:: cost
                                    
                                    	Interface cost
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: database_filter
                                    
                                    	Database filter
                                    	**type**\:   :py:class:`DatabaseFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DatabaseFilter>`
                                    
                                    .. attribute:: dead_interval
                                    
                                    	Interval after which a neighbor is declared dead (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: demand_circuit
                                    
                                    	Enable/disable demand circuit operation
                                    	**type**\:  bool
                                    
                                    .. attribute:: distribute_list
                                    
                                    	Filter prefixes to/from RIB
                                    	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DistributeList>`
                                    
                                    .. attribute:: enable
                                    
                                    	Enable OSPFv3 interface
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: encryption
                                    
                                    	Encrypt and authenticate OSPFv3 packets
                                    	**type**\:   :py:class:`Encryption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Encryption>`
                                    
                                    .. attribute:: fast_reroute
                                    
                                    	Fast\-reroute configuration
                                    	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute>`
                                    
                                    .. attribute:: flood_reduction
                                    
                                    	Enable/disable flood reduction
                                    	**type**\:  bool
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Time between HELLO packets
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: instance
                                    
                                    	Instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ldp_sync
                                    
                                    	Enable/Disable MPLS LDP sync
                                    	**type**\:  bool
                                    
                                    .. attribute:: mtu_ignore
                                    
                                    	Enable/disable ignoring of MTU in DBD packets
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbors
                                    
                                    	Specify a neighbor router
                                    	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Neighbors>`
                                    
                                    .. attribute:: network
                                    
                                    	Specify network type
                                    	**type**\:   :py:class:`Ospfv3NetworkEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3NetworkEnum>`
                                    
                                    .. attribute:: packet_size
                                    
                                    	Limit size of OSPFv3 packets
                                    	**type**\:  int
                                    
                                    	**range:** 256..10000
                                    
                                    .. attribute:: passive
                                    
                                    	Enable/disable routing updates on an interface
                                    	**type**\:  bool
                                    
                                    .. attribute:: prefix_suppression
                                    
                                    	Enable/disable prefix suppression on an interface
                                    	**type**\:  bool
                                    
                                    .. attribute:: priority
                                    
                                    	Specify router priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: retransmit_interval
                                    
                                    	Specify the transmit interval in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: transmit_delay
                                    
                                    	Specify the transmit delay in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None
                                        self.authentication = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Authentication()
                                        self.authentication.parent = self
                                        self.bfd = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Bfd()
                                        self.bfd.parent = self
                                        self.cost = None
                                        self.database_filter = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DatabaseFilter()
                                        self.database_filter.parent = self
                                        self.dead_interval = None
                                        self.demand_circuit = None
                                        self.distribute_list = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DistributeList()
                                        self.distribute_list.parent = self
                                        self.enable = None
                                        self.encryption = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Encryption()
                                        self.encryption.parent = self
                                        self.fast_reroute = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute()
                                        self.fast_reroute.parent = self
                                        self.flood_reduction = None
                                        self.hello_interval = None
                                        self.instance = None
                                        self.ldp_sync = None
                                        self.mtu_ignore = None
                                        self.neighbors = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Neighbors()
                                        self.neighbors.parent = self
                                        self.network = None
                                        self.packet_size = None
                                        self.passive = None
                                        self.prefix_suppression = None
                                        self.priority = None
                                        self.retransmit_interval = None
                                        self.transmit_delay = None


                                    class Authentication(object):
                                        """
                                        Authenticate OSPFv3 packets
                                        
                                        .. attribute:: algorithm
                                        
                                        	Use the MD5 or SHA1 algorithm
                                        	**type**\:   :py:class:`Ospfv3AuthenticationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationEnum>`
                                        
                                        .. attribute:: enable
                                        
                                        	Authenticate packets
                                        	**type**\:  bool
                                        
                                        .. attribute:: password
                                        
                                        	Specify MD5 or SHA1 password
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: spi
                                        
                                        	Use IPSec AH authentication. Specify the Security Parameter Index (SPI) value
                                        	**type**\:  int
                                        
                                        	**range:** 256..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.algorithm = None
                                            self.enable = None
                                            self.password = None
                                            self.spi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:authentication'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.algorithm is not None:
                                                return True

                                            if self.enable is not None:
                                                return True

                                            if self.password is not None:
                                                return True

                                            if self.spi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Authentication']['meta_info']


                                    class Neighbors(object):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: neighbor
                                        
                                        	IPv6 address
                                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Neighbors.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.neighbor = YList()
                                            self.neighbor.parent = self
                                            self.neighbor.name = 'neighbor'


                                        class Neighbor(object):
                                            """
                                            IPv6 address
                                            
                                            .. attribute:: neighbor_address  <key>
                                            
                                            	IPV6 address
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: cost
                                            
                                            	OSPFv3 cost for point\-to\-multipoint neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: database_filter
                                            
                                            	Filter OSPFv3 LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: poll_interval
                                            
                                            	OSPFv3 dead\-router polling interval (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: priority
                                            
                                            	OSPFv3 priority of non\-broadcast neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: zone
                                            
                                            	Zone
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.neighbor_address = None
                                                self.cost = None
                                                self.database_filter = None
                                                self.poll_interval = None
                                                self.priority = None
                                                self.zone = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.neighbor_address is None:
                                                    raise YPYModelError('Key property neighbor_address is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:neighbor[Cisco-IOS-XR-ipv6-ospfv3-cfg:neighbor-address = ' + str(self.neighbor_address) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.neighbor_address is not None:
                                                    return True

                                                if self.cost is not None:
                                                    return True

                                                if self.database_filter is not None:
                                                    return True

                                                if self.poll_interval is not None:
                                                    return True

                                                if self.priority is not None:
                                                    return True

                                                if self.zone is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Neighbors.Neighbor']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:neighbors'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.neighbor is not None:
                                                for child_ref in self.neighbor:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Neighbors']['meta_info']


                                    class Encryption(object):
                                        """
                                        Encrypt and authenticate OSPFv3 packets
                                        
                                        .. attribute:: authentication_algorithm
                                        
                                        	Use the NULL, MD5 or SHA1 algorithm
                                        	**type**\:   :py:class:`Ospfv3AuthenticationType2Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationType2Enum>`
                                        
                                        .. attribute:: authentication_password
                                        
                                        	Specify MD5 or SHA1 password
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: enable
                                        
                                        	Authenticate packets
                                        	**type**\:  bool
                                        
                                        .. attribute:: encryption_algorithm
                                        
                                        	Specify the encryption algorithm
                                        	**type**\:   :py:class:`Ospfv3EncryptionAlgorithmEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EncryptionAlgorithmEnum>`
                                        
                                        .. attribute:: encryption_password
                                        
                                        	Encryption password
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: spi
                                        
                                        	Use IPSec ESP authentication. Specify the Security Parameter Index (SPI) value
                                        	**type**\:  int
                                        
                                        	**range:** 256..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.authentication_algorithm = None
                                            self.authentication_password = None
                                            self.enable = None
                                            self.encryption_algorithm = None
                                            self.encryption_password = None
                                            self.spi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:encryption'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.authentication_algorithm is not None:
                                                return True

                                            if self.authentication_password is not None:
                                                return True

                                            if self.enable is not None:
                                                return True

                                            if self.encryption_algorithm is not None:
                                                return True

                                            if self.encryption_password is not None:
                                                return True

                                            if self.spi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Encryption']['meta_info']


                                    class Bfd(object):
                                        """
                                        Configure BFD parameters
                                        
                                        .. attribute:: detection_multiplier
                                        
                                        	Detect multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 2..50
                                        
                                        .. attribute:: fast_detect_mode
                                        
                                        	Enable or disable BFD fast detection
                                        	**type**\:   :py:class:`Ospfv3BfdEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3BfdEnableModeEnum>`
                                        
                                        .. attribute:: interval
                                        
                                        	Hello interval in milli\-seconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.detection_multiplier = None
                                            self.fast_detect_mode = None
                                            self.interval = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:bfd'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.detection_multiplier is not None:
                                                return True

                                            if self.fast_detect_mode is not None:
                                                return True

                                            if self.interval is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.Bfd']['meta_info']


                                    class DatabaseFilter(object):
                                        """
                                        Database filter
                                        
                                        .. attribute:: all
                                        
                                        	All
                                        	**type**\:   :py:class:`All <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DatabaseFilter.All>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.all = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DatabaseFilter.All()
                                            self.all.parent = self


                                        class All(object):
                                            """
                                            All
                                            
                                            .. attribute:: out
                                            
                                            	Enable or disable database\-filter
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.out = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:all'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.out is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DatabaseFilter.All']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:database-filter'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.all is not None and self.all._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DatabaseFilter']['meta_info']


                                    class DistributeList(object):
                                        """
                                        Filter prefixes to/from RIB
                                        
                                        .. attribute:: in_
                                        
                                        	Filter prefixes installed to RIB
                                        	**type**\:   :py:class:`In_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DistributeList.In_>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.in_ = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DistributeList.In_()
                                            self.in_.parent = self


                                        class In_(object):
                                            """
                                            Filter prefixes installed to RIB
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Filter prefixes based on an IPv6 prefix\-list
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix_list = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix_list is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DistributeList.In_']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:distribute-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.in_ is not None and self.in_._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.DistributeList']['meta_info']


                                    class FastReroute(object):
                                        """
                                        Fast\-reroute configuration
                                        
                                        .. attribute:: fast_reroute_enable
                                        
                                        	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                        	**type**\:   :py:class:`Ospfv3FastRerouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3FastRerouteEnum>`
                                        
                                        .. attribute:: per_link
                                        
                                        	Fast\-reroute per\-link configuration
                                        	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink>`
                                        
                                        .. attribute:: per_prefix
                                        
                                        	Fast\-reroute per\-link configuration
                                        	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.fast_reroute_enable = None
                                            self.per_link = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink()
                                            self.per_link.parent = self
                                            self.per_prefix = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix()
                                            self.per_prefix.parent = self


                                        class PerLink(object):
                                            """
                                            Fast\-reroute per\-link configuration
                                            
                                            .. attribute:: candidate_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink.CandidateInterfaces>`
                                            
                                            .. attribute:: exclude_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix exclude interface configuration
                                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink.ExcludeInterfaces>`
                                            
                                            .. attribute:: fast_reroute_use_candidate_only
                                            
                                            	Use only interfaces on the candidate list as a backup path
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.candidate_interfaces = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self.exclude_interfaces = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self.fast_reroute_use_candidate_only = None


                                            class CandidateInterfaces(object):
                                                """
                                                Fast\-reroute per\-link/per\-prefix candidate
                                                interface configuration
                                                
                                                .. attribute:: candidate_interface
                                                
                                                	Candidate backup interface
                                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.candidate_interface = YList()
                                                    self.candidate_interface.parent = self
                                                    self.candidate_interface.name = 'candidate_interface'


                                                class CandidateInterface(object):
                                                    """
                                                    Candidate backup interface
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-cfg'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                                        if self.interface_name is None:
                                                            raise YPYModelError('Key property interface_name is None')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return True

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink.CandidateInterfaces.CandidateInterface']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interfaces'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.candidate_interface is not None:
                                                        for child_ref in self.candidate_interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink.CandidateInterfaces']['meta_info']


                                            class ExcludeInterfaces(object):
                                                """
                                                Fast\-reroute per\-link/per\-prefix exclude
                                                interface configuration
                                                
                                                .. attribute:: exclude_interface
                                                
                                                	Exclude an interface from becoming a backup
                                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.exclude_interface = YList()
                                                    self.exclude_interface.parent = self
                                                    self.exclude_interface.name = 'exclude_interface'


                                                class ExcludeInterface(object):
                                                    """
                                                    Exclude an interface from becoming a backup
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-cfg'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                                        if self.interface_name is None:
                                                            raise YPYModelError('Key property interface_name is None')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return True

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interfaces'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.exclude_interface is not None:
                                                        for child_ref in self.exclude_interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink.ExcludeInterfaces']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-link'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.candidate_interfaces is not None and self.candidate_interfaces._has_data():
                                                    return True

                                                if self.exclude_interfaces is not None and self.exclude_interfaces._has_data():
                                                    return True

                                                if self.fast_reroute_use_candidate_only is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerLink']['meta_info']


                                        class PerPrefix(object):
                                            """
                                            Fast\-reroute per\-link configuration
                                            
                                            .. attribute:: candidate_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix.CandidateInterfaces>`
                                            
                                            .. attribute:: exclude_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix exclude interface configuration
                                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix.ExcludeInterfaces>`
                                            
                                            .. attribute:: fast_reroute_use_candidate_only
                                            
                                            	Use only interfaces on the candidate list as a backup path
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.candidate_interfaces = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self.exclude_interfaces = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self.fast_reroute_use_candidate_only = None


                                            class CandidateInterfaces(object):
                                                """
                                                Fast\-reroute per\-link/per\-prefix candidate
                                                interface configuration
                                                
                                                .. attribute:: candidate_interface
                                                
                                                	Candidate backup interface
                                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.candidate_interface = YList()
                                                    self.candidate_interface.parent = self
                                                    self.candidate_interface.name = 'candidate_interface'


                                                class CandidateInterface(object):
                                                    """
                                                    Candidate backup interface
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-cfg'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                                        if self.interface_name is None:
                                                            raise YPYModelError('Key property interface_name is None')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return True

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interfaces'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.candidate_interface is not None:
                                                        for child_ref in self.candidate_interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix.CandidateInterfaces']['meta_info']


                                            class ExcludeInterfaces(object):
                                                """
                                                Fast\-reroute per\-link/per\-prefix exclude
                                                interface configuration
                                                
                                                .. attribute:: exclude_interface
                                                
                                                	Exclude an interface from becoming a backup
                                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.exclude_interface = YList()
                                                    self.exclude_interface.parent = self
                                                    self.exclude_interface.name = 'exclude_interface'


                                                class ExcludeInterface(object):
                                                    """
                                                    Exclude an interface from becoming a backup
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-cfg'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                                        if self.interface_name is None:
                                                            raise YPYModelError('Key property interface_name is None')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return True

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interfaces'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.exclude_interface is not None:
                                                        for child_ref in self.exclude_interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix.ExcludeInterfaces']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.candidate_interfaces is not None and self.candidate_interfaces._has_data():
                                                    return True

                                                if self.exclude_interfaces is not None and self.exclude_interfaces._has_data():
                                                    return True

                                                if self.fast_reroute_use_candidate_only is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute.PerPrefix']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:fast-reroute'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.fast_reroute_enable is not None:
                                                return True

                                            if self.per_link is not None and self.per_link._has_data():
                                                return True

                                            if self.per_prefix is not None and self.per_prefix._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface.FastReroute']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.interface_name is None:
                                            raise YPYModelError('Key property interface_name is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        if self.authentication is not None and self.authentication._has_data():
                                            return True

                                        if self.bfd is not None and self.bfd._has_data():
                                            return True

                                        if self.cost is not None:
                                            return True

                                        if self.database_filter is not None and self.database_filter._has_data():
                                            return True

                                        if self.dead_interval is not None:
                                            return True

                                        if self.demand_circuit is not None:
                                            return True

                                        if self.distribute_list is not None and self.distribute_list._has_data():
                                            return True

                                        if self.enable is not None:
                                            return True

                                        if self.encryption is not None and self.encryption._has_data():
                                            return True

                                        if self.fast_reroute is not None and self.fast_reroute._has_data():
                                            return True

                                        if self.flood_reduction is not None:
                                            return True

                                        if self.hello_interval is not None:
                                            return True

                                        if self.instance is not None:
                                            return True

                                        if self.ldp_sync is not None:
                                            return True

                                        if self.mtu_ignore is not None:
                                            return True

                                        if self.neighbors is not None and self.neighbors._has_data():
                                            return True

                                        if self.network is not None:
                                            return True

                                        if self.packet_size is not None:
                                            return True

                                        if self.passive is not None:
                                            return True

                                        if self.prefix_suppression is not None:
                                            return True

                                        if self.priority is not None:
                                            return True

                                        if self.retransmit_interval is not None:
                                            return True

                                        if self.transmit_delay is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces.Interface']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:interfaces'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface is not None:
                                        for child_ref in self.interface:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Interfaces']['meta_info']


                            class AreaScope(object):
                                """
                                Area Scope Configuration
                                
                                .. attribute:: fast_reroute
                                
                                	Fast\-reroute configuration
                                	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.fast_reroute = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute()
                                    self.fast_reroute.parent = self


                                class FastReroute(object):
                                    """
                                    Fast\-reroute configuration
                                    
                                    .. attribute:: fast_reroute_enable
                                    
                                    	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                    	**type**\:   :py:class:`Ospfv3FastRerouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3FastRerouteEnum>`
                                    
                                    .. attribute:: per_link
                                    
                                    	Fast\-reroute per\-link configuration
                                    	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink>`
                                    
                                    .. attribute:: per_prefix
                                    
                                    	Fast\-reroute per\-link configuration
                                    	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.fast_reroute_enable = None
                                        self.per_link = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink()
                                        self.per_link.parent = self
                                        self.per_prefix = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix()
                                        self.per_prefix.parent = self


                                    class PerLink(object):
                                        """
                                        Fast\-reroute per\-link configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.candidate_interfaces = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self.exclude_interfaces = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self.fast_reroute_use_candidate_only = None


                                        class CandidateInterfaces(object):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.candidate_interface = YList()
                                                self.candidate_interface.parent = self
                                                self.candidate_interface.name = 'candidate_interface'


                                            class CandidateInterface(object):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.interface_name is None:
                                                        raise YPYModelError('Key property interface_name is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interfaces'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.candidate_interface is not None:
                                                    for child_ref in self.candidate_interface:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces']['meta_info']


                                        class ExcludeInterfaces(object):
                                            """
                                            Fast\-reroute per\-link/per\-prefix exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.exclude_interface = YList()
                                                self.exclude_interface.parent = self
                                                self.exclude_interface.name = 'exclude_interface'


                                            class ExcludeInterface(object):
                                                """
                                                Exclude an interface from becoming a backup
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.interface_name is None:
                                                        raise YPYModelError('Key property interface_name is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interfaces'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.exclude_interface is not None:
                                                    for child_ref in self.exclude_interface:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-link'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.candidate_interfaces is not None and self.candidate_interfaces._has_data():
                                                return True

                                            if self.exclude_interfaces is not None and self.exclude_interfaces._has_data():
                                                return True

                                            if self.fast_reroute_use_candidate_only is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink']['meta_info']


                                    class PerPrefix(object):
                                        """
                                        Fast\-reroute per\-link configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.candidate_interfaces = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self.exclude_interfaces = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self.fast_reroute_use_candidate_only = None


                                        class CandidateInterfaces(object):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.candidate_interface = YList()
                                                self.candidate_interface.parent = self
                                                self.candidate_interface.name = 'candidate_interface'


                                            class CandidateInterface(object):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.interface_name is None:
                                                        raise YPYModelError('Key property interface_name is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interfaces'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.candidate_interface is not None:
                                                    for child_ref in self.candidate_interface:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces']['meta_info']


                                        class ExcludeInterfaces(object):
                                            """
                                            Fast\-reroute per\-link/per\-prefix exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-cfg'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.exclude_interface = YList()
                                                self.exclude_interface.parent = self
                                                self.exclude_interface.name = 'exclude_interface'


                                            class ExcludeInterface(object):
                                                """
                                                Exclude an interface from becoming a backup
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-cfg'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.interface_name is None:
                                                        raise YPYModelError('Key property interface_name is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return True

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interfaces'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return True

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.exclude_interface is not None:
                                                    for child_ref in self.exclude_interface:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-prefix'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.candidate_interfaces is not None and self.candidate_interfaces._has_data():
                                                return True

                                            if self.exclude_interfaces is not None and self.exclude_interfaces._has_data():
                                                return True

                                            if self.fast_reroute_use_candidate_only is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:fast-reroute'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.fast_reroute_enable is not None:
                                            return True

                                        if self.per_link is not None and self.per_link._has_data():
                                            return True

                                        if self.per_prefix is not None and self.per_prefix._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:area-scope'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.fast_reroute is not None and self.fast_reroute._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope']['meta_info']


                            class ShamLinks(object):
                                """
                                Sham Link sub\-mode
                                
                                .. attribute:: sham_link
                                
                                	ShamLink local and remote endpoints
                                	**type**\: list of    :py:class:`ShamLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinks.ShamLink>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.sham_link = YList()
                                    self.sham_link.parent = self
                                    self.sham_link.name = 'sham_link'


                                class ShamLink(object):
                                    """
                                    ShamLink local and remote endpoints
                                    
                                    .. attribute:: destination_address  <key>
                                    
                                    	Remote sham\-link endpoint
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address  <key>
                                    
                                    	Local sham\-link endpoint
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: authentication
                                    
                                    	Authenticate OSPFv3 packets
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinks.ShamLink.Authentication>`
                                    
                                    .. attribute:: dead_interval
                                    
                                    	Interval after which a neighbor is declared dead (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: enable
                                    
                                    	Enable sham link
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: encryption
                                    
                                    	Encrypt and authenticate OSPFv3 packets
                                    	**type**\:   :py:class:`Encryption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinks.ShamLink.Encryption>`
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Time between HELLO packets
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: retransmit_interval
                                    
                                    	Specify the transmit interval in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: transmit_delay
                                    
                                    	Specify the transmit delay in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.destination_address = None
                                        self.source_address = None
                                        self.authentication = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinks.ShamLink.Authentication()
                                        self.authentication.parent = self
                                        self.dead_interval = None
                                        self.enable = None
                                        self.encryption = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinks.ShamLink.Encryption()
                                        self.encryption.parent = self
                                        self.hello_interval = None
                                        self.retransmit_interval = None
                                        self.transmit_delay = None


                                    class Authentication(object):
                                        """
                                        Authenticate OSPFv3 packets
                                        
                                        .. attribute:: algorithm
                                        
                                        	Use the MD5 or SHA1 algorithm
                                        	**type**\:   :py:class:`Ospfv3AuthenticationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationEnum>`
                                        
                                        .. attribute:: enable
                                        
                                        	Authenticate packets
                                        	**type**\:  bool
                                        
                                        .. attribute:: password
                                        
                                        	Specify MD5 or SHA1 password
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: spi
                                        
                                        	Use IPSec AH authentication. Specify the Security Parameter Index (SPI) value
                                        	**type**\:  int
                                        
                                        	**range:** 256..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.algorithm = None
                                            self.enable = None
                                            self.password = None
                                            self.spi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:authentication'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.algorithm is not None:
                                                return True

                                            if self.enable is not None:
                                                return True

                                            if self.password is not None:
                                                return True

                                            if self.spi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinks.ShamLink.Authentication']['meta_info']


                                    class Encryption(object):
                                        """
                                        Encrypt and authenticate OSPFv3 packets
                                        
                                        .. attribute:: authentication_algorithm
                                        
                                        	Use the NULL, MD5 or SHA1 algorithm
                                        	**type**\:   :py:class:`Ospfv3AuthenticationType2Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationType2Enum>`
                                        
                                        .. attribute:: authentication_password
                                        
                                        	Specify MD5 or SHA1 password
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: enable
                                        
                                        	Authenticate packets
                                        	**type**\:  bool
                                        
                                        .. attribute:: encryption_algorithm
                                        
                                        	Specify the encryption algorithm
                                        	**type**\:   :py:class:`Ospfv3EncryptionAlgorithmEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EncryptionAlgorithmEnum>`
                                        
                                        .. attribute:: encryption_password
                                        
                                        	Encryption password
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: spi
                                        
                                        	Use IPSec ESP authentication. Specify the Security Parameter Index (SPI) value
                                        	**type**\:  int
                                        
                                        	**range:** 256..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.authentication_algorithm = None
                                            self.authentication_password = None
                                            self.enable = None
                                            self.encryption_algorithm = None
                                            self.encryption_password = None
                                            self.spi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:encryption'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.authentication_algorithm is not None:
                                                return True

                                            if self.authentication_password is not None:
                                                return True

                                            if self.enable is not None:
                                                return True

                                            if self.encryption_algorithm is not None:
                                                return True

                                            if self.encryption_password is not None:
                                                return True

                                            if self.spi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinks.ShamLink.Encryption']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.destination_address is None:
                                            raise YPYModelError('Key property destination_address is None')
                                        if self.source_address is None:
                                            raise YPYModelError('Key property source_address is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:sham-link[Cisco-IOS-XR-ipv6-ospfv3-cfg:destination-address = ' + str(self.destination_address) + '][Cisco-IOS-XR-ipv6-ospfv3-cfg:source-address = ' + str(self.source_address) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.destination_address is not None:
                                            return True

                                        if self.source_address is not None:
                                            return True

                                        if self.authentication is not None and self.authentication._has_data():
                                            return True

                                        if self.dead_interval is not None:
                                            return True

                                        if self.enable is not None:
                                            return True

                                        if self.encryption is not None and self.encryption._has_data():
                                            return True

                                        if self.hello_interval is not None:
                                            return True

                                        if self.retransmit_interval is not None:
                                            return True

                                        if self.transmit_delay is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinks.ShamLink']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:sham-links'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.sham_link is not None:
                                        for child_ref in self.sham_link:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinks']['meta_info']


                            class VirtualLinks(object):
                                """
                                Virtual link sub\-mode
                                
                                .. attribute:: virtual_link
                                
                                	Router ID of virtual link neighbor
                                	**type**\: list of    :py:class:`VirtualLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinks.VirtualLink>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.virtual_link = YList()
                                    self.virtual_link.parent = self
                                    self.virtual_link.name = 'virtual_link'


                                class VirtualLink(object):
                                    """
                                    Router ID of virtual link neighbor
                                    
                                    .. attribute:: virtual_link_address  <key>
                                    
                                    	Router ID of virtual link neighbor
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: authentication
                                    
                                    	Authenticate OSPFv3 packets
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinks.VirtualLink.Authentication>`
                                    
                                    .. attribute:: dead_interval
                                    
                                    	Interval after which a neighbor is declared dead (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: enable
                                    
                                    	Enabled virtual link
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: encryption
                                    
                                    	Encrypt and authenticate OSPFv3 packets
                                    	**type**\:   :py:class:`Encryption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinks.VirtualLink.Encryption>`
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Time between HELLO packets
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: retransmit_interval
                                    
                                    	Specify the transmit interval in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: transmit_delay
                                    
                                    	Specify the transmit delay in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.virtual_link_address = None
                                        self.authentication = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinks.VirtualLink.Authentication()
                                        self.authentication.parent = self
                                        self.dead_interval = None
                                        self.enable = None
                                        self.encryption = Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinks.VirtualLink.Encryption()
                                        self.encryption.parent = self
                                        self.hello_interval = None
                                        self.retransmit_interval = None
                                        self.transmit_delay = None


                                    class Authentication(object):
                                        """
                                        Authenticate OSPFv3 packets
                                        
                                        .. attribute:: algorithm
                                        
                                        	Use the MD5 or SHA1 algorithm
                                        	**type**\:   :py:class:`Ospfv3AuthenticationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationEnum>`
                                        
                                        .. attribute:: enable
                                        
                                        	Authenticate packets
                                        	**type**\:  bool
                                        
                                        .. attribute:: password
                                        
                                        	Specify MD5 or SHA1 password
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: spi
                                        
                                        	Use IPSec AH authentication. Specify the Security Parameter Index (SPI) value
                                        	**type**\:  int
                                        
                                        	**range:** 256..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.algorithm = None
                                            self.enable = None
                                            self.password = None
                                            self.spi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:authentication'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.algorithm is not None:
                                                return True

                                            if self.enable is not None:
                                                return True

                                            if self.password is not None:
                                                return True

                                            if self.spi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinks.VirtualLink.Authentication']['meta_info']


                                    class Encryption(object):
                                        """
                                        Encrypt and authenticate OSPFv3 packets
                                        
                                        .. attribute:: authentication_algorithm
                                        
                                        	Use the NULL, MD5 or SHA1 algorithm
                                        	**type**\:   :py:class:`Ospfv3AuthenticationType2Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationType2Enum>`
                                        
                                        .. attribute:: authentication_password
                                        
                                        	Specify MD5 or SHA1 password
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: enable
                                        
                                        	Authenticate packets
                                        	**type**\:  bool
                                        
                                        .. attribute:: encryption_algorithm
                                        
                                        	Specify the encryption algorithm
                                        	**type**\:   :py:class:`Ospfv3EncryptionAlgorithmEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EncryptionAlgorithmEnum>`
                                        
                                        .. attribute:: encryption_password
                                        
                                        	Encryption password
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: spi
                                        
                                        	Use IPSec ESP authentication. Specify the Security Parameter Index (SPI) value
                                        	**type**\:  int
                                        
                                        	**range:** 256..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.authentication_algorithm = None
                                            self.authentication_password = None
                                            self.enable = None
                                            self.encryption_algorithm = None
                                            self.encryption_password = None
                                            self.spi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:encryption'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.authentication_algorithm is not None:
                                                return True

                                            if self.authentication_password is not None:
                                                return True

                                            if self.enable is not None:
                                                return True

                                            if self.encryption_algorithm is not None:
                                                return True

                                            if self.encryption_password is not None:
                                                return True

                                            if self.spi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinks.VirtualLink.Encryption']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.virtual_link_address is None:
                                            raise YPYModelError('Key property virtual_link_address is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:virtual-link[Cisco-IOS-XR-ipv6-ospfv3-cfg:virtual-link-address = ' + str(self.virtual_link_address) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.virtual_link_address is not None:
                                            return True

                                        if self.authentication is not None and self.authentication._has_data():
                                            return True

                                        if self.dead_interval is not None:
                                            return True

                                        if self.enable is not None:
                                            return True

                                        if self.encryption is not None and self.encryption._has_data():
                                            return True

                                        if self.hello_interval is not None:
                                            return True

                                        if self.retransmit_interval is not None:
                                            return True

                                        if self.transmit_delay is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinks.VirtualLink']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:virtual-links'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.virtual_link is not None:
                                        for child_ref in self.virtual_link:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinks']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.area_id is None:
                                    raise YPYModelError('Key property area_id is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:area-area-id[Cisco-IOS-XR-ipv6-ospfv3-cfg:area-id = ' + str(self.area_id) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.area_id is not None:
                                    return True

                                if self.area_scope is not None and self.area_scope._has_data():
                                    return True

                                if self.authentication is not None and self.authentication._has_data():
                                    return True

                                if self.bfd is not None and self.bfd._has_data():
                                    return True

                                if self.cost is not None:
                                    return True

                                if self.database_filter is not None and self.database_filter._has_data():
                                    return True

                                if self.dead_interval is not None:
                                    return True

                                if self.default_cost is not None:
                                    return True

                                if self.demand_circuit is not None:
                                    return True

                                if self.distribute_list is not None and self.distribute_list._has_data():
                                    return True

                                if self.enable is not None:
                                    return True

                                if self.encryption is not None and self.encryption._has_data():
                                    return True

                                if self.flood_reduction is not None:
                                    return True

                                if self.hello_interval is not None:
                                    return True

                                if self.instance is not None:
                                    return True

                                if self.interfaces is not None and self.interfaces._has_data():
                                    return True

                                if self.ldp_sync is not None:
                                    return True

                                if self.mtu_ignore is not None:
                                    return True

                                if self.network is not None:
                                    return True

                                if self.nssa is not None and self.nssa._has_data():
                                    return True

                                if self.packet_size is not None:
                                    return True

                                if self.passive is not None:
                                    return True

                                if self.prefix_suppression is not None:
                                    return True

                                if self.priority is not None:
                                    return True

                                if self.ranges is not None and self.ranges._has_data():
                                    return True

                                if self.retransmit_interval is not None:
                                    return True

                                if self.sham_links is not None and self.sham_links._has_data():
                                    return True

                                if self.stub is not None:
                                    return True

                                if self.transmit_delay is not None:
                                    return True

                                if self.virtual_links is not None and self.virtual_links._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:area-addresses'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.area_address is not None:
                                for child_ref in self.area_address:
                                    if child_ref._has_data():
                                        return True

                            if self.area_area_id is not None:
                                for child_ref in self.area_area_id:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaAddresses']['meta_info']


                    class Timers(object):
                        """
                        Adjust routing timers
                        
                        .. attribute:: lsa_timers
                        
                        	LSA timers
                        	**type**\:   :py:class:`LsaTimers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Timers.LsaTimers>`
                        
                        .. attribute:: pacing
                        
                        	Pacing timers
                        	**type**\:   :py:class:`Pacing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Timers.Pacing>`
                        
                        .. attribute:: throttle
                        
                        	Throttle timers
                        	**type**\:   :py:class:`Throttle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Timers.Throttle>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.lsa_timers = Ospfv3.Processes.Process.Vrfs.Vrf.Timers.LsaTimers()
                            self.lsa_timers.parent = self
                            self.pacing = Ospfv3.Processes.Process.Vrfs.Vrf.Timers.Pacing()
                            self.pacing.parent = self
                            self.throttle = Ospfv3.Processes.Process.Vrfs.Vrf.Timers.Throttle()
                            self.throttle.parent = self


                        class Pacing(object):
                            """
                            Pacing timers
                            
                            .. attribute:: flood
                            
                            	The minimum interval in milliseconds to pace limit flooding on interface
                            	**type**\:  int
                            
                            	**range:** 5..100
                            
                            	**units**\: millisecond
                            
                            .. attribute:: lsa_group
                            
                            	Interval in seconds at which LSAs are grouped and refreshed, checksummed, or aged
                            	**type**\:  int
                            
                            	**range:** 10..1800
                            
                            	**units**\: second
                            
                            .. attribute:: retransmission
                            
                            	The minimum interval in msec between neighbor retransmissions
                            	**type**\:  int
                            
                            	**range:** 5..100
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.flood = None
                                self.lsa_group = None
                                self.retransmission = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:pacing'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.flood is not None:
                                    return True

                                if self.lsa_group is not None:
                                    return True

                                if self.retransmission is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Timers.Pacing']['meta_info']


                        class LsaTimers(object):
                            """
                            LSA timers
                            
                            .. attribute:: arrival
                            
                            	The minimum interval in milliseconds between accepting the same LSA
                            	**type**\:  int
                            
                            	**range:** 0..60000
                            
                            	**units**\: millisecond
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.arrival = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:lsa-timers'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.arrival is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Timers.LsaTimers']['meta_info']


                        class Throttle(object):
                            """
                            Throttle timers
                            
                            .. attribute:: lsa
                            
                            	LSA throttle timers for all types of OSPF LSAs
                            	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Timers.Throttle.Lsa>`
                            
                            .. attribute:: spf
                            
                            	SPF throttle timers
                            	**type**\:   :py:class:`Spf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Timers.Throttle.Spf>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.lsa = Ospfv3.Processes.Process.Vrfs.Vrf.Timers.Throttle.Lsa()
                                self.lsa.parent = self
                                self.spf = Ospfv3.Processes.Process.Vrfs.Vrf.Timers.Throttle.Spf()
                                self.spf.parent = self


                            class Lsa(object):
                                """
                                LSA throttle timers for all types of OSPF LSAs
                                
                                .. attribute:: first_delay
                                
                                	Delay to generate first occurrence of LSA in milliseconds
                                	**type**\:  int
                                
                                	**range:** 0..600000
                                
                                	**units**\: millisecond
                                
                                .. attribute:: maximum_delay
                                
                                	Maximum delay between originating the same LSA in milliseconds
                                	**type**\:  int
                                
                                	**range:** 1..600000
                                
                                	**units**\: millisecond
                                
                                .. attribute:: minimum_delay
                                
                                	Minimum delay between originating the same LSA in milliseconds
                                	**type**\:  int
                                
                                	**range:** 1..600000
                                
                                	**units**\: millisecond
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.first_delay = None
                                    self.maximum_delay = None
                                    self.minimum_delay = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:lsa'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.first_delay is not None:
                                        return True

                                    if self.maximum_delay is not None:
                                        return True

                                    if self.minimum_delay is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Timers.Throttle.Lsa']['meta_info']


                            class Spf(object):
                                """
                                SPF throttle timers
                                
                                .. attribute:: first_delay
                                
                                	Initial delay between receiving a change and starting SPF in ms
                                	**type**\:  int
                                
                                	**range:** 1..600000
                                
                                .. attribute:: maximum_delay
                                
                                	Maximum wait time between consecutive SPF calculations in ms
                                	**type**\:  int
                                
                                	**range:** 1..600000
                                
                                .. attribute:: minimum_delay
                                
                                	Minimum hold time between consecutive SPF calculations in ms
                                	**type**\:  int
                                
                                	**range:** 1..600000
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.first_delay = None
                                    self.maximum_delay = None
                                    self.minimum_delay = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:spf'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.first_delay is not None:
                                        return True

                                    if self.maximum_delay is not None:
                                        return True

                                    if self.minimum_delay is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Timers.Throttle.Spf']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:throttle'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.lsa is not None and self.lsa._has_data():
                                    return True

                                if self.spf is not None and self.spf._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Timers.Throttle']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:timers'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.lsa_timers is not None and self.lsa_timers._has_data():
                                return True

                            if self.pacing is not None and self.pacing._has_data():
                                return True

                            if self.throttle is not None and self.throttle._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Timers']['meta_info']


                    class SummaryPrefixes(object):
                        """
                        Summarize redistributed routes matching
                        prefix/length
                        
                        .. attribute:: summary_prefix
                        
                        	IPv6 address
                        	**type**\: list of    :py:class:`SummaryPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefix>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.summary_prefix = YList()
                            self.summary_prefix.parent = self
                            self.summary_prefix.name = 'summary_prefix'


                        class SummaryPrefix(object):
                            """
                            IPv6 address
                            
                            .. attribute:: prefix  <key>
                            
                            	IPv6 prefix string format
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: prefix_length  <key>
                            
                            	IPV6 prefix length
                            	**type**\:  int
                            
                            	**range:** 0..128
                            
                            .. attribute:: not_advertise
                            
                            	Suppress routes matching prefix/length
                            	**type**\:  bool
                            
                            .. attribute:: tag
                            
                            	Tag
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.prefix = None
                                self.prefix_length = None
                                self.not_advertise = None
                                self.tag = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.prefix is None:
                                    raise YPYModelError('Key property prefix is None')
                                if self.prefix_length is None:
                                    raise YPYModelError('Key property prefix_length is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:summary-prefix[Cisco-IOS-XR-ipv6-ospfv3-cfg:prefix = ' + str(self.prefix) + '][Cisco-IOS-XR-ipv6-ospfv3-cfg:prefix-length = ' + str(self.prefix_length) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.prefix is not None:
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.not_advertise is not None:
                                    return True

                                if self.tag is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefix']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:summary-prefixes'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.summary_prefix is not None:
                                for child_ref in self.summary_prefix:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes']['meta_info']


                    class Snmp(object):
                        """
                        SNMP configuration
                        
                        .. attribute:: context
                        
                        	SNMP context configuration
                        	**type**\:  str
                        
                        .. attribute:: trap_rate_limit
                        
                        	SNMP trap rate configuration
                        	**type**\:   :py:class:`TrapRateLimit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Snmp.TrapRateLimit>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.context = None
                            self.trap_rate_limit = Ospfv3.Processes.Process.Vrfs.Vrf.Snmp.TrapRateLimit()
                            self.trap_rate_limit.parent = self


                        class TrapRateLimit(object):
                            """
                            SNMP trap rate configuration
                            
                            .. attribute:: max_window_traps
                            
                            	Max number of traps sent in window time
                            	**type**\:  int
                            
                            	**range:** 0..300
                            
                            .. attribute:: window_size
                            
                            	Trap rate limit sliding window size
                            	**type**\:  int
                            
                            	**range:** 2..60
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.max_window_traps = None
                                self.window_size = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:trap-rate-limit'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.max_window_traps is not None:
                                    return True

                                if self.window_size is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Snmp.TrapRateLimit']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:snmp'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.context is not None:
                                return True

                            if self.trap_rate_limit is not None and self.trap_rate_limit._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Snmp']['meta_info']


                    class FastReroute(object):
                        """
                        Fast\-reroute instance scoped parameters
                        
                        .. attribute:: per_link
                        
                        	Fast\-reroute per\-link global configuration
                        	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.FastReroute.PerLink>`
                        
                        .. attribute:: per_prefix
                        
                        	Fast\-reroute per\-prefix global configuration
                        	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.per_link = Ospfv3.Processes.Process.Vrfs.Vrf.FastReroute.PerLink()
                            self.per_link.parent = self
                            self.per_prefix = Ospfv3.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix()
                            self.per_prefix.parent = self


                        class PerLink(object):
                            """
                            Fast\-reroute per\-link global configuration
                            
                            .. attribute:: priority
                            
                            	Fast\-reroute per\-link/per\-prefix priority\-limit command
                            	**type**\:   :py:class:`Ospfv3FastReroutePriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3FastReroutePriorityEnum>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.priority = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-link'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.priority is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.FastReroute.PerLink']['meta_info']


                        class PerPrefix(object):
                            """
                            Fast\-reroute per\-prefix global configuration
                            
                            .. attribute:: load_sharing_disable
                            
                            	Disable load sharing between multiple backups
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: priority
                            
                            	Fast\-reroute per\-link/per\-prefix priority\-limit command
                            	**type**\:   :py:class:`Ospfv3FastReroutePriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3FastReroutePriorityEnum>`
                            
                            .. attribute:: tiebreakers
                            
                            	Fast\-reroute tiebreakers configurations
                            	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.load_sharing_disable = None
                                self.priority = None
                                self.tiebreakers = Ospfv3.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers()
                                self.tiebreakers.parent = self


                            class Tiebreakers(object):
                                """
                                Fast\-reroute tiebreakers configurations
                                
                                .. attribute:: tiebreaker
                                
                                	Fast\-reroute tiebreakers configuration
                                	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.tiebreaker = YList()
                                    self.tiebreaker.parent = self
                                    self.tiebreaker.name = 'tiebreaker'


                                class Tiebreaker(object):
                                    """
                                    Fast\-reroute tiebreakers configuration
                                    
                                    .. attribute:: tiebreaker_type  <key>
                                    
                                    	Tiebreaker type
                                    	**type**\:   :py:class:`Ospfv3FastRerouteTiebreakersEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3FastRerouteTiebreakersEnum>`
                                    
                                    .. attribute:: tiebreaker_index
                                    
                                    	Index value for a tiebreaker
                                    	**type**\:  int
                                    
                                    	**range:** 1..255
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tiebreaker_type = None
                                        self.tiebreaker_index = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.tiebreaker_type is None:
                                            raise YPYModelError('Key property tiebreaker_type is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:tiebreaker[Cisco-IOS-XR-ipv6-ospfv3-cfg:tiebreaker-type = ' + str(self.tiebreaker_type) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tiebreaker_type is not None:
                                            return True

                                        if self.tiebreaker_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers.Tiebreaker']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:tiebreakers'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.tiebreaker is not None:
                                        for child_ref in self.tiebreaker:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.load_sharing_disable is not None:
                                    return True

                                if self.priority is not None:
                                    return True

                                if self.tiebreakers is not None and self.tiebreakers._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:fast-reroute'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.per_link is not None and self.per_link._has_data():
                                return True

                            if self.per_prefix is not None and self.per_prefix._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.FastReroute']['meta_info']


                    class Distance(object):
                        """
                        Define an administrative distance
                        
                        .. attribute:: administrative
                        
                        	Define an administrative distance
                        	**type**\:  int
                        
                        	**range:** 1..255
                        
                        .. attribute:: ospfv3
                        
                        	OSPFv3 administrative distance
                        	**type**\:   :py:class:`Ospfv3_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Distance.Ospfv3_>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.administrative = None
                            self.ospfv3 = Ospfv3.Processes.Process.Vrfs.Vrf.Distance.Ospfv3_()
                            self.ospfv3.parent = self


                        class Ospfv3_(object):
                            """
                            OSPFv3 administrative distance
                            
                            .. attribute:: external
                            
                            	Distance for external type 5 and type 7 routes
                            	**type**\:  int
                            
                            	**range:** 1..255
                            
                            .. attribute:: inter_area
                            
                            	Distance for inter\-area routes
                            	**type**\:  int
                            
                            	**range:** 1..255
                            
                            .. attribute:: intra_area
                            
                            	Distance for intra\-area routes
                            	**type**\:  int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.external = None
                                self.inter_area = None
                                self.intra_area = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:ospfv3'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.external is not None:
                                    return True

                                if self.inter_area is not None:
                                    return True

                                if self.intra_area is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Distance.Ospfv3_']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:distance'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.administrative is not None:
                                return True

                            if self.ospfv3 is not None and self.ospfv3._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Distance']['meta_info']


                    class Maximum(object):
                        """
                        Set OSPFv3 limits
                        
                        .. attribute:: interfaces
                        
                        	Specify maximum number of interfaces
                        	**type**\:  int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: paths
                        
                        	Specify maximum number of paths per route
                        	**type**\:  int
                        
                        	**range:** 1..64
                        
                        .. attribute:: redistributed_prefixes
                        
                        	Limit number of redistributed prefixes
                        	**type**\:   :py:class:`RedistributedPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Maximum.RedistributedPrefixes>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interfaces = None
                            self.paths = None
                            self.redistributed_prefixes = Ospfv3.Processes.Process.Vrfs.Vrf.Maximum.RedistributedPrefixes()
                            self.redistributed_prefixes.parent = self


                        class RedistributedPrefixes(object):
                            """
                            Limit number of redistributed prefixes
                            
                            .. attribute:: prefixes
                            
                            	Maximum number of prefixes redistributed to protocol
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: threshold
                            
                            	Threshold value (%) at which to generate a warning message
                            	**type**\:  int
                            
                            	**range:** 1..100
                            
                            .. attribute:: warning_only
                            
                            	Only give warning message when limit is exceeded
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.prefixes = None
                                self.threshold = None
                                self.warning_only = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:redistributed-prefixes'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.prefixes is not None:
                                    return True

                                if self.threshold is not None:
                                    return True

                                if self.warning_only is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Maximum.RedistributedPrefixes']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:maximum'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interfaces is not None:
                                return True

                            if self.paths is not None:
                                return True

                            if self.redistributed_prefixes is not None and self.redistributed_prefixes._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Maximum']['meta_info']


                    class Redistributes(object):
                        """
                        Redistribute information from another routing
                        protocol
                        
                        .. attribute:: redistribute
                        
                        	Redistribute information from another routing protocol
                        	**type**\: list of    :py:class:`Redistribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Redistributes.Redistribute>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.redistribute = YList()
                            self.redistribute.parent = self
                            self.redistribute.name = 'redistribute'


                        class Redistribute(object):
                            """
                            Redistribute information from another routing
                            protocol
                            
                            .. attribute:: protocol_name  <key>
                            
                            	Protocol
                            	**type**\:   :py:class:`Ospfv3ProtocolType2Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3ProtocolType2Enum>`
                            
                            .. attribute:: bgp
                            
                            	bgp
                            	**type**\: list of    :py:class:`Bgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Redistributes.Redistribute.Bgp>`
                            
                            .. attribute:: connected_or_static_or_subscriber_or_mobile
                            
                            	connected or static or subscriber or mobile
                            	**type**\:   :py:class:`ConnectedOrStaticOrSubscriberOrMobile <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Redistributes.Redistribute.ConnectedOrStaticOrSubscriberOrMobile>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: eigrp
                            
                            	eigrp
                            	**type**\: list of    :py:class:`Eigrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Redistributes.Redistribute.Eigrp>`
                            
                            .. attribute:: ospfv3_or_isis_or_application
                            
                            	ospfv3 or isis or application
                            	**type**\: list of    :py:class:`Ospfv3OrIsisOrApplication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Redistributes.Redistribute.Ospfv3OrIsisOrApplication>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.protocol_name = None
                                self.bgp = YList()
                                self.bgp.parent = self
                                self.bgp.name = 'bgp'
                                self.connected_or_static_or_subscriber_or_mobile = None
                                self.eigrp = YList()
                                self.eigrp.parent = self
                                self.eigrp.name = 'eigrp'
                                self.ospfv3_or_isis_or_application = YList()
                                self.ospfv3_or_isis_or_application.parent = self
                                self.ospfv3_or_isis_or_application.name = 'ospfv3_or_isis_or_application'


                            class ConnectedOrStaticOrSubscriberOrMobile(object):
                                """
                                connected or static or subscriber or mobile
                                
                                .. attribute:: default_metric
                                
                                	OSPFv3 default metric
                                	**type**\:  int
                                
                                	**range:** 0..16777214
                                
                                .. attribute:: eigrp_route_type
                                
                                	EIGRP route type
                                	**type**\:   :py:class:`Ospfv3EigrpRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EigrpRouteEnum>`
                                
                                .. attribute:: external_route_type
                                
                                	Redistribute OSPFv3 external routes
                                	**type**\:   :py:class:`Ospfv3ExternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3ExternalRouteEnum>`
                                
                                .. attribute:: internal_route_type
                                
                                	Redistribute OSPFv3 routes
                                	**type**\:   :py:class:`Ospfv3InternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3InternalRouteEnum>`
                                
                                .. attribute:: isis_route_type
                                
                                	ISIS route type
                                	**type**\:   :py:class:`Ospfv3IsisRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3IsisRouteEnum>`
                                
                                .. attribute:: metric_type
                                
                                	OSPFv3 exterior metric type for redistributed routes
                                	**type**\:   :py:class:`Ospfv3MetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3MetricEnum>`
                                
                                .. attribute:: nssa_external_route_type
                                
                                	Redistribute OSPFv3 NSSA external routes
                                	**type**\:   :py:class:`Ospfv3NssaExternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3NssaExternalRouteEnum>`
                                
                                .. attribute:: preserve_med
                                
                                	Preserve (Multi\-Exit Discriminator) of BGP routes
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: preserve_med_info
                                
                                	Preserve Information (Multi\-Exit Discriminator) of BGP routes
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: redistribute_route
                                
                                	Redistribution of OSPFv3 routes
                                	**type**\:  bool
                                
                                .. attribute:: route_policy_name
                                
                                	Route policy to redistribution
                                	**type**\:  str
                                
                                .. attribute:: tag
                                
                                	Tag for routes redistributed into OSPFv3
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: _is_presence
                                
                                	Is present if this instance represents presence container else not
                                	**type**\: bool
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self._is_presence = True
                                    self.default_metric = None
                                    self.eigrp_route_type = None
                                    self.external_route_type = None
                                    self.internal_route_type = None
                                    self.isis_route_type = None
                                    self.metric_type = None
                                    self.nssa_external_route_type = None
                                    self.preserve_med = None
                                    self.preserve_med_info = None
                                    self.redistribute_route = None
                                    self.route_policy_name = None
                                    self.tag = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:connected-or-static-or-subscriber-or-mobile'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self._is_presence:
                                        return True
                                    if self.default_metric is not None:
                                        return True

                                    if self.eigrp_route_type is not None:
                                        return True

                                    if self.external_route_type is not None:
                                        return True

                                    if self.internal_route_type is not None:
                                        return True

                                    if self.isis_route_type is not None:
                                        return True

                                    if self.metric_type is not None:
                                        return True

                                    if self.nssa_external_route_type is not None:
                                        return True

                                    if self.preserve_med is not None:
                                        return True

                                    if self.preserve_med_info is not None:
                                        return True

                                    if self.redistribute_route is not None:
                                        return True

                                    if self.route_policy_name is not None:
                                        return True

                                    if self.tag is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Redistributes.Redistribute.ConnectedOrStaticOrSubscriberOrMobile']['meta_info']


                            class Bgp(object):
                                """
                                bgp
                                
                                .. attribute:: as_xx  <key>
                                
                                	4\-byte AS number in asdot (X.Y) format \- first half (X)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: as_yy  <key>
                                
                                	4\-byte AS number in asdot (X.Y) format \- second half (Y), or 2\-byte AS number, or 4\-byte AS number in asplain format
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: default_metric
                                
                                	OSPFv3 default metric
                                	**type**\:  int
                                
                                	**range:** 0..16777214
                                
                                .. attribute:: eigrp_route_type
                                
                                	EIGRP route type
                                	**type**\:   :py:class:`Ospfv3EigrpRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EigrpRouteEnum>`
                                
                                .. attribute:: external_route_type
                                
                                	Redistribute OSPFv3 external routes
                                	**type**\:   :py:class:`Ospfv3ExternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3ExternalRouteEnum>`
                                
                                .. attribute:: internal_route_type
                                
                                	Redistribute OSPFv3 routes
                                	**type**\:   :py:class:`Ospfv3InternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3InternalRouteEnum>`
                                
                                .. attribute:: isis_route_type
                                
                                	ISIS route type
                                	**type**\:   :py:class:`Ospfv3IsisRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3IsisRouteEnum>`
                                
                                .. attribute:: metric_type
                                
                                	OSPFv3 exterior metric type for redistributed routes
                                	**type**\:   :py:class:`Ospfv3MetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3MetricEnum>`
                                
                                .. attribute:: nssa_external_route_type
                                
                                	Redistribute OSPFv3 NSSA external routes
                                	**type**\:   :py:class:`Ospfv3NssaExternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3NssaExternalRouteEnum>`
                                
                                .. attribute:: preserve_med
                                
                                	Preserve (Multi\-Exit Discriminator) of BGP routes
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: preserve_med_info
                                
                                	Preserve Information (Multi\-Exit Discriminator) of BGP routes
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: redistribute_route
                                
                                	Redistribution of OSPFv3 routes
                                	**type**\:  bool
                                
                                .. attribute:: route_policy_name
                                
                                	Route policy to redistribution
                                	**type**\:  str
                                
                                .. attribute:: tag
                                
                                	Tag for routes redistributed into OSPFv3
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.as_xx = None
                                    self.as_yy = None
                                    self.default_metric = None
                                    self.eigrp_route_type = None
                                    self.external_route_type = None
                                    self.internal_route_type = None
                                    self.isis_route_type = None
                                    self.metric_type = None
                                    self.nssa_external_route_type = None
                                    self.preserve_med = None
                                    self.preserve_med_info = None
                                    self.redistribute_route = None
                                    self.route_policy_name = None
                                    self.tag = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.as_xx is None:
                                        raise YPYModelError('Key property as_xx is None')
                                    if self.as_yy is None:
                                        raise YPYModelError('Key property as_yy is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:bgp[Cisco-IOS-XR-ipv6-ospfv3-cfg:as-xx = ' + str(self.as_xx) + '][Cisco-IOS-XR-ipv6-ospfv3-cfg:as-yy = ' + str(self.as_yy) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.as_xx is not None:
                                        return True

                                    if self.as_yy is not None:
                                        return True

                                    if self.default_metric is not None:
                                        return True

                                    if self.eigrp_route_type is not None:
                                        return True

                                    if self.external_route_type is not None:
                                        return True

                                    if self.internal_route_type is not None:
                                        return True

                                    if self.isis_route_type is not None:
                                        return True

                                    if self.metric_type is not None:
                                        return True

                                    if self.nssa_external_route_type is not None:
                                        return True

                                    if self.preserve_med is not None:
                                        return True

                                    if self.preserve_med_info is not None:
                                        return True

                                    if self.redistribute_route is not None:
                                        return True

                                    if self.route_policy_name is not None:
                                        return True

                                    if self.tag is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Redistributes.Redistribute.Bgp']['meta_info']


                            class Ospfv3OrIsisOrApplication(object):
                                """
                                ospfv3 or isis or application
                                
                                .. attribute:: process_name  <key>
                                
                                	ISIS process name if protocol is ISIS, or OSPFv3 process name if protocol is OSPFv3
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: default_metric
                                
                                	OSPFv3 default metric
                                	**type**\:  int
                                
                                	**range:** 0..16777214
                                
                                .. attribute:: eigrp_route_type
                                
                                	EIGRP route type
                                	**type**\:   :py:class:`Ospfv3EigrpRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EigrpRouteEnum>`
                                
                                .. attribute:: external_route_type
                                
                                	Redistribute OSPFv3 external routes
                                	**type**\:   :py:class:`Ospfv3ExternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3ExternalRouteEnum>`
                                
                                .. attribute:: internal_route_type
                                
                                	Redistribute OSPFv3 routes
                                	**type**\:   :py:class:`Ospfv3InternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3InternalRouteEnum>`
                                
                                .. attribute:: isis_route_type
                                
                                	ISIS route type
                                	**type**\:   :py:class:`Ospfv3IsisRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3IsisRouteEnum>`
                                
                                .. attribute:: metric_type
                                
                                	OSPFv3 exterior metric type for redistributed routes
                                	**type**\:   :py:class:`Ospfv3MetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3MetricEnum>`
                                
                                .. attribute:: nssa_external_route_type
                                
                                	Redistribute OSPFv3 NSSA external routes
                                	**type**\:   :py:class:`Ospfv3NssaExternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3NssaExternalRouteEnum>`
                                
                                .. attribute:: preserve_med
                                
                                	Preserve (Multi\-Exit Discriminator) of BGP routes
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: preserve_med_info
                                
                                	Preserve Information (Multi\-Exit Discriminator) of BGP routes
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: redistribute_route
                                
                                	Redistribution of OSPFv3 routes
                                	**type**\:  bool
                                
                                .. attribute:: route_policy_name
                                
                                	Route policy to redistribution
                                	**type**\:  str
                                
                                .. attribute:: tag
                                
                                	Tag for routes redistributed into OSPFv3
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.process_name = None
                                    self.default_metric = None
                                    self.eigrp_route_type = None
                                    self.external_route_type = None
                                    self.internal_route_type = None
                                    self.isis_route_type = None
                                    self.metric_type = None
                                    self.nssa_external_route_type = None
                                    self.preserve_med = None
                                    self.preserve_med_info = None
                                    self.redistribute_route = None
                                    self.route_policy_name = None
                                    self.tag = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.process_name is None:
                                        raise YPYModelError('Key property process_name is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:ospfv3-or-isis-or-application[Cisco-IOS-XR-ipv6-ospfv3-cfg:process-name = ' + str(self.process_name) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.process_name is not None:
                                        return True

                                    if self.default_metric is not None:
                                        return True

                                    if self.eigrp_route_type is not None:
                                        return True

                                    if self.external_route_type is not None:
                                        return True

                                    if self.internal_route_type is not None:
                                        return True

                                    if self.isis_route_type is not None:
                                        return True

                                    if self.metric_type is not None:
                                        return True

                                    if self.nssa_external_route_type is not None:
                                        return True

                                    if self.preserve_med is not None:
                                        return True

                                    if self.preserve_med_info is not None:
                                        return True

                                    if self.redistribute_route is not None:
                                        return True

                                    if self.route_policy_name is not None:
                                        return True

                                    if self.tag is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Redistributes.Redistribute.Ospfv3OrIsisOrApplication']['meta_info']


                            class Eigrp(object):
                                """
                                eigrp
                                
                                .. attribute:: as_xx  <key>
                                
                                	4\-byte AS number in asdot (X.Y) format \- first half (X)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: default_metric
                                
                                	OSPFv3 default metric
                                	**type**\:  int
                                
                                	**range:** 0..16777214
                                
                                .. attribute:: eigrp_route_type
                                
                                	EIGRP route type
                                	**type**\:   :py:class:`Ospfv3EigrpRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EigrpRouteEnum>`
                                
                                .. attribute:: external_route_type
                                
                                	Redistribute OSPFv3 external routes
                                	**type**\:   :py:class:`Ospfv3ExternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3ExternalRouteEnum>`
                                
                                .. attribute:: internal_route_type
                                
                                	Redistribute OSPFv3 routes
                                	**type**\:   :py:class:`Ospfv3InternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3InternalRouteEnum>`
                                
                                .. attribute:: isis_route_type
                                
                                	ISIS route type
                                	**type**\:   :py:class:`Ospfv3IsisRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3IsisRouteEnum>`
                                
                                .. attribute:: metric_type
                                
                                	OSPFv3 exterior metric type for redistributed routes
                                	**type**\:   :py:class:`Ospfv3MetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3MetricEnum>`
                                
                                .. attribute:: nssa_external_route_type
                                
                                	Redistribute OSPFv3 NSSA external routes
                                	**type**\:   :py:class:`Ospfv3NssaExternalRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3NssaExternalRouteEnum>`
                                
                                .. attribute:: preserve_med
                                
                                	Preserve (Multi\-Exit Discriminator) of BGP routes
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: preserve_med_info
                                
                                	Preserve Information (Multi\-Exit Discriminator) of BGP routes
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: redistribute_route
                                
                                	Redistribution of OSPFv3 routes
                                	**type**\:  bool
                                
                                .. attribute:: route_policy_name
                                
                                	Route policy to redistribution
                                	**type**\:  str
                                
                                .. attribute:: tag
                                
                                	Tag for routes redistributed into OSPFv3
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.as_xx = None
                                    self.default_metric = None
                                    self.eigrp_route_type = None
                                    self.external_route_type = None
                                    self.internal_route_type = None
                                    self.isis_route_type = None
                                    self.metric_type = None
                                    self.nssa_external_route_type = None
                                    self.preserve_med = None
                                    self.preserve_med_info = None
                                    self.redistribute_route = None
                                    self.route_policy_name = None
                                    self.tag = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.as_xx is None:
                                        raise YPYModelError('Key property as_xx is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:eigrp[Cisco-IOS-XR-ipv6-ospfv3-cfg:as-xx = ' + str(self.as_xx) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.as_xx is not None:
                                        return True

                                    if self.default_metric is not None:
                                        return True

                                    if self.eigrp_route_type is not None:
                                        return True

                                    if self.external_route_type is not None:
                                        return True

                                    if self.internal_route_type is not None:
                                        return True

                                    if self.isis_route_type is not None:
                                        return True

                                    if self.metric_type is not None:
                                        return True

                                    if self.nssa_external_route_type is not None:
                                        return True

                                    if self.preserve_med is not None:
                                        return True

                                    if self.preserve_med_info is not None:
                                        return True

                                    if self.redistribute_route is not None:
                                        return True

                                    if self.route_policy_name is not None:
                                        return True

                                    if self.tag is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Redistributes.Redistribute.Eigrp']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.protocol_name is None:
                                    raise YPYModelError('Key property protocol_name is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:redistribute[Cisco-IOS-XR-ipv6-ospfv3-cfg:protocol-name = ' + str(self.protocol_name) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.protocol_name is not None:
                                    return True

                                if self.bgp is not None:
                                    for child_ref in self.bgp:
                                        if child_ref._has_data():
                                            return True

                                if self.connected_or_static_or_subscriber_or_mobile is not None and self.connected_or_static_or_subscriber_or_mobile._has_data():
                                    return True

                                if self.eigrp is not None:
                                    for child_ref in self.eigrp:
                                        if child_ref._has_data():
                                            return True

                                if self.ospfv3_or_isis_or_application is not None:
                                    for child_ref in self.ospfv3_or_isis_or_application:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Redistributes.Redistribute']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:redistributes'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.redistribute is not None:
                                for child_ref in self.redistribute:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Redistributes']['meta_info']


                    class Ignore(object):
                        """
                        Do not complain about a specified event
                        
                        .. attribute:: lsa
                        
                        	Do not complain upon receiving LSA of the specified type
                        	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.Ignore.Lsa>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.lsa = Ospfv3.Processes.Process.Vrfs.Vrf.Ignore.Lsa()
                            self.lsa.parent = self


                        class Lsa(object):
                            """
                            Do not complain upon receiving LSA of the
                            specified type
                            
                            .. attribute:: mospf
                            
                            	Enable ignore of MOSPF type 6 LSA
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mospf = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:lsa'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mospf is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Ignore.Lsa']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:ignore'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.lsa is not None and self.lsa._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Ignore']['meta_info']


                    class DistributeListOut(object):
                        """
                        Filter prefixes from RIB 
                        
                        .. attribute:: distribute_outs
                        
                        	Filter generated type\-5 LSAs
                        	**type**\:   :py:class:`DistributeOuts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.DistributeListOut.DistributeOuts>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.distribute_outs = Ospfv3.Processes.Process.Vrfs.Vrf.DistributeListOut.DistributeOuts()
                            self.distribute_outs.parent = self


                        class DistributeOuts(object):
                            """
                            Filter generated type\-5 LSAs
                            
                            .. attribute:: distribute_out
                            
                            	Filter generated type\-5 LSAs
                            	**type**\: list of    :py:class:`DistributeOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.DistributeListOut.DistributeOuts.DistributeOut>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.distribute_out = YList()
                                self.distribute_out.parent = self
                                self.distribute_out.name = 'distribute_out'


                            class DistributeOut(object):
                                """
                                Filter generated type\-5 LSAs
                                
                                .. attribute:: protocol_name  <key>
                                
                                	none
                                	**type**\:   :py:class:`Ospfv3ProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3ProtocolEnum>`
                                
                                .. attribute:: as_yy_and_as_xx_and_process_name
                                
                                	keys\: as\-yy, as\-xx, process\-name
                                	**type**\: list of    :py:class:`AsYyAndAsXxAndProcessName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.DistributeListOut.DistributeOuts.DistributeOut.AsYyAndAsXxAndProcessName>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.protocol_name = None
                                    self.as_yy_and_as_xx_and_process_name = YList()
                                    self.as_yy_and_as_xx_and_process_name.parent = self
                                    self.as_yy_and_as_xx_and_process_name.name = 'as_yy_and_as_xx_and_process_name'


                                class AsYyAndAsXxAndProcessName(object):
                                    """
                                    keys\: as\-yy, as\-xx, process\-name
                                    
                                    .. attribute:: as_xx  <key>
                                    
                                    	4\-byte AS number in asdot (X.Y) format \- first half (X)
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: as_yy  <key>
                                    
                                    	4\-byte AS number in asdot (X.Y) format \- second half (Y), or 2\-byte AS number, or 4\-byte AS number in asplain format
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_name  <key>
                                    
                                    	If ISIS or OSPFv3, specify the instance name
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Prefix\-list name
                                    	**type**\:  str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.as_xx = None
                                        self.as_yy = None
                                        self.process_name = None
                                        self.prefix_list = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.as_xx is None:
                                            raise YPYModelError('Key property as_xx is None')
                                        if self.as_yy is None:
                                            raise YPYModelError('Key property as_yy is None')
                                        if self.process_name is None:
                                            raise YPYModelError('Key property process_name is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:as-yy-and-as-xx-and-process-name[Cisco-IOS-XR-ipv6-ospfv3-cfg:as-xx = ' + str(self.as_xx) + '][Cisco-IOS-XR-ipv6-ospfv3-cfg:as-yy = ' + str(self.as_yy) + '][Cisco-IOS-XR-ipv6-ospfv3-cfg:process-name = ' + str(self.process_name) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.as_xx is not None:
                                            return True

                                        if self.as_yy is not None:
                                            return True

                                        if self.process_name is not None:
                                            return True

                                        if self.prefix_list is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DistributeListOut.DistributeOuts.DistributeOut.AsYyAndAsXxAndProcessName']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.protocol_name is None:
                                        raise YPYModelError('Key property protocol_name is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:distribute-out[Cisco-IOS-XR-ipv6-ospfv3-cfg:protocol-name = ' + str(self.protocol_name) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.protocol_name is not None:
                                        return True

                                    if self.as_yy_and_as_xx_and_process_name is not None:
                                        for child_ref in self.as_yy_and_as_xx_and_process_name:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DistributeListOut.DistributeOuts.DistributeOut']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:distribute-outs'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.distribute_out is not None:
                                    for child_ref in self.distribute_out:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DistributeListOut.DistributeOuts']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:distribute-list-out'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.distribute_outs is not None and self.distribute_outs._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DistributeListOut']['meta_info']


                    class DistributeList(object):
                        """
                        Filter prefixes to/from RIB
                        
                        .. attribute:: in_
                        
                        	Filter prefixes installed to RIB
                        	**type**\:   :py:class:`In_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.DistributeList.In_>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.in_ = Ospfv3.Processes.Process.Vrfs.Vrf.DistributeList.In_()
                            self.in_.parent = self


                        class In_(object):
                            """
                            Filter prefixes installed to RIB
                            
                            .. attribute:: prefix_list
                            
                            	Filter prefixes based on an IPv6 prefix\-list
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.prefix_list = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:in'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.prefix_list is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DistributeList.In_']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:distribute-list'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.in_ is not None and self.in_._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DistributeList']['meta_info']


                    class StubRouter(object):
                        """
                        Stub router configuration
                        
                        .. attribute:: max_metric
                        
                        	Stub router max\-metric configuration
                        	**type**\:   :py:class:`MaxMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.StubRouter.MaxMetric>`
                        
                        .. attribute:: rbit
                        
                        	Stub router R\-bit configuration
                        	**type**\:   :py:class:`Rbit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.StubRouter.Rbit>`
                        
                        .. attribute:: v6bit
                        
                        	Stub router V6\-bit configuration
                        	**type**\:   :py:class:`V6Bit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.StubRouter.V6Bit>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.max_metric = Ospfv3.Processes.Process.Vrfs.Vrf.StubRouter.MaxMetric()
                            self.max_metric.parent = self
                            self.rbit = Ospfv3.Processes.Process.Vrfs.Vrf.StubRouter.Rbit()
                            self.rbit.parent = self
                            self.v6bit = Ospfv3.Processes.Process.Vrfs.Vrf.StubRouter.V6Bit()
                            self.v6bit.parent = self


                        class Rbit(object):
                            """
                            Stub router R\-bit configuration
                            
                            .. attribute:: always
                            
                            	Unconditionally enter stub router operational state
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: enable
                            
                            	Enabled stub router configuration mode
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: external_lsa
                            
                            	Advertise external LSAs with modified metric in stub router mode
                            	**type**\:  int
                            
                            	**range:** 1..16777214
                            
                            	**default value**\: 16711680
                            
                            .. attribute:: include_stub
                            
                            	Advertise stub links with maximum metric in stub router mode
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: on_proc_migration
                            
                            	Time (in seconds) to stay in stub router operational state
                            	**type**\:  int
                            
                            	**range:** 5..86400
                            
                            	**units**\: second
                            
                            .. attribute:: on_proc_restart
                            
                            	Time (in seconds) to stay in stub router operational state
                            	**type**\:  int
                            
                            	**range:** 5..86400
                            
                            	**units**\: second
                            
                            .. attribute:: on_startup
                            
                            	Enter stub router operational state on startup
                            	**type**\:   :py:class:`OnStartup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.StubRouter.Rbit.OnStartup>`
                            
                            .. attribute:: on_switchover
                            
                            	Time (in seconds) to stay in stub router operational state
                            	**type**\:  int
                            
                            	**range:** 5..86400
                            
                            	**units**\: second
                            
                            .. attribute:: summary_lsa
                            
                            	Advertise summary LSAs with modified metric in stub router mode
                            	**type**\:  int
                            
                            	**range:** 1..16777214
                            
                            	**default value**\: 16711680
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.always = None
                                self.enable = None
                                self.external_lsa = None
                                self.include_stub = None
                                self.on_proc_migration = None
                                self.on_proc_restart = None
                                self.on_startup = Ospfv3.Processes.Process.Vrfs.Vrf.StubRouter.Rbit.OnStartup()
                                self.on_startup.parent = self
                                self.on_switchover = None
                                self.summary_lsa = None


                            class OnStartup(object):
                                """
                                Enter stub router operational state on startup
                                
                                .. attribute:: wait_for_bgp
                                
                                	Wait until BGP converges (only applicable to default VRF)
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: wait_time
                                
                                	Time (in seconds) to stay in stub router operational state
                                	**type**\:  int
                                
                                	**range:** 5..86400
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.wait_for_bgp = None
                                    self.wait_time = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:on-startup'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.wait_for_bgp is not None:
                                        return True

                                    if self.wait_time is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.StubRouter.Rbit.OnStartup']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:rbit'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.always is not None:
                                    return True

                                if self.enable is not None:
                                    return True

                                if self.external_lsa is not None:
                                    return True

                                if self.include_stub is not None:
                                    return True

                                if self.on_proc_migration is not None:
                                    return True

                                if self.on_proc_restart is not None:
                                    return True

                                if self.on_startup is not None and self.on_startup._has_data():
                                    return True

                                if self.on_switchover is not None:
                                    return True

                                if self.summary_lsa is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.StubRouter.Rbit']['meta_info']


                        class V6Bit(object):
                            """
                            Stub router V6\-bit configuration
                            
                            .. attribute:: always
                            
                            	Unconditionally enter stub router operational state
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: enable
                            
                            	Enabled stub router configuration mode
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: external_lsa
                            
                            	Advertise external LSAs with modified metric in stub router mode
                            	**type**\:  int
                            
                            	**range:** 1..16777214
                            
                            	**default value**\: 16711680
                            
                            .. attribute:: include_stub
                            
                            	Advertise stub links with maximum metric in stub router mode
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: on_proc_migration
                            
                            	Time (in seconds) to stay in stub router operational state
                            	**type**\:  int
                            
                            	**range:** 5..86400
                            
                            	**units**\: second
                            
                            .. attribute:: on_proc_restart
                            
                            	Time (in seconds) to stay in stub router operational state
                            	**type**\:  int
                            
                            	**range:** 5..86400
                            
                            	**units**\: second
                            
                            .. attribute:: on_startup
                            
                            	Enter stub router operational state on startup
                            	**type**\:   :py:class:`OnStartup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.StubRouter.V6Bit.OnStartup>`
                            
                            .. attribute:: on_switchover
                            
                            	Time (in seconds) to stay in stub router operational state
                            	**type**\:  int
                            
                            	**range:** 5..86400
                            
                            	**units**\: second
                            
                            .. attribute:: summary_lsa
                            
                            	Advertise summary LSAs with modified metric in stub router mode
                            	**type**\:  int
                            
                            	**range:** 1..16777214
                            
                            	**default value**\: 16711680
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.always = None
                                self.enable = None
                                self.external_lsa = None
                                self.include_stub = None
                                self.on_proc_migration = None
                                self.on_proc_restart = None
                                self.on_startup = Ospfv3.Processes.Process.Vrfs.Vrf.StubRouter.V6Bit.OnStartup()
                                self.on_startup.parent = self
                                self.on_switchover = None
                                self.summary_lsa = None


                            class OnStartup(object):
                                """
                                Enter stub router operational state on startup
                                
                                .. attribute:: wait_for_bgp
                                
                                	Wait until BGP converges (only applicable to default VRF)
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: wait_time
                                
                                	Time (in seconds) to stay in stub router operational state
                                	**type**\:  int
                                
                                	**range:** 5..86400
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.wait_for_bgp = None
                                    self.wait_time = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:on-startup'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.wait_for_bgp is not None:
                                        return True

                                    if self.wait_time is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.StubRouter.V6Bit.OnStartup']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:v6bit'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.always is not None:
                                    return True

                                if self.enable is not None:
                                    return True

                                if self.external_lsa is not None:
                                    return True

                                if self.include_stub is not None:
                                    return True

                                if self.on_proc_migration is not None:
                                    return True

                                if self.on_proc_restart is not None:
                                    return True

                                if self.on_startup is not None and self.on_startup._has_data():
                                    return True

                                if self.on_switchover is not None:
                                    return True

                                if self.summary_lsa is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.StubRouter.V6Bit']['meta_info']


                        class MaxMetric(object):
                            """
                            Stub router max\-metric configuration
                            
                            .. attribute:: always
                            
                            	Unconditionally enter stub router operational state
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: enable
                            
                            	Enabled stub router configuration mode
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: external_lsa
                            
                            	Advertise external LSAs with modified metric in stub router mode
                            	**type**\:  int
                            
                            	**range:** 1..16777214
                            
                            	**default value**\: 16711680
                            
                            .. attribute:: include_stub
                            
                            	Advertise stub links with maximum metric in stub router mode
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: on_proc_migration
                            
                            	Time (in seconds) to stay in stub router operational state
                            	**type**\:  int
                            
                            	**range:** 5..86400
                            
                            	**units**\: second
                            
                            .. attribute:: on_proc_restart
                            
                            	Time (in seconds) to stay in stub router operational state
                            	**type**\:  int
                            
                            	**range:** 5..86400
                            
                            	**units**\: second
                            
                            .. attribute:: on_startup
                            
                            	Enter stub router operational state on startup
                            	**type**\:   :py:class:`OnStartup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.StubRouter.MaxMetric.OnStartup>`
                            
                            .. attribute:: on_switchover
                            
                            	Time (in seconds) to stay in stub router operational state
                            	**type**\:  int
                            
                            	**range:** 5..86400
                            
                            	**units**\: second
                            
                            .. attribute:: summary_lsa
                            
                            	Advertise summary LSAs with modified metric in stub router mode
                            	**type**\:  int
                            
                            	**range:** 1..16777214
                            
                            	**default value**\: 16711680
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.always = None
                                self.enable = None
                                self.external_lsa = None
                                self.include_stub = None
                                self.on_proc_migration = None
                                self.on_proc_restart = None
                                self.on_startup = Ospfv3.Processes.Process.Vrfs.Vrf.StubRouter.MaxMetric.OnStartup()
                                self.on_startup.parent = self
                                self.on_switchover = None
                                self.summary_lsa = None


                            class OnStartup(object):
                                """
                                Enter stub router operational state on startup
                                
                                .. attribute:: wait_for_bgp
                                
                                	Wait until BGP converges (only applicable to default VRF)
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: wait_time
                                
                                	Time (in seconds) to stay in stub router operational state
                                	**type**\:  int
                                
                                	**range:** 5..86400
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.wait_for_bgp = None
                                    self.wait_time = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:on-startup'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.wait_for_bgp is not None:
                                        return True

                                    if self.wait_time is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.StubRouter.MaxMetric.OnStartup']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:max-metric'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.always is not None:
                                    return True

                                if self.enable is not None:
                                    return True

                                if self.external_lsa is not None:
                                    return True

                                if self.include_stub is not None:
                                    return True

                                if self.on_proc_migration is not None:
                                    return True

                                if self.on_proc_restart is not None:
                                    return True

                                if self.on_startup is not None and self.on_startup._has_data():
                                    return True

                                if self.on_switchover is not None:
                                    return True

                                if self.summary_lsa is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.StubRouter.MaxMetric']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:stub-router'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.max_metric is not None and self.max_metric._has_data():
                                return True

                            if self.rbit is not None and self.rbit._has_data():
                                return True

                            if self.v6bit is not None and self.v6bit._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.StubRouter']['meta_info']


                    class Bfd(object):
                        """
                        Configure BFD parameters
                        
                        .. attribute:: detection_multiplier
                        
                        	Detect multiplier
                        	**type**\:  int
                        
                        	**range:** 2..50
                        
                        .. attribute:: fast_detect_mode
                        
                        	Enable or disable BFD fast detection
                        	**type**\:   :py:class:`Ospfv3BfdEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3BfdEnableModeEnum>`
                        
                        .. attribute:: interval
                        
                        	Hello interval in milli\-seconds
                        	**type**\:  int
                        
                        	**range:** 3..30000
                        
                        	**units**\: millisecond
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.detection_multiplier = None
                            self.fast_detect_mode = None
                            self.interval = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:bfd'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.detection_multiplier is not None:
                                return True

                            if self.fast_detect_mode is not None:
                                return True

                            if self.interval is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Bfd']['meta_info']


                    class DatabaseFilter(object):
                        """
                        Database filter
                        
                        .. attribute:: all
                        
                        	All
                        	**type**\:   :py:class:`All <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseFilter.All>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.all = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseFilter.All()
                            self.all.parent = self


                        class All(object):
                            """
                            All
                            
                            .. attribute:: out
                            
                            	Enable out
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.out = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:all'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.out is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseFilter.All']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:database-filter'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.all is not None and self.all._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseFilter']['meta_info']


                    class Authentication(object):
                        """
                        Authenticate OSPFv3 packets
                        
                        .. attribute:: algorithm
                        
                        	Use the MD5 or SHA1 algorithm
                        	**type**\:   :py:class:`Ospfv3AuthenticationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationEnum>`
                        
                        .. attribute:: enable
                        
                        	Authenticate packets
                        	**type**\:  bool
                        
                        .. attribute:: password
                        
                        	Specify MD5 or SHA1 password
                        	**type**\:  str
                        
                        	**pattern:** (!.+)\|([^!].+)
                        
                        .. attribute:: spi
                        
                        	Use IPSec AH authentication. Specify the Security Parameter Index (SPI) value
                        	**type**\:  int
                        
                        	**range:** 256..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.algorithm = None
                            self.enable = None
                            self.password = None
                            self.spi = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:authentication'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.algorithm is not None:
                                return True

                            if self.enable is not None:
                                return True

                            if self.password is not None:
                                return True

                            if self.spi is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Authentication']['meta_info']


                    class GracefulRestart(object):
                        """
                        Graceful restart configuration
                        
                        .. attribute:: enable
                        
                        	Enable graceful restart
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: helper
                        
                        	Disable router's helper support
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: interval
                        
                        	Minimum interval between graceful restarts (seconds)
                        	**type**\:  int
                        
                        	**range:** 90..3600
                        
                        	**units**\: second
                        
                        .. attribute:: lifetime
                        
                        	Maximum route lifetime following restart (seconds)
                        	**type**\:  int
                        
                        	**range:** 90..1800
                        
                        	**units**\: second
                        
                        .. attribute:: strict_lsa_checking
                        
                        	Terminate graceful restart helper mode if LSA changed
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.enable = None
                            self.helper = None
                            self.interval = None
                            self.lifetime = None
                            self.strict_lsa_checking = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:graceful-restart'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.enable is not None:
                                return True

                            if self.helper is not None:
                                return True

                            if self.interval is not None:
                                return True

                            if self.lifetime is not None:
                                return True

                            if self.strict_lsa_checking is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.GracefulRestart']['meta_info']


                    class DefaultInformation(object):
                        """
                        Control distribution of default information
                        
                        .. attribute:: originate
                        
                        	Distribute a default route
                        	**type**\:   :py:class:`Originate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.DefaultInformation.Originate>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.originate = None


                        class Originate(object):
                            """
                            Distribute a default route
                            
                            .. attribute:: always
                            
                            	Always advertise default route
                            	**type**\:  bool
                            
                            	**mandatory**\: True
                            
                            .. attribute:: metric
                            
                            	OSPFv3 default metric
                            	**type**\:  int
                            
                            	**range:** 0..16777214
                            
                            .. attribute:: metric_type
                            
                            	OSPFv3 metric type for default routes
                            	**type**\:  int
                            
                            	**range:** 1..2
                            
                            .. attribute:: route_policy_name
                            
                            	Route policy to default\-information origination
                            	**type**\:  str
                            
                            .. attribute:: tag
                            
                            	Tag for default route
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: _is_presence
                            
                            	Is present if this instance represents presence container else not
                            	**type**\: bool
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self._is_presence = True
                                self.always = None
                                self.metric = None
                                self.metric_type = None
                                self.route_policy_name = None
                                self.tag = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:originate'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self._is_presence:
                                    return True
                                if self.always is not None:
                                    return True

                                if self.metric is not None:
                                    return True

                                if self.metric_type is not None:
                                    return True

                                if self.route_policy_name is not None:
                                    return True

                                if self.tag is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DefaultInformation.Originate']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:default-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.originate is not None and self.originate._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DefaultInformation']['meta_info']


                    class ProcessScope(object):
                        """
                        Process scope configuration
                        
                        .. attribute:: fast_reroute
                        
                        	Fast\-reroute configuration
                        	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.fast_reroute = Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute()
                            self.fast_reroute.parent = self


                        class FastReroute(object):
                            """
                            Fast\-reroute configuration
                            
                            .. attribute:: fast_reroute_enable
                            
                            	Enable/Disable Fast\-reroute per\-link or per\-prefix
                            	**type**\:   :py:class:`Ospfv3FastRerouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3FastRerouteEnum>`
                            
                            .. attribute:: per_link
                            
                            	Fast\-reroute per\-link configuration
                            	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink>`
                            
                            .. attribute:: per_prefix
                            
                            	Fast\-reroute per\-link configuration
                            	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.fast_reroute_enable = None
                                self.per_link = Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink()
                                self.per_link.parent = self
                                self.per_prefix = Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix()
                                self.per_prefix.parent = self


                            class PerLink(object):
                                """
                                Fast\-reroute per\-link configuration
                                
                                .. attribute:: candidate_interfaces
                                
                                	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces>`
                                
                                .. attribute:: exclude_interfaces
                                
                                	Fast\-reroute per\-link/per\-prefix exclude interface configuration
                                	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces>`
                                
                                .. attribute:: fast_reroute_use_candidate_only
                                
                                	Use only interfaces on the candidate list as a backup path
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.candidate_interfaces = Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces()
                                    self.candidate_interfaces.parent = self
                                    self.exclude_interfaces = Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces()
                                    self.exclude_interfaces.parent = self
                                    self.fast_reroute_use_candidate_only = None


                                class CandidateInterfaces(object):
                                    """
                                    Fast\-reroute per\-link/per\-prefix candidate
                                    interface configuration
                                    
                                    .. attribute:: candidate_interface
                                    
                                    	Candidate backup interface
                                    	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.candidate_interface = YList()
                                        self.candidate_interface.parent = self
                                        self.candidate_interface.name = 'candidate_interface'


                                    class CandidateInterface(object):
                                        """
                                        Candidate backup interface
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.interface_name is None:
                                                raise YPYModelError('Key property interface_name is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interfaces'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.candidate_interface is not None:
                                            for child_ref in self.candidate_interface:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces']['meta_info']


                                class ExcludeInterfaces(object):
                                    """
                                    Fast\-reroute per\-link/per\-prefix exclude
                                    interface configuration
                                    
                                    .. attribute:: exclude_interface
                                    
                                    	Exclude an interface from becoming a backup
                                    	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.exclude_interface = YList()
                                        self.exclude_interface.parent = self
                                        self.exclude_interface.name = 'exclude_interface'


                                    class ExcludeInterface(object):
                                        """
                                        Exclude an interface from becoming a backup
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.interface_name is None:
                                                raise YPYModelError('Key property interface_name is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interfaces'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.exclude_interface is not None:
                                            for child_ref in self.exclude_interface:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-link'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.candidate_interfaces is not None and self.candidate_interfaces._has_data():
                                        return True

                                    if self.exclude_interfaces is not None and self.exclude_interfaces._has_data():
                                        return True

                                    if self.fast_reroute_use_candidate_only is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink']['meta_info']


                            class PerPrefix(object):
                                """
                                Fast\-reroute per\-link configuration
                                
                                .. attribute:: candidate_interfaces
                                
                                	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                
                                .. attribute:: exclude_interfaces
                                
                                	Fast\-reroute per\-link/per\-prefix exclude interface configuration
                                	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                
                                .. attribute:: fast_reroute_use_candidate_only
                                
                                	Use only interfaces on the candidate list as a backup path
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.candidate_interfaces = Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces()
                                    self.candidate_interfaces.parent = self
                                    self.exclude_interfaces = Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                    self.exclude_interfaces.parent = self
                                    self.fast_reroute_use_candidate_only = None


                                class CandidateInterfaces(object):
                                    """
                                    Fast\-reroute per\-link/per\-prefix candidate
                                    interface configuration
                                    
                                    .. attribute:: candidate_interface
                                    
                                    	Candidate backup interface
                                    	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.candidate_interface = YList()
                                        self.candidate_interface.parent = self
                                        self.candidate_interface.name = 'candidate_interface'


                                    class CandidateInterface(object):
                                        """
                                        Candidate backup interface
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.interface_name is None:
                                                raise YPYModelError('Key property interface_name is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:candidate-interfaces'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.candidate_interface is not None:
                                            for child_ref in self.candidate_interface:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces']['meta_info']


                                class ExcludeInterfaces(object):
                                    """
                                    Fast\-reroute per\-link/per\-prefix exclude
                                    interface configuration
                                    
                                    .. attribute:: exclude_interface
                                    
                                    	Exclude an interface from becoming a backup
                                    	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.exclude_interface = YList()
                                        self.exclude_interface.parent = self
                                        self.exclude_interface.name = 'exclude_interface'


                                    class ExcludeInterface(object):
                                        """
                                        Exclude an interface from becoming a backup
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-cfg'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.interface_name is None:
                                                raise YPYModelError('Key property interface_name is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interface[Cisco-IOS-XR-ipv6-ospfv3-cfg:interface-name = ' + str(self.interface_name) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return True

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:exclude-interfaces'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return True

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.exclude_interface is not None:
                                            for child_ref in self.exclude_interface:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:per-prefix'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return True

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.candidate_interfaces is not None and self.candidate_interfaces._has_data():
                                        return True

                                    if self.exclude_interfaces is not None and self.exclude_interfaces._has_data():
                                        return True

                                    if self.fast_reroute_use_candidate_only is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:fast-reroute'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return True

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.fast_reroute_enable is not None:
                                    return True

                                if self.per_link is not None and self.per_link._has_data():
                                    return True

                                if self.per_prefix is not None and self.per_prefix._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:process-scope'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.fast_reroute is not None and self.fast_reroute._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ProcessScope']['meta_info']


                    class Encryption(object):
                        """
                        Encrypt and authenticate OSPFv3 packets
                        
                        .. attribute:: authentication_algorithm
                        
                        	Use the NULL, MD5 or SHA1 algorithm
                        	**type**\:   :py:class:`Ospfv3AuthenticationType2Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AuthenticationType2Enum>`
                        
                        .. attribute:: authentication_password
                        
                        	Specify MD5 or SHA1 password
                        	**type**\:  str
                        
                        	**pattern:** (!.+)\|([^!].+)
                        
                        .. attribute:: enable
                        
                        	Authenticate packets
                        	**type**\:  bool
                        
                        .. attribute:: encryption_algorithm
                        
                        	Specify the encryption algorithm
                        	**type**\:   :py:class:`Ospfv3EncryptionAlgorithmEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3EncryptionAlgorithmEnum>`
                        
                        .. attribute:: encryption_password
                        
                        	Encryption password
                        	**type**\:  str
                        
                        	**pattern:** (!.+)\|([^!].+)
                        
                        .. attribute:: spi
                        
                        	Use IPSec ESP authentication. Specify the Security Parameter Index (SPI) value
                        	**type**\:  int
                        
                        	**range:** 256..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.authentication_algorithm = None
                            self.authentication_password = None
                            self.enable = None
                            self.encryption_algorithm = None
                            self.encryption_password = None
                            self.spi = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:encryption'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.authentication_algorithm is not None:
                                return True

                            if self.authentication_password is not None:
                                return True

                            if self.enable is not None:
                                return True

                            if self.encryption_algorithm is not None:
                                return True

                            if self.encryption_password is not None:
                                return True

                            if self.spi is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Encryption']['meta_info']


                    class AutoCost(object):
                        """
                        Calculate interface cost according to bandwidth
                        
                        .. attribute:: disable
                        
                        	Specify 'true' to assign cost based on interface type
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: reference_bandwidth
                        
                        	Specify reference bandwidth for cost computations in terms of Mbits per second
                        	**type**\:  int
                        
                        	**range:** 1..4294967
                        
                        	**units**\: Mbit/s
                        
                        .. attribute:: _is_presence
                        
                        	Is present if this instance represents presence container else not
                        	**type**\: bool
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ipv6-ospfv3-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self._is_presence = True
                            self.disable = None
                            self.reference_bandwidth = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:auto-cost'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return True

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self._is_presence:
                                return True
                            if self.disable is not None:
                                return True

                            if self.reference_bandwidth is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AutoCost']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.vrf_name is None:
                            raise YPYModelError('Key property vrf_name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:vrf[Cisco-IOS-XR-ipv6-ospfv3-cfg:vrf-name = ' + str(self.vrf_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return True

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.vrf_name is not None:
                            return True

                        if self.area_addresses is not None and self.area_addresses._has_data():
                            return True

                        if self.authentication is not None and self.authentication._has_data():
                            return True

                        if self.auto_cost is not None and self.auto_cost._has_data():
                            return True

                        if self.bfd is not None and self.bfd._has_data():
                            return True

                        if self.capability is not None and self.capability._has_data():
                            return True

                        if self.cost is not None:
                            return True

                        if self.database_filter is not None and self.database_filter._has_data():
                            return True

                        if self.dead_interval is not None:
                            return True

                        if self.default_information is not None and self.default_information._has_data():
                            return True

                        if self.default_metric is not None:
                            return True

                        if self.demand_circuit is not None:
                            return True

                        if self.distance is not None and self.distance._has_data():
                            return True

                        if self.distribute_list is not None and self.distribute_list._has_data():
                            return True

                        if self.distribute_list_out is not None and self.distribute_list_out._has_data():
                            return True

                        if self.domain_id is not None and self.domain_id._has_data():
                            return True

                        if self.enable is not None:
                            return True

                        if self.encryption is not None and self.encryption._has_data():
                            return True

                        if self.fast_reroute is not None and self.fast_reroute._has_data():
                            return True

                        if self.flood_reduction is not None:
                            return True

                        if self.graceful_restart is not None and self.graceful_restart._has_data():
                            return True

                        if self.hello_interval is not None:
                            return True

                        if self.ignore is not None and self.ignore._has_data():
                            return True

                        if self.instance is not None:
                            return True

                        if self.log_adjacency_changes is not None:
                            return True

                        if self.maximum is not None and self.maximum._has_data():
                            return True

                        if self.mtu_ignore is not None:
                            return True

                        if self.network is not None:
                            return True

                        if self.packet_size is not None:
                            return True

                        if self.passive is not None:
                            return True

                        if self.prefix_suppression is not None:
                            return True

                        if self.priority is not None:
                            return True

                        if self.process_scope is not None and self.process_scope._has_data():
                            return True

                        if self.redistributes is not None and self.redistributes._has_data():
                            return True

                        if self.retransmit_interval is not None:
                            return True

                        if self.router_id is not None:
                            return True

                        if self.snmp is not None and self.snmp._has_data():
                            return True

                        if self.snmpvrf_trap is not None:
                            return True

                        if self.spf_prefix_priority_policy is not None:
                            return True

                        if self.stub_router is not None and self.stub_router._has_data():
                            return True

                        if self.summary_prefixes is not None and self.summary_prefixes._has_data():
                            return True

                        if self.timers is not None and self.timers._has_data():
                            return True

                        if self.transmit_delay is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:vrfs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return True

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.vrf is not None:
                        for child_ref in self.vrf:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs']['meta_info']


            class Af(object):
                """
                Address Family (AF)
                
                .. attribute:: af_name
                
                	Address Family (AF) identifier
                	**type**\:   :py:class:`Ospfv3AddressFamilyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3AddressFamilyEnum>`
                
                	**mandatory**\: True
                
                .. attribute:: saf_name
                
                	Subsequent Address Family (SAF) identifier
                	**type**\:   :py:class:`Ospfv3SubsequentAddressFamilyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3SubsequentAddressFamilyEnum>`
                
                .. attribute:: _is_presence
                
                	Is present if this instance represents presence container else not
                	**type**\: bool
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ipv6-ospfv3-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self._is_presence = True
                    self.af_name = None
                    self.saf_name = None

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:af'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return True

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self._is_presence:
                        return True
                    if self.af_name is not None:
                        return True

                    if self.saf_name is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                    return meta._meta_table['Ospfv3.Processes.Process.Af']['meta_info']


            class TraceBufs(object):
                """
                Configuration to change size of trace buffer
                
                .. attribute:: trace_buf
                
                	Changes the size of the specified trace buffer
                	**type**\: list of    :py:class:`TraceBuf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.Ospfv3.Processes.Process.TraceBufs.TraceBuf>`
                
                

                """

                _prefix = 'ipv6-ospfv3-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.trace_buf = YList()
                    self.trace_buf.parent = self
                    self.trace_buf.name = 'trace_buf'


                class TraceBuf(object):
                    """
                    Changes the size of the specified trace
                    buffer
                    
                    .. attribute:: trace_buf_name  <key>
                    
                    	Name for this VRF
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: bufsize
                    
                    	Buffer size
                    	**type**\:   :py:class:`TraceBufSizeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_cfg.TraceBufSizeEnum>`
                    
                    	**mandatory**\: True
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.trace_buf_name = None
                        self.bufsize = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.trace_buf_name is None:
                            raise YPYModelError('Key property trace_buf_name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:trace-buf[Cisco-IOS-XR-ipv6-ospfv3-cfg:trace-buf-name = ' + str(self.trace_buf_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return True

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.trace_buf_name is not None:
                            return True

                        if self.bufsize is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                        return meta._meta_table['Ospfv3.Processes.Process.TraceBufs.TraceBuf']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-cfg:trace-bufs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return True

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.trace_buf is not None:
                        for child_ref in self.trace_buf:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                    return meta._meta_table['Ospfv3.Processes.Process.TraceBufs']['meta_info']

            @property
            def _common_path(self):
                if self.process_name is None:
                    raise YPYModelError('Key property process_name is None')

                return '/Cisco-IOS-XR-ipv6-ospfv3-cfg:ospfv3/Cisco-IOS-XR-ipv6-ospfv3-cfg:processes/Cisco-IOS-XR-ipv6-ospfv3-cfg:process[Cisco-IOS-XR-ipv6-ospfv3-cfg:process-name = ' + str(self.process_name) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return True

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.process_name is not None:
                    return True

                if self.af is not None and self.af._has_data():
                    return True

                if self.default_vrf is not None and self.default_vrf._has_data():
                    return True

                if self.enable is not None:
                    return True

                if self.nsr is not None:
                    return True

                if self.protocol_shutdown is not None:
                    return True

                if self.trace_bufs is not None and self.trace_bufs._has_data():
                    return True

                if self.vrfs is not None and self.vrfs._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
                return meta._meta_table['Ospfv3.Processes.Process']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-ipv6-ospfv3-cfg:ospfv3/Cisco-IOS-XR-ipv6-ospfv3-cfg:processes'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return True

        def _has_data(self):
            if not self.is_config():
                return False
            if self.process is not None:
                for child_ref in self.process:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
            return meta._meta_table['Ospfv3.Processes']['meta_info']

    @property
    def _common_path(self):

        return '/Cisco-IOS-XR-ipv6-ospfv3-cfg:ospfv3'

    def is_config(self):
        ''' Returns True if this instance represents config data else returns False '''
        return True

    def _has_data(self):
        if not self.is_config():
            return False
        if self.dns_name_lookup is not None:
            return True

        if self.processes is not None and self.processes._has_data():
            return True

        return False

    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_cfg as meta
        return meta._meta_table['Ospfv3']['meta_info']


